# -*- coding: utf-8 -*-
from global_defines import *

__doc__ = """Functionality for the technic skill item combinations."""


def move_weapon_history(old_weapon_id, new_weapon_id):
	"""Made a weapon history update when weapon is change id""" 
	for char in system.get_pcs():
		if objects.has_attribute(char, "weapon_id_history"):
			weapon_id_history = objects.get_attribute(char, "weapon_id_history")
		else:
			weapon_id_history={}

		if old_weapon_id in weapon_id_history:
			kill_count=weapon_id_history[old_weapon_id]
			del weapon_id_history[old_weapon_id]
		else:
			#kill_count = [0] * len(kill_type_list) #[160423][half-integer]
			continue								#[160423][half-integer]

		weapon_id_history[new_weapon_id] = kill_count
		objects.set_attribute(char, "weapon_id_history", weapon_id_history) 

import sys
sys.modules["objects"].move_weapon_history = move_weapon_history

def copy_item_attributes(source_item, target_item):
	"""Copies attributes from source_item to target_item.

Parameters:
        source_item - Id of item, which attributes will be copied.
        target_item - Id of item that gets all attributes and values of source_item.
"""
	attributes=objects.get_attributes(object=source_item)
	source_item_type=objects.get_attribute(object=source_item, attribute="typeid")
	type_attributes=objects.get_attributes(object=source_item_type)
	not_copy_list=["id","type","3d_id","typeid","grid","x","y","z"]
	# copy attributes
	for act_attribute in attributes:
		if (act_attribute not in not_copy_list and
		   act_attribute not in type_attributes):
			   # print "copy attribute: "+act_attribute
			   objects.set_attribute(object=target_item,
				attribute=act_attribute,
				value=objects.get_attribute(object=source_item, attribute=act_attribute))

def disassemble_weapon_silencer_laserpointer(character_id, item):
	"""Removes silencer and/or laser pointer from a weapon.

Parameters:
        character_id - Id of the owner of the weapon(item).
        item         - Id of the item.
"""
	#todo: auseinandergebaute waffe wieder equipen
	if objects.has_attribute(item, "item_combination"):
		if character.is_equiped(character_id, item):
			character.un_equip_direct(character_id, item)

		combination = objects.get_attribute(item, "item_combination")
		all_combinations = combination["combination_list"]
		
		combi = []
		max_len = 0
		for act_combination in all_combinations:
			if len(act_combination) > max_len:
				combi = act_combination[:]
		if combi!=None:
			objects.remove_item_from_inventory(character_id, item)
			for act_item in combi:
				new_item = objects.create_item_in_inventory(object=character_id, equipment=act_item)
				if objects.get_attribute(new_item, "typeid")!="SET_LASERPOINTER" \
					and objects.get_attribute(new_item, "typeid")!="SET_DUCT_TAPE" \
					and objects.get_attribute(new_item, "typeid")!="SET_SILENCER":
					copy_item_attributes(item, new_item)		
					move_weapon_history(item, new_item)
		return True
	return False

def assemble_weapon_silencer_laserpointer(character_id, items, item):
	"""Adds silencer or laser pointer to the weapon.

Parameters:
        character_id - Id of the char.
        items        - List of id of items to combine.
        item         - The item_type of new item.
"""
	# remove all non weapons of the combination
	weapon=[]
	for act_item in items:
		remove=True
		if objects.has_attribute(object=act_item, attribute="item_type"):
			if objects.get_attribute(object=act_item, attribute="item_type")=="weapon":
				weapon.append(act_item)
				remove=False 
		if remove: 
			objects.remove_item_from_inventory(character_id, act_item)

	assert len(weapon)==1
	source_item=weapon[0]

	# unequip weapon if equiped
	was_equiped = False
	if character.is_equiped(character_id, source_item):
		character.un_equip_direct(character_id, source_item)
		was_equiped = True

	#remove old weapon
	objects.remove_item_from_inventory(character_id, source_item)

	#create new item
	target_item=source_item+"_COMBINED"
	objects.create_item_in_inventory(object=character_id, equipment=item, id=target_item)

	#copy item attributes
	copy_item_attributes(source_item, target_item)
	move_weapon_history(source_item, target_item)

	# equip again if wepaon was equiped
	if was_equiped:
		character.equip_direct(character_id, target_item)

	return True

def assemble_weapon_sawed_off(character_id, items, item):
	"""Creates a sawed-off variant of the weapon.

Parameters:
        character_id - Id of owner of items.
        items        - List of id of items to combine.
        item         - The item_type of new item.
"""
	old_item=""
	for act_item in items:
		if objects.get_attribute(act_item, "typeid")!="SET_HACKSAW":
			old_item = act_item
	
	#copy_item_attributes
	#create new item
	if len(old_item)!=0:
		new_item = objects.create_item_in_inventory(object=character_id, equipment=item)
		copy_item_attributes(old_item, new_item)
		objects.remove_item_from_inventory(character_id, old_item)
	
	return True

def assemble_dumdum_munition(character_id, items, item):
	"""Transforms the ammo to dumdum ammo.

Parameters:
        character_id - Id of owner of items.
        items        - List of id of items to combine.
        item         - The item_type of new item.
"""
	if not has_talent(character_id, "technic", "manipulate_munition"): return False
	ammo = 0
	for act_item in items:
		if objects.get_attribute(act_item, "typeid")!="SET_RASP":
			if objects.has_attribute(act_item,"act_ammo_count"):
				ammo = objects.get_attribute(act_item,"act_ammo_count")
			objects.remove_item_from_inventory(character_id, act_item)
	
	#copy_item_attributes
	#create new item
	new_item = objects.create_item_in_inventory(object=character_id, equipment=item)
	if objects.has_attribute(new_item,"act_ammo_count"):
		objects.set_attribute(new_item,"act_ammo_count",ammo)
	return True

	
def assemble_parlor_game(character_id, items, item):
	"""Assembles a parlor game.

Parameters:
        character_id - Id of owner of items.
        items        - List of id of items to combine.
        item         - The item_type of new item.
"""
	for act_item in items:
		if (objects.get_attribute(act_item, "typeid")!="SET_GIANT_KNIFE" and
			objects.get_attribute(act_item, "typeid")!="SET_KNIFE"):
			objects.remove_item_from_inventory(character_id, act_item)
	
	#copy_item_attributes
	#create new item
	objects.create_item_in_inventory(object=character_id, equipment=item)
	return True

def assemble_vamped_picklock_set(character_id, items, item):
	"""Creates an improved picklock set.

Parameters:
        character_id - Id of owner of items.
        items        - List of id of items to combine.
        item         - The item_type of new item.
"""
	for act_item in items:
		if objects.get_attribute(act_item, "typeid")!="SET_PLIERS":
			objects.remove_item_from_inventory(character_id, act_item)
	
	#copy_item_attributes
	#create new item
	objects.create_item_in_inventory(object=character_id, equipment=item)
	return True

def assemble_chain_mail(character_id, items, item):
	"""Creates chain mail.

Parameters:
        character_id - Id of owner of items.
        items        - List of id of items to combine.
        item         - The item_type of new item.
"""
	for act_item in items:
		if (objects.get_attribute(act_item, "typeid")!="SET_CRANK" and
			objects.get_attribute(act_item, "typeid")!="SET_PLIERS"):
			objects.remove_item_from_inventory(character_id, act_item)
	
	#copy_item_attributes
	#create new item
	objects.create_item_in_inventory(object=character_id, equipment=item)
	return True

def assemble_plate_armor(character_id, items, item):
	"""Creates plate armor.

Parameters:
        character_id - Id of owner of items.
        items        - List of id of items to combine.
        item         - The item_type of new item.
"""
	for act_item in items:
		if (objects.get_attribute(act_item, "typeid")!="SET_SLEDGE_HAMMER"):
			objects.remove_item_from_inventory(character_id, act_item)
	
	#copy_item_attributes
	#create new item
	objects.create_item_in_inventory(object=character_id, equipment=item)
	return True

def assemble_alternative_medicine(character_id, items, item):
	"""Creates alternative medicine.

Parameters:
        character_id - Id of owner of items.
        items        - List of id of items to combine.
        item         - The item_type of new item.
"""
	if has_talent( character_id, "medicine", "alternative_medicine" ):
		for act_item in items:
			# items with charge aren't useable when empty
			# this is mostly for SET_WATER_SKIN
			if objects.has_attribute(act_item, "charge"):
				if objects.get_attribute(act_item, "charge") < 1:
					return False
		
		for act_item in items:
			objects.remove_item_from_inventory(character_id, act_item)
		objects.create_item_in_inventory(object=character_id, equipment=item)
		give_first_use_exp(character_id, "medicine", "alternative_medicine")
		return True
	return False

def assemble_explosives(character_id, items, item):
	"""Creates explosives.

Parameters:
        character_id - Id of owner of items.
        items        - List of id of items to combine.
        item         - The item_type of new item.
"""
	if has_talent(character_id, "explosives", "build_explosives"):
		for act_item in items:
			# items with charge aren't useable when empty
			# this is mostly for SET_WATER_SKIN
			if objects.has_attribute(act_item, "charge"):
				if objects.get_attribute(act_item, "charge") < 1:
					return False
		
		for act_item in items:
			objects.remove_item_from_inventory(character_id, act_item)
		objects.create_item_in_inventory(object=character_id, equipment=item)
		return True
	return False

# Derff's underguns and backpacks.

UNDERGUNS_TYPES = ["SET_SAWED_OFF_BROWNING_B_SS_DOUBLE_BARREL","SET_SAWED_OFF_REMINGTON_M870","SET_M_203","SET_BG_15","SET_KNIFE"]

def disassemble_over_and_under_gun(character_id, item):
	if objects.has_attribute(item, "item_combination"):
		was_equiped = False
		if character.is_equiped(character_id, item):
			character.un_equip_direct(character_id, item)
			was_equiped = True
		ammo_type = objects.get_att(item,"act_ammo_type")
		ammo_count = objects.get_att(item,"act_ammo_count")
		sec_ammo_type = objects.get_att(item,"saved_act_ammo_type")
		sec_ammo_count = objects.get_att(item,"saved_act_ammo_count")
		print sec_ammo_type, sec_ammo_count
			
		combination = objects.get_attribute(item, "item_combination")
		all_combinations = combination["combination_list"]
		objects.remove_item_from_inventory(character_id, item)
		combi = []
		max_len = 0
		for act_combination in all_combinations:
			if len(act_combination) > max_len:
				combi = act_combination[:]
		if combi!=None:
			for act_item in combi:
				weapon_id = objects.create_item_in_inventory(object=character_id, equipment=act_item)
				if objects.get_att(weapon_id, "item_type") == "weapon" \
					and not act_item in UNDERGUNS_TYPES: #To made a main weapon history correct
						copy_item_attributes(item, weapon_id)			#[160527][half-integer]
						#objects.move_weapon_history(weapon_id, item)	#[160430][half-integer]
						objects.move_weapon_history(item, weapon_id)	#[160430][half-integer]
						if was_equiped and objects.count_in_inventory(character_id, weapon_id): #Weapon could be dropped
							character.equip_direct(character_id, weapon_id)
				if objects.has_attribute(act_item,"munitionsarten") and ammo_type != None \
					and ammo_type in objects.get_attribute(act_item,"munitionsarten"): #This weapon should be loaded
					objects.set_attribute(weapon_id,"act_ammo_type",ammo_type)
					objects.set_attribute(weapon_id,"act_ammo_count",ammo_count)
				if objects.has_attribute(act_item,"munitionsarten") and sec_ammo_type != None \
					and sec_ammo_type in objects.get_attribute(act_item,"munitionsarten"): #This weapon should be loaded
					objects.set_attribute(weapon_id,"act_ammo_type",sec_ammo_type)
					objects.set_attribute(weapon_id,"act_ammo_count",sec_ammo_count)
		return True
	return False

def assemble_over_and_under_gun(character_id, items, item):
	was_equiped = False
	for act_item in items:
		if objects.get_attribute(act_item, "typeid") in UNDERGUNS_TYPES:
			secondary_item=act_item
			sec_ammo_type = objects.get_att(act_item, "act_ammo_type")
			sec_ammo_count = objects.get_att(act_item, "act_ammo_count")							
		elif objects.has_attribute(object=act_item, attribute="item_type"):
			if objects.get_attribute(object=act_item, attribute="item_type")=="weapon":	
				primary_item=act_item
				ammo_type = objects.get_att(act_item, "act_ammo_type")
				ammo_count = objects.get_att(act_item, "act_ammo_count")				
				if character.is_equiped(character_id, primary_item):
					was_equiped = True
		objects.remove_item_from_inventory(character_id, act_item)
			
	#create new item
	target_item=primary_item+"_COMBINED"
	objects.create_item_in_inventory(object=character_id, equipment=item, id=target_item)
	copy_item_attributes(primary_item, target_item)			#[160527][half-integer]
	#objects.move_weapon_history(target_item, primary_item)	#[160430][half-integer]
	objects.move_weapon_history(primary_item, target_item)	#[160430][half-integer]
	#loading gun
	if ammo_type != None:
		objects.set_attribute(target_item,"act_ammo_type",ammo_type)
	if ammo_count != None:	
		objects.set_attribute(target_item,"act_ammo_count",ammo_count)
	if sec_ammo_type != None:
		objects.set_attribute(target_item,"saved_act_ammo_type",sec_ammo_type)
	if sec_ammo_count != None:	
		objects.set_attribute(target_item,"saved_act_ammo_count",sec_ammo_count)

	if was_equiped:
		character.equip_direct(character_id, target_item)
	return True

	
def assemble_backpack(character_id, items, item):
	import helpfile
	helper = helpfile.create_helper()
	new_id = objects.create_item_in_inventory(object=helper, equipment=item)
	was_equiped = False
	for act_item in items:
		if objects.has_attribute(act_item,"container"):
			objects.backpack_check(act_item)
			if character.is_equiped(character_id, act_item):
				was_equiped = True
			for id in objects.get_inventory_id_list(act_item):
				objects.transfer_item(act_item, id, new_id)
		objects.remove_item_from_inventory(character_id,act_item)
	objects.transfer_item(helper,new_id,character_id)
	data().backpack_was_equiped = was_equiped
	objects.update_backpack(character_id,new_id)
	return True

def chop_meat(character_id, items, item):
	for act_item in items:
		if objects.has_attribute(act_item,"le_recovery"):
			old_meat = act_item
		else:
			knife = act_item

	if old_meat.count("COOKED"):
		small_meat = 'SET_MEAT_COOKED_TINY'
	else:
		small_meat = 'SET_MEAT_RAW_TINY'

	old_le = objects.get_attribute(old_meat, "le_recovery")
	small_le = objects.get_attribute(small_meat, "le_recovery")
	new_le = objects.get_attribute(item, "le_recovery")
	was_equiped = character.is_equiped(character_id, knife)
	number_of_big = old_le / new_le
	number_of_small = ( old_le - number_of_big * new_le ) / small_le

	objects.remove_item_from_inventory( character_id, old_meat )
	for i in range( number_of_big ):
		objects.create_item_in_inventory( character_id, item )
	for i in range( number_of_small ):
		objects.create_item_in_inventory( character_id, small_meat )
		
	if was_equiped:
		character.equip_direct( character_id, knife )
		
	return True
	
def assemble_with_knife(character_id, items, item):
	for act_item in items:
		if not objects.get_att ( act_item, 'typeid' ) == 'SET_KNIFE':
			objects.remove_item_from_inventory ( character_id, act_item )
	objects.create_item_in_inventory( character_id, item )
	return True

def clean_alcohol_with_coal(character_id, items, item):
	for act_item in items:
		if objects.get_att ( act_item, 'typeid' ) == 'SET_BOTTLE_OF_WHISKEY':
			objects.remove_item_from_inventory ( character_id, act_item )
			objects.create_item_in_inventory( character_id, 'SET_EMPTY_BOTTLE' )
		elif objects.get_att ( act_item, 'typeid' ) == 'SET_TIN_OF_ALCOHOL' :
			objects.remove_item_from_inventory ( character_id, act_item )
			objects.create_item_in_inventory( character_id, 'SET_TIN_CAN' )
		elif objects.get_att ( act_item, 'typeid' ) == 'SET_WHISKEY_BARREL':
			if objects.has_attribute ( act_item, "charge" ) and objects.get_attribute ( act_item, "charge" ) > 0:
				objects.set_attribute ( act_item, "charge", objects.get_attribute ( act_item, "charge" ) - 1 )
			elif objects.has_attribute ( act_item, "charge" ):
				objects.remove_item_from_inventory ( character_id, act_item )
				objects.create_item_in_inventory( character_id, 'SET_EMPTY_BARREL' )
			else: objects.set_attribute ( act_item, "charge", 4 )
		elif objects.get_att ( act_item, 'typeid' ) != 'SET_WATERING_CAN':
			objects.remove_item_from_inventory ( character_id, act_item )
	objects.create_item_in_inventory( character_id, item )
	return True

# Derff's finish


