# -*- coding: utf-8 -*-
from global_defines import *
import globaltext
import bonus

__doc__= """This module contains data access functions for skills, talents, and attributes.

The effects of skill & attribute values are determined here."""


attributes = 	["strength", "agility", "dexterity", "constitution", "intelligence", "charisma"]
skills = 		["light_weapons", "heavy_weapons", "sniper_weapons", "speech", "throw_weapons",
				"explosives", "survival", "technic", "medicine", "sneak", "driving", "pick_pocket",
				"lock_pick", "close_combat"]

####################################################################################################
# attributes
####################################################################################################

def strength_max_load(strength):
	"""Returns max load (i.e., max. added weight of all inventory items) in kg.

Chars can carry more than max load, but they get penalties.

Parameters:
        strength - Strength value.
"""
	assert strength >= 1
	return strength * 3

def strength_move_speed(rel_load):
	"""Returns the movement speed factor.

This presents the movement penalty when the char carries more than his strength
allows.

Parameters:
        rel_load - Overload factor.
"""
	if rel_load<=1:
		return 1.0
	else:
		if rel_load<=1.1:
			return 0.95
		elif rel_load<=1.2:
			return 0.85
		elif rel_load<=1.3:
			return 0.7
		else:
			return 0.55

def strength_heavy_weapons_hitchance(strength):
	"""Returns the hit chance modification for heavy weapons.

Hit chance for heavy weapons depends on strength.

Parameters:
        strength - Strength value.
"""
	assert strength >= 1
	if strength <= 3: return 0.4
	if strength <= 6: return 0.6
	if strength <= 8: return 0.8
	if strength <= 12: return 1.0
	if strength <= 15: return 1.1
	if strength <= 18: return 1.15
	if strength <= 19: return 1.2
	if strength <= 20: return 1.25
	if strength <= 21: return 1.27
	if strength <= 22: return 1.29
	if strength <= 23: return 1.30
	if strength <= 24: return 1.31
	if strength <= 25: return 1.32
	return 1.32

def strength_heavy_weapons_speed(strength):
	"""Returns speed factor for heavy weapons.

Speed (i.e. reload speed) for heavy weapons depends on strength.

Parameters:
        strength - Strength value.
"""
	assert strength >= 1
	if strength <= 3: return 1.3
	if strength <= 6: return 1.2
	if strength <= 8: return 1.1
	if strength <= 12: return 1.0
	if strength <= 15: return 0.9
	if strength <= 18: return 0.85
	if strength <= 19: return 0.8
	if strength <= 20: return 0.75
	if strength <= 21: return 0.73
	if strength <= 22: return 0.71
	if strength <= 23: return 0.70
	if strength <= 24: return 0.69
	if strength <= 25: return 0.68
	return 0.68

def strength_close_combat_damage(strength):
	"""Returns damage factor for close combat.

Damage dealt in melee depends on strength.

Parameters:
        strength - Strength value.
"""
	assert strength >= 1
	if strength <= 3: return 0.4
	if strength <= 6: return 0.6
	if strength <= 8: return 0.8
	if strength <= 12: return 1.0
	if strength <= 15: return 1.1
	if strength <= 18: return 1.15
	if strength <= 19: return 1.2
	if strength <= 20: return 1.25
	if strength <= 21: return 1.27
	if strength <= 22: return 1.29
	if strength <= 23: return 1.30
	if strength <= 24: return 1.31
	if strength <= 25: return 1.32
	return 1.32

def agility_move_speed(agility):
	"""Returns speed factor.

Movement speed depends on agility.

Parameters:
        agility - Agility value.
"""
	assert agility >= 1
	if agility <= 3: return 0.7
	if agility <= 6: return 0.8
	if agility <= 8: return 0.9
	if agility <= 12: return 1.0
	if agility <= 15: return 1.1
	if agility <= 18: return 1.2
	if agility <= 19: return 1.3
	if agility <= 20: return 1.4
	if agility <= 21: return 1.45
	if agility <= 22: return 1.48
	if agility <= 23: return 1.50
	if agility <= 24: return 1.51
	if agility <= 25: return 1.52
	return 1.52

def agility_armor(agility):
	"""Returns the armor bonus.

Agility gives an armor bonus or penalty.

Parameters:
        agility - Agility value.
"""
	assert agility >= 1
	if agility <= 3: return -6
	if agility <= 6: return -4
	if agility <= 8: return -2
	if agility <= 12: return 0
	if agility <= 15: return +2
	if agility <= 18: return +4
	if agility <= 19: return +6
	if agility <= 20: return +8
	if agility <= 21: return +9
	if agility <= 22: return +10
	if agility <= 23: return +11
	if agility <= 24: return +12
	if agility <= 25: return +13
	return +13

def agility_move_silently_factor(agility):
	"""Returns speed factor.

Movement speed while moving silently depends on agility.

Parameters:
        agility - Agility value.
"""
	assert agility >= 1
	if agility <= 3: return 1.3
	if agility <= 6: return 1.2
	if agility <= 8: return 1.1
	if agility <= 12: return 1.0
	if agility <= 15: return 0.95
	if agility <= 18: return 0.90
	if agility <= 19: return 0.85
	if agility <= 20: return 0.80
	if agility <= 21: return 0.78
	if agility <= 22: return 0.76
	if agility <= 23: return 0.75
	if agility <= 24: return 0.74
	if agility <= 25: return 0.73
	return 0.73

def dexterity_weapons_hitchance(dexterity):
	"""Returns hit chance factor.

Weapon hit chance depends on dexterity (except heavy weapons depend on strength).

Parameters:
        dexterity - Dexterity value.
"""
	assert dexterity >= 1
	if dexterity <= 3: return 0.7
	if dexterity <= 6: return 0.8
	if dexterity <= 8: return 0.9
	if dexterity <= 12: return 1.0
	if dexterity <= 15: return 1.1
	if dexterity <= 18: return 1.15
	if dexterity <= 19: return 1.2
	if dexterity <= 20: return 1.25
	if dexterity <= 21: return 1.27
	if dexterity <= 22: return 1.29
	if dexterity <= 23: return 1.30
	if dexterity <= 24: return 1.31
	if dexterity <= 25: return 1.32
	return 1.32

def dexterity_pick_pocket(dexterity):
	"""Returns pick pocket success chance factor.

Pick pocket success chance depends on dexterity.

Parameters:
        dexterity - Dexterity value.
"""
	assert dexterity >= 1
	if dexterity <= 3: return 0.7
	if dexterity <= 6: return 0.8
	if dexterity <= 8: return 0.9
	if dexterity <= 12: return 1.0
	if dexterity <= 15: return 1.1
	if dexterity <= 18: return 1.15
	if dexterity <= 19: return 1.2
	if dexterity <= 20: return 1.25
	if dexterity <= 21: return 1.27
	if dexterity <= 22: return 1.29
	if dexterity <= 23: return 1.30
	if dexterity <= 24: return 1.31
	if dexterity <= 25: return 1.32
	return 1.32

def dexterity_lock_picking(dexterity):
	"""Returns lock picking success chance factor.

Lock picking success chance depends on dexterity.

Parameters:
        dexterity - Dexterity value.
"""
	assert dexterity >= 1
	if dexterity <= 3: return 0.7
	if dexterity <= 6: return 0.8
	if dexterity <= 8: return 0.9
	if dexterity <= 12: return 1.0
	if dexterity <= 15: return 1.1
	if dexterity <= 18: return 1.15
	if dexterity <= 19: return 1.2
	if dexterity <= 20: return 1.25
	if dexterity <= 21: return 1.27
	if dexterity <= 22: return 1.29
	if dexterity <= 23: return 1.30
	if dexterity <= 24: return 1.31
	if dexterity <= 25: return 1.32
	return 1.32

def constitution_life_energy_start(constitution):
	"""Returns health points at game start.

How much HP a char starts with depends on constitution.

Parameters:
        constitution - Constitution value.
"""
	assert constitution >= 1
	if constitution <= 3: return 5
	if constitution <= 6: return 10
	if constitution <= 8: return 15
	if constitution <= 12: return 20
	if constitution <= 15: return 25
	if constitution <= 18: return 30
	if constitution <= 19: return 35
	if constitution <= 20: return 40
	if constitution <= 21: return 42
	if constitution <= 22: return 44
	if constitution <= 23: return 45
	if constitution <= 24: return 46
	if constitution <= 25: return 47
	return 47

def constitution_life_energy_level(constitution):
	"""Returns health points at level up.

How many HP a char gets on level up depends on constitution.
Each char gets 4-8 HP per level. This is modified by this bonus
(char can loose HP on level up!!! -2 HP if const is <= 3 and player is unlucky).

Parameters:
        constitution - Constitution value.
"""
	assert constitution >= 1
	if constitution <= 3: return -6
	if constitution <= 6: return -4
	if constitution <= 8: return -2
	if constitution <= 12: return 0
	if constitution <= 15: return 2
	if constitution <= 18: return 4
	if constitution <= 19: return 6
	if constitution <= 20: return 8
	if constitution <= 21: return 9
	if constitution <= 22: return 10
	if constitution <= 23: return 11
	if constitution <= 24: return 12
	if constitution <= 25: return 13
	return 13

def intelligence_skill_points(intelligence):
	"""Returns skill point modifier on level up or character creation.

How much skill points a char gets at level up or character creation depends on 
intelligence.
The char can distribute 10, plus these modifier points, on level up.

Parameters:
        intelligence - Intelligence value.
"""
	assert intelligence >= 1
	if intelligence <= 3: return -6
	if intelligence <= 6: return -4
	if intelligence <= 8: return -2
	if intelligence <= 12: return 0
	if intelligence <= 15: return 1
	if intelligence <= 18: return 2
	if intelligence <= 19: return 3
	if intelligence <= 20: return 4
	if intelligence <= 21: return 5
	if intelligence <= 22: return 6
	if intelligence <= 23: return 7
	if intelligence <= 24: return 8
	if intelligence <= 25: return 9
	return 9

def charisma_talk_bonus_factor(charisma):
	"""Returns talk bonus factor.

A char gets a bonus in his NPC communication depending on his charisma.

Parameters:
        charisma - Charisma value.
"""
	assert charisma >= 1
	if charisma <= 3: return 0.7
	if charisma <= 6: return 0.8
	if charisma <= 8: return 0.9
	if charisma <= 12: return 1.0
	if charisma <= 15: return 1.1
	if charisma <= 18: return 1.15
	if charisma <= 19: return 1.2
	if charisma <= 20: return 1.25
	if charisma <= 21: return 1.27
	if charisma <= 22: return 1.29
	if charisma <= 23: return 1.30
	if charisma <= 24: return 1.31
	if charisma <= 25: return 1.32
	return 1.32

def charisma_npc_bad_mood_time_factor(charisma):
	"""Returns the bad mood factor.

When the player has done something bad (pick pocket, killing peaceful NPCs, etc.),
the NPCs will not talk to him. This factor influences how long this bad mood lasts.

Parameters:
        charisma - Charisma value.
"""
	assert charisma >= 1
	if charisma <= 3: return 1.3
	if charisma <= 6: return 1.2
	if charisma <= 8: return 1.1
	if charisma <= 12: return 1.0
	if charisma <= 15: return 0.9
	if charisma <= 18: return 0.8
	if charisma <= 19: return 0.7
	if charisma <= 20: return 0.6
	if charisma <= 21: return 0.58
	if charisma <= 22: return 0.56
	if charisma <= 23: return 0.55
	if charisma <= 24: return 0.54
	if charisma <= 25: return 0.53
	return 0.53

####################################################################################################
# skills
####################################################################################################

def lock_pick_crack_lock_chance(lock_pick):
	"""Returns crack lock chance depending on lock pick skill.

Parameters:
        lock_pick - lock pick skill.
"""
	assert lock_pick >= 1
	if lock_pick <= 14: return 0.0
	if lock_pick <= 39: return 0.0
	if lock_pick <= 54: return 0.0
	if lock_pick <= 69: return 0.2
	if lock_pick <= 84: return 0.4
	if lock_pick <= 94: return 0.6
	if lock_pick <= 104: return 0.8
	if lock_pick <= 114: return 0.85
	if lock_pick <= 124: return 0.9
	if lock_pick <= 134: return 0.93
	if lock_pick <= 149: return 0.95
	return 0.96

def lock_pick_destroy_lock_chance(lock_pick):
	"""Returns destroy lock chance depending on lock pick skill.

Parameters:
        lock_pick - lock pick skill.
"""
	assert lock_pick >= 1
	if lock_pick <= 14: return 0.75
	if lock_pick <= 39: return 0.5
	if lock_pick <= 54: return 0.0
	if lock_pick <= 69: return 0.0
	if lock_pick <= 84: return 0.0
	if lock_pick <= 94: return 0.0
	if lock_pick <= 99: return 0.0
	return 0.0

def lock_pick_destroy_picklock_chance(lock_pick):
	"""Returns destroy picklock chance depending on lock pick skill.

Parameters:
        lock_pick - lock pick skill.
"""
	assert lock_pick >= 1
	if lock_pick <= 14: return 0.5
	if lock_pick <= 39: return 0.4
	if lock_pick <= 54: return 0.3
	if lock_pick <= 69: return 0.1
	if lock_pick <= 84: return 0.07
	if lock_pick <= 94: return 0.05
	if lock_pick <= 104: return 0.04
	if lock_pick <= 114: return 0.03
	if lock_pick <= 124: return 0.02
	if lock_pick <= 134: return 0.01
	return 0.00

def close_combat_weapons_hit_chance(close_combat):
	"""Returns hit chance factor depending on close combat skill.

Parameters:
        close_combat - Close_combat value.
"""
	assert close_combat >= 1
	if close_combat <= 10: return 0.4
	if close_combat <= 29: return 0.6
	if close_combat <= 44: return 0.8
	if close_combat <= 54: return 1.0
	if close_combat <= 69: return 1.2
	if close_combat <= 84: return 1.4
	if close_combat <= 94: return 1.6
	if close_combat <= 104: return 1.8
	if close_combat <= 114: return 2.0
	if close_combat <= 124: return 2.1
	if close_combat <= 134: return 2.15
	if close_combat <= 149: return 2.2
	return 2.25

def close_combat_weapons_damage(close_combat):
	"""Returns damage factor depending on close combat skill.

Parameters:
        close_combat - Close_combat value.
"""
	assert close_combat >= 1
	if close_combat <= 10: return 0.4
	if close_combat <= 29: return 0.6
	if close_combat <= 44: return 0.8
	if close_combat <= 54: return 1.0
	if close_combat <= 69: return 1.2
	if close_combat <= 84: return 1.4
	if close_combat <= 94: return 1.6
	if close_combat <= 104: return 1.8
	if close_combat <= 114: return 2.0
	if close_combat <= 124: return 2.1
	if close_combat <= 134: return 2.15
	if close_combat <= 149: return 2.2
	return 2.25

def light_weapons_hit_chance(light_weapons):
	"""Returns hit chance factor depending on light weapons skill.

Parameters:
        light_weapons - Light_weapons value.
"""
	assert light_weapons >= 1
	if light_weapons <= 10: return 0.4
	if light_weapons <= 29: return 0.6
	if light_weapons <= 44: return 0.8
	if light_weapons <= 54: return 1.0
	if light_weapons <= 69: return 1.2
	if light_weapons <= 84: return 1.4
	if light_weapons <= 94: return 1.6
	if light_weapons <= 104: return 1.8
	if light_weapons <= 114: return 2.0
	if light_weapons <= 124: return 2.1
	if light_weapons <= 134: return 2.15
	if light_weapons <= 149: return 2.2
	return 2.25

def light_weapons_speed(light_weapons):
	"""Returns weapon speed factor depending on light weapons skill.

Parameters:
        light_weapons - Light_weapons value.
"""
	assert light_weapons >= 1
	if light_weapons <= 10: return 1.6
	if light_weapons <= 29: return 1.4
	if light_weapons <= 44: return 1.2
	if light_weapons <= 54: return 1.0
	if light_weapons <= 69: return 0.8
	if light_weapons <= 84: return 0.6
	if light_weapons <= 94: return 0.4
	if light_weapons <= 104: return 0.2
	if light_weapons <= 114: return 0.0
	if light_weapons <= 124: return -0.1
	if light_weapons <= 134: return -0.15
	if light_weapons <= 149: return -0.2
	return -0.25

def heavy_weapons_hit_chance(heavy_weapons):
	"""Returns hit chance factor depending on heavy weapons skill.

Parameters:
        heavy_weapons - Heavy_weapons value.
"""
	assert heavy_weapons >= 1
	if heavy_weapons <= 10: return 0.4
	if heavy_weapons <= 29: return 0.6
	if heavy_weapons <= 44: return 0.8
	if heavy_weapons <= 54: return 1.0
	if heavy_weapons <= 69: return 1.2
	if heavy_weapons <= 84: return 1.4
	if heavy_weapons <= 94: return 1.6
	if heavy_weapons <= 104: return 1.8
	if heavy_weapons <= 114: return 2.0
	if heavy_weapons <= 124: return 2.1
	if heavy_weapons <= 134: return 2.15
	if heavy_weapons <= 149: return 2.2
	return 2.25

def heavy_weapons_speed(heavy_weapons):
	"""Returns weapon speed factor depending on heavy weapons skill.

Parameters:
        heavy_weapons - Heavy_weapons value.
"""
	assert heavy_weapons >= 1
	if heavy_weapons <= 10: return 1.6
	if heavy_weapons <= 29: return 1.4
	if heavy_weapons <= 44: return 1.2
	if heavy_weapons <= 54: return 1.0
	if heavy_weapons <= 69: return 0.8
	if heavy_weapons <= 84: return 0.6
	if heavy_weapons <= 94: return 0.4
	if heavy_weapons <= 104: return 0.2
	if heavy_weapons <= 114: return 0.0
	if heavy_weapons <= 124: return -0.1
	if heavy_weapons <= 134: return -0.15
	if heavy_weapons <= 149: return -0.2
	return -0.25

def sniper_weapons_hit_chance(sniper_weapons):
	"""Returns hit chance factor depending on sniper skill.

Parameters:
        sniper_weapons - Sniper_weapons value.
"""
	assert sniper_weapons >= 1
	if sniper_weapons <= 10: return 0.4
	if sniper_weapons <= 29: return 0.6
	if sniper_weapons <= 44: return 0.8
	if sniper_weapons <= 54: return 1.0
	if sniper_weapons <= 69: return 1.2
	if sniper_weapons <= 84: return 1.4
	if sniper_weapons <= 94: return 1.6
	if sniper_weapons <= 104: return 1.8
	if sniper_weapons <= 114: return 2.0
	if sniper_weapons <= 124: return 2.1
	if sniper_weapons <= 134: return 2.15
	if sniper_weapons <= 149: return 2.2
	return 2.25

def sniper_weapons_speed(sniper_weapons):
	"""Returns weapon speed factor depending on sniper skill.

Parameters:
        sniper_weapons - Sniper_weapons value.
"""
	assert sniper_weapons >= 1
	if sniper_weapons <= 10: return 1.6
	if sniper_weapons <= 29: return 1.4
	if sniper_weapons <= 44: return 1.2
	if sniper_weapons <= 54: return 1.0
	if sniper_weapons <= 69: return 0.8
	if sniper_weapons <= 84: return 0.6
	if sniper_weapons <= 94: return 0.4
	if sniper_weapons <= 104: return 0.2
	if sniper_weapons <= 114: return 0.0
	if sniper_weapons <= 124: return -0.1
	if sniper_weapons <= 134: return -0.15
	if sniper_weapons <= 149: return -0.2
	return -0.25

def throw_weapons_hit_chance(throw_weapons):
	"""Returns hit chance factor depending on throw skill.

Parameters:
        throw_weapons - Throw_weapons value.
"""
	assert throw_weapons >= 1
	if throw_weapons <= 10: return 0.4
	if throw_weapons <= 29: return 0.6
	if throw_weapons <= 44: return 0.8
	if throw_weapons <= 54: return 1.0
	if throw_weapons <= 69: return 1.2
	if throw_weapons <= 84: return 1.4
	if throw_weapons <= 94: return 1.6
	if throw_weapons <= 104: return 1.8
	if throw_weapons <= 114: return 2.0
	if throw_weapons <= 124: return 2.1
	if throw_weapons <= 134: return 2.15
	if throw_weapons <= 149: return 2.2
	return 2.25

def throw_weapons_speed(throw_weapons):
	"""Returns weapon speed factor depending on throw skill.

Parameters:
        throw_weapons - Throw_weapons value.
"""
	assert throw_weapons >= 1
	if throw_weapons <= 10: return 1.6
	if throw_weapons <= 29: return 1.4
	if throw_weapons <= 44: return 1.2
	if throw_weapons <= 54: return 1.0
	if throw_weapons <= 69: return 0.8
	if throw_weapons <= 84: return 0.6
	if throw_weapons <= 94: return 0.4
	if throw_weapons <= 104: return 0.2
	if throw_weapons <= 114: return 0.0
	if throw_weapons <= 124: return -0.1
	if throw_weapons <= 134: return -0.15
	if throw_weapons <= 149: return -0.2
	return -0.25

def throw_weapons_miss_radius_factor(throw_weapons):
	"""Returns miss radius factor depending on throw skill.

Parameters:
        throw_weapons - Throw_weapons value.
"""
	assert throw_weapons >= 1
	if throw_weapons <= 10: return 0.6
	if throw_weapons <= 29: return 0.5
	if throw_weapons <= 44: return 0.4
	if throw_weapons <= 54: return 0.35
	if throw_weapons <= 69: return 0.3
	if throw_weapons <= 84: return 0.25
	if throw_weapons <= 94: return 0.2
	if throw_weapons <= 104: return 0.15
	if throw_weapons <= 114: return 0.12
	if throw_weapons <= 124: return 0.1
	if throw_weapons <= 134: return 0.09
	if throw_weapons <= 149: return 0.08
	return 0.07

def sneak_detection_factor(sneak):
	"""Returns sneak detection factor depending on sneak skill.

Parameters:
        sneak - Sneak value.
"""
	assert sneak >= 1
	if sneak <= 14: return 8.0
	if sneak <= 39: return 4.0
	if sneak <= 44: return 2.0
	if sneak <= 59: return 1.0
	if sneak <= 64: return 0.7
	if sneak <= 69: return 0.5
	if sneak <= 74: return 0.4
	if sneak <= 79: return 0.3
	if sneak <= 84: return 0.2
	if sneak <= 89: return 0.1
	if sneak <= 94: return 0.06
	if sneak <= 104: return 0.03
	if sneak <= 124: return 0.02
	if sneak <= 149: return 0.01
	return 0.00

def pick_pocket_success_front(pick_pocket):
	"""Returns pick pocket success modifier depending on pick pocket skill.

Basic success chance is 0.1 + this modifier.

Parameters:
        pick_pocket - Pick_pocket value.
"""
	assert pick_pocket >= 1
	if pick_pocket <= 14: return -0.1
	if pick_pocket <= 39: return -0.05
	if pick_pocket <= 54: return 0.0
	if pick_pocket <= 69: return 0.1
	if pick_pocket <= 84: return 0.3
	if pick_pocket <= 94: return 0.5
	if pick_pocket <= 104: return 0.65
	if pick_pocket <= 114: return 0.7
	if pick_pocket <= 124: return 0.73
	if pick_pocket <= 134: return 0.75
	if pick_pocket <= 149: return 0.76
	return 0.77

def pick_pocket_success_back(pick_pocket):
	"""Returns pick pocket success modifier depending on pick pocket skill.

Basic success chance is 0.2 + this modifier.

Parameters:
        pick_pocket - Pick_pocket value.
"""
	assert pick_pocket >= 1
	if pick_pocket <= 14: return -0.2
	if pick_pocket <= 39: return -0.1
	if pick_pocket <= 54: return 0.0
	if pick_pocket <= 69: return 0.2
	if pick_pocket <= 84: return 0.4
	if pick_pocket <= 94: return 0.6
	if pick_pocket <= 104: return 0.75
	if pick_pocket <= 114: return 0.78
	if pick_pocket <= 124: return 0.80
	if pick_pocket <= 134: return 0.82
	if pick_pocket <= 149: return 0.83
	return 0.84

def medicine_aloe_vera(medicine):
	"""Returns HP modifier for medicine_aloe_vera depending on alternative_medicine
skill.

HP healed is 8 HP + this modifier.

Parameters:
        medicine - Medicine value.
"""
	assert medicine >= 1
	if medicine <= 14: return -8 # 0
	if medicine <= 39: return -6 # 2
	if medicine <= 54: return -3 # 5
	if medicine <= 69: return  0 # 8
	if medicine <= 84: return +2 # 10
	if medicine <= 94: return +5 # 13
	if medicine <= 104: return +8 # 16
	if medicine <= 114: return +9 # 17
	if medicine <= 124: return +10 # 18
	if medicine <= 134: return +11 # 19
	if medicine <= 149: return +11 # 19
	return +12
	
def medicine_wood_garlic(medicine):
	"""Returns HP modifier for medicine_wood_garlic depending on alternative_medicine
skill.

Parameters:
        medicine - Medicine value.
"""
	assert medicine >= 1
	if medicine <= 14: return -10 # 0
	if medicine <= 39: return - 7 # 3
	if medicine <= 54: return - 3 # 7
	if medicine <= 69: return   0 #10
	if medicine <= 84: return   3 #13
	if medicine <= 94: return   7 #17
	if medicine <= 104: return  10 #20
	if medicine <= 114: return  11 #21
	if medicine <= 124: return  12 #22
	if medicine <= 134: return  13 #23
	if medicine <= 149: return  14 #24
	return +15

def medicine_burnet(medicine):
	"""HP healed is 12 HP + this modifier.

Parameters:
        medicine - Medicine value.
"""
	assert medicine >= 1
	if medicine <= 14: return -12 # 0
	if medicine <= 39: return - 8 # 4
	if medicine <= 54: return - 4 # 8
	if medicine <= 69: return   0 #12
	if medicine <= 84: return + 4 #16
	if medicine <= 94: return + 8 #20
	if medicine <= 104: return +12 #24
	if medicine <= 114: return +14 #26
	if medicine <= 124: return +15 #27
	if medicine <= 134: return +16 #28
	if medicine <= 149: return +17 #29
	return +18
	
def medicine_aloe_vera_ointmant(medicine):
	"""Returns HP modifier for medicine_aloe_vera depending on alternative_medicine
skill.

HP healed is 8 HP + this modifier.

Parameters:
        medicine - Medicine value.
"""
	assert medicine >= 1
	if medicine <= 14: return -18 # 0
	if medicine <= 39: return -12 # 6
	if medicine <= 54: return - 6 #12
	if medicine <= 69: return   0 #18
	if medicine <= 84: return   6 #24
	if medicine <= 94: return  12 #30
	if medicine <= 104: return  18 #36
	if medicine <= 114: return  20 #38
	if medicine <= 124: return  21 #39
	if medicine <= 134: return  23 #41
	if medicine <= 149: return  25 #43
	return +27
	
def medicine_wood_garlic_ointmant(medicine):
	"""Returns HP modifier for medicine_wood_garlic depending on alternative_medicine
skill.

Parameters:
        medicine - Medicine value.
"""
	assert medicine >= 1
	if medicine <= 14: return -22# 0
	if medicine <= 39: return -15# 7
	if medicine <= 54: return - 7#15
	if medicine <= 69: return   0#22
	if medicine <= 84: return   7#29
	if medicine <= 94: return  15#37
	if medicine <= 104: return  22#44
	if medicine <= 114: return  24#46
	if medicine <= 124: return  27#49
	if medicine <= 134: return  29#51
	if medicine <= 149: return  31#53
	return +33

def medicine_burnet_ointmant(medicine):
	"""HP healed is 8 HP + this modifier.

Parameters:
        medicine - Medicine value.
"""
	assert medicine >= 1
	if medicine <= 14: return -26# 0
	if medicine <= 39: return -17# 9
	if medicine <= 54: return - 9#17
	if medicine <= 69: return   0#26
	if medicine <= 84: return   9#33
	if medicine <= 94: return  17#43
	if medicine <= 104: return  26#52
	if medicine <= 114: return  29#55
	if medicine <= 124: return  31#57
	if medicine <= 134: return  34#60
	if medicine <= 149: return  36#62
	return +39
	
def medicine_medipack_standard(medicine):
	"""Returns HP modifier for small medipack depending on medicine skill.

HP healed is 10 HP + this modifier.

Parameters:
        medicine - Medicine value.
"""
	assert medicine >= 1
	if medicine <= 14: return -10
	if medicine <= 39: return -5
	if medicine <= 54: return 0
	if medicine <= 69: return +2
	if medicine <= 84: return +4
	if medicine <= 94: return +6
	if medicine <= 104: return +10
	if medicine <= 114: return +11
	if medicine <= 124: return +12
	if medicine <= 134: return +13
	if medicine <= 149: return +14
	return +15

def medicine_medipack_big(medicine):
	"""Returns HP modifier for big medipack depending on medicine skill.

HP healed is 25 HP + this modifier.

Parameters:
        medicine - Medicine value.
"""
	# multiplier for multi medipack in use_heal_item
	assert medicine >= 1
	if medicine <= 14: return -25
	if medicine <= 39: return -15
	if medicine <= 54: return 0
	if medicine <= 69: return +5
	if medicine <= 84: return +10
	if medicine <= 94: return +15
	if medicine <= 104: return +25
	if medicine <= 114: return +28
	if medicine <= 124: return +30
	if medicine <= 134: return +32
	if medicine <= 149: return +34
	return +35

def technic_combination_value(technic):
	"""Returns max. combination difficulty depending on technical skill.

Parameters:
        technic - Technical value.
"""
	assert technic >= 1
	return technic

def survival_water_dection_range(survival):
	"""Returns water detection range in meters depending on survival skill.

Parameters:
        survival - Survival value.
"""
	assert survival >= 1
	if survival <= 69: return 0.0
	if survival <= 84: return 30.0
	if survival <= 94: return 50.0
	if survival <= 99: return 80.0
	return 80.0

def speech_trader_value(speech):
	"""Returns advantage/disadvantage when trading.

Parameters:
        speech - Speech value.
"""
	if speech <= 14: return 1.6
	if speech <= 39: return 1.4
	if speech <= 54: return 1.0
	if speech <= 69: return 0.8
	if speech <= 84: return 0.6
	if speech <= 94: return 0.4
	return 0.2	

def helper_format_percent(value, min_value=0.0, max_value=2.0, middle=None, zero_text=None, display_sign=True):
	"""Helper function for get_attribute_skill_text."""
	if middle==None: middle = abs((max_value - min_value) / 2.0)
	if middle==0:
		# prevent ZeroDivisionError
		min_value += 1
		max_value += 1
		middle += 1
		value += 1
	text = ""
	if display_sign: text = "+ "
	if (value < middle and min_value < middle) or (value > middle and min_value > middle):
		if display_sign: text = "- "
	elif value == middle:
		if zero_text != None: return zero_text
		if display_sign: text = "+- "
	max_value -= middle
	min_value -= middle
	value -= middle
	value = abs(100.0*value/middle)
	text += "%d %%" % round(value)
	return text


def helper_format_value(value, zero_text=None, display_sign=True):
	"""Helper function for get_attribute_skill_text."""
	str_value = ""
	if value < 0:
		if display_sign: str_value = "- "
		str_value += str(value*-1)
	elif value > 0:
		if display_sign: str_value = "+ "
		str_value += str(value)
	else:
		if zero_text != None: return zero_text
		if display_sign: str_value = "+- "
		str_value += str(value)
	return str_value

def get_attribute_skill_text( id, attribute, value ):
	"""Returns UI display strings for the attribute &amp; skill effects.

Parameters:
        id        - Id of the char.
        attribute - Skill or Attribute to display.
        value     - Value of Skill or Attribute.
"""
	text = ""
	attr_value = objects.get_attribute( id, attribute )
	
	
	if value=="value_hint":
		#import bonus
		#print "get value_hint:", attribute
		bonus_string = bonus.get_boni_string(id, attribute)
		return bonus_string

### ATTRIBUTES ###
	### STRENGTH ###
	if attribute=="strength":
		if value=="effect_1":
			attr_value*=3
			text = globaltext.STRENGTH_EFFECT_1 % {"value":attr_value}
			return text
		if value=="effect_2":
			text = globaltext.STRENGTH_EFFECT_2 % {"value":
					helper_format_percent(strength_heavy_weapons_hitchance(attr_value))}
		if value=="effect_3":
			text = globaltext.STRENGTH_EFFECT_3 % {"value":
					helper_format_percent(strength_close_combat_damage(attr_value))}
		if value=="name":
			return globaltext.MISSION_ATTRIBUTE_NAME_STRENGTH
		if value=="name_short":
			return globaltext.MISSION_ATTRIBUTE_NAME_SHORT_STRENGTH
		if value=="hint":
			return "MISSION_ATTRIBUTE_STRENGTH_HINT"
		#if value=="value_hint":
			#import bonus
			#return bonus.get_boni_string(id, attribute)
			#if (bonus.get_temp_bonus(id, "strength") > 0):
			#	return ""
			#else:
			#	return ""
	### AGILITY ###
	if attribute=="agility":
		if value=="effect_1":
			text = globaltext.AGILITY_EFFECT_1 % {"value":
					helper_format_percent(agility_move_speed(attr_value))}
		if value=="effect_2":
			text = globaltext.AGILITY_EFFECT_2 % {"value":
					helper_format_value(agility_armor(attr_value))}
		if value=="effect_3":
			text = globaltext.AGILITY_EFFECT_3 % {"value":
					helper_format_percent(agility_move_silently_factor(attr_value), min_value=2.0, max_value=0.0)}
		if value=="name":
			return globaltext.MISSION_ATTRIBUTE_NAME_AGILITY
		if value=="name_short":
			return globaltext.MISSION_ATTRIBUTE_NAME_SHORT_AGILITY
		if value=="hint":
			return "MISSION_ATTRIBUTE_AGILITY_HINT"
			
	### DEXTERITY ###
	if attribute=="dexterity":
		if value=="effect_1":
			text = globaltext.DEXTERITY_EFFECT_1 % {"value":
					helper_format_percent(dexterity_weapons_hitchance(attr_value))}
		if value=="effect_2":
			text = globaltext.DEXTERITY_EFFECT_3 % {"value":
					helper_format_percent(dexterity_pick_pocket(attr_value))}
		if value=="effect_3":
			text = globaltext.DEXTERITY_EFFECT_4 % {"value":
					helper_format_percent(dexterity_lock_picking(attr_value))}
		if value=="name":
			return globaltext.MISSION_ATTRIBUTE_NAME_DEXTERITY
		if value=="name_short":
			return globaltext.MISSION_ATTRIBUTE_NAME_SHORT_DEXTERITY
		if value=="hint":
			return "MISSION_ATTRIBUTE_DEXTERITY_HINT"

	### CONSTITUTION ###
	if attribute=="constitution":
		if value=="effect_1":
			text = globaltext.CONSTITUTION_EFFECT_1 % {"value":helper_format_value(constitution_life_energy_start(attr_value), display_sign=False)}
		if value=="effect_2":
			text = globaltext.CONSTITUTION_EFFECT_2 % {"value":helper_format_value(constitution_life_energy_level(attr_value))}
  		if value=="name":
			return globaltext.MISSION_ATTRIBUTE_NAME_CONSTITUTION
		if value=="name_short":
			return globaltext.MISSION_ATTRIBUTE_NAME_SHORT_CONSTITUTION
		if value=="hint":
			return "MISSION_ATTRIBUTE_CONSTITUTION_HINT"

	### INTELLIGENCE ###
	if attribute=="intelligence":
		if value=="effect_1":
			text = globaltext.INTELLIGENCE_EFFECT_1 % {"value":helper_format_value(intelligence_skill_points(attr_value))}
		if value=="effect_2":
			pass
		if value=="name":
			return globaltext.MISSION_ATTRIBUTE_NAME_INTELLIGENCE
		if value=="name_short":
			return globaltext.MISSION_ATTRIBUTE_NAME_SHORT_INTELLIGENCE
		if value=="hint":
			return "MISSION_ATTRIBUTE_INTELLIGENCE_HINT"

	### CHARISMA ###
	if attribute=="charisma":
		if value=="effect_1":
			text = globaltext.CHARISMA_EFFECT_1 % {"value":
					helper_format_percent(charisma_talk_bonus_factor(attr_value))}
		if value=="effect_2":
			value = charisma_npc_bad_mood_time_factor(attr_value)
			if value > 1: text = globaltext.CHARISMA_EFFECT_2_A
			elif value < 1: text = globaltext.CHARISMA_EFFECT_2_C
			else: text = globaltext.CHARISMA_EFFECT_2_B
			text = text % {"value":helper_format_percent(value)}
		if value=="name":
			return globaltext.MISSION_ATTRIBUTE_NAME_CHARISMA
		if value=="name_short":
			return globaltext.MISSION_ATTRIBUTE_NAME_SHORT_CHARISMA
		if value=="hint":
			return "MISSION_ATTRIBUTE_CHARISMA_HINT"

### SKILLS ###

	### LIGHT WEAPONS ###
	if attribute=="light_weapons":
		if value=="effect_1":
			text = globaltext.LIGHT_WEAPONS_EFFECT_1 % {"value":
					helper_format_percent(light_weapons_speed(attr_value), min_value=2, max_value=0)}
		if value=="effect_2":
			text = globaltext.LIGHT_WEAPONS_EFFECT_2 % {"value":helper_format_percent(light_weapons_hit_chance(attr_value))}
		if value=="effect_3":
			pass
		if value=="name":
			return globaltext.MISSION_SKILL_NAME_LIGHT_WEAPONS
		if value=="hint":
			return "MISSION_SKILL_LIGHT_WEAPONS_HINT"

	### HEAVY WEAPONS ###
	if attribute=="heavy_weapons":
		if value=="effect_1":
			text = globaltext.HEAVY_WEAPONS_EFFECT_1 % {"value":
					helper_format_percent(heavy_weapons_speed(attr_value), min_value=2, max_value=0)}
		if value=="effect_2":
			text = globaltext.HEAVY_WEAPONS_EFFECT_2 % {"value":helper_format_percent(heavy_weapons_hit_chance(attr_value))}
		if value=="name":
			return globaltext.MISSION_SKILL_NAME_HEAVY_WEAPONS
		if value=="hint":
			return "MISSION_SKILL_HEAVY_WEAPONS_HINT"

	### SNIPER WEAPONS ###
	if attribute=="sniper_weapons":
		if value=="effect_1":
			text = globaltext.SNIPER_WEAPONS_EFFECT_1 % {"value":
					helper_format_percent(sniper_weapons_speed(attr_value), min_value=2, max_value=0)}
		if value=="effect_2":
			text = globaltext.SNIPER_WEAPONS_EFFECT_2 % {"value":helper_format_percent(heavy_weapons_hit_chance(attr_value))}
		if value=="effect_3":
			pass
		if value=="name":
			return globaltext.MISSION_SKILL_NAME_SNIPER_WEAPONS
		if value=="hint":
			return "MISSION_SKILL_SNIPER_WEAPONS_HINT"

	### THROW WEAPONS ###
	if attribute=="throw_weapons":
		if value=="effect_1":
			text = globaltext.THROW_WEAPONS_EFFECT_1 % {"value":
					helper_format_percent(throw_weapons_speed(attr_value), min_value=2, max_value=0)}
		if value=="effect_2":
			text = globaltext.THROW_WEAPONS_EFFECT_2 % {"value":helper_format_percent(throw_weapons_hit_chance(attr_value))}
		if value=="effect_3":
			value = throw_weapons_miss_radius_factor(attr_value)
			text = globaltext.THROW_WEAPONS_EFFECT_3 % {"value":
					helper_format_percent(value, min_value=0, max_value=1, middle=0, display_sign=False)}
		if value=="name":
			return globaltext.MISSION_SKILL_NAME_THROW_WEAPONS
		if value=="hint":
			return "MISSION_SKILL_THROW_WEAPONS_HINT"

	### EXPLOSIVES ###
	if attribute=="explosives":
		if value=="effect_1":
		  	#1 bis 14	= 100 % Sprengstoff explodiert bei Beruehrung
			#15 bis 39	= 50 % Sprengstoff explodiert bei Beruehrung
			#40 bis 54	= Keine Sprengstoffanwendung
			#55 bis 69	= Standard-Sprengstoffe
			#70 bis 84	= Standard-Sprengstoffe + Minen
			#85 bis 94	= Standard-Sprengstoffe + Minen
			#95 bis 99	= Standard-Sprengstoffe + Minen
			_str = ""
			if attr_value >= 1 and attr_value <= 14: text = globaltext.EXPLOSIVES_EFFECT_1_A % {"value":"90 %"}
			elif attr_value >= 15 and attr_value <= 39: text = globaltext.EXPLOSIVES_EFFECT_1_A % {"value":"50 %"}
			elif attr_value >= 40 and attr_value <= 54: text = globaltext.EXPLOSIVES_EFFECT_1_B
			elif attr_value >= 55 and attr_value <= 69: text = globaltext.EXPLOSIVES_EFFECT_1_C
			elif attr_value >= 70 and attr_value <= 84: text = globaltext.EXPLOSIVES_EFFECT_1_D
			elif attr_value >= 85 and attr_value <= 94: text = globaltext.EXPLOSIVES_EFFECT_1_D
			elif attr_value >= 95: text = globaltext.EXPLOSIVES_EFFECT_1_D
		if value=="effect_2":
			#95 bis 99	= + Bomben entschärfen
			_str = ""
			if attr_value >= 1 and attr_value <= 54: text = globaltext.EXPLOSIVES_EFFECT_3_A
			elif attr_value >= 55 and attr_value <= 69: text = globaltext.EXPLOSIVES_EFFECT_3_B
			elif attr_value >= 70 and attr_value <= 84: text = globaltext.EXPLOSIVES_EFFECT_3_C
			elif attr_value >= 85 and attr_value <= 94: text = globaltext.EXPLOSIVES_EFFECT_3_D
			elif attr_value >= 95: text = globaltext.EXPLOSIVES_EFFECT_3_E
		if value=="effect_3":
			#85 bis 94	= Komplexe Sprengstoffe
			#95 bis 99	= Komplexe Sprengstoffe + Bomben entschaerfen
			_str = ""
			if attr_value >= 70: text = globaltext.EXPLOSIVES_EFFECT_2
		if value=="name":
			return globaltext.MISSION_SKILL_NAME_EXPLOSIVES
		
		if value=="hint":
			return "MISSION_SKILL_EXPLOSIVES_HINT"

	### SURVIVAL ###
	if attribute=="survival":
		if value=="effect_1":
			#1 bis 14	= + 40 % Verletzungsgefahr Ausweiden
			#15 bis 39	= + 20 % Verletzungsgefahr Ausweiden
			#40 bis 54	= Ausweiden Fleisch 1 LE
			#55 bis 69	= Ausweiden Fleisch 3 LE
			#70 bis 84	= Ausweiden Fleisch 6 LE
			#85 bis 94	= Ausweiden Fleisch 8 LE
			#95 bis 99	= Ausweiden Nahrung 10 LE
			_str = ""
			if attr_value >= 1 and attr_value <= 14: text = globaltext.SURVIVAL_EFFECT_1_A % {"value":"+ 40 %"}
			elif attr_value >= 15 and attr_value <= 39: text = globaltext.SURVIVAL_EFFECT_1_A % {"value":"+ 20 %"}
			elif attr_value >= 40 and attr_value <= 54: text = globaltext.SURVIVAL_EFFECT_1_B % {"value": 1}
			elif attr_value >= 55 and attr_value <= 69: text = globaltext.SURVIVAL_EFFECT_1_B % {"value": 3}
			elif attr_value >= 70 and attr_value <= 84: text = globaltext.SURVIVAL_EFFECT_1_B % {"value": 6}
			elif attr_value >= 85 and attr_value <= 94: text = globaltext.SURVIVAL_EFFECT_1_B % {"value": 8}
			elif attr_value >= 95 and attr_value <= 104: text = globaltext.SURVIVAL_EFFECT_1_B % {"value": 10}
			elif attr_value >= 105 and attr_value <= 114: text = globaltext.SURVIVAL_EFFECT_1_B % {"value": 12}
			elif attr_value >= 115 and attr_value <= 124: text = globaltext.SURVIVAL_EFFECT_1_B % {"value": 13}
			elif attr_value >= 125 and attr_value <= 134: text = globaltext.SURVIVAL_EFFECT_1_B % {"value": 14}
			elif attr_value >= 135 and attr_value <= 149: text = globaltext.SURVIVAL_EFFECT_1_B % {"value": 15}
			elif attr_value >= 150: text = globaltext.SURVIVAL_EFFECT_1_B % {"value": 16}

		if value=="effect_2":
			#70 bis 84	= Häuten
   			#85 bis 94	= Häuten + Entkrallen
			#95 bis 99	= Häuten + Entkrallen + Entzahnen
			_str = ""
			if attr_value >= 70 and attr_value <= 84: text = globaltext.SURVIVAL_EFFECT_2_A
			elif attr_value >= 85 and attr_value <= 94: text = globaltext.SURVIVAL_EFFECT_2_B
			elif attr_value >= 95: text = globaltext.SURVIVAL_EFFECT_2_C

		if value=="effect_3":
			text = helper_format_value(int(survival_water_dection_range(attr_value)), display_sign=False, zero_text="")
			if text:
				text = globaltext.SURVIVAL_EFFECT_3 % {"value1": text}
		if value=="name":
			return globaltext.MISSION_SKILL_NAME_SURVIVAL

		if value=="hint":
			return "MISSION_SKILL_SURVIVAL_HINT"

	### SNEAK ###
	if attribute=="sneak":
		if value=="effect_1":
			text = globaltext.SNEAK_EFFECT_1 % {"value":
					helper_format_percent(sneak_detection_factor(attr_value), min_value=0, max_value=8, middle=1)}
		if value=="name":
			return globaltext.MISSION_SKILL_NAME_SNEAK
		if value=="hint":
			return "MISSION_SKILL_SNEAK_HINT"

	### TECHNIC ###
	if attribute=="technic":
		if value=="effect_1":
			#1 bis 54	= Keine
			#55 bis 69	= Einfache Itemkombinationen
			#70 bis 84	= Mittelschwere Itemkombinationen
			#85 bis 94	= Schwere Itemkombinationen
			#95 bis 99	= Hochkomplexe Itemkombinationen
			_str = ""
 			if attr_value >= 1 and attr_value <= 54: text = globaltext.TECHNIC_EFFECT_1_A
			elif attr_value >= 55 and attr_value <= 69: text = globaltext.TECHNIC_EFFECT_1_B
			elif attr_value >= 70 and attr_value <= 84: text = globaltext.TECHNIC_EFFECT_1_C
			elif attr_value >= 85 and attr_value <= 94: text = globaltext.TECHNIC_EFFECT_1_D
			elif attr_value >= 95: text = globaltext.TECHNIC_EFFECT_1_E

		if value=="effect_2":
	 		#1 bis 14	= + 60 % Beschädigung
			#15 bis 39	= + 30 % Beschädigung
			#40 bis 54	= +- 0 % bedienen, reparieren, bauen
			#55 bis 69	= + 30% Technik bedienen
			#70 bis 84	= + 60% Technik bedienen
			#85 bis 94	= + 80% Technik bedienen
			#95 bis 99	= + 90% Technik bedienen
			_str = ""
 			if attr_value >= 1 and attr_value <= 14: text = globaltext.TECHNIC_EFFECT_2_A % {"value":"+ 60 %"}
			elif attr_value >= 15 and attr_value <= 39: text = globaltext.TECHNIC_EFFECT_2_A % {"value":"+ 30 %"}
			elif attr_value >= 40 and attr_value <= 54: text = globaltext.TECHNIC_EFFECT_2_B
			elif attr_value >= 55 and attr_value <= 69: text = globaltext.TECHNIC_EFFECT_2_C % {"value":"+ 30 %"}
			elif attr_value >= 70 and attr_value <= 84: text = globaltext.TECHNIC_EFFECT_2_C % {"value":"+ 60 %"}
			elif attr_value >= 85 and attr_value <= 94: text = globaltext.TECHNIC_EFFECT_2_C % {"value":"+ 80 %"}
			elif attr_value >= 95: text = globaltext.TECHNIC_EFFECT_2_C % {"value":"+ 90 %"}

		if value=="effect_3":
			#55 bis 69	= + 20 % Technik reparieren
			#70 bis 84	= + 40 % Technik reparieren
			#85 bis 94	= + 60 % Technik reparieren
			#95 bis 99	= + 80 % Technik reparieren
			_str = ""
			if attr_value >= 55 and attr_value <= 69: text = globaltext.TECHNIC_EFFECT_3 % {"value":"+ 20 %"}
			elif attr_value >= 70 and attr_value <= 84: text = globaltext.TECHNIC_EFFECT_3 % {"value":"+ 40 %"}
			elif attr_value >= 85 and attr_value <= 94: text = globaltext.TECHNIC_EFFECT_3 % {"value":"+ 60 %"}
			elif attr_value >= 95: text = globaltext.TECHNIC_EFFECT_3 % {"value":"+ 80 %"}

		if value=="name":
			return globaltext.MISSION_SKILL_NAME_TECHNIC

		if value=="hint":
			return "MISSION_SKILL_TECHNIC_HINT"

	### MEDICINE ###
	if attribute=="medicine":
		if value=="effect_1":
			text = helper_format_value(medicine_medipack_standard(attr_value))
			text = globaltext.MEDICINE_EFFECT_1_A % {"value": text}
		if value=="effect_2":
			text = helper_format_value(medicine_medipack_big(attr_value))
			text = globaltext.MEDICINE_EFFECT_2_A % {"value": text}
		if value=="effect_3":
			value = medicine_aloe_vera(attr_value)
			value += medicine_wood_garlic(attr_value)
			value += medicine_burnet(attr_value)
			value += medicine_aloe_vera_ointmant(attr_value)
			value += medicine_wood_garlic_ointmant(attr_value)
			value += medicine_burnet_ointmant(attr_value)
			value /= 6.0
			value = int(round(value))
			text = helper_format_value(value)
			text = globaltext.MEDICINE_EFFECT_3_A % {"value": text}
		if value=="name":
			return globaltext.MISSION_SKILL_NAME_MEDICINE

		if value=="hint":
			return "MISSION_SKILL_MEDICINE_HINT"

	### DRIVING ###
	if attribute=="driving":
		if value=="effect_1":
			#1 bis 14	= Unfähig Fahrzeug zu steuern
			#15 bis 39	= Unfähig Fahrzeug zu steuern
			#  Bug 11314 fahrgeschickskill inkonsistent
			#  old state 40 bis 54	= - 50 % Fahrgeschwindigkeit
			#  new state 40 bis 54	= Unfähig Fahrzeug zu steuern
			#55 bis 69	= +- 0% Fahrgeschwindigkeit
			#70 bis 84	= + 20% Fahrgeschwindigkeit
			#85 bis 94	= + 30% Fahrgeschwindigkeit
			#95 bis 99	= + 50% Fahrgeschwindigkeit
			_str = ""
			if attr_value >= 1 and attr_value <= 14: text = globaltext.DRIVING_EFFECT_1_A
			elif attr_value >= 15 and attr_value <= 39: text = globaltext.DRIVING_EFFECT_1_A
			elif attr_value >= 40 and attr_value <= 54: text = globaltext.DRIVING_EFFECT_1_A
			elif attr_value >= 55 and attr_value <= 69: text = globaltext.DRIVING_EFFECT_1_B % {"value":"+- 0 %"}
			elif attr_value >= 70 and attr_value <= 84: text = globaltext.DRIVING_EFFECT_1_B % {"value":"+ 20 %"}
			elif attr_value >= 85 and attr_value <= 94: text = globaltext.DRIVING_EFFECT_1_B % {"value":"+ 30 %"}
			elif attr_value >= 95: text = globaltext.DRIVING_EFFECT_1_B % {"value":"+ 40 %"}
		if value=="effect_2":
			#1 bis 14	= Benzinverbrauch nicht moeglich
			#15 bis 39	= Benzinverbrauch nicht moeglich
			#40 bis 54	= + 30 % Benzinverbrauch
			#55 bis 69	= Keine Auswirkung auf den Benzinverbrauch
			#70 bis 84	= - 10 % Benzinverbrauch
			#85 bis 94	= - 20 % Benzinverbrauch
			#95 bis 99	= - 30 % Benzinverbrauch
			_str = ""
			if attr_value >= 1 and attr_value <= 14: text = globaltext.DRIVING_EFFECT_3_A
			elif attr_value >= 15 and attr_value <= 39: text = globaltext.DRIVING_EFFECT_3_A
			elif attr_value >= 40 and attr_value <= 54: text = globaltext.DRIVING_EFFECT_3_A
			elif attr_value >= 55 and attr_value <= 69: text = globaltext.DRIVING_EFFECT_3_C
			elif attr_value >= 70 and attr_value <= 84: text = globaltext.DRIVING_EFFECT_3_B % {"value":"- 10 %"}
			elif attr_value >= 85 and attr_value <= 94: text = globaltext.DRIVING_EFFECT_3_B % {"value":"- 20 %"}
			elif attr_value >= 95 and attr_value <= 104: text = globaltext.DRIVING_EFFECT_3_B % {"value":"- 30 %"}
			elif attr_value >= 105 and attr_value <= 114: text = globaltext.DRIVING_EFFECT_3_B % {"value":"- 40 %"}
			elif attr_value >= 115 and attr_value <= 124: text = globaltext.DRIVING_EFFECT_3_B % {"value":"- 45 %"}
			elif attr_value >= 125 and attr_value <= 134: text = globaltext.DRIVING_EFFECT_3_B % {"value":"- 50 %"}
			elif attr_value >= 135 and attr_value <= 149: text = globaltext.DRIVING_EFFECT_3_B % {"value":"- 53 %"}
			elif attr_value >= 150: text = globaltext.DRIVING_EFFECT_3_B % {"value":"- 55 %"}
		if value=="name":
			return globaltext.MISSION_SKILL_NAME_DRIVING

		if value=="hint":
			return "MISSION_SKILL_DRIVING_HINT"


	### LOCK PICK ###
	if attribute=="lock_pick":
	  	if value=="effect_1":
			text1 = helper_format_percent(lock_pick_crack_lock_chance(attr_value), min_value=0, max_value=1, middle=0)
			text2 = helper_format_percent(lock_pick_destroy_lock_chance(attr_value), min_value=0, max_value=1, middle=0, zero_text="", display_sign=False)
			if text2:
				text = globaltext.LOCK_PICK_EFFECT_1_A % {"value":text2}
			else:
				text = globaltext.LOCK_PICK_EFFECT_1 % {"value":text1}
	  	if value=="effect_2":
			text = helper_format_percent(lock_pick_destroy_picklock_chance(attr_value), min_value=0, max_value=1, middle=0, display_sign=False)
			text = globaltext.LOCK_PICK_EFFECT_2 % {"value":text}
		if value=="name":
			return globaltext.MISSION_SKILL_NAME_LOCK_PICK
		if value=="hint":
			return "MISSION_SKILL_LOCK_PICK_HINT"

	### PICK POCKET ###
	if attribute=="pick_pocket":
  		if value=="effect_1":
			_str = helper_format_percent(pick_pocket_success_front(attr_value), min_value=-1, max_value=1, middle=0)
			text = globaltext.PICK_POCKET_EFFECT_1 % {"value":_str}
		if value=="effect_2":
			_str = helper_format_percent(pick_pocket_success_back(attr_value), min_value=-1, max_value=1, middle=0)
			text = globaltext.PICK_POCKET_EFFECT_2 % {"value":_str}
		if value=="name":
			return globaltext.MISSION_SKILL_NAME_PICK_POCKET

		if value=="hint":
			return "MISSION_SKILL_PICK_POCKET_HINT"


	### CLOSE COMBAT ###
	if attribute=="close_combat":
		if value=="effect_1":
			_str = helper_format_percent(close_combat_weapons_hit_chance(attr_value))
			text = globaltext.CLOSE_COMBAT_EFFECT_1 % {"value":_str}
		if value=="effect_2":
			_str = helper_format_percent(close_combat_weapons_damage(attr_value))
			text = globaltext.CLOSE_COMBAT_EFFECT_2 % {"value":_str}
		if value=="name":
			return globaltext.MISSION_SKILL_NAME_CLOSE_COMBAT

		if value=="hint":
			return "MISSION_SKILL_CLOSE_COMBAT_HINT"


	### SPEECH ###
	if attribute=="speech":
		if value=="effect_1":
			#1 bis 14	= Keine Chance zu überreden
			#15 bis 39	= Keine Chance zu überreden
			#40 bis 54	= Keine Chance zu überreden
			#55 bis 69	= Niedrige Chance zu überreden
			#70 bis 84	= Ordentliche Chance zu überreden
			#85 bis 94	= Hohe Chance zu überreden
			#95 bis 99	= Sehr hohe Chance zu überreden
			if attr_value >= 1 and attr_value <= 14: text = globaltext.SPEECH_EFFECT_1_A
			elif attr_value >= 15 and attr_value <= 39: text = globaltext.SPEECH_EFFECT_1_A
			elif attr_value >= 40 and attr_value <= 54: text = globaltext.SPEECH_EFFECT_1_A
			elif attr_value >= 55 and attr_value <= 69: text = globaltext.SPEECH_EFFECT_1_B
			elif attr_value >= 70 and attr_value <= 84: text = globaltext.SPEECH_EFFECT_1_C
			elif attr_value >= 85 and attr_value <= 94: text = globaltext.SPEECH_EFFECT_1_D
			elif attr_value >= 95: text = globaltext.SPEECH_EFFECT_1_E
		if value=="effect_2":
			_str = helper_format_percent(speech_trader_value(attr_value), min_value=2, max_value=0, zero_text="")
			if not _str:
				text = globaltext.SPEECH_EFFECT_2_B
				_str = "0 %"
			elif _str[0]=="-": text = globaltext.SPEECH_EFFECT_2_A
			else: text = globaltext.SPEECH_EFFECT_2_C
			text = text % {"value":_str}
		if value=="name":
			return globaltext.MISSION_SKILL_NAME_SPEECH
		if value=="hint":
			return "MISSION_SKILL_SPEECH_HINT"

	return text


def get_trade_text( trader_id, character_id, value ):
	"""Returns UI display strings for the charisma trading effects.

Parameters:
        trader_id    - Id of the trader.
        character_id - Id of the character.
        value        - Value of charisma.
"""
	if value=="line_1":
		_str = ""
		
		attr_value = objects.get_attribute( character_id, "speech" )
		factortrade = charisma_talk_bonus_factor(objects.get_attribute(character_id, "charisma"))	# [BrainRipper]
		attr_value=int(attr_value*factortrade)														# [BrainRipper]

		talent = False
		if has_talent(character_id, "speech", "trade"):
			talent = True

		#1 bis 14	= -  60 % Tauschnachteil
		#15 bis 39	= -  40 % Tauschnachteil
		#40 bis 54	=      0 % Auswirkung beim Tauschen
		#55 bis 69	= + 20 % Tauschvorteil
		#70 bis 84	= + 40 % Tauschvorteil
		#85 bis 94	= + 60 % Tauschvorteil
		#95 bis 99	= + 80 % Tauschvorteil
		if attr_value >= 1 and attr_value <= 14: _str = "- 60 %"
		elif attr_value >= 15 and attr_value <= 39: _str = "- 40 %"
		elif attr_value >= 40 and attr_value <= 54: _str = "0 %"
		elif attr_value >= 55 and attr_value <= 69: _str = "+ 20 %"
		elif attr_value >= 70 and attr_value <= 84:
			if talent:
				_str = "+ 60 %"
			else:
				_str = "+ 40 %"
		elif attr_value >= 85 and attr_value <= 94:
			if talent:
				_str = "+ 80 %"
			else:
				_str = "+ 60 %"
		elif attr_value >= 95:
			if talent:
				_str = "+100 %"
			else:
				_str = "+ 80 %"
		if attr_value<55:
			text = globaltext.MISSION_TRADINGPANEL_DISADVANTAGE % {"value1":_str, "value2": attr_value }
		else:
			if talent:
				text = globaltext.MISSION_TRADINGPANEL_ADVANTAGE_TALENT % {"value1":_str, "value2": attr_value }
			else:
				text = globaltext.MISSION_TRADINGPANEL_ADVANTAGE % {"value1":_str, "value2": attr_value }
		return text
	elif value=="line_2":
		bonus_malus = {}
		if objects.has_attribute(trader_id, "last_trade_bonus_malus"):
			bonus_malus = objects.get_attribute( trader_id, "last_trade_bonus_malus")
			if character_id in bonus_malus:
				return globaltext.MISSION_TRADINGPANEL_BONUS_MALUS % {"value": int(bonus_malus[character_id]*100)}
	return ""

####################################################################################################
# other tables
####################################################################################################

def weapon_accustoming(id_kills, type_kills):
	"""Returns skill bonus for being accustomed to this weapon/weapon type.

Parameters:
        id_kills   - Number of kills with this weapon.
        type_kills - Number of kills with this weapon_type.
"""
	if id_kills <= 9: id_bonus = 0
	elif id_kills <= 29: id_bonus = 5
	elif id_kills <= 59: id_bonus = 10
	elif id_kills <= 99: id_bonus = 15
	else: id_bonus = 20
	if type_kills <= 9: type_bonus = 0
	elif type_kills <= 29: type_bonus = 0
	elif type_kills <= 59: type_bonus = 5
	elif type_kills <= 99: type_bonus = 10
	else: type_bonus = 15
	return max(id_bonus, type_bonus)



def animal_armor_piercing_per_level(animal_type, level):
	"""Returns armor piercing for the given animal type and level.

Parameters:
        animal_type - animal type.
        level       - level of the animal.
"""
	if animal_type=="BEAR":
		return 20 + 3*level
	if animal_type=="TIGER":
		return 20 + 2*level
	if animal_type=="WARG":
		return 20 + 3*level
	if animal_type=="WILDDOG":
		return 15 + 2*level
	if animal_type=="WOLF":
		return 10 + 2*level
	return 0

def animal_damage_per_level(animal_type, level):
	"""Returns the damage caused by the given animal type and level.

Parameters:
        animal_type - animal type.
        level       - level of the animal.

Returns:
        (min_dmg, max_dmg)
"""
	if animal_type=="BEAR":
		return (5 + 3*level, 10 + 3*level)
	if animal_type=="TIGER":
		return (5 + 3*level, 10 + 3*level)
	if animal_type=="WARG":
		return (5 + 3*level, 10 + 3*level)
	if animal_type=="WILDDOG":
		return (1 + 2*level, 5 + 2*level)
	if animal_type=="WOLF":
		return (1 + 2*level, 5 + 2*level)
	return (0, 0)

def get_reputation_bonus_per_killpoints(killpoints):
	"""Returns the reputation skill point bonus for the given amount of killpoints.
"""
	if killpoints < 25: return 0
	elif killpoints < 50: return 1
	elif killpoints < 100: return 1
	elif killpoints < 150: return 2
	elif killpoints < 250: return 2
	elif killpoints < 500: return 3
	elif killpoints < 1000: return 4
	else: return 5

def get_reputation_description(killpoints):
	"""Returns the reputation description for the given amount of killpoints.
"""
	if killpoints < 25: return globaltext.MISSION_IDCARD_REPUTATION_DESC_0
	elif killpoints < 50: return globaltext.MISSION_IDCARD_REPUTATION_DESC_1
	elif killpoints < 100: return globaltext.MISSION_IDCARD_REPUTATION_DESC_2
	elif killpoints < 150: return globaltext.MISSION_IDCARD_REPUTATION_DESC_3
	elif killpoints < 250: return globaltext.MISSION_IDCARD_REPUTATION_DESC_4
	elif killpoints < 500: return globaltext.MISSION_IDCARD_REPUTATION_DESC_5
	elif killpoints < 1000: return globaltext.MISSION_IDCARD_REPUTATION_DESC_6
	else: return globaltext.MISSION_IDCARD_REPUTATION_DESC_7
