# -*- coding: utf-8 -*-
import sound

__doc__ = """This module provides high level, id-based access to predefined sound effects.

The functions here wrap, and use the lower level functions in the sound module.
"""

VOLUME_MAX = 0
VOLUME_MIN = -100000 

DEFAULT_MIN_DISTANCE = 5.0
DEFAULT_MAX_DISTANCE = 500.0
DEFAULT_VOLUME = VOLUME_MAX

#sound settings - npcs (daily routine)
DEFAULT_MIN_DISTANCE_NPC_SOUND = 1.0
DEFAULT_MAX_DISTANCE_NPC_SOUND = 30.0
DEFAULT_NPC_VOLUME = -200

#sound settings - objects (fireplaces etc)
DEFAULT_MIN_DISTANCE_OBJECT_SOUND = 1.0
DEFAULT_MAX_DISTANCE_OBJECT_SOUND = 20.0
DEFAULT_OBJECT_VOLUME = VOLUME_MAX

#sound settings - weapons
DEFAULT_MIN_DISTCANCE_WEAPON = 25.0
DEFAULT_MAX_DISTCANCE_WEAPON = 100.0
DEFAULT_WEAPON_VOLUME = VOLUME_MAX

DEFAULT_CLOSE_COMBAT_WEAPON_VOLUME = -1400

#SFX
sfx_list = {
	#sounds\ingame\animals
	"bear_1"				: ("sounds\\ingame\\animals\\bear_1.wav",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"bear_2"				: ("sounds\\ingame\\animals\\bear_2.wav",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"bear_death"			: ("sounds\\ingame\\animals\\bear_death.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"cow_1"					: ("sounds\\ingame\\animals\\cow_1.wav",			5, 50, -100),
	"cow_2"					: ("sounds\\ingame\\animals\\cow_2.wav",			5, 50, -100),
	"donkey"				: ("sounds\\ingame\\animals\\donkey.wav",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"horse"					: ("sounds\\ingame\\animals\\horse.wav",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"mustang_1"				: ("sounds\\ingame\\animals\\mustang_1.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"mustang_2"				: ("sounds\\ingame\\animals\\mustang_2.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"mustang_3"				: ("sounds\\ingame\\animals\\mustang_3.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"mustang_4"				: ("sounds\\ingame\\animals\\mustang_4.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"pig_1"					: ("sounds\\ingame\\animals\\pig_1.wav",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"pig_2"					: ("sounds\\ingame\\animals\\pig_2.wav",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"pigs"					: ("sounds\\ingame\\animals\\pigs.wav",				DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"tiger"					: ("sounds\\ingame\\animals\\tiger.wav",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"wolf_1"				: ("sounds\\ingame\\animals\\wolf_1.wav",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"wolf_2"				: ("sounds\\ingame\\animals\\wolf_2.wav",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"wolf_3"				: ("sounds\\ingame\\animals\\wolf_3.wav",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	#sounds\ingame\crates
	"close_crate"					: ("sounds\\ingame\\crates\\close_crate.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"open_crate"					: ("sounds\\ingame\\crates\\open_crate.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	#sounds\ingame\gui
	"handy_buttonclick"				: ("sounds\\ingame\\ui\\communicator_buttonclick.wav",	DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"handy_connecting"				: ("sounds\\ingame\\ui\\communicator_connecting.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"handy_voice2"					: ("sounds\\ingame\\ui\\communicator_voice2.wav",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"handy_voice3"					: ("sounds\\ingame\\ui\\communicator_voice3.wav",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"handy_voice"					: ("sounds\\ingame\\ui\\communicator_voice.wav",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"level_up"						: ("sounds\\ingame\\misc\\levelup.wav",				DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"combine"						: ("sounds\\ingame\\misc\\combine.wav",				DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"combine_failed"				: ("sounds\\ingame\\misc\\combine_failed.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"signature"						: ("sounds\\ingame\\misc\\signature.wav",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),

	#sounds\ingame\injured
	"startklick"					: ("sounds\\ingame\\injured\\female_breathing.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"male_breathing"				: ("sounds\\ingame\\injured\\male_breathing.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"male_dying"					: ("sounds\\ingame\\injured\\male_dying.wav",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"male_heavy_hit_1"				: ("sounds\\ingame\\injured\\male_heavy_hit_1.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"male_medium_hit_1"				: ("sounds\\ingame\\injured\\male_medium_hit_1.wav",	DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"male_medium_hit_2"				: ("sounds\\ingame\\injured\\male_medium_hit_2.wav",	DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"male_medium_hit_3"				: ("sounds\\ingame\\injured\\male_medium_hit_3.wav",	DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"male_slightly_hit_1"			: ("sounds\\ingame\\injured\\male_slightly_hit_1.wav",	DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"male_slightly_hit_2"			: ("sounds\\ingame\\injured\\male_slightly_hit_2.wav",	DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	#sounds\ingame\interior
	"door_close"					: ("sounds\\ingame\\interior\\door_close.wav",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"door_creak"					: ("sounds\\ingame\\interior\\door_creak.wav",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"door_locked"					: ("sounds\\ingame\\interior\\door_locked.wav",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"door_open"						: ("sounds\\ingame\\interior\\door_open.wav",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	#sounds\ingame\locks
	"lockpick_fail"					: ("sounds\\ingame\\locks\\lockpick_fail.wav",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"lockpick_success"				: ("sounds\\ingame\\locks\\lockpick_success.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	#sounds\ingame\npc
	"barrel_fire"					: ("sounds\\ingame\\npc\\barrel_fire.wav",				DEFAULT_MIN_DISTANCE_NPC_SOUND, DEFAULT_MAX_DISTANCE_NPC_SOUND, DEFAULT_VOLUME),
	"blowing_horn"					: ("sounds\\ingame\\npc\\blowing_horn.wav",				DEFAULT_MIN_DISTANCE_NPC_SOUND, DEFAULT_MAX_DISTANCE, DEFAULT_NPC_VOLUME),
	"boiling_water"					: ("sounds\\ingame\\npc\\boiling_water.wav",			DEFAULT_MIN_DISTANCE_NPC_SOUND, DEFAULT_MAX_DISTANCE, DEFAULT_NPC_VOLUME),
	"campfire_big"					: ("sounds\\ingame\\npc\\campfire_big.wav",				DEFAULT_MIN_DISTANCE_OBJECT_SOUND, DEFAULT_MAX_DISTANCE_OBJECT_SOUND, DEFAULT_OBJECT_VOLUME),
	"campfire_small"				: ("sounds\\ingame\\npc\\campfire_small.wav",			DEFAULT_MIN_DISTANCE_OBJECT_SOUND, DEFAULT_MAX_DISTANCE_OBJECT_SOUND, DEFAULT_OBJECT_VOLUME),
	"choping_wood"					: ("sounds\\ingame\\npc\\choping_wood.wav",				DEFAULT_MIN_DISTANCE_NPC_SOUND, DEFAULT_MAX_DISTANCE_NPC_SOUND, DEFAULT_NPC_VOLUME),
	"drinking"						: ("sounds\\ingame\\npc\\drinking.wav",					DEFAULT_MIN_DISTANCE_NPC_SOUND, DEFAULT_MAX_DISTANCE_NPC_SOUND, DEFAULT_NPC_VOLUME),
	"eating"						: ("sounds\\ingame\\npc\\eating.wav",					DEFAULT_MIN_DISTANCE_NPC_SOUND, DEFAULT_MAX_DISTANCE_NPC_SOUND, DEFAULT_NPC_VOLUME),
	"frying"						: ("sounds\\ingame\\npc\\frying.wav",					DEFAULT_MIN_DISTANCE_NPC_SOUND, DEFAULT_MAX_DISTANCE_NPC_SOUND, DEFAULT_NPC_VOLUME),
	"hammering"						: ("sounds\\ingame\\npc\\hammering.wav",				DEFAULT_MIN_DISTANCE_NPC_SOUND, DEFAULT_MAX_DISTANCE_NPC_SOUND, DEFAULT_NPC_VOLUME),
	"laundry"						: ("sounds\\ingame\\npc\\laundry.wav",					DEFAULT_MIN_DISTANCE_NPC_SOUND, DEFAULT_MAX_DISTANCE_NPC_SOUND, DEFAULT_NPC_VOLUME),
	"paint"							: ("sounds\\ingame\\npc\\paint.wav",					DEFAULT_MIN_DISTANCE_NPC_SOUND, DEFAULT_MAX_DISTANCE_NPC_SOUND, DEFAULT_NPC_VOLUME),
	"repairing_bike"				: ("sounds\\ingame\\npc\\repairing_bike.wav",			DEFAULT_MIN_DISTANCE_NPC_SOUND, DEFAULT_MAX_DISTANCE_NPC_SOUND, DEFAULT_NPC_VOLUME),
	"repairing_car"					: ("sounds\\ingame\\npc\\repairing_car.wav",			DEFAULT_MIN_DISTANCE_NPC_SOUND, DEFAULT_MAX_DISTANCE_NPC_SOUND, DEFAULT_NPC_VOLUME),
	"sawing"						: ("sounds\\ingame\\npc\\sawing.wav",					DEFAULT_MIN_DISTANCE_NPC_SOUND, DEFAULT_MAX_DISTANCE_NPC_SOUND, DEFAULT_NPC_VOLUME),
	"shoveling"						: ("sounds\\ingame\\npc\\shoveling.wav",				DEFAULT_MIN_DISTANCE_NPC_SOUND, DEFAULT_MAX_DISTANCE_NPC_SOUND, DEFAULT_NPC_VOLUME),
	"snoring_female"				: ("sounds\\ingame\\npc\\snoring_female.wav",			DEFAULT_MIN_DISTANCE_NPC_SOUND, DEFAULT_MAX_DISTANCE_NPC_SOUND, DEFAULT_NPC_VOLUME),
	"snoring_male"					: ("sounds\\ingame\\npc\\snoring_male.wav",				DEFAULT_MIN_DISTANCE_NPC_SOUND, DEFAULT_MAX_DISTANCE_NPC_SOUND, DEFAULT_NPC_VOLUME),
	"sweeping"						: ("sounds\\ingame\\npc\\sweeping.wav",					DEFAULT_MIN_DISTANCE_NPC_SOUND, DEFAULT_MAX_DISTANCE_NPC_SOUND, DEFAULT_NPC_VOLUME),
	"guitar"						: ("sounds\\ingame\\npc\\playing_guitar.wav",			DEFAULT_MIN_DISTANCE_NPC_SOUND, DEFAULT_MAX_DISTANCE_NPC_SOUND, DEFAULT_NPC_VOLUME),
	"flute"							: ("sounds\\ingame\\npc\\playing_flute.wav",			DEFAULT_MIN_DISTANCE_NPC_SOUND, DEFAULT_MAX_DISTANCE_NPC_SOUND, DEFAULT_NPC_VOLUME),
	
	#sounds\ingame\zone1
	"butt_down"						: ("sounds\\ingame\\zone1\\butt_down.wav",				DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"execution_audience"			: ("sounds\\ingame\\zone1\\execution_audience.wav",		4, 20000, DEFAULT_VOLUME),
	"execution_music"				: ("sounds\\ingame\\zone1\\execution_music.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"guillotine"					: ("sounds\\ingame\\zone1\\guillotine.wav",				10, 20000, DEFAULT_VOLUME),
	"gate"							: ("sounds\\ingame\\zone1\\gate.wav",					0.7, 12, -200),
	#sounds\ingame\zone2
	"body_bounce"					: ("sounds\\ingame\\zone2\\body_bounce.wav",			100, 200, -800),
	"explosion_house_david"			: ("sounds\\ingame\\zone2\\explosion_house_david.wav",	20, 80, DEFAULT_VOLUME),
	"timemachine"					: ("sounds\\ingame\\zone2\\timemachine.wav",			200, 400, DEFAULT_VOLUME),
	"explosion_timemachine"			: ("sounds\\ingame\\zone2\\ex_timemachine.wav",			200, 400, DEFAULT_VOLUME),
	"whistling"						: ("sounds\\ingame\\zone2\\whistling.wav",				DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"hit_stomach"					: ("sounds\\ingame\\zone2\\hit_stomach.wav",			100, 200, DEFAULT_VOLUME),
	"hit_pain"						: ("sounds\\ingame\\zone2\\hit_pain.wav",				100, 200, DEFAULT_VOLUME),
	#sounds\ingame\zone3
	"crying_female"					: ("sounds\\ingame\\zone3\\crying_female.wav",					DEFAULT_MIN_DISTANCE_NPC_SOUND, DEFAULT_MAX_DISTANCE_NPC_SOUND, DEFAULT_NPC_VOLUME),
	"explosion_bunker"				: ("sounds\\ingame\\zone3\\explosion_bunker.wav",				DEFAULT_MIN_DISTANCE_NPC_SOUND, DEFAULT_MAX_DISTANCE_NPC_SOUND, DEFAULT_NPC_VOLUME),
	"snoring_drunken_female"		: ("sounds\\ingame\\zone3\\snoring_drunken_female.wav",			DEFAULT_MIN_DISTANCE_NPC_SOUND, DEFAULT_MAX_DISTANCE_NPC_SOUND, DEFAULT_NPC_VOLUME),
	"z3_landmine"					: ("sounds\\ingame\\zone3\\landmine.wav",						20, 60, DEFAULT_OBJECT_VOLUME),
	"cadaver_fly"					: ("sounds\\ingame\\zone3\\cadaver_fly.wav",					DEFAULT_MIN_DISTANCE_OBJECT_SOUND, DEFAULT_MAX_DISTANCE_OBJECT_SOUND, DEFAULT_OBJECT_VOLUME),
	#sounds\ingame\zzone1
	"seeker_at_garbage_container"	: ("sounds\\ingame\\zzone1\\seeker_at_garbage_container.wav",	5, 50, -150),
	
	#sounds\ingame\zone7
	"crane_engine_loop"				: ("sounds\\ingame\\zone7\\crane_engine_loop.wav",			100, 200, -150),
	"crane_engine_starts"			: ("sounds\\ingame\\zone7\\crane_engine_starts.wav",		100, 200, -150),
	"crane_engine_off"				: ("sounds\\ingame\\zone7\\crane_engine_off.wav",			100, 200, -150),
	"crane_lifting_container"		: ("sounds\\ingame\\zone7\\crane_lifting_container.wav",	100, 200, -150),
	"crane_rotating"				: ("sounds\\ingame\\zone7\\crane_rotating.wav",				100, 200, -150),
	"crane_setting_down_container"	: ("sounds\\ingame\\zone7\\crane_setting_down_container.wav",	100, 200, -150),
	"crane_working_steel_cable"		: ("sounds\\ingame\\zone7\\crane_working_steel_cable.wav",	100, 200, -150),
	"fissling_plants_1"				: ("sounds\\ingame\\zone7\\fissling_plants_1.wav",			1, 10, -600),
	"fissling_plants_2"				: ("sounds\\ingame\\zone7\\fissling_plants_2.wav",			1, 10, -600),
	"gyrocopter_crash"				: ("sounds\\ingame\\zone7\\gyrocopter_crash.wav",			500.0, 550.0, DEFAULT_VOLUME),
	"gyrocopter_start"				: ("sounds\\ingame\\zone7\\gyrocopter_start.wav",			500.0, 550.0, DEFAULT_VOLUME),
	"open_prisondoor"				: ("sounds\\ingame\\zone7\\opening_prisondoor.wav",				DEFAULT_MIN_DISTANCE_NPC_SOUND, DEFAULT_MAX_DISTANCE_NPC_SOUND, DEFAULT_VOLUME),

	#sounds\ingame\zone6
	"generator_engine_off"			: ("sounds\\ingame\\zone6\\generator_engine_off.wav",		100, 200, -150),
	"generator_engine_starts"		: ("sounds\\ingame\\zone6\\generator_engine_starts.wav",	100, 200, -150),
	"generator_loop"				: ("sounds\\ingame\\zone6\\generator_loop.wav",				100, 200, -150),
	"robot_approached"				: ("sounds\\ingame\\zone6\\robot_approached.wav",			100, 200, -150),
	"whiskey_barrel"				: ("sounds\\ingame\\zone6\\whiskey_barrel.wav",				100, 200, -150),

	#sounds\ingame\zone4
	"audience_applause"				: ("sounds\\ingame\\zone4\\audience_applause.wav",			10, 60, -150),
	"audience_applause_long"		: ("sounds\\ingame\\zone4\\audience_applause_long.wav",		10, 60, -150),
	"laughing_audience"				: ("sounds\\ingame\\zone4\\laughing_audience.wav",			10, 60, -150),
	"splashing_water"				: ("sounds\\ingame\\zone4\\splashing_water.wav",			100, 200, -150),
	"treshing_machine"				: ("sounds\\ingame\\zone4\\treshing_machine.wav",			5, 75, -500),
	"working_windmill"				: ("sounds\\ingame\\zone4\\working_windmill.wav",			5, 75, -500),

	#sounds\ingame\zone5
	"weeping_female"				: ("sounds\\ingame\\zone5\\weeping_female.wav",				10, 60, -150),
	"warg_whines_2"					: ("sounds\\ingame\\zone5\\warg_whines_2.wav",				10, 60, -150),
	"warg_whines"					: ("sounds\\ingame\\zone5\\warg_whines.wav",				10, 60, -150),
	"warg_snarls"					: ("sounds\\ingame\\zone5\\warg_snarls.wav",				10, 60, -150),
	"smooth_firecracks"				: ("sounds\\ingame\\zone5\\smooth_firecracks.wav",			DEFAULT_MIN_DISTANCE_OBJECT_SOUND, DEFAULT_MAX_DISTANCE_OBJECT_SOUND, DEFAULT_OBJECT_VOLUME),
	"falling_buckets"				: ("sounds\\ingame\\zone5\\falling_buckets.wav",			10, 60, -150),
	"breathing_fire"				: ("sounds\\ingame\\zone5\\breathing_fire.wav",				10, 60, -150),

	#sounds\ingame\zone_8
	"npc_pissing"					: ("sounds\\ingame\\zone8\\npc_pissing.wav",				DEFAULT_MIN_DISTANCE_NPC_SOUND, DEFAULT_MAX_DISTANCE_NPC_SOUND, -300),
	"bicycle_loop"					: ("sounds\\ingame\\zone8\\bicycle_loop.wav",				DEFAULT_MIN_DISTANCE_NPC_SOUND, DEFAULT_MAX_DISTANCE_NPC_SOUND, DEFAULT_VOLUME),
	"treadmill_loop"				: ("sounds\\ingame\\zone8\\treadmill_loop.wav",				DEFAULT_MIN_DISTANCE_NPC_SOUND, DEFAULT_MAX_DISTANCE_NPC_SOUND, DEFAULT_VOLUME),
	
	#sounds\ingame\zone_9
	"injured_male_1"				: ("sounds\\ingame\\zone9\\injured_male_1.wav",				DEFAULT_MIN_DISTANCE_NPC_SOUND, DEFAULT_MAX_DISTANCE_NPC_SOUND, DEFAULT_NPC_VOLUME),
	"injured_male_2"				: ("sounds\\ingame\\zone9\\injured_male_2.wav",				DEFAULT_MIN_DISTANCE_NPC_SOUND, DEFAULT_MAX_DISTANCE_NPC_SOUND, DEFAULT_NPC_VOLUME),
	"injured_male_3"				: ("sounds\\ingame\\zone9\\injured_male_3.wav",				DEFAULT_MIN_DISTANCE_NPC_SOUND, DEFAULT_MAX_DISTANCE_NPC_SOUND, DEFAULT_NPC_VOLUME),
	"injured_male_4"				: ("sounds\\ingame\\zone9\\injured_male_4.wav",				DEFAULT_MIN_DISTANCE_NPC_SOUND, DEFAULT_MAX_DISTANCE_NPC_SOUND, DEFAULT_NPC_VOLUME),
	"injured_male_5"				: ("sounds\\ingame\\zone9\\injured_male_5.wav",				DEFAULT_MIN_DISTANCE_NPC_SOUND, DEFAULT_MAX_DISTANCE_NPC_SOUND, DEFAULT_NPC_VOLUME),
	"injured_male_6"				: ("sounds\\ingame\\zone9\\injured_male_6.wav",				DEFAULT_MIN_DISTANCE_NPC_SOUND, DEFAULT_MAX_DISTANCE_NPC_SOUND, DEFAULT_NPC_VOLUME),
	"injured_male_7"				: ("sounds\\ingame\\zone9\\injured_male_7.wav",				DEFAULT_MIN_DISTANCE_NPC_SOUND, DEFAULT_MAX_DISTANCE_NPC_SOUND, DEFAULT_NPC_VOLUME),
	"injured_male_8"				: ("sounds\\ingame\\zone9\\injured_male_8.wav",				DEFAULT_MIN_DISTANCE_NPC_SOUND, DEFAULT_MAX_DISTANCE_NPC_SOUND, DEFAULT_NPC_VOLUME),
	"injured_male_9"				: ("sounds\\ingame\\zone9\\injured_male_9.wav",				DEFAULT_MIN_DISTANCE_NPC_SOUND, DEFAULT_MAX_DISTANCE_NPC_SOUND, DEFAULT_NPC_VOLUME),
	"working_excravator"			: ("sounds\\ingame\\zone9\\working_excravator.wav",			400, 600, 0), # cutscene bedingt wegen objects.set_position()
	
	#sounds\ingame\zone_10
	"timemachine_returns"			: ("sounds\\ingame\\zone10\\timemachine_returns.wav",		100, 600, 0), # cutscene bedingt wegen objects.set_position()
	"timemachine_prebang"			: ("sounds\\ingame\\zone10\\timemachine_prebang.wav",		100, 600, 0), # cutscene bedingt wegen objects.set_position()
	
	#sounds\ingame\zzone_6
	"scream_male"					: ("sounds\\ingame\\zzone6\\scream_male.wav",		30, 100, DEFAULT_NPC_VOLUME),
	"scream_female"					: ("sounds\\ingame\\zzone6\\scream_female.wav",		30, 100, DEFAULT_NPC_VOLUME),
	
	#sounds\ingame\steps
	"step_beton_tile"				: ("sounds\\ingame\\steps\\step_beton_tile.wav",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"step_gras"						: ("sounds\\ingame\\steps\\step_gras.wav",					DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"step_metal"					: ("sounds\\ingame\\steps\\step_metal.wav",					DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"step_sand"						: ("sounds\\ingame\\steps\\step_sand.wav",					DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"step_standard"					: ("sounds\\ingame\\steps\\step_standard.wav",				1, 5, -1000),
	"step_stone_nature"				: ("sounds\\ingame\\steps\\step_stone_nature.wav",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"step_wood"						: ("sounds\\ingame\\steps\\step_wood.wav",					DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),

	#sounds\ingame\vehicles	
	"car_impact_soft"				: ("sounds\\ingame\\vehicles\\car_impact_soft.wav",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"car_impact_heavy"				: ("sounds\\ingame\\vehicles\\car_impact_heavy.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"car_skidding"					: ("sounds\\ingame\\vehicles\\car_skidding.wav",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	
	"pickup_loop_idle"				: ("sounds\\ingame\\vehicles\\pickup_loop_idle.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"pickup_loop_revs1"				: ("sounds\\ingame\\vehicles\\pickup_loop_revs1.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"pickup_loop_revs2"				: ("sounds\\ingame\\vehicles\\pickup_loop_revs2.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"pickup_loop_revs3"				: ("sounds\\ingame\\vehicles\\pickup_loop_revs3.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"pickup_loop_revsdown"			: ("sounds\\ingame\\vehicles\\pickup_loop_revsdown.wav",	DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"pickup_failstart"				: ("sounds\\ingame\\vehicles\\pickup_failstart.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"pickup_start"					: ("sounds\\ingame\\vehicles\\pickup_start.wav",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"pickup_opening_door"			: ("sounds\\ingame\\vehicles\\pickup_opening_door.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"pickup_closing_door"			: ("sounds\\ingame\\vehicles\\pickup_closing_door.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"pickup_explosion"				: ("sounds\\ingame\\vehicles\\pickup_explosion.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	

	"tank_closing_hatch"			: ("sounds\\ingame\\vehicles\\tank_closing_hatch.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),	
	"tank_explosion"				: ("sounds\\ingame\\vehicles\\tank_explosion.wav",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"tank_failstart"				: ("sounds\\ingame\\vehicles\\tank_failstart.wav",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"tank_loop_idle"				: ("sounds\\ingame\\vehicles\\tank_loop_idle.wav",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),	
	"tank_loop_revs1"				: ("sounds\\ingame\\vehicles\\tank_loop_revs1.wav",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"tank_loop_revs2"				: ("sounds\\ingame\\vehicles\\tank_loop_revs2.wav",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"tank_loop_revs3"				: ("sounds\\ingame\\vehicles\\tank_loop_revs3.wav",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"tank_opening_hatch"			: ("sounds\\ingame\\vehicles\\tank_opening_hatch.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"tank_shot"						: ("sounds\\ingame\\vehicles\\tank_shot.wav",				DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"tank_start"					: ("sounds\\ingame\\vehicles\\tank_start.wav",				DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"tank_stop"						: ("sounds\\ingame\\vehicles\\tank_stop.wav",				DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),	

	"humvee_explosion"				: ("sounds\\ingame\\vehicles\\humvee_explosion.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"humvee_closing_door"			: ("sounds\\ingame\\vehicles\\humvee_closing_door.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"humvee_failstart"				: ("sounds\\ingame\\vehicles\\humvee_failstart.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"humvee_gun_carriage"			: ("sounds\\ingame\\vehicles\\humvee_gun_carriage.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"humvee_loop_idle"				: ("sounds\\ingame\\vehicles\\humvee_loop_idle.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"humvee_loop_revs1"				: ("sounds\\ingame\\vehicles\\humvee_loop_revs1.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"humvee_loop_revs2"				: ("sounds\\ingame\\vehicles\\humvee_loop_revs2.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"humvee_loop_revs3"				: ("sounds\\ingame\\vehicles\\humvee_loop_revs3.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),	
	"humvee_opening_door"			: ("sounds\\ingame\\vehicles\\humvee_opening_door.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"humvee_start"					: ("sounds\\ingame\\vehicles\\humvee_start.wav",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"humvee_stop"					: ("sounds\\ingame\\vehicles\\humvee_stop.wav",				DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),

	"buggy_explosion"				: ("sounds\\ingame\\vehicles\\buggy_explosion.wav",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),	
	"buggy_failstart"				: ("sounds\\ingame\\vehicles\\buggy_failstart.wav",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"buggy_loop_idle"				: ("sounds\\ingame\\vehicles\\buggy_loop_idle.wav",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"buggy_loop_revs1"				: ("sounds\\ingame\\vehicles\\buggy_loop_revs1.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"buggy_loop_revs2"				: ("sounds\\ingame\\vehicles\\buggy_loop_revs2.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"buggy_loop_revs3"				: ("sounds\\ingame\\vehicles\\buggy_loop_revs3.wav",		DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"buggy_start"					: ("sounds\\ingame\\vehicles\\buggy_start.wav",				DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"buggy_stop"					: ("sounds\\ingame\\vehicles\\buggy_stop.wav",				DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),

	"bike_explosion"				: ("sounds\\ingame\\vehicles\\bike_explosion.wav",			400.0, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"bike_failstart"				: ("sounds\\ingame\\vehicles\\bike_failstart.wav",			400.0, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"bike_loop"						: ("sounds\\ingame\\vehicles\\bike_loop.wav",				400.0, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"bike_loop_idle"				: ("sounds\\ingame\\vehicles\\bike_loop_idle.wav",			400.0, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"bike_start"					: ("sounds\\ingame\\vehicles\\bike_start.wav",				400.0, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"bike_stop"						: ("sounds\\ingame\\vehicles\\bike_stop.wav",				400.0, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),

	#sounds\ingame\weapons
	"pistol_discharge"				: ("sounds\\ingame\\weapons\\pistol_discharge.wav",				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"pistol_gunjam"					: ("sounds\\ingame\\weapons\\pistol_gunjam.wav",				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"pistol_charge"					: ("sounds\\ingame\\weapons\\pistol_charge.wav",				5.0, 15.0, DEFAULT_WEAPON_VOLUME),

	"revolver_discharge"			: ("sounds\\ingame\\weapons\\revolver_discharge.wav",			DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"revolver_gunjam"				: ("sounds\\ingame\\weapons\\revolver_gunjam.wav",				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"revolver_charge"				: ("sounds\\ingame\\weapons\\revolver_charge.wav",				5.0, 15.0, DEFAULT_WEAPON_VOLUME),
	"rifle_discharge"				: ("sounds\\ingame\\weapons\\rifle_discharge.wav",				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"rifle_gunjam"					: ("sounds\\ingame\\weapons\\rifle_gunjam.wav",					DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"rifle_charge"					: ("sounds\\ingame\\weapons\\rifle_charge.wav",					5.0, 15.0, DEFAULT_WEAPON_VOLUME),

	"throwing_knife_loop"			: ("sounds\\ingame\\weapons\\throwing_knife_loop.wav",			DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),

	"smg_discharge"					: ("sounds\\ingame\\weapons\\smg_discharge.wav",				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"smg_gunjam"					: ("sounds\\ingame\\weapons\\smg_gunjam.wav",					DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"smg_charge"					: ("sounds\\ingame\\weapons\\smg_charge.wav",					5.0, 15.0, DEFAULT_WEAPON_VOLUME),

	"crossbow_discharge"			: ("sounds\\ingame\\weapons\\crossbow_discharge.wav",			DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"crossbow_charge"				: ("sounds\\ingame\\weapons\\crossbow_charge.wav",				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),

	"shot_colt_anaconda"			: ("sounds\\ingame\\weapons\\shot_colt_anaconda.wav",			DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"shot_walther_ppk"				: ("sounds\\ingame\\weapons\\shot_walther_ppk.wav",				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"shot_walther_ppk_silenced"		: ("sounds\\ingame\\weapons\\shot_walther_ppk_silenced.wav",	DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"shot_special_38"				: ("sounds\\ingame\\weapons\\shot_special_38.wav",				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"shot_sig_sauer"				: ("sounds\\ingame\\weapons\\shot_sig_sauer.wav",				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"shot_sig_sauer_silenced"		: ("sounds\\ingame\\weapons\\shot_sig_sauer_silenced.wav",		DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),

	"shot_beretta_92f"				: ("sounds\\ingame\\weapons\\shot_beretta_92f.wav",				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"shot_beretta_92f_silenced"		: ("sounds\\ingame\\weapons\\shot_beretta_92f_silenced.wav",	DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"shot_desert_eagle"				: ("sounds\\ingame\\weapons\\shot_desert_eagle.wav",			DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"shot_colt_45"					: ("sounds\\ingame\\weapons\\shot_colt_45.wav",					DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"shot_colt_45_silenced"			: ("sounds\\ingame\\weapons\\shot_colt_45_silenced.wav",		DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"shot_glock_21"					: ("sounds\\ingame\\weapons\\shot_glock_21.wav",				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"shot_glock_21_silenced"		: ("sounds\\ingame\\weapons\\shot_glock_21_silenced.wav",		DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"shot_hk_usp_45"				: ("sounds\\ingame\\weapons\\shot_hk_usp_45.wav",				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"shot_hk_usp_45_silenced"		: ("sounds\\ingame\\weapons\\shot_hk_usp_45_silenced.wav",		DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"shot_calico_m950"				: ("sounds\\ingame\\weapons\\shot_calico_m950.wav",				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"shot_calico_m950_silenced"		: ("sounds\\ingame\\weapons\\shot_calico_m950_silenced.wav",	DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"shot_automag_3"				: ("sounds\\ingame\\weapons\\shot_automag_3.wav",				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_micro_uzi"				: ("sounds\\ingame\\weapons\\burst_micro_uzi.wav",				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_micro_uzi_silenced"		: ("sounds\\ingame\\weapons\\burst_micro_uzi_silenced.wav",		DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_uzi"						: ("sounds\\ingame\\weapons\\burst_uzi.wav",					DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_uzi_silenced"			: ("sounds\\ingame\\weapons\\burst_uzi_silenced.wav",			DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_mp5"						: ("sounds\\ingame\\weapons\\burst_mp5.wav",					DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_mp5_silenced"			: ("sounds\\ingame\\weapons\\burst_mp5_silenced.wav",			DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_hk_mp7"					: ("sounds\\ingame\\weapons\\burst_hk_mp7.wav",					DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_xm8"					: ("sounds\\ingame\\weapons\\burst_xm8.wav",					DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_hk_g11"					: ("sounds\\ingame\\weapons\\burst_hk_g11.wav",					DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"shot_gmg_ocsw"				: ("sounds\\ingame\\weapons\\shot_gmg_ocsw.wav",				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_mac_10"					: ("sounds\\ingame\\weapons\\burst_mac_10.wav",					DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_mac_10_silenced"			: ("sounds\\ingame\\weapons\\burst_mac_10_silenced.wav",		DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_hk_ump_45"				: ("sounds\\ingame\\weapons\\burst_hk_ump_45.wav",				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_hk_ump_45_silenced"		: ("sounds\\ingame\\weapons\\burst_hk_ump_45_silenced.wav",		DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_steyr_tmp"				: ("sounds\\ingame\\weapons\\burst_steyr_tmp.wav",				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_steyr_tmp_silenced"		: ("sounds\\ingame\\weapons\\burst_steyr_tmp_silenced.wav",		DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_aksu74"					: ("sounds\\ingame\\weapons\\burst_aksu74.wav",					DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_p90_smg"					: ("sounds\\ingame\\weapons\\burst_p90_smg.wav",				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_p90_smg_silenced"		: ("sounds\\ingame\\weapons\\burst_p90_smg_silenced.wav",		DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_lasergun"				: ("sounds\\ingame\\weapons\\burst_lasergun.wav",				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"shot_browning_double_barrel"	: ("sounds\\ingame\\weapons\\shot_browning_double_barrel.wav",	DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"shot_remington_m870"			: ("sounds\\ingame\\weapons\\shot_remington_m870.wav",			DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"shot_spas_15"					: ("sounds\\ingame\\weapons\\shot_spas_15.wav",					DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_hk_caws"					: ("sounds\\ingame\\weapons\\burst_hk_caws.wav",				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"shot_simonov_sks"				: ("sounds\\ingame\\weapons\\shot_simonov_sks.wav",				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_ak_47"					: ("sounds\\ingame\\weapons\\burst_ak_47.wav",					DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_ak_74"					: ("sounds\\ingame\\weapons\\burst_ak_74.wav",					DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_m4a1"					: ("sounds\\ingame\\weapons\\burst_m4a1.wav",					DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"shot_m203"						: ("sounds\\ingame\\weapons\\shot_m203.wav",					DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"shot_bg_15"					: ("sounds\\ingame\\weapons\\shot_bg_15.wav",					DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),	# [BrainRipper]
	"shot_calico_m900"				: ("sounds\\ingame\\weapons\\shot_calico_m900.wav",				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"shot_calico_m900_silenced"		: ("sounds\\ingame\\weapons\\shot_calico_m900_silenced.wav",	DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_sa_80"					: ("sounds\\ingame\\weapons\\burst_sa_80.wav",					DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_famas"					: ("sounds\\ingame\\weapons\\burst_famas.wav",					DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_hk_g36c"					: ("sounds\\ingame\\weapons\\burst_hk_g36c.wav",				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_hk_g41"					: ("sounds\\ingame\\weapons\\burst_hk_g41.wav",					DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_oicw_gewehr"				: ("sounds\\ingame\\weapons\\burst_oicw_gewehr.wav",			DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"shot_oicw_granate"				: ("sounds\\ingame\\weapons\\shot_oicw_granate.wav",			DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),	
	"burst_sig_sg552"				: ("sounds\\ingame\\weapons\\burst_sig_sg552.wav",				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_steyr_aug"				: ("sounds\\ingame\\weapons\\burst_steyr_aug.wav",				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_m14"						: ("sounds\\ingame\\weapons\\burst_m14.wav",					DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_mg_3"					: ("sounds\\ingame\\weapons\\burst_mg_3.wav",					DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_rpk_74"					: ("sounds\\ingame\\weapons\\burst_rpk_74.wav",					DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_m249"					: ("sounds\\ingame\\weapons\\burst_m249.wav",					DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_fn_mag"					: ("sounds\\ingame\\weapons\\burst_fn_mag.wav",					DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_m60"						: ("sounds\\ingame\\weapons\\burst_m60.wav",					DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"shot_m_79"						: ("sounds\\ingame\\weapons\\shot_m_79.wav",					DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"shot_rpg7"						: ("sounds\\ingame\\weapons\\shot_rpg7.wav",					DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"shot_law"						: ("sounds\\ingame\\weapons\\shot_law.wav",						DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"shot_walther_ppk"				: ("sounds\\ingame\\weapons\\shot_walther_ppk.wav",				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"shot_dragunov"					: ("sounds\\ingame\\weapons\\shot_dragunov.wav",				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"shot_psg_1"					: ("sounds\\ingame\\weapons\\shot_psg_1.wav",					DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"shot_barret_m82a2"				: ("sounds\\ingame\\weapons\\shot_barret_m82a2.wav",			DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"shot_m24"						: ("sounds\\ingame\\weapons\\shot_m24.wav",						DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"shot_crossbow"					: ("sounds\\ingame\\weapons\\shot_crossbow.wav",				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"shot_dsr1"						: ("sounds\\ingame\\weapons\\shot_dsr1.wav",					DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"shot_railgun"					: ("sounds\\ingame\\weapons\\shot_railgun.wav",					DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	
	"shot_sr800"					: ("sounds\\ingame\\weapons\\shot_sr800.wav",			DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_plasmablaster"					: ("sounds\\ingame\\weapons\\burst_plasmablaster.wav",						DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_lw_hammer"				: ("sounds\\ingame\\weapons\\burst_lw_hammer.wav",				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_quadhammer"				: ("sounds\\ingame\\weapons\\burst_quadhammer.wav",					DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"burst_superlw"					: ("sounds\\ingame\\weapons\\burst_superlw.wav",					DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),

	"c4_small_explo"				: ("sounds\\ingame\\weapons\\c4_small_explo.wav",				25.0, 300.0, DEFAULT_WEAPON_VOLUME),
	"c4_big_explo"					: ("sounds\\ingame\\weapons\\c4_big_explo.wav",					25.0, 300.0, DEFAULT_WEAPON_VOLUME),
	"grenade_explo_fire"			: ("sounds\\ingame\\weapons\\grenade_explo_fire.wav", 			25.0, 300.0, DEFAULT_WEAPON_VOLUME),
	
	"grenade_explo_frag"			: ("sounds\\ingame\\weapons\\grenade_explo_frag.wav", 			25.0, 300.0, DEFAULT_WEAPON_VOLUME),
	"grenade_explo_rpg7"			: ("sounds\\ingame\\weapons\\grenade_explo_rpg7.wav", 			25.0, 300.0, DEFAULT_WEAPON_VOLUME),
	"various_explosive_explo"		: ("sounds\\ingame\\weapons\\various_explosive_explo.wav", 		25.0, 300.0, DEFAULT_WEAPON_VOLUME),
	"landmine_explo"				: ("sounds\\ingame\\weapons\\landmine_explo.wav", 				25.0, 300.0, DEFAULT_WEAPON_VOLUME),

	#close combat
	"attack_baseball_bat"			: ("sounds\\ingame\\weapons\\attack_baseball_bat.wav", 			DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_CLOSE_COMBAT_WEAPON_VOLUME),
	"attack_baseball_bat_nails"		: ("sounds\\ingame\\weapons\\attack_baseball_bat_nails.wav",	DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_CLOSE_COMBAT_WEAPON_VOLUME),
	"attack_chainsaw"				: ("sounds\\ingame\\weapons\\attack_chainsaw.wav",				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_CLOSE_COMBAT_WEAPON_VOLUME),
	"attack_fist_01"				: ("sounds\\ingame\\weapons\\attack_fist_01.wav", 				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_CLOSE_COMBAT_WEAPON_VOLUME),
	"attack_fist_02"				: ("sounds\\ingame\\weapons\\attack_fist_02.wav", 				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_CLOSE_COMBAT_WEAPON_VOLUME),
	"attack_fist_03"				: ("sounds\\ingame\\weapons\\attack_fist_03.wav", 				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_CLOSE_COMBAT_WEAPON_VOLUME),
	"attack_fist_04"				: ("sounds\\ingame\\weapons\\attack_fist_04.wav", 				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_CLOSE_COMBAT_WEAPON_VOLUME),
	"attack_iron_bar"				: ("sounds\\ingame\\weapons\\attack_iron_bar.wav", 				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_CLOSE_COMBAT_WEAPON_VOLUME),
	"attack_knife"					: ("sounds\\ingame\\weapons\\attack_knife.wav", 				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_CLOSE_COMBAT_WEAPON_VOLUME),
	"attack_throw"					: ("sounds\\ingame\\weapons\\attack_throw.wav", 				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_CLOSE_COMBAT_WEAPON_VOLUME),
	
	"bullethit_flesh_01"			: ("sounds\\ingame\\weapons\\bullethit_flesh_01.wav", 			DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"bullethit_flesh_02"			: ("sounds\\ingame\\weapons\\bullethit_flesh_02.wav", 			DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"bullethit_flesh_03"			: ("sounds\\ingame\\weapons\\bullethit_flesh_03.wav", 			DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"bullethit_headshot"			: ("sounds\\ingame\\weapons\\bullethit_headshot.wav", 			DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"bullethit_bricks_01"			: ("sounds\\ingame\\weapons\\bullethit_bricks_01.wav", 			DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"bullethit_bricks_02"			: ("sounds\\ingame\\weapons\\bullethit_bricks_02.wav", 			DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"bullethit_bricks_03"			: ("sounds\\ingame\\weapons\\bullethit_bricks_03.wav", 			DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"bullethit_bricks_04"			: ("sounds\\ingame\\weapons\\bullethit_bricks_04.wav", 			DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"bullethit_glass_01"			: ("sounds\\ingame\\weapons\\bullethit_glass_01.wav", 			DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"bullethit_glass_02"			: ("sounds\\ingame\\weapons\\bullethit_glass_02.wav", 			DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"bullethit_glass_03"			: ("sounds\\ingame\\weapons\\bullethit_glass_03.wav", 			DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"bullethit_metal_01"			: ("sounds\\ingame\\weapons\\bullethit_metal_01.wav", 			DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"bullethit_metal_02"			: ("sounds\\ingame\\weapons\\bullethit_metal_02.wav", 			DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"bullethit_metal_03"			: ("sounds\\ingame\\weapons\\bullethit_metal_03.wav", 			DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"bullethit_nothing_01"			: ("sounds\\ingame\\weapons\\bullethit_nothing_01.wav", 		DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"bullethit_nothing_02"			: ("sounds\\ingame\\weapons\\bullethit_nothing_02.wav", 		DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"bullethit_nothing_03"			: ("sounds\\ingame\\weapons\\bullethit_nothing_03.wav", 		DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"bullethit_plants_01"			: ("sounds\\ingame\\weapons\\bullethit_plants_01.wav", 			DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"bullethit_plants_02"			: ("sounds\\ingame\\weapons\\bullethit_plants_02.wav", 			DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"bullethit_plants_03"			: ("sounds\\ingame\\weapons\\bullethit_plants_03.wav", 			DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"bullethit_wood_01"				: ("sounds\\ingame\\weapons\\bullethit_wood_01.wav", 			DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"bullethit_wood_02"				: ("sounds\\ingame\\weapons\\bullethit_wood_02.wav", 			DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	"bullethit_wood_03"				: ("sounds\\ingame\\weapons\\bullethit_wood_03.wav", 			DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_WEAPON_VOLUME),
	
	"chainsaw_loop"					: ("sounds\\ingame\\weapons\\chainsaw_loop.wav", 				DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_CLOSE_COMBAT_WEAPON_VOLUME),
	"attack_electro_shocker"		: ("sounds\\ingame\\weapons\\attack_electro_shocker.wav",		DEFAULT_MIN_DISTCANCE_WEAPON, DEFAULT_MAX_DISTCANCE_WEAPON, DEFAULT_CLOSE_COMBAT_WEAPON_VOLUME),
	
	#sounds for alarms
	"alarm_1"						: ("sounds\\ingame\\misc\\alarm_1.wav",							DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"alarm_2"						: ("sounds\\ingame\\misc\\alarm_2.wav",							DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"alarm_firehorn"				: ("sounds\\ingame\\misc\\alarm_firehorn.wav",					DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"alarm_fort_zone4"				: ("sounds\\ingame\\misc\\alarm_fort_zone4.wav",				DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),

	# Zzone_9
	"tower_up"				: ("sounds\\ingame\\zzone9\\tower_up.ogg",100, 200, DEFAULT_VOLUME),
	"tower_down"				: ("sounds\\ingame\\zzone9\\tower_down.ogg",100, 200, DEFAULT_VOLUME),
	"tower_salve"				: ("sounds\\ingame\\zzone9\\tower_salve.ogg",100, 200, DEFAULT_VOLUME),
	"tower_turn_loop"			: ("sounds\\ingame\\zzone9\\tower_rotating.ogg",100, 200, DEFAULT_VOLUME),
	"bunkerdoor"				: ("sounds\\ingame\\zzone9\\bunkerdoor.ogg",20, 40, DEFAULT_VOLUME),
	
	#ambientsounds
	"eagle_1"				: ("sounds\\ingame\\animals\\eagle_1.ogg",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"eagle_2"				: ("sounds\\ingame\\animals\\eagle_2.ogg",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"buzzard_1"				: ("sounds\\ingame\\animals\\buzzard_1.ogg",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"buzzard_2"				: ("sounds\\ingame\\animals\\buzzard_2.ogg",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"vulture_1"				: ("sounds\\ingame\\animals\\vulture_1.ogg",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"vulture_2"				: ("sounds\\ingame\\animals\\vulture_2.ogg",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"owlet_1"				: ("sounds\\ingame\\animals\\owl_1.ogg",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"owlet_2"				: ("sounds\\ingame\\animals\\owl_2.ogg",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"wing_1"				: ("sounds\\ingame\\animals\\wing_1.ogg",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
	"wing_2"				: ("sounds\\ingame\\animals\\wing_2.ogg",			DEFAULT_MIN_DISTANCE, DEFAULT_MAX_DISTANCE, DEFAULT_VOLUME),
}

SFX_PATH = 0
SFX_MIN_DISTANCE = 1
SFX_MAX_DISTANCE = 2
SFX_VOLUME = 3

def get_sfx_data(sfx, data=None):
	"""Returns data about this sound effect.

Parameters:
        sfx  - One of the sound ids in sounds.sfx_list.
        data - Index to inquire a specific part of the data

Where data is:
       None             - All data about this sound effect is returned.
       SFX_PATH         - Path of the sound effect.
       SFX_MIN_DISTANCE - Min distance in which the sound can be heard.
           Pre-defined default values:
               DEFAULT_MIN_DISTANCE = 5.0
               DEFAULT_MIN_DISTANCE_OBJECT_SOUND = 1.0
               DEFAULT_MIN_DISTANCE_NPC_SOUND = 1.0
               DEFAULT_MIN_DISTCANCE_WEAPON = 25.0
       SFX_MAX_DISTANCE - Max distance in which the sound can be heard.
           Pre-defined default values:
               DEFAULT_MAX_DISTANCE = 500.0
               DEFAULT_MAX_DISTANCE_NPC_SOUND = 30.0
               DEFAULT_MAX_DISTANCE_OBJECT_SOUND = 20.0
               DEFAULT_MAX_DISTCANCE_WEAPON = 100.0
       SFX_VOLUME - Volume of this sound effect.
           Pre-defined default values:
               VOLUME_MIN = -100000
               VOLUME_MAX = 0
               DEFAULT_VOLUME = 0
               DEFAULT_NPC_VOLUME = -200
               DEFAULT_OBJECT_VOLUME = 0
               DEFAULT_WEAPON_VOLUME = 0
               DEFAULT_CLOSE_COMBAT_WEAPON_VOLUME = -1400
"""
	if sfx_list.has_key(sfx):
		if data==None:
			return sfx_list[sfx]
		elif data==SFX_PATH:
			return sfx_list[sfx][data]
	else:
		raise ValueError, "no sound with this identifier registered '" + sfx + "'" 

def play_2d_sound(sfx_id):
	"""Plays the sound with the given effect id.

The sound is not tied to a location in the game world, and is played at full volume.

Parameters:
        sfx_id  - One of the sound ids in sounds.sfx_list.
"""
	data = get_sfx_data(sfx_id)
	sound.play_2d_sound(data[SFX_PATH])

def play_3d_sound(sfx_id, x, y, z, loop = None, identifier = None):
	"""Plays the sound with the given effect id.

The sound is tied to a location in the game world. If the player is too far away
from this location, the sound will not be heard.

Parameters:
        sfx_id     - One of the sound ids in sounds.sfx_list.
        x, y, z    - Sound will be played at this coordinate.
        loop       - Sound will be repeated if this is True.
        identifier - Assigns an identifier to this sound.
                     This is necessary to access the sound with stop_sound or
                     is_sound_playing.
"""
	data = get_sfx_data(sfx_id)
	var_loop = False
	if loop!=None: var_loop = loop
	if identifier!=None:
		sound.play_3d_sound(
			data[SFX_PATH],
			x,y,z,
			data[SFX_MIN_DISTANCE],
			data[SFX_MAX_DISTANCE],
			data[SFX_VOLUME],
			var_loop,
			identifier)
	else:
		sound.play_3d_sound(
			data[SFX_PATH],
			x,y,z,
			data[SFX_MIN_DISTANCE],
			data[SFX_MAX_DISTANCE],
			data[SFX_VOLUME],
			var_loop)

def play_3d_sound_object(sfx_id, object, loop = None, identifier = None):
	"""Plays the sound with the given effect id.

The sound is tied to an object in the game world. If the player is too far away
from this object, the sound will not be heard.

Parameters:
        sfx_id     - One of the sound ids in sounds.sfx_list.
        object     - Id of the object to link sound to.
        loop       - Sound will be repeated if this is True.
        identifier - Assigns an identifier to this sound.
                     This is necessary to access the sound with stop_sound or
                     is_sound_playing.
"""
	data = get_sfx_data(sfx_id)
	var_loop = False
	if loop!=None: var_loop = loop
	if identifier!=None:
		#print "play_3d_sound", sfx_id, identifier
		
		sound.play_3d_sound_object(
			data[SFX_PATH],
			object,
			data[SFX_MIN_DISTANCE],
			data[SFX_MAX_DISTANCE],
			data[SFX_VOLUME],
			var_loop,
			identifier)
	else:
		sound.play_3d_sound_object(
			data[SFX_PATH],
			object,
			data[SFX_MIN_DISTANCE],
			data[SFX_MAX_DISTANCE],
			data[SFX_VOLUME],
			var_loop)

def load_sound(sfx_id):
	"""Pre-loads a sound file.

Normally, sound files are loaded when they're first played, but this can lead
to a noticeable performance spike. To prevent that, you can pre-load the sound
file at an appropriate moment (e.g., in on_map_loaded).

Parameters:
        sfx_id     - One of the sound ids in sounds.sfx_list.
"""
	data = get_sfx_data(sfx_id)
	sound.load_sound(filename=data[SFX_PATH])

def stop_sound(id):
	"""Stops the sound.

Parameters:
        id  - Identifier set in play_3d_sound or play_3d_sound_object.
"""
	#print "stop_sound", id
	sound.stop_sound(id=id)

def is_sound_playing(id):
	"""Returns True when the sound is running.

Parameters:
        id  - Identifier set in play_3d_sound or play_3d_sound_object.
"""
	#print "is_sound_playing", id
	return sound.is_sound_playing(id=id)

def validate_resources():
	"""Helper function to test if the music files exist.
"""
	# print "check sfx" 
	import os
	values = sfx_list.values()
	for sfx in sfx_list.keys():
		if ".wav" in sfx:
			raise ValueError, "'.wav' not valid in sound identifier"
		fullpath = os.getcwd()+"\\"+sfx_list[sfx][SFX_PATH]
		fullpath = fullpath[:-3] + "ogg"
		if not os.path.isfile(fullpath):
			raise ValueError, "missing resource: "+fullpath
		if not os.path.getsize(fullpath) > 0:
			raise ValueError, "file size incorrect: "+fullpath
		if values.count(sfx_list[sfx]) > 1:
			# at the moment it is not valid to use the same values twice, to
			# prevent copy&past mistakes, it may become valid later
			raise ValueError, "different identifier, same values: "+str(sfx_list[sfx])

