# -*- coding: utf-8 -*-
from global_defines import *
import character
import system
import sounds
import random

flesh_wound_sounds = ["bullethit_flesh_01","bullethit_flesh_02","bullethit_flesh_03","bullethit_headshot"]
hit_sounds = ["bullethit_bricks_01", "bullethit_bricks_02", "bullethit_bricks_03",
	"bullethit_bricks_04", "bullethit_glass_01", "bullethit_glass_02",
	"bullethit_glass_03", "bullethit_metal_01",	"bullethit_metal_02", "bullethit_metal_03",
	"bullethit_nothing_01", "bullethit_nothing_02", "bullethit_nothing_03", "bullethit_plants_01",
	"bullethit_plants_02", "bullethit_plants_03", "bullethit_wood_01", "bullethit_wood_02",
	"bullethit_wood_03"]

__doc__= """The functions in this module will be called when certain weapon
events happen, like weapon fires a shot.

Nearly all functions here are very performance critical.
Only optimized code please :-).
"""

def on_weapon_reload(weapon_type,startx,starty,startz):
	"""Called when a weapon is reloaded.

Plays the reload sound for this weapon.

Parameters:
        startx,starty,startz - Position of the weapon.
        weapon_type          - Weapon type from scripts/itemdata/weapons.py.
"""
	# no effects? then nothing to do here
	if not objects.has_attribute(weapon_type, "effects"): return

	effects = objects.get_attribute(weapon_type, "effects")
	sounds.play_3d_sound(sfx_id=effects["sound_reload"], x=startx, y=starty, z=startz)

def on_weapon_unload(weapon_type,startx,starty,startz):
	"""Called when a weapon is unloaded.

Plays the unload sound for this weapon.

Parameters:
        startx,starty,startz - Position of the weapon.
        weapon_type          - weapon type from scripts/itemdata/weapons.py.
"""
	# no effects? then nothing to do here
	if not objects.has_attribute(weapon_type, "effects"): return

	effects = objects.get_attribute(weapon_type, "effects")
	sounds.play_3d_sound(sfx_id=effects["sound_unload"], x=startx, y=starty, z=startz)

def on_weapon_fire_multi(char, weapon_type,startx,starty,startz,endx,endy,endz):
	"""Called when a weapon fires a volley.

Plays the sound and gfx for the weapon.

Parameters:
        char                 - Char who is using the weapon.
        weapon_type          - Weapon type from scripts/itemdata/weapons.py.
        startx,starty,startz - Position of the weapon.
        endx,endy,endz       - Target that has been shot at.
"""
	# no effects? then nothing to do here
	if not objects.has_attribute(weapon_type, "effects"):
		print "no effects for weapon "+weapon_type
		return

	volley = objects.get_attribute(weapon_type, "salvenlaenge")
	weapon_id = character.get_primary_weapon(char)
	ammo = objects.get_attribute(weapon_id, "act_ammo_count")
	if ammo<volley: volley=ammo
	shot_per_second = objects.get_attribute(weapon_type, "feuergeschwindigkeit")/60		
	effects = objects.get_attribute(weapon_type, "effects")

	sounds.play_3d_sound(sfx_id=effects["sound_shot"], x=startx, y=starty, z=startz)

	if "flash_type" in effects:
		try:
			system.start_effect_object(object=char,node="Dummy_muzzleflash", parameter=[
				FX_MUZZLE_FLASH,
				volley,
				shot_per_second,
				effects["flash_type"],
				effects["flash_size"],
				effects["stream_type"],
				effects["stream_size"],
				effects["fade_out"]])
		except:
			pass

def on_weapon_fire_single(char, weapon_type,startx,starty,startz,endx,endy,endz):
	"""Called when a weapon fires a single shot.

Plays the sound and gfx for the weapon.

Parameters:
        char                 - Char who is using the weapon.
        weapon_type          - Weapon type from scripts/itemdata/weapons.py.
        startx,starty,startz - Position of the weapon.
        endx,endy,endz       - Target that has been shot at.
"""
	# no effects? then nothing to do here
	if not objects.has_attribute(weapon_type, "effects"):
		print "no effects for weapon "+weapon_type
		return
	effects = objects.get_attribute(weapon_type, "effects")

	shot_sound = effects["sound_shot"]
	sound_identifier = None
	if isinstance(shot_sound,list):
		sound_identifier = random.choice(shot_sound)
	else:
		sound_identifier = shot_sound

	sounds.play_3d_sound(sfx_id=sound_identifier, x=startx, y=starty, z=startz)

	if "flash_type" in effects: 
		try:
			system.start_effect_object(object=char,node="Dummy_muzzleflash", parameter=[
				FX_MUZZLE_FLASH,
				1,
				8.0,
				effects["flash_type"],
				effects["flash_size"],
				effects["stream_type"],
				effects["stream_size"],
				effects["fade_out"]])
		except:
			pass

			
def on_weapon_ignition(weapon_type,startx,starty,startz,endx,endy,endz):
	"""Called when a special "weapon" ignites.

So far only used for bombs (e.g., "SET_C4_REMOTE_CONTROL").
Plays the sound and gfx for the weapon.

Parameters:
        weapon_type          - Weapon type from scripts/itemdata/weapons.py.
        startx,starty,startz - Position of the weapon.
        endx,endy,endz       - Target/end point, usually equal to start.
"""
	print "on_weapon_ignition", weapon_type
	if objects.has_attribute(weapon_type, "bomb_type"):
		
		sounds.play_3d_sound(sfx_id="c4_small_explo", x=startx, y=starty, z=startz)

		system.start_effect(startx,starty,0,endx,endy,0,
			parameter=fx_explosion_big)

def on_weapon_misfire(char, weapon_type, startx, starty, startz, endx, endy, endz ):
	"""Called when a weapon misfires.

Plays the sound and gfx for the weapon.

Parameters:
        char                 - Char who is using the weapon.
        weapon_type          - Weapon type from scripts/itemdata/weapons.py.
        startx,starty,startz - Position of the weapon.
        endx,endy,endz       - Target that has been shot at.
"""
	# no effects? then nothing to do here
	if not objects.has_attribute(weapon_type, "effects"):
		print "no effects for weapon "+weapon_type
		return
	effects = objects.get_attribute(weapon_type, "effects")
	if "sound_gunjam" in effects:
		sounds.play_3d_sound(sfx_id=effects["sound_gunjam"], 
			x=startx, y=starty, z=startz)

def do_throw_weapon_fx(pShooter,pWeapon,pTarget,fTargetX,fTargetY,fTargetZ):
	"""Graphic effect, sound, and damage distribution for throw weapons.

Parameters:
        pShooter                   - Id of the char using the weapon.
        pWeapon                    - Id of the weapon.
        pTarget                    - Id of the target.
        fTargetX,fTargetY,fTargetZ - Position where the thrown weapon lands.
"""
	#objects.set_attribute(target_id, "hitpoints", hitpoints)
	print "do_throw_weapon_fx"
	animation_type = objects.get_attribute(pWeapon, "fire_animation")
	if animation_type in [FPA_THROW_GRENADE,FPA_SHOULDER_BASED]:
		fx_object_id = random.choice([fx_explosion])
		system.start_effect( 
			startx=fTargetX,starty=fTargetY,startz=fTargetZ,
			dirx=0,diry=0,dirz=1,
			parameter=fx_object_id)
		sounds.play_3d_sound( "grenade_explo_frag", fTargetX, fTargetY, fTargetZ )
		radius=amount_of_piercing=value_structure=value_organic=0.0
		if objects.has_attribute(pWeapon, "munitionsarten"):
			ammo = objects.get_attribute(pWeapon, "munitionsarten")[0]
			if objects.has_attribute(ammo, "schaden_organisch_max") and objects.has_attribute(ammo, "schaden_organisch_min"):
				value_organic = random.randint(objects.get_attribute(ammo, "schaden_organisch_min"), objects.get_attribute(ammo, "schaden_organisch_max"))
			if objects.has_attribute(ammo, "schaden_struktur_max") and objects.has_attribute(ammo, "schaden_struktur_min"):
				value_structure = random.randint(objects.get_attribute(ammo, "schaden_struktur_min"), objects.get_attribute(ammo, "schaden_struktur_max"))
			if objects.has_attribute(ammo, "durchschlag"):
				amount_of_piercing = objects.get_attribute(ammo, "durchschlag")
			if objects.has_attribute(ammo, "wirkungsbereich"):
				radius = objects.get_attribute(ammo, "wirkungsbereich")
		system.hit_objects_in_ambit( pShooter, fTargetX, fTargetY, fTargetZ, radius, amount_of_piercing, 0, value_structure, value_organic, pWeapon )

	if animation_type in [FPA_THROW_KNIFE]:
		sounds.play_3d_sound( random.choice(flesh_wound_sounds), fTargetX, fTargetY, fTargetZ )
		if objects.has_attribute(pWeapon, "munitionsarten"):
			ammo = objects.get_attribute(pWeapon, "munitionsarten")[0]
		if pTarget != "":
			if(objects.has_attribute(pTarget,"type")): #early out if target is no meatbag
				if objects.get_attribute(pTarget, "type") in ["character", "animal"]:
					objects.do_hit_via_weapon( pTarget, pShooter, pWeapon, ammo )
				if hasattr(data("zone_1.zone_1"), "training_pappkameraden"):
					if filter(lambda x: x in pTarget, data("zone_1.zone_1").training_pappkameraden):
						# special case: "pappkameraden" in z1 should be hitable by knifes
						objects.do_hit_via_weapon( pTarget, pShooter, pWeapon, ammo )
					
def do_weapon_hit_fx( weapon_id, location, location_normal, hit ):
	"""Graphic effect and sound for some special weapons.

The hit parameter only specifies that the intended target was missed. The other
parameters are still valid.

Parameters:
        weapon_id			- id of the weapon.
		location			- location of the hitted surface
		location_normal		- normal of the surface at the hitted location
		hit					- true if hit; false if missed target
"""
	if(objects.get_attribute(weapon_id,"typeid")=="SET_M_79" or \
		objects.get_attribute(weapon_id,"typeid")=="SET_M_16_M203_UNDERGUN" or \
		objects.get_attribute(weapon_id,"typeid")=="SET_AK_74_BG_15_UNDERGUN" or \
		objects.get_attribute(weapon_id,"typeid")=="SET_GMG_OCSW" or \
		objects.get_attribute(weapon_id,"typeid")=="SET_OICW_UNDERGUN"):	# [BrainRipper]
		fx_object_id = random.choice([fx_explosion])
		system.start_effect( 
			startx=location[0],starty=location[1],startz=location[2],
			dirx=location_normal[0],diry=location_normal[1],dirz=location_normal[2],
			parameter=fx_object_id)
		sounds.play_3d_sound( "grenade_explo_frag", location[0], location[1], location[2] )
	else:
		if objects.get_attribute(weapon_id,"weapon_type") in ["leicht","schwer","sniper"]:
			if hit:
				sounds.play_3d_sound( random.choice(flesh_wound_sounds), location[0], location[1], location[2]) 
			else:
				sounds.play_3d_sound( random.choice(hit_sounds), location[0], location[1], location[2])
				system.start_effect( 
					startx=location[0],starty=location[1],startz=location[2],
					dirx=location_normal[0],diry=location_normal[1],dirz=location_normal[2],
					parameter=[FX_BULLET_HIT,0,0,0.25] )

def do_explosives_dam(pShooter,pWeapon):
	"""Calculates and distributes the area damage for bombs.

Parameters:
        pShooter                   - Id of the char using the weapon.
        pWeapon                    - Id of the weapon.
"""
	radius=amount_of_piercing=value_structure=value_organic=0.0
	typeid = objects.get_attribute(pWeapon,"typeid")

	radius=7.5
	amount_of_piercing=200
	value_structure=random.randint(400, 500)
	value_organic=random.randint(150, 250)
	if objects.has_attribute(typeid, "wirkungsbereich"):
		radius = objects.get_attribute(typeid, "wirkungsbereich")/2.0
	else: warning("unknown explosiv '%s'" % typeid)
	if objects.has_attribute(typeid, "durchschlag"):
		amount_of_piercing = objects.get_attribute(typeid, "durchschlag")
	else: warning("unknown explosiv '%s'" % typeid)
	if objects.has_attribute(typeid, "schaden_organisch_min") and objects.has_attribute(typeid, "schaden_organisch_max"):
		_min = objects.get_attribute(typeid, "schaden_organisch_min")
		_max = objects.get_attribute(typeid, "schaden_organisch_max")
		value_organic=random.randint(_min, _max)
	else: warning("unknown explosiv '%s'" % typeid)
	if objects.has_attribute(typeid, "schaden_struktur_min") and objects.has_attribute(typeid, "schaden_struktur_max"):
		_min = objects.get_attribute(typeid, "schaden_struktur_min")
		_max = objects.get_attribute(typeid, "schaden_struktur_max")
		value_structure=random.randint(_min, _max)
	else: warning("unknown explosiv '%s'" % typeid)

	if objects.has_attribute(pWeapon,"max_explosive_effect"):
		factor = objects.get_attribute(pWeapon,"max_explosive_effect")
		factor = 1.0 + factor / 100.0
		value_structure=value_structure*factor
		value_organic=value_organic*factor
	system.hit_objects_in_ambit( pShooter, objects.get_x(pWeapon), objects.get_y(pWeapon), 0, radius, amount_of_piercing, 0, value_structure, value_organic, pWeapon)

