# -*- coding: utf-8 -*-
import global_defines
from global_defines import data
from global_defines import Lambda
from global_defines import is_water_repository
from global_defines import give_first_use_exp
from global_defines import kill_type_list
from global_defines import kill_points
from global_defines import Fire_Modes_Char
import character
import objects
import globaltext
import system
import comments
import skill_tables
import grids
import string
import math
import music
import global_character
import global_item
import random
import sounds
import dialog
import timerepr
import vehicle
import water
import combos
import zone_ambients
import bonus
import options
combos=combos # dummy to prevent pyChecker warning; combos module is used in eval calls

__doc__ = """This module contains all handlers for events related to characters.
Together they supply the default behavior of characters.

Nearly all functions here can be overloaded by the zone script. When you do this, it 
is your responsibility to ensure the overloading function implements the necessary behavior
or calls the default handler.

2 functions work differently in zone script:
        on_examine_object
        on_gut_object
These functions need to return True or False:
        True  - Stops calling of standard behavior.
        False - Calls the standard functions(object_event).
"""

def helper_get_weapon_accustom(weapon_accustom):
	"Helper function for get_idcard_reputation"
	max_accustom = 20.0
	accustom_percent =  (weapon_accustom / max_accustom) * 100
	text_id_accustom = globaltext.MISSION_EXTENDED_HINT_WEAPON_ACCUSTOM_0
	if accustom_percent > 24: 
		text_id_accustom  = globaltext.MISSION_EXTENDED_HINT_WEAPON_ACCUSTOM_1
	if accustom_percent > 49: 
		text_id_accustom  = globaltext.MISSION_EXTENDED_HINT_WEAPON_ACCUSTOM_4
	if accustom_percent > 74: 
		text_id_accustom  = globaltext.MISSION_EXTENDED_HINT_WEAPON_ACCUSTOM_5
	if accustom_percent > 99: 
		text_id_accustom  = globaltext.MISSION_EXTENDED_HINT_WEAPON_ACCUSTOM_6
	return text_id_accustom

def get_idcard_reputation( id, element ):
	"""Returns the text for the reputation page in the id card."""
	kill_stats = get_kill_stats(id)
	if element=="title":
		return globaltext.MISSION_IDCARD_REPUTATION
	elif element=="stats":
		rep = kill_stats["REPUTATION"]
		rep_bonus = skill_tables.get_reputation_bonus_per_killpoints(rep)
		rep_desc = skill_tables.get_reputation_description(rep)
		return globaltext.MISSION_IDCARD_REPUTATION_STATS % {"value1": rep_desc, "value2": rep_bonus}
	elif element=="list_header_1":
		kills=0
		type_lst = ["DESERT_MONKS","RAT_SKULLS","SEEKER","INDIANS","NOMADS","SHADOWS","GNO_SOLDIERS","MISC_NPCS","UNKNOWN_NPCS"]
		for act_type in type_lst:
			textidentifier = "KILL_TYPE_" + act_type
			if hasattr(globaltext, textidentifier):
				if kill_stats[act_type] > 0:
					kills+=kill_stats[act_type]
		return (globaltext.MISSION_IDCARD_REPUTATION_LIST_1 +" " +str(kills))
	elif element=="list_header_2":
		kills=0
		type_lst =  ["WOLF","BEAR","WARG","TIGER","WILDDOG","PEACEFUL_ANIMALS","UNKNOWN_ANIMALS"]
		for act_type in type_lst:
			textidentifier = "KILL_TYPE_" + act_type
			if hasattr(globaltext, textidentifier):
				if kill_stats[act_type] > 0:
					kills+=kill_stats[act_type]
		return (globaltext.MISSION_IDCARD_REPUTATION_LIST_2 +" "+str(kills))
	elif element=="list_header_3":
		return globaltext.MISSION_IDCARD_REPUTATION_LIST_3
	elif element=="list_header_4":
		return globaltext.MISSION_IDCARD_REPUTATION_LIST_4
	elif element=="list_1":
		lst = []
		type_lst = ["DESERT_MONKS","RAT_SKULLS","SEEKER","INDIANS","NOMADS","SHADOWS","GNO_SOLDIERS","MISC_NPCS","UNKNOWN_NPCS"]
		for act_type in type_lst:
			textidentifier = "KILL_TYPE_" + act_type
			if hasattr(globaltext, textidentifier):
				if kill_stats[act_type] > 0:
					lst.append([getattr(globaltext, textidentifier), str(kill_stats[act_type])])
		return lst
	elif element=="list_2":
		lst = []
		type_lst = ["WOLF","BEAR","WARG","TIGER","WILDDOG","PEACEFUL_ANIMALS","UNKNOWN_ANIMALS"]
		for act_type in type_lst:
			textidentifier = "KILL_TYPE_" + act_type
			if hasattr(globaltext, textidentifier):
				if kill_stats[act_type] > 0:
					lst.append([getattr(globaltext, textidentifier), str(kill_stats[act_type])])
		return lst
	elif element=="list_3":
		lst = []
		weapon_type_history = {}
		if objects.has_attribute(id, "weapon_type_history"):
			weapon_type_history = objects.get_attribute(id, "weapon_type_history")

		final_data = []
		for weapon_type in weapon_type_history:
			type_kills = weapon_type_history[weapon_type]
			type_kills = sum(type_kills)
			final_data.append((type_kills,weapon_type))

		final_data.sort()
		final_data.reverse()
		final_data = final_data[0:9]
		for id in final_data:
			lst.append([objects.get_attribute(id[1], "name"), helper_get_weapon_accustom(skill_tables.weapon_accustoming(0,id[0]))])

		return lst
	elif element=="list_4":
		lst = []
		weapon_id_history = {}

		if objects.has_attribute(id, "weapon_id_history"):
			weapon_id_history = objects.get_attribute(id, "weapon_id_history")

		final_data = []
		for weapon_id in weapon_id_history:
			if objects.is_in_inventory(weapon_id):
				id_kills = weapon_id_history[weapon_id]
				id_kills = sum(id_kills)
				final_data.append((id_kills, weapon_id))

		final_data.sort()
		final_data.reverse()
		final_data = final_data[0:6]
		
		for id in final_data:
			nickname = globaltext.MISSION_EXTENDED_HINT_WEAPON_NICK_NAME_VALUE_NONE
			if objects.has_attribute(id[1], "nickname"):
				nickname = objects.get_attribute(id[1], "nickname")
			lst.append([objects.get_attribute(id[1], "name")+" ("+nickname+") ", helper_get_weapon_accustom(skill_tables.weapon_accustoming(id[0],0))])
			
		return lst
	return None

def get_vehicle_entry_exit_animation( vehicle_type , seat, type, character ):
	"""Returns the animation that should be played when the vehicle is entered or exited.

Parameters:
        vehicle_type - Type of vehicle (vehicles.py)
        seat         - Seat the char will occupy/has occupied (e.g., "seat_1").
        type         - "entry" or "exit".
        character    - Id of the char.
"""
	attribute = None
	if type=="entry":
		attribute = "get_in_animations"
	elif type=="exit":
		attribute = "get_out_animations"
	else:
		raise ValueError, "unknown animation type" 
	if objects.has_attribute( vehicle_type, attribute):
		get_in_out_animations = objects.get_attribute( vehicle_type, attribute)
		if seat in get_in_out_animations:
			if character:
				return get_in_out_animations[seat][0]
			else:
				return get_in_out_animations[seat][1]
	return ""

def get_random_name( gender ):
	"""Returns a random, gender-specific ALTER_EGO name.

Parameters:
        gender - "male" or "female".
"""
	resource_id = None
	if gender=="male":
		resource_id = "globaltext.NAME_AE_MALE_"+str(random.randint(1,20))
	elif gender == "female":
		resource_id = "globaltext.NAME_AE_FEMALE_"+str(random.randint(1,20))
	else: raise ValueError, "unknown gender"

	if resource_id:
		name = eval(resource_id)
		if name:
			return name
		else: raise ValueError
	else: raise ValueError

	return None

def check_talents( id, skill ):
	"""Checks (and corrects) the number of talents the char has in this skill.

This is used by system_events.on_post_load to correct a bug with some older savegames.

Parameters:
        id    - Id of the char.
        skill - Skill to check.
"""
	attr = skill+"_"+"talents"
	_max = get_talent_skills(id, skill, True)
	act_talents = global_defines.helper_get_talents( id , skill )
	if len(act_talents)>_max:
		act_talents = act_talents[0:_max]
		objects.set_attribute( id , attr, act_talents )

def create_default_talents( id, skill ):
	"""If the char hasn't enough talents for this skill, he gets some default 
talents assigned.

Used by the id card panel.

Parameters:
        id    - Id of the char.
        skill - Skill to check.
"""
	attr = skill+"_"+"talents"
	if not objects.has_attribute( id , attr ):
		objects.set_attribute( id , attr, [] )
	while (get_talent_skills(id, skill, False)):
		talents = objects.get_attribute( id , attr  )
		available = get_available_talents(id, skill)
		if (len(available)):
			talents.append(available[0])
			objects.set_attribute( id , attr ,talents )

def get_available_talents( id , skill ):
	"""Returns a list of talents the char can learn for this skill.

Parameters:
        id    - Id of the char.
        skill - Skill to check.
"""
	talents = None
	value = objects.get_attribute( id , skill )
	value -= get_temp_bonus_for_skill(id, skill)
	if (value >=99): talents = global_defines.all_talents[skill][0:5]
	elif (value >=85): talents = global_defines.all_talents[skill][0:4]
	elif (value >=75): talents = global_defines.all_talents[skill][0:3]
	else: return []
	attr = skill+"_"+"talents"
	if not objects.has_attribute( id , attr ):
		objects.set_attribute( id , attr, [] )
	char_talents = objects.get_attribute( id , attr )
	available_talents = filter(lambda source: not source in char_talents, talents)
	return available_talents

def get_talent_skills( id, skill, ignore_existing_talents ):
	"""Returns the number of talents for this skill.

Parameters:
        id                      - Id of the char.
        skill                   - Skill to check.
        ignore_existing_talents - True returns only number of new talents.
"""
	value = objects.get_attribute( id , skill )
	value -= get_temp_bonus_for_skill(id, skill)
	attr = skill+"_"+"talents"
	if not objects.has_attribute( id , attr ):
		objects.set_attribute( id , attr, [] )
	talents = objects.get_attribute( id , attr )
	count = 0
	if (value >=75 and (len(talents) < 1 or ignore_existing_talents)): count+=1 
	if (value >=85 and (len(talents) < 2 or ignore_existing_talents)): count+=1
	if (value >=99 and (len(talents) < 3 or ignore_existing_talents)): count+=1
	return count

def get_max_skill_value(char, skill):
	"""Returns the max value for this skill.

This is normally 99, but it can be higher with weapon customization.

Parameters:
        char  - Id of the char.
        skill - Skill to check.
"""
	bonus = get_temp_bonus_for_skill(char, skill)
	return 99 + bonus

def get_max_attribute_value(char, attribute):
	"""Returns the max value for this skill.

This is normally 20, but it can be lower with fatigue.

Parameters:
        char  - Id of the char.
        attribute - Attribute to check.
"""
	bonus = get_temp_bonus_for_attribute(char, attribute)
	return 20 + bonus

def get_temp_bonus_for_attribute(char, att):
	"""Helper function for get_max_skill_value.

Parameters:
        char  - Id of the char.
        skill - Skill to check.
"""
	return bonus.get_temp_bonus(char, att)


def get_temp_bonus_for_skill(char, skill):
	"""Helper function for get_max_skill_value.

Parameters:
        char  - Id of the char.
        skill - Skill to check.
"""
	return bonus.get_temp_bonus(char, skill)

def get_hint_text( ids ):
	"""Generates the hint text (i.e., mouse over text/tooltip) for this object.

Parameters:
        id - Id of the object.
"""
	id = ids[0]
	data = None
	if objects.get_attribute(id, "type")=="equipment":
		data = item_hint_collection ( ids )			
	else:
		data = character_hint_collection(ids)
	return data

def get_attribute_skill_text( id, attribute, value ):
	"""Returns UI display strings for the attribute &amp; skill effects.

See skill_tables.get_attribute_skill_text(id, attribute, value ).
"""
	return skill_tables.get_attribute_skill_text(id, attribute, value )

def get_trade_text( trader_id, character_id, value ):
	"""Returns UI display strings for the charisma trading effects.
        
See skill_tables.get_trade_text( trader_id, character_id, value ).
"""
	return skill_tables.get_trade_text( trader_id, character_id, value )

def get_load_text( character_id ):
	"""Called if an update of the load display in the character detail panel is forced.

Parameters:
        character_id - Id of the character.
"""
	load = float(character.get_load( char=character_id ))
	strength = objects.get_attribute( object=character_id, attribute="strength" )

	if strength>0:
		relload = load / skill_tables.strength_max_load(strength)
	else:
		relload = 0

	text = "%.0f %s / %.0f %s (%.0f%%)" % (load,
						globaltext.MEASUREMENT_WEIGHT,
						skill_tables.strength_max_load(strength),
						globaltext.MEASUREMENT_WEIGHT,
						relload * 100)
	return text

def on_attribute_change( object_id, attribute_name, new_value, old_value ):
	# print 'on_attribute_change(', object_id, attribute_name, new_value, old_value ,')'
	"""Called if an attribute of an object changes.

Parameters:
        object_id      - Id of the object.
        attribute_name - Name of attribute.
        new_value      - New attribute value.
        old_value      - Old attribute value.
"""
	if attribute_name in skill_tables.attributes or attribute_name in skill_tables.skills:
		if type(new_value) != int:
			raise ValueError, "char '%s': value for attribute '%s' must be <type 'int'> but it is '%s'" % (object_id, attribute_name, type(new_value))
		if attribute_name in skill_tables.attributes:
			assert new_value >= 1 and new_value <= get_max_attribute_value(object_id, attribute_name)\
			, "char '%s': attribute '%s' must be 1 <= att <= %s, but it is: %s" % (object_id, attribute_name, get_max_attribute_value(object_id, attribute_name), str(new_value))

	if attribute_name=="constitution":
		if objects.has_attribute( object_id, "char_creation"):
			value = objects.get_attribute( object_id, "char_creation")
			if value:
				calc_life_energy_start( object_id, new_value, old_value)
	elif attribute_name=="strength":
		# update speed
		update_speed( object_id )
	elif attribute_name=="agility":
		calc_armor_value( object_id )
		# update speed
		update_speed( object_id )
	elif attribute_name=="trader":
		objects.set_immortal_state( object_id, new_value )
		if new_value:
			objects.set_attribute(object_id, "inventory_overstock_behaviour", "enlarge_inventory")
		else:
			objects.set_attribute(object_id, "inventory_overstock_behaviour", "drop_item")
	elif attribute_name=="experience":
		calc_level( object_id , new_value, old_value )
		system.update_ui()
	elif attribute_name=="level":
		if (object_id in system.get_pcs() and
			old_value>0):
			sounds.play_2d_sound("level_up")
			system.update_ui()
			calc_life_energy( object_id , new_value, old_value )
		elif object_id in system.get_npcs():
			calc_npc_attribute_skills( object_id , new_value, old_value )
			calc_npc_le( object_id , new_value, old_value )
		elif object_id in system.get_animals():
			calc_npc_le( object_id , new_value, old_value )
			level = objects.get_attribute(object_id, "level")
			if level >= 1:
				typeid = objects.get_attribute(object_id, "typeid")
				damage = skill_tables.animal_damage_per_level(typeid, level)
				piercing = skill_tables.animal_armor_piercing_per_level(typeid, level)
				objects.set_attribute(object_id, "damage_base", damage[0])
				objects.set_attribute(object_id, "damage_dice", damage[1] - damage[0] + 1)
				objects.set_attribute(object_id, "piercing", piercing)
	elif attribute_name=="body_feature":
		if object_id=="ALTER_EGO":
			calc_body_feature( object_id, new_value, old_value )
	elif attribute_name=="experience_of_life":
		if object_id=="ALTER_EGO":
			calc_experience_of_life( object_id, new_value, old_value )
	elif attribute_name=="name":
		if object_id in system.get_pcs():
			system.update_ui()
	elif attribute_name=="generic_item":
		if objects.has_attribute( object_id, "item_type" ):
			object_type = objects.get_attribute( object_id, "item_type" )
			if object_type == "weapon":
				# if a weapon is set as a quest item
				# then its quality is set to 100%
				if not new_value:
					objects.set_attribute( object_id, "quality", 100 )
	elif attribute_name=="bodymode":
		calc_perception_values(object_id)
		update_speed(object_id)
		if has_talent(object_id, "sniper_weapons", "camouflage"):
			if character.get_body_mode(object_id)=="LIE":
				system.add_text(globaltext.TALENT_SNIPER_CAMOUFLAGE_ON % {"char": objects.get_attribute(object_id, "name")})
			else:
				system.add_text(globaltext.TALENT_SNIPER_CAMOUFLAGE_OFF % {"char": objects.get_attribute(object_id, "name")})
		if has_talent(object_id, "sneak", "camouflage"):
			if character.get_body_mode(object_id)=="LIE" or character.get_body_mode(object_id)=="KNEEL":
				system.add_text(globaltext.TALENT_SNEAK_CAMOUFLAGE_ON % {"char": objects.get_attribute(object_id, "name")})
			else:
				system.add_text(globaltext.TALENT_SNEAK_CAMOUFLAGE_OFF % {"char": objects.get_attribute(object_id, "name")})
	elif attribute_name=="sneak":
		calc_perception_values(object_id)
	elif attribute_name=="foes":
		if type(new_value)==list and objects.get_party(object_id) in new_value:
			print "objects.get_attribute('%s', 'foes') = %s" % (object_id, repr(objects.get_attribute(object_id, "foes")))
			objects.set_attribute(object_id, "foes", None)
			raise ValueError, "'%s' is foe to his/her own party ('%s')!" % (object_id, objects.get_party(object_id))
	elif attribute_name.endswith("_talents"):
		helper_update_talent_effects( object_id )

def on_equipment_add( object_id, equipment_id ):
	"""Called if an item is added to the character inventory.

Parameters:
        character_id - Id of the character.
        equipment_id - Id of the item.
"""
	if character.exists( object_id ):
		character_id = object_id
		
		if objects.has_attribute(equipment_id, "weapon_type"):
			if objects.get_attribute(equipment_id, "weapon_type")=="wurf":
				if objects.get_attribute(equipment_id, "act_ammo_count") != 1:
					objects.set_attribute(equipment_id, "act_ammo_count", 1)
		
		# test if it is an explosiv that we can't handle
		if not test_explosion(character_id, equipment_id):
			# update speed and allowed moves
			update_speed( character_id )
			comments.on_equipment_add( character_id, equipment_id )

def on_equipment_remove( object_id, equipment_id ):
	"""Called if an item is removed from the character inventory.

Parameters:
        character_id - Id of the character.
        equipment_id - Id of the item.
"""

	if character.exists( object_id ):
		character_id = object_id
		
		# update speed and allowed moves
		update_speed( character_id )
	
	if objects.has_attribute(object_id, "typeid"):
		animal = objects.get_attribute(object_id, "typeid")
		if animal == "WARG" and objects.has_attribute( object_id, "has_head_in_inventory" ):
			# check if warghead is taken
			if not "SET_WARG_HEAD" in objects.get_inventory_list( object_id ):
				objects.set_attribute( object_id, "has_head_in_inventory", None )
				# replace the warg with the head with one without it,-)
				# first save old warg data
				x = objects.get_x( object_id )
				y = objects.get_y( object_id )
				direction = objects.get_direction( object_id )
				
				objects.set_active_state( object_id, False )
				new_warg = system.create_object( "RES3D_WARGKADAVER_KOPFLOS", x, y, object_id + "_HEADLESS", direction )
				objects.set_attribute( new_warg, "disembowl_level", objects.get_attribute( object_id, "disembowl_level" ) )
				
				for item in objects.get_inventory_id_list( object_id ):
					typeID = objects.get_attribute(item, "typeid")
					itemId = objects.create_item_in_inventory( new_warg, typeID)
					objects.set_attribute(item, "WARG_DOUBLE_ITEM", [new_warg, itemId])
				
		#Notwendig um duplizierten Gegentand in der Warg Kopie zu entfernen. Denn die Gegenstände werden in die
		#kopflose Kopie übernommen, egal ob diese schon aufgenommen wurden, oder nicht.
		elif animal == "WARG":
			if objects.has_attribute(equipment_id, "WARG_DOUBLE_ITEM"):
				old_warg = objects.get_attribute(equipment_id, "WARG_DOUBLE_ITEM")
				if old_warg[1] in objects.get_inventory_id_list(old_warg[0]):
					objects.remove_item_from_inventory(old_warg[0], old_warg[1])
				objects.set_attribute(equipment_id, "WARG_DOUBLE_ITEM", None)

def can_climb( character_id, object_id ):
	"""Returns True if the character can climb the object.

Parameters:
        character_id - Id of the character.
        object       - Id of the object to climb.
"""
	return True

def can_entertain( character_id, object_id ):
	"""Returns True if the character can entertain the target.

Parameters:
        character_id - Id of the character.
        object_id    - Id of the target character.
"""
	if has_talent(character_id, "speech", "entertainment") and character_id != object_id:
		if not 	objects.has_attribute(object_id,"was_entertained"):
			if objects.is_npc(object_id)and not objects.has_attribute(object_id,"foes"):
				if not objects.is_destroyed(object_id) and not objects.is_unconscious(object_id):
					return True
	return False

def can_tune( character_id, object_id ):
	"""Returns True if the character can tune the object(vehicle).

Parameters:
        character_id - Id of the character.
        object       - Id of the car to tune.
"""
	if not has_talent( character_id, "technic", "tuning" ):
		return False
	if objects.has_attribute(object_id, "tuned"):
		if objects.get_attribute(object_id, "tuned"):
			return False
	if objects.has_attribute(object_id, "type"):
		_type = objects.get_attribute(object_id, "type")
		if _type=="vehicle":
			return True
	return False
def tune( character_id, object_id ):
	"""Tune the car.

Parameters:
        character_id - Id of the character.
        object       - Id of the car to tune.
"""
	character.play_animation( character_id, "STEHEND_TUERSCHLOSS_KNACKEN" )
	objects.set_attribute(object_id,"tuned",True)

	give_first_use_exp(character_id, "technic", "tuning")

def get_dumdum_variant(char, ammo):
	"""Returns the dumdum variant that the char can make of the given ammo.
	
Parameters:
        char - Id of the character.
        ammo - Id of the ammo pack (must be in chars inventory).
Returns:
	If dumdum variant has been found:
	(dumdum_item_type, [needed/used items])
	e.g. ('SET_AMMOPACK_38_DUMDUM', ['TEST_EQU_SET_AMMOPACK_38_100028','TEST_EQU_SET_RASP_100007'])
	If no dumdum variant has been found or none can be build:
	False, []
"""
	if not has_talent(char, "technic", "manipulate_munition"): return False, []
	if not objects.has_attribute(ammo, "item_type"): return False, []
	if objects.get_attribute(ammo, "item_type") != "ammo": return False, []
	if not objects.has_attribute(ammo, "typeid"): return False, []
	typeid = objects.get_attribute(ammo, "typeid")
	variants = filter(lambda x: typeid in x and "DUMDUM" in x and x != typeid, system.get_item_list())
	if not variants: return False, []
	
	for variant in variants:
		if not objects.has_attribute(variant, "item_combination"): continue
		combine = objects.get_attribute(variant, "item_combination")
		
		if "difficulty_assemble" in combine:
			if combine["difficulty_assemble"] > objects.get_attribute(char, "technic"):
				continue

		if "combination_list" in combine:
			for item_list in combine["combination_list"]:
				hit = True
				inv = objects.get_inventory_list(char)[:] # need a copy
				inv_ids = objects.get_inventory_id_list(char)[:] # need a copy
				return_list = [ammo]
				for item in item_list:
					if item != typeid:
						if item not in inv:
							hit = False
							break
						else:
							item_id = inv_ids[inv.index(item)]
							return_list.append(item_id)
							inv.remove(item)
							inv_ids.remove(item_id)
							
				if hit:
					return variant, return_list

	return False, []

def can_manipulate_munition(char, ammo):
	"""Returns True if the character can change the ammo to dumdum.

Parameters:
        char - Id of the character.
        ammo - Id of the ammo.
"""
	dumdum, item_list = get_dumdum_variant(char, ammo)
	if not dumdum or not item_list: return False
	return True

def on_manipulate_munition(char, ammo):
	"""Exchanges the ammo with dumdum.

Parameters:
        char - Id of the character.
        ammo - Id of the ammo.
"""
	slot_nr = -1
	inventory = objects.get_inventory_ids(char)
	dumdum, item_list = get_dumdum_variant(char, ammo)
	if not dumdum or not item_list: return
	item_list.remove(ammo)
	combo_list = []
	for slot in inventory:
		slot_nr += 1
		ammos = slot[0]
		if ammo in ammos:
			for item in ammos:
				_item_list = item_list[:]
				_item_list.append(item)
				combo_list.append(_item_list)
			break
	on_combine(char, combo_list)

def can_stronger_armor( character_id, object_id ):
	"""Returns True if the character can increase armor value of an armor.

Parameters:
        character_id - Id of the character.
        object_id    - Id of the armor to improve.
"""
	if not objects.has_attribute(object_id, "armor"): return False
	if not objects.has_attribute(object_id, "occupied_slots"): return False
	if objects.has_attribute(object_id, "stronger_armor"):
		if objects.get_attribute(object_id, "stronger_armor"): return False

	if has_talent(character_id, "technic", "stronger_armor"):
		if 'clothes' in objects.get_attribute(object_id, 'occupied_slots'):
			return True
	
	if has_talent(character_id, "technic", "stronger_armor_parts"):
		if objects.get_attribute(object_id, 'occupied_slots')[0] in ['gloves', 'helm', 'boots']:
			return True
	
	return False
	
def on_stronger_armor(character_id, object_id):
	"""Increase strength of armor by 1 point.

Parameters:
        character_id - Id of the character.
        object       - Id of the armor.
"""
	if not can_stronger_armor(character_id, object_id): return

	armor = objects.get_attribute(object_id, 'armor')
	objects.set_attribute(object_id, 'armor', armor + 1)
	objects.set_attribute(object_id, 'stronger_armor', True)
	calc_armor_value(character_id)

	if 'clothes' in objects.get_attribute(object_id, 'occupied_slots'):
		give_first_use_exp(character_id, "technic", "stronger_armor")
	elif objects.get_attribute(object_id, 'occupied_slots')[0] in ['gloves', 'helm', 'boots']:
		give_first_use_exp(character_id, "technic", "stronger_armor_parts")

def can_repair_vehicle(character_id, object_id):
	"""Returns True if the char can repair the vehicle.

Parameters:
        character_id - Id of the character.
        object       - Id of the vehicle.
"""
	if objects.has_attribute(object_id, "type"):
		_type = objects.get_attribute(object_id, "type")
		if _type=="vehicle" and objects.get_attribute(object_id,"hitpoints")\
		< objects.get_attribute(object_id,"maxhitpoints") and\
		has_talent(character_id, "driving", "repair_vehicles") and \
		not objects.get_att ( object_id, "destroy_model" ) : # To prevent repairing of destroyed car.
			return True
	return False
	
def on_repair_vehicle(character_id, object_id):
	"""Called when the char repairs the vehicle.

Parameters:
        character_id - Id of the character.
        object       - Id of the vehicle.
"""
	objects.set_attribute(object_id,"hitpoints",objects.get_attribute(object_id,"maxhitpoints"))
	mode = character.get_body_mode(character_id)
	if mode == "KNEEL":
		character.change_body_mode(character_id, "STAND")
	if mode == "LIE":
		character.change_body_mode(character_id, "STAND")
	character.play_animation( character_id, "CM_NPC_MOTORRAD_SCHRAUBEN_START" )
	character.play_animation( character_id, "CM_NPC_MOTORRAD_SCHRAUBEN_LOOP_1" )
	character.play_animation( character_id, "CM_NPC_MOTORRAD_SCHRAUBEN_ENDE" )

def can_teach(teacher, student):
	"""Returns True if the char can teach the target.

Parameters:
        character_id - Id of the character.
        object_id    - Id of the target character.
"""
	if has_talent(teacher, "speech", "teach") and teacher != student:
		if objects.is_pc(student):
			if objects.has_attribute(student, "taught_by"):
				if teacher in objects.get_attribute(student, "taught_by"):
					return False
			if get_teach_skill(teacher, student):
				return True
	return False

def get_teach_skill(teacher, student):
	"""Helper function for teaching.

Returns the best teachable skill of the char or None if no skill is teachable.

Parameters:
        teacher - Id of the teacher.
        student - Id of the student.
"""
	teach_skill = None
	teach_skill_value = 0
	for skill in skill_tables.skills:
		value_teacher = objects.get_attribute(teacher, skill) - get_temp_bonus_for_skill(teacher, skill)
		value_student = objects.get_attribute(student, skill) - get_temp_bonus_for_skill(student, skill)
		if value_teacher >= teach_skill_value and value_teacher >= value_student + 5 and value_student < 94:
			if value_teacher == teach_skill_value and teach_skill:
				# in case of equal top skills choose randomly
				if random.choice((True, False)):
					continue
			teach_skill = skill
			teach_skill_value = value_teacher
	return teach_skill

def on_teach(teacher, student):
	"""Called when the char teaches the target.

Parameters:
        character_id - Id of the character.
        object       - Id of the target character.
"""
	skill = get_teach_skill(teacher, student)
	if skill:
		value_student = objects.get_attribute(student, skill)
		objects.set_attribute(student, skill, value_student + 5)
		taught_by = []
		if objects.has_attribute(student, "taught_by"):
			taught_by = objects.get_attribute(student, "taught_by")
		taught_by.append(teacher)
		objects.set_attribute(student, "taught_by", taught_by)
		if objects.get_attribute(student,"gender") == "female":
			system.add_text(globaltext.PC_TEACHES_PC_F % {"char": objects.get_attribute(student, "name"),"skill": skill_tables.get_attribute_skill_text(teacher,skill,"name"),"char2": objects.get_attribute(teacher, "name") })
		else:
			system.add_text(globaltext.PC_TEACHES_PC % {"char": objects.get_attribute(student, "name"),"skill": skill_tables.get_attribute_skill_text(teacher,skill,"name"),"char2": objects.get_attribute(teacher, "name") })

def on_entertainment(character_id, object_id):
	"""Called when the char entertains the target.

Parameters:
        character_id - Id of the character.
        object       - Id of the target character.
"""
	item_type = get_random_item()
	objects.create_item_in_inventory(character_id, item_type)
	objects.set_attribute(object_id,"was_entertained",True)
	system.add_text(globaltext.PC_ENTERTAINS_NPC % {"char": objects.get_attribute(character_id, "name") })

def can_repair( character_id, items ):
	"""Returns True if the item can be repaired.

Parameters:
        character_id - Id of the character.
        items        - List of size one with the id of the item.
"""
	if len(items)==1:
		item = items[0]
		if has_talent(character_id, "technic", "repair_weapons"):
			if objects.has_attribute(item, "item_type"):
				if objects.get_attribute(item, "item_type")=="weapon":
					if objects.has_attribute(item, "quality"):
						if objects.get_attribute(item, "quality") < 100:
							return True
	return False

def on_repair( character_id, items ):
	"""Called when the player wants to repair the items.

Parameters:
        character_id - Id of the character.
        items        - List of size one with the id of the item.
"""
	if can_repair(character_id, items):
		objects.set_attribute(items[0], "quality", 100)
		sounds.play_2d_sound("combine")
		system.update_ui()
		return True
	return False

def can_disassemble( character_id, items ):
	"""Returns True if the item can be disassembled.

Parameters:
        character_id - Id of the character.
        items        - List of size one with the id of the item.
"""
	if len(items)==1:
		typeid = objects.get_attribute(items[0], "typeid")
		if objects.has_attribute(typeid, "item_combination"):
			combination = objects.get_attribute(typeid, "item_combination")
			if not combination.has_key("difficulty_disassemble"):
				difficulty = global_defines.COMBO_IMPOSSIBLE
			else:
				difficulty = combination["difficulty_disassemble"]
			if difficulty!=global_defines.COMBO_IMPOSSIBLE:
				all_combinations = combination["combination_list"]
				for act_combination in all_combinations:
					if len(act_combination) > 0:
						return True
	return False

def on_disassemble( character_id, items ):
	"""Called when the player wants to disassemble the items.

Parameters:
        character_id - Id of the character.
        items        - List of size one with the id of the item.
"""
	if len(items)==1:
		item_type = objects.get_attribute(items[0], "typeid")
		if objects.has_attribute(item_type, "item_combination"):
			combination =  objects.get_attribute(item_type, "item_combination")
			diassemble_func = combination["disassemble_function"]
			if diassemble_func!=None:
				if not combination.has_key("difficulty_disassemble"):
					difficulty = global_defines.COMBO_IMPOSSIBLE
				else:
					difficulty = combination["difficulty_disassemble"]
				technic = skill_tables.technic_combination_value(
								objects.get_attribute(character_id, "technic"))
				if technic >= difficulty:
					eval_str = "combos."+diassemble_func
					function = eval(eval_str)
					if callable(function):
						if function(character_id, items[0]):
							sounds.play_2d_sound("combine")
							return True
	return False

def get_combine_items( character_id ):
	"""Returns the items, in the inventory of the given character, that can be combined.

Parameters:
        character_id - Id of the character.
"""
	items = objects.get_inventory_id_list( character_id )
	result = []
	item_types = []
	itemlist = system.get_combo_item_list()
	for act_item in items:
		item_types.append(objects.get_attribute(act_item, "typeid"))

	technic = skill_tables.technic_combination_value(
					objects.get_attribute(character_id, "technic"))
	for item in itemlist:
		if objects.has_attribute(item, "item_combination"):
			combination =  objects.get_attribute(item, "item_combination")
			difficulty = combination["difficulty_assemble"]
			if "skill" in combination: # skill attribute is yet untested
				skill = skill_tables.technic_combination_value(
							objects.get_attribute(character_id, combination["skill"]))
			else:
				skill = technic
			if skill >= difficulty:
				all_combinations = combination["combination_list"]
				for act_combination in all_combinations:
					for item_type in item_types:
						if objects.has_attribute(item_type,"pseudo_weapon") :
							real_type = objects.get_attribute(item_type,"pseudo_weapon") 
						else:
							real_type = item_type
						if real_type in act_combination:
							if not item_type in result:
								result.append(item_type)
	return result

def has_alternative_medicine( character_id ):
	"""Returns True if the char has alternative medicine items that can heal.

Parameters:
        character_id - Id of the character.
"""
	equipment = objects.get_inventory_id_list( character_id )

	for item in equipment:
		if objects.has_attribute( item, "typeid" ):
			typeid=objects.get_attribute( item, "typeid" )
			if (typeid == "SET_ALOE_VERA") or (typeid == "SET_WOOD_GARLIC") or (typeid == "SET_BURNET") :
					return True
	return False
	
def has_alternative_detox( character_id ):
	"""Returns True if the char has an alternative medicine antidote.

Parameters:
        character_id - Id of the character.
"""
	equipment = objects.get_inventory_id_list( character_id )

	for item in equipment:
		if objects.has_attribute( item, "typeid" ):
			typeid=objects.get_attribute( item, "typeid" )
			if (typeid == "SET_ANGELICA") :
					return True
	return False
	
def has_detox( character_id ):
	"""Returns True if the char has an antidote in his inventory.

Parameters:
        character_id - Id of the character.
"""
	equipment = objects.get_inventory_id_list( character_id )

	for item in equipment:
		if objects.has_attribute( item, "typeid" ):
			typeid=objects.get_attribute( item, "typeid" )
			if (typeid == "SET_ANTIDOTE") :
					return True
	return False
	
def can_heal(char, target):
	"""Returns True if the char can heal the target.

Parameters:
        char   - Id of the character.
        target - Id of the target character.
"""
	if not objects.has_attribute(target, "type"): return False
	if not objects.get_attribute(target, "type") in ["character", "animal"]: return False
	if objects.get_attribute(target, "hitpoints")>=objects.get_attribute(target, "maxhitpoints"):
		return False
	return has_medicine(char)

def has_medicine( character_id ):
	"""Returns True if the char has items that can heal.

Parameters:
        character_id - Id of the character.
"""
	equipment = objects.get_inventory_id_list( character_id )

	for item in equipment:
		if objects.has_attribute( item, "typeid" ):
			typeid=objects.get_attribute( item, "typeid" )
			if get_heal_item_strength(character_id, item, typeid) > 0:
				return True
	return False

def can_activate_bomb( character_id, object_ident ):
	"""Returns True if the char can activate the bomb.

Parameters:
        character_id - Id of the character.
        object_ident - Id of the bomb object.
"""
	explosive_skill=objects.get_attribute(character_id, "explosives")
	object_id=objects.get_attribute( object_ident, "typeid" )
	print "can_activate_bomb: ",object_id, explosive_skill

	if(objects.has_attribute(object_ident, "bomb_is_sharp")):
		if objects.get_attribute(object_ident, "bomb_is_sharp"):
			return False
	if(explosive_skill > 54):
		if(object_id=="SET_GAS_BOMB" or \
			object_id=="SET_DYNAMITE_WITH_TIME_BASED_DETONATOR" or \
			object_id=="SET_DYNAMITE" ):
			print "i can "
			return True
	if(explosive_skill > 69):
		if(object_id=="SET_C4_TIMEBASED" or \
			object_id=="SET_C4_TIMEBASED_W_NAILS" or \
			object_id=="SET_C4_REMOTE_CONTROL_W_NAILS" or \
			object_id=="SET_ANTITANKMINE" or \
			object_id=="SET_LANDMINE" or \
			object_id=="SET_FERTILIZER_EXPLOSIVE_TIME_BASED" or \
			object_id=="SET_FERTILIZER_EXPLOSIVE_REMOTE_CONTROL" or \
			object_id=="SET_C4_REMOTE_CONTROL" ):
			print "i can "
			return True
		
	print "can_t_activate_bomb "
	return False
	
def on_combine( character_id, items ):
	"""Called when the player wants to combine items.

Parameters:
        character_id - Id of the character.
        items        - List with the ids of the items.
                       or List of lists with the ids of the items for several
                       combinations at once.
"""
	def get_item_types():
		if not len(combine_lists): return False, False
		items = combine_lists.pop()
		item_types = []
		# get item types of all given items
		for act_item in items:
			if objects.has_attribute(objects.get_attribute(act_item, "typeid"),"pseudo_weapon"):
				item_types.append(objects.get_attribute(objects.get_attribute(act_item, "typeid"),"pseudo_weapon"))
			else:
				item_types.append(objects.get_attribute(act_item, "typeid"))
		item_types.sort()
		return item_types, items

	# get the list of all item types
	itemlist = system.get_combo_item_list()
	combine_lists = items[:]
	if len(combine_lists) and type(combine_lists[0]) != list: combine_lists = [combine_lists]
	item_types, items = get_item_types()
	played_sound = False

	for item in itemlist:
		if objects.has_attribute(item, "item_combination"):
			combination = objects.get_attribute(item, "item_combination")
			if not isinstance(combination,dict):
				raise ValueError, "'item_combination' attribute must be of type dictionary"
			difficulty = combination["difficulty_assemble"]
			if "skill" in combination: # skill attribute is yet untested
				skill = skill_tables.technic_combination_value(
								objects.get_attribute(character_id, combination["skill"]))
			else:
				skill = skill_tables.technic_combination_value(
								objects.get_attribute(character_id, "technic"))
			
			all_combinations = combination["combination_list"]
			for act_combination in all_combinations:
				combi = act_combination[:] # we need a copy, instead reference
				combi.sort()
				if item_types==combi:
					while item_types:
						if combination.has_key("assemble_function"):
							if combination["assemble_function"]!=None:
								assemble_function = combination["assemble_function"]
								eval_str = "combos."+assemble_function
								function = eval(eval_str)
								if callable(function):
									if skill >= difficulty:
										if function(character_id, items, item):
											on_combine_first_xp(character_id, item)
											if not played_sound:
												sounds.play_2d_sound("combine")
												played_sound = True
									else:
										system.add_text(globaltext.NOT_ENOUGH_TECHNIC_RESULT% {"char": objects.get_attribute(character_id, "name")})
										return False
						else:
							if skill >= difficulty:
								#default assemble, no special behaviour possible, all source items
								#will be combined to one target item, all source items will be destroyed
								if not played_sound:
									sounds.play_2d_sound("combine")
									played_sound = True
								# remove items
								for act_item in items:
									objects.remove_item_from_inventory(character_id, act_item)
								#create new item
								objects.create_item_in_inventory(object=character_id, equipment=item, id=items[0]+"_COMBINED")
								
								# für party dialog ,"Nachdem Francis eine Itemkombination durchgeführt hat und Carmen weniger als Technikwert 65 hat."
								if not hasattr( data("comments"), "spoken_party_dialog_en" ): 
									data("comments").spoken_party_dialog_en = {}
									
								if character_id == 'MERCENARY_FRANCIS' and 'MERCENARY_CARMEN' in system.get_pcs():
									if objects.get_attribute('MERCENARY_CARMEN', 'technic') < 65:
										data("comments").spoken_party_dialog_en['combine'] = True
										comments.make_party_comment()
								on_combine_first_xp(character_id, item)
							else:
								system.add_text(globaltext.NOT_ENOUGH_TECHNIC_RESULT% {"char": objects.get_attribute(character_id, "name")})
								return False

						item_types, items = get_item_types()
					return True

						
						
	sounds.play_2d_sound("combine_failed")
	return False

def on_combine_first_xp(character_id, item_type):
	"""Helper for on_combine: Checks first combine xp.

Parameters:
        character_id - Id of the character.
        item_type    - Type of build item.
                       
"""
	if not item_type:
		return
	combine_xp = 0
	if objects.has_attribute(item_type,'combine_xp'):
		combine_xp = objects.get_attribute(item_type,'combine_xp')
	elif '_DUMDUM' in item_type:
		item_type = 'DUMDUM'
		combine_xp = 150
	elif '_LASERPOINTER' in item_type:
		item_type = 'LASERPOINTER'
		combine_xp = 25
	else:
		return
			
	# check if already combined
	
	if objects.has_attribute(character_id,'first_combine_done') and len(objects.get_attribute(character_id, 'first_combine_done')):
		for combined_item in objects.get_attribute(character_id, 'first_combine_done'):
			if item_type == combined_item:
				return
		
	else:
		objects.set_attribute(character_id, 'first_combine_done', [])
		
	# add item to list and give xp
	combined_list = objects.get_attribute(character_id, 'first_combine_done')
	combined_list.append(item_type)
	objects.set_attribute(character_id, 'first_combine_done', combined_list)
	character_name = 'Siv'
	if objects.has_attribute(character_id, 'name'):
		character_name = objects.get_attribute(character_id, 'name')
		
	system.add_text(globaltext.PC_FIRST_TIME_COMBINE%{'char':character_name, 'exp': combine_xp})
	character.add_experience(character_id, combine_xp)
	
	
	
def can_use( character_id, object_id ):
	"""Returns True for items the character is able to use.

Parameters:
        character_id - Id of the character.
        object_id    - Id of the object that should be used.
"""
	#print "global.can_use"
	if global_item.can_use( character_id, object_id ):
		return True

	_type = objects.get_attribute(object_id, "type")
	if _type=="equipment":
		if objects.has_attribute(object_id, "weapon_type"):
			if objects.get_attribute(object_id, "weapon_type") == "explosiv":
				return True #jan: try explosives always
				#return can_activate_bomb(character_id, object_id)
		if objects.has_attribute(object_id, "le_recovery"):
			if global_defines.is_water_repository( object_id ):
				if objects.get_attribute( object_id, "charge" )<=0:
					return False
			return True
		if objects.has_attribute(object_id, "drug_effects"):
			return True
		if objects.has_attribute(object_id, "container"):	# Derff's backpacks
			return True

		# ignore equip items
		if objects.has_attribute(object_id, "occupied_slots"):
			return False
		return True

	return False

def is_raw_meat( item_id ):
	"""Tests if the given item is raw meat.

Parameters:
        item_id - Id of the item.
"""
	item_type = ""

	if objects.has_attribute( item_id, "typeid" ):
		item_type = objects.get_attribute( item_id, "typeid" )

	meat = [	'SET_MEAT_RAW_HUMONGOUS',
			'SET_MEAT_RAW_BIG',
			'SET_MEAT_RAW',
			'SET_MEAT_RAW_SMALL',
			'SET_MEAT_RAW_TINY']

	# if the used item is raw meat
	if item_id in meat or item_type in meat:
		return True
	else:
		return False

def is_usable_to_improve( object_id ):
	"""Tests if the given object can be used to improve meat.

Parameters:
        object_id - Id of the object.
"""

	improve = False
	object_type = None

	# check if object can purify
	if objects.has_attribute( object_id, "typeid" ):
		# get the type of the object 
		object_type = objects.get_attribute( object_id, "typeid" )

		# must use try/except, because the attribute system is not
		# implemented for every typeid and therefore has_attribute
		# will throw an exception, that i have to catch here
		try:
			objects.has_attribute( object_type, "improve" )
		except:
			return False

		if objects.has_attribute( object_type, "improve" ):
			# if meat can be purified with the object
			improve = objects.get_attribute( object_type, "improve" )
	
	# if the object can be used to improve,
	# then check if it is in the right state to be used
	if improve:
		# if object is a bonfire, check if it is burning
		if object_type == "RES3D_LAGERFEUER" or object_type == "RES3D_TRES_OBJECTS_BUILDING_BIG_CAMPFIRE" or object_type == 'RES3D_LAGERFEUER_KLEIN':
			if objects.has_attribute( object_type, "burning" ):
				improve = objects.get_attribute( object_type, "burning" )

	if improve:
		return True
	else:
		return False


def cannot_improve_comment( character_id, object_id ):
	"""Lets the char say a comment depending on the object he tries to use to improve.

Parameters:
        character_id - Id of the character.
        object_id    - Id of the object that should be used to improve.
"""
	object_type = None

	if objects.has_attribute( object_id, "typeid" ):
		# get the type of the object 
		object_type = objects.get_attribute( object_id, "typeid" )
	
		# if object is a bonfire, check if it is burning
		if object_type == "RES3D_LAGERFEUER":
			if objects.has_attribute( object_type, "burning" ):
				if not objects.get_attribute( object_type, "burning" ):
					comments.comment( character_id, "IMPROVE_MEAT_FAILED_FIRE" )


def is_water_source( object_id ):
	"""Returns True if the given object is a water source.

Parameters:
        object_id - Id of the object that should be tested.
"""

	object_type = ""
	water_sources = [ "RES3D_TRES_OBJECTS_BUILDING_WATERHOLE_EMPTY", "RES3D_TRES_OBJECTS_BUILDING_WATERHOLE_FULL" ]

	if objects.has_attribute( object_id, "typeid" ):
		object_type = objects.get_attribute( object_id, "typeid" )

	if object_id in water_sources or object_type in water_sources:
		return True
	else:
		return False

def fill_water_repository( item_id, item_type, object_id ):
	"""Fills the given item with water from the given object.

Parameters:
        item_id   - Item that should be filled with water.
        object_id - Object from which the water is taken.
"""

	x = objects.get_x( object_id )
	y = objects.get_y( object_id )

	available_water   = water.get_available_water( objects.get_x( object_id ), objects.get_y( object_id ), 0.5 )
	current_charge	  = objects.get_attribute( item_id, "charge" ) # current charge value
	max_charge	  = objects.get_attribute( item_type, "charge" ) # max charge value
	charge_diff       = max_charge - current_charge # how much water is needed to fill the item up
	remaining_water   = available_water - charge_diff # how much water remains in the object

	if remaining_water < 0: # the water in the object is not enough to fill the item up
		# add the complete available_water to the item and remove it from the object
		objects.set_attribute( item_id, "charge", current_charge + available_water )
		if objects.has_attribute(item_type, 'weight_container') and objects.has_attribute(item_type, 'charge') and objects.has_attribute(item_type, 'weight'):
			weight_container = objects.get_attribute(item_type, 'weight_container')
			weight_per_charge = (objects.get_attribute(item_type,'weight') - weight_container) / objects.get_attribute(item_type, "charge")
			new_weight = ((current_charge + available_water) * weight_per_charge) + weight_container
			objects.set_attribute( item_id, "weight", new_weight )
			
		water.reduce_available_water( objects.get_x( object_id ), objects.get_y( object_id ), 0.5, available_water )
		system.create_object( "RES3D_TRES_OBJECTS_BUILDING_WATERHOLE_EMPTY", x, y )
	else: # there is more water in the object than neede
		objects.set_attribute( item_id, "charge", max_charge )
		objects.set_attribute( item_id, "weight", objects.get_attribute(item_type, 'weight') )
		water.reduce_available_water( objects.get_x( object_id ), objects.get_y( object_id ), 0.5, charge_diff )

	system.update_ui()

def fill_all_water_repositories( character_id, water_source_id ):
	"""Tries to fill all the water repositories with the water from the give water 
source until there is no more water in the water source. Starts filling with 
water repositories that are partially empty.

Parameters:
        character_id    - Id of the character.
        water_source_id - Id of the source from where the water is taken.
"""

	sorted_items = [] # water repositories are sorted by fill level. Empty ones first
	item_type = ""
	equipment = objects.get_inventory_id_list( character_id )

	available_water = water.get_available_water( objects.get_x( water_source_id ), objects.get_y( water_source_id ), 1 )
	if available_water == 0:
		return

	# sort water repositories by fill level
	for item in equipment:
		if global_defines.is_water_repository( item ):
			if objects.has_attribute( item, "typeid" ):
				item_type = objects.get_attribute( item, "typeid" )
			else:
				continue

			current_charge = objects.get_attribute( item, "charge" )
			max_charge = objects.get_attribute( item_type, "charge" )

			if current_charge == 0:
				sorted_items.append( item )
			elif current_charge < max_charge:
				sorted_items.insert( 0, item )

	for item in sorted_items:
		available_water = water.get_available_water( objects.get_x( water_source_id ), objects.get_y( water_source_id ), 1 )
		if available_water <= 0:
			random_comment(  character_id, "WATER_SOURCE_EMPTY_", 1 )
			break

		if objects.has_attribute( item, "typeid" ):
			item_type = objects.get_attribute( item, "typeid" )
		else:
			continue

		fill_water_repository( item, item_type, water_source_id )


def use_raw_meat( character_id, meat_id ):
	"""Search for a cooking place and use meat on it.

Parameters:
        character_id - Id of the character.
        meat_id      - Id of the meat that should be cooked.
"""

	x = objects.get_x( character_id )
	y = objects.get_y( character_id )
	max_dist = 40

	# get all object in a 80x80 square around the char
	_objects = system.get_objects( None, x - max_dist, y + max_dist, x + max_dist, y - max_dist )

	tmpObjectList = []
	# sort out all objects that are further away then 80 meters
	for tmpObject in _objects:
		if objects.get_distance_to_position( character_id, objects.get_x( tmpObject ), objects.get_y( tmpObject ) ) <= 80:
			tmpObjectList.append( tmpObject )

	_objects = tmpObjectList # object list now contains only objects that are nearer or equalor equal than 80 meter

	# ( cookingplace object, dist to char )
	cooking_place = ( None, None )

	# search for the nearest cooking place
	for tmp_object in _objects:
		if not is_usable_to_improve( tmp_object ):
			continue

		objectX = objects.get_x( tmp_object )
		objectY = objects.get_y( tmp_object )
		
		# is object in radius dist
		dist = math.hypot( x - objectX, y - objectY )
		if dist < max_dist and ( cooking_place[1] == None or dist < cooking_place[1] ):
			cooking_place = ( tmp_object, dist )

	# if a cooking place is found then cook the meat on it
	if cooking_place[0] != None:
		character.use( character_id, meat_id, cooking_place[0] )
	else:
		comments.comment( character_id, "IMPROVE_MEAT_FAILED_FIRE" )


def use_water_repository( character_id, water_repository_id ):
	"""Search for a water source, and use water container on it.

Parameters:
        character_id        - Id of the char.
        water_repository_id - Id of the water container that should be used.
"""

	# check if the zone has unearthed water sources
	if not hasattr( data(), "water_unearthed" ):
		random_comment( character_id, "NO_WATER_SOURCE_AROUND_", 1 )
		return

	# ( xpos, ypos, dist to char )
	water_source = ( None, None, None )

	char_x = objects.get_x( character_id )
	char_y = objects.get_y( character_id )

	# search for the nearest unearthed water source
	for source in data().water_unearthed:
		dist =  math.hypot( char_x - source[0], char_y - source[1] )
		if dist <= 80 and ( water_source[2] == None or dist < water_source[2] ):
			water_source = ( source[0], source[1], dist )

	if water_source[0] != None:
		dist = 1
		x = water_source[0]
		y = water_source[1]

		# get the object that represents the water source.
		# use a radius to get it even if it has not the same coords as the water source
		_objects = system.get_objects( None, x - dist, y - dist, x + dist, y + dist )

		# if objects are found then check for the water source object and use the
		# water repository on it
		if len( _objects ) > 0:
			for tmp_object in _objects:
				if is_water_source( tmp_object ):
					character.use( character_id, water_repository_id, tmp_object )
					return
	else:
		random_comment( character_id, "NO_WATER_SOURCE_AROUND_", 1 )


def pre_use( character_id, object_id, item_id, item_type ):
	"""Called directly before a char uses an item on an object.

Parameters:
        character_id - Id of the character.
        object_id    - Id of the object on which the item should be used
                       (can be the same as character_id).
        item_id      - Id of the object that should be used.
        item_type    - Type of the object that should be used.
"""
	# do nothing by default
	pass
	

def on_use( character_id, object_id, item_id, item_type ):
	"""Called when the player wants to use an item.

Parameters:
        character_id - Id of the character.
        object_id    - Id of the object that the item should be used on.
                       (can be the same as character_id).
        item_id      - Id of the object that should be used.
        item_type    - Type of the object that should be used.
"""
	#system.add_text("on_use('%s','%s','%s','%s')" %( character_id, object_id, item_id, item_type ))
	#print "object_events.on_use", character_id, object_id, item_id, item_type
	#default code verwaltet nur items z.Zt., return wenn kein item angegeben
	# an item is used on an other object
	if global_item.can_use( character_id, item_id ):
		if global_item.on_use( character_id, object_id, item_id, item_type ):
			if item_id == 'Z2 TATTERED_NOTE':
				if not global_defines.is_zone_enabled("zone_3"):
					global_defines.set_zone_enabled("zone_3", True)
					character.add_experience_party(50)
					if global_defines.was_zone_entered('zone_2.zone_2'):
						data('zone_2.zone_2').zone_3_on = True
						system.set_qb_entry_state(data('zone_2.zone_2').QB_013, global_defines.UNCOMPLETE)
			return True
	
	if character_id != None and item_type != None:
		if character_id == 'MERCENARY_AGNES' and item_type in ['SET_MEAT_RAW', 'SET_MEAT_RAW_SMALL', 'SET_MEAT_RAW_TINY',
															   'SET_MEAT_COOKED_TINY', 'SET_MEAT_RAW_HUMONGOUS', 'SET_MEAT_RAW_BIG',
															   'SET_MEAT_COOKED_BIG', 'SET_MEAT_COOKED', 'SET_MEAT_COOKED_SMALL',
															   'SET_MEAT_COOKED_HUMONGOUS', 'SET_TIGER_MEAT', 'SET_RAT_MEAT',
															   'SET_BISON_MEAT', 'SET_PAN_WITH_MEAT', 'SET_SPIT_WITH_MEAT']:
			if not dialog.is_dialog_active():
				dialog.init_dialog(type=global_defines.DIALOGSMALL)
				dialog.add_text(text='MKEN_AGNES_D_2', speaker=character_id, follower="ENDDIALOG")
				#dialog.add_text(text='MKEN_AGNES_D_4', speaker=character_id, follower="ENDDIALOG")
				dialog.start()
				return True
			return True
	
	if item_id != None and object_id != None:
		#refuel vehicles
		if objects.has_attribute(object_id, "type"):
			_type = objects.get_attribute(object_id, "type")
			if _type=="vehicle":
				if objects.has_attribute(item_type, "fuel"):
					fuel = objects.get_attribute(item_type, "fuel")
					current_fuel = objects.get_attribute(object_id, "current_fuel_quantity")
					current_fuel+=fuel
					objects.set_attribute(object_id, "current_fuel_quantity",current_fuel)
					objects.remove_item_from_inventory(character_id,item_id)
					return True

		# is raw meat used
		if is_raw_meat( item_id ):
			if is_usable_to_improve( object_id ): # is the object usable to improve the meat
				if can_cook_meat( character_id ): # is the char able to cook
					character.cook_meat( character_id, item_id, object_id )
					return True
				else:
					comments.comment( character_id, "IMPROVE_MEAT_FAILED_TOOL" )
					return True
			else:
				# char says comment on why the object 
				# can not be used to improve
				cannot_improve_comment( character_id, object_id )
				return True

		# is a water repository used
		if global_defines.is_water_repository( item_id ):
			if is_water_source( object_id ):
				available_water = water.get_available_water( objects.get_x( object_id ), objects.get_y( object_id ), 1 )
				if available_water <= 0:
					random_comment(  character_id, "WATER_SOURCE_EMPTY_", 1 )
				else:
					fill_water_repository( item_id, item_type, object_id )

				return True

	# Derff's backpack
	if (object_id != None) and objects.has_attribute(object_id, "container") and ( item_id == None ):
		return backpack_transfer(character_id, object_id, True)

	if (item_id==None or object_id!=None):
		return False

	if (objects.has_attribute(item_type, "bomb_type") and 
		len(objects.get_attribute(item_type, "bomb_type"))): 
		if objects.count_in_inventory(character_id, item_id):
			objects.put_down_item(character_id, item_id)
		#activate or defuse?
		if objects.has_attribute(item_id,"bomb_is_sharp") \
		and	objects.get_attribute(item_id,"bomb_is_sharp"):
			# defuse
			if objects.get_attribute(item_type, "bomb_type")!="mine":
				system.remove_explosive_control( item_id)
			chance=calc_defuse_chance(character_id,item_id)
			if(chance< random.randint(1,100)):
				fail_defuse(character_id,item_id)
			else:
				if objects.has_attribute(item_id, "max_explosive_effect"):
					objects.set_attribute(item_id,"max_explosive_effect",0)
				if objects.get_attribute(item_type, "bomb_type")=="mine":
					objects.deactivate_mine(item_id)
				else:
					objects.set_attribute(item_id, "bomb_is_sharp", False)
				give_first_use_exp(character_id, "defuse_bomb")
		else:
			# activate
			if can_activate_bomb(character_id,item_id):
				print "activate", item_id
				if objects.get_attribute(item_type, "bomb_type") == "mine":
					objects.activate_mine(item_id, immune=[objects.get_party(character_id)], bomb_owner=character_id)
					#system.add_text(globaltext.MINE_ACTIVATED)
				else:
					if has_talent( character_id, "explosives", "max_explosive_effect" ):
						objects.set_attribute(item_id,"max_explosive_effect",30)
					system.add_explosive_control(character_id, item_id)
					objects.set_attribute(item_id,"bomb_owner",character_id)
			else:
				print "unable to activate"
				text = "HANDLE_EXPLOSIVES_DENY_001" 
				comments.comment( character_id, text )

			
				
		print "object_events.on_use", "usebomb ",item_id
		return True

	if (item_type=="SET_ANGELICA" and has_talent( character_id, "medicine", "alternative_medicine" ) ) or (item_type=="SET_ANTIDOTE" ):
		print character_id
		print object_id
		if object_id:
			target_id=object_id
		else:
			target_id=character_id
		if objects.has_attribute(target_id,"poison_ticks"):
		 	if objects.get_attribute(target_id,"poison_ticks")>0:

				mode = character.get_body_mode(character_id)
				lambdastring = 'on_detox_use_callback("%s","%s","%s")' %(character_id,target_id,item_id)
				if character_id!=target_id:
					if mode == "STAND":
						character.play_animation( character_id, "CM_STEHEN_UEBERGEBEN_WAFFENLOS" , callback=["ONEND", Lambda(lambdastring)])
					if mode == "KNEEL":
						character.play_animation( character_id, "CM_KNIEND_UEBERGEBEN_WAFFENLOS", callback=["ONEND", Lambda(lambdastring)] )
					if mode == "LIE":
						character.play_animation( character_id, "CM_LIEGEN_UEBERGEBEN_WAFFENLOS" , callback=["ONEND", Lambda(lambdastring)])
				else:
					Lambda(lambdastring)()
				return True

	if objects.has_attribute(item_type, "le_recovery"):
		return use_heal_item(character_id, object_id, item_id, item_type)
		
	if objects.has_attribute(item_id, "drug_effects"):
		return use_drug(character_id, object_id, item_id, item_type)
	
	if global_defines.was_zone_entered('zzone_10.zzone_10'):
		if item_id == data('zzone_10.zzone_10').brief2:
			gender = objects.get_attribute("ALTER_EGO","gender")
			dialog.init_dialog(type=global_defines.DIALOGSMALL)
			if character_id != "ALTER_EGO":
				if gender == "male":
					dialog.add_text(text='MERCENERY_USEITEM_DENY', speaker='ALTER_EGO', follower='ENDDIALOG')
				else:
					dialog.add_text(text='MERCENERY_USEITEM_DENY_F', speaker='ALTER_EGO', follower='ENDDIALOG')
			else:
				dialog.add_text(text='EXAMINE_ZZ10_LETTER', speaker='ALTER_EGO', follower='ENDDIALOG')
			dialog.start(False)
			return True	

	# Derff's try to use backpack's
	if objects.has_attribute(item_id, "container"):
		return backpack_transfer(character_id, item_id, True)
	
	return False

def on_use_failed( character_id, object_id, item_id, item_type ):		
	"""Called when on_use returned False for this item.

Parameters:
        character_id - Id of the character.
        object_id    - Id of the object that the item should be used on
                       (can be the same as character_id).
        item_id      - Id of the object that should be used.
        item_type    - Type of the object that should be used.
"""
	# failed to use object/item
	text = "HANDLE_ITEM_" + str(random.choice([3,5,10]))
	comments.comment(character_id=character_id, text=text)
	return False

def can_exchange( character_id, target_id, item_id, item_type ):
	"""Return True if the item can be given from character to target.

Parameters:
        character_id - Id of the character who gives.
        target_id    - Id of the object that receives the item.
        item_id      - Id of the object that should be transferred.
        item_type    - Type of the object that should be transferred.
"""
	#print "can_exchange", character_id, target_id, item_id, item_type

	if objects.has_attribute(target_id, "type"):
		_type = objects.get_attribute(target_id, "type")
		if _type=="vehicle":
			return False

	if objects.is_npc(target_id):
		if objects.has_attribute(item_id, "generic_item"):
			print "generic_item", objects.get_attribute(item_id, "generic_item")
			if not objects.get_attribute(item_id, "generic_item"):
				text = "TRANSFER_QUESTITEM_" + str(random.choice([10,3,7]))
				comments.comment(character_id=character_id, text=text)
				return False
	elif objects.is_pc(target_id):
		return True
	return True

def on_exchange( character_id, target_id, item_id, item_type ):
	"""Called when the item should be transferred from character to target.

Parameters:
        character_id - Id of the character who gives.
        target_id    - Id of the object that receives the item.
        item_id      - Id of the object that should be transferred.
        item_type    - Type of the object that should be transferred.
"""
	#print "on_exchange", character_id, target_id, item_id, item_type
	if objects.is_pc(target_id):
		if objects.can_transfer_item(target_id,item_id):
			return True
		else:
			text = "TRANSFER_ITEM_" + str(random.choice([1,5,7]))
			comments.comment(character_id=target_id, text=text)
			return False
	return True

def get_item_of_type_from_inventory( character_id,item_type):
	"""Returns the id of the first item of the given type the char has in his 
inventory.

If the char has no item of the specified type in his inventory, "" is returned.

Parameters:
        character_id - Id of the character.
        item_type    - Type of the searched item.
"""
	itemlist=objects.get_inventory_id_list(character_id)
	for element in itemlist:
		if objects.has_attribute(element, "typeid"):
			if objects.get_attribute(element, "typeid") ==item_type:
				return element
	return ""

def test_explosion(char, item_id):
	"""Checks and explodes the item if it's a bomb the char can't handle.

Returns True in case of an explosion.

Parameters:
        char    - Id of the character.
        item_id - Id of the bomb object.
"""
	dodamage = False
	if not char in system.get_pcs(): return False
	if system.is_trading_screen(): return False
	if not objects.has_attribute(item_id, "typeid"): return False
	if not item_id in objects.get_inventory_id_list(char): return False
	item_type = objects.get_attribute(item_id, "typeid")
	if (objects.has_attribute(item_type, "weapon_type")):
		if objects.get_attribute(item_type, "weapon_type")=="explosiv":
			explosives = objects.get_attribute( object=char, attribute="explosives" )
			#print "skill: " ,explosives
			if explosives < 15:
				if random.randint(0, 9): #90% chance
					dodamage=True
			elif explosives < 40:
				if random.randint(0, 1): #50% chance
					dodamage=True
	if dodamage:
		#print "do_explosive_damage"
		objects.remove_item_from_inventory(char,item_id)
		hitpoints=objects.get_attribute(char, "hitpoints")
		factor=random.randint(5, 10)
		hitpoints=hitpoints*factor/100
		objects.set_attribute(char, "hitpoints", hitpoints)
		fx_object_id = random.choice([global_defines.fx_explosion,global_defines.fx_explosion_medium])
		sound_object_id = random.choice(['grenade_explo_frag','grenade_explo_rpg7','various_explosive_explo'])
		pos = objects.get_position(char)
		system.start_effect( 
			startx=pos[0],starty=pos[1],startz=pos[2],
			dirx=0,diry=0,dirz=1,
			parameter=fx_object_id)
		sounds.play_3d_sound(
			sfx_id=sound_object_id,
			x=pos[0],y=pos[1],z=pos[2])
		return True
	return False
	
def fail_defuse(character_id, target_id ):
	"""Called when the char fails to defuse the bomb.

Helper function for on_use on bombs.

Parameters:
        character_id - Id of the character.
        target_id    - Id of the bomb object that explodes.
"""
	#print "do_explosive_damage"
	#hack to remove mine from the ground . (what happens if inventory is full??)
	objects.pick_up_item_direct(character_id,target_id)
	objects.remove_item_from_inventory(character_id,target_id)

	hitpoints=objects.get_attribute(character_id, "hitpoints")
	factor=random.randint(5, 10)
	hitpoints=hitpoints*factor/100
	objects.set_attribute(character_id, "hitpoints", hitpoints)
	fx_object_id = random.choice([global_defines.fx_explosion,global_defines.fx_explosion_medium])
	sound_object_id = random.choice(['grenade_explo_frag','grenade_explo_rpg7','various_explosive_explo'])
	pos = objects.get_position(character_id)
	system.start_effect( 
		startx=pos[0],starty=pos[1],startz=pos[2],
		dirx=0,diry=0,dirz=1,
		parameter=fx_object_id)
	sounds.play_3d_sound(
		sfx_id=sound_object_id,
		x=pos[0],y=pos[1],z=pos[2])

def calc_defuse_chance( operator, target ):
	"""Calculates the chance to defuse a given bomb.

Returns the chance to defuse.

Parameters:
        operator - Id of the character defusing the bomb.
        target   - Id of the bomb.
"""
	defuse_bonus=0
	defuse_chance=0
	if has_talent( operator, "explosives", "defuse" ):
		defuse_bonus=30
	explosives = objects.get_attribute( object=operator, attribute="explosives" )
	item_type=objects.get_attribute( target, "typeid" )
	
	if(item_type=="SET_GAS_BOMB" or \
		item_type=="SET_DYNAMITE_WITH_TIME_BASED_DETONATOR" or \
		item_type=="SET_DYNAMITE" ):
		if explosives >54:
			defuse_chance=30
		if explosives >69:
			defuse_chance=50
		if explosives >84:
			defuse_chance=70
	if(item_type=="SET_C4_TIMEBASED" or \
		item_type=="SET_C4_TIMEBASED_W_NAILS" or \
		item_type=="SET_C4_REMOTE_CONTROL_W_NAILS" or \
		item_type=="SET_ANTITANKMINE" or \
		item_type=="SET_LANDMINE" or \
		item_type=="SET_FERTILIZER_EXPLOSIVE_TIME_BASED" or \
		item_type=="SET_FERTILIZER_EXPLOSIVE_REMOTE_CONTROL" or \
		item_type=="SET_C4_REMOTE_CONTROL" ):
		if explosives >69:
			defuse_chance=30
		if explosives >84:
			defuse_chance=50
		if explosives >94:
			defuse_chance=70
		
	#print "defuse_chance ", defuse_chance, defuse_bonus
	return defuse_chance+defuse_bonus
	
def can_examine_object( character_id, object_id ):
	"""Returns True if the object can be examined.

If used in zone scripting, do not copy this function or call it.
Instead return True or False:
        True  - Zone scripting handles examine of this object.
        False - Standard behavior. ("zone".on_examine_object is not called!)

Parameters:
        character_id - Id of the character.
        object_id    - Id of the object.
"""

	# dead animals to examine
	if objects.has_attribute(object_id, "type"):
		_type = objects.get_attribute(object_id, "type")
		if _type=="animal":
			if not objects.get_attribute( object_id, "hitpoints" ):
				return True
			else:
				return False

	# dead characters to examine
	if character.exists( object_id ):
		if objects.is_destroyed( object_id ) or objects.is_unconscious( object_id ):
			return True
		else:
			return False

	# normal objects
	if objects.has_attribute(object_id, "typeid"):
		typeid = objects.get_attribute(object_id, "typeid")
		if objects.has_attribute(typeid, "examine"):
			return True

	return False

def pre_examine_object( character_id, object_id ):
	"""Called before the char starts to examine an object.

I.e. before he walks over to the object and examines it.

Set the character attribute "on_examine_coordinates" to make character move to 
the coordinates given in this attribute (instead of object dummy).
Example:
        if object_id == "ZZONE_9_BUILDING_19272":
                object.set_attribute(object_id, "on_examine_coordinates", [395.0, 481.0,0])

Parameters:
        character_id - Id of the character.
        object_id    - Id of the object.
"""
	#do nothing by default
	pass

def on_examine_object( character_id, object_id ):
	"""Called if an item is examined by a character.

!Attention!
If overridden in zone script, the function in zone script needs to return 
True or False instead of calling this function:
        True  - Stops calling of standard behavior.
        False - Calls the standard functions(object_event).

Parameters:
        character_id - Id of the character.
        object_id    - Id of the object.
"""
	if object_id in system.get_npcs():
		inventorylist = objects.get_inventory_id_list(object_id)
		if inventorylist:
			for item in inventorylist:
				if objects.has_attribute(item, 'stealable'):
					if not objects.get_attribute(item, 'stealable'):
						objects.remove_item_from_inventory(object_id, item)
						
	# examine animal - refer to disembowl or loot
	if objects.has_attribute(object_id, "type"):
		_type = objects.get_attribute(object_id, "type")
		if _type=="animal":
			typeid = objects.get_attribute(object_id, "typeid")
			inventorylist = objects.get_inventory_list(object_id)
			if inventorylist and not "REST_RAIDER_" in object_id:
				system.item_panel( character_id, object_id )
			else:
				comments.comment(character_id=character_id, text="EXAMINE_"+typeid)

	# loot characters
	if character.exists( object_id ):
		if objects.is_pc( character_id ):
			if not "REST_RAIDER_" in object_id:
				inventorylist = objects.get_inventory_list(object_id)
				if inventorylist:
					system.item_panel( character_id, object_id )
		else:
			# foe?
			foes = []
			if objects.has_attribute( character_id, "foes" ):
				foes = objects.get_attribute( character_id, "foes" )
			if object_id in foes:
				inventorylist = objects.get_inventory_list(object_id)
				for item in inventorylist:
					objects.transfer_item(object_id, item, character_id)

	# normal objects
	if (objects.has_attribute(object_id, "typeid") and
		objects.has_attribute(object_id, "type")):
		_type = objects.get_attribute(object_id, "type")
		if _type=="building":
			typeid = objects.get_attribute(object_id, "typeid")
			if objects.has_attribute(typeid, "examine"):
				inventorylist = objects.get_inventory_list(object_id)	

				# get the exmaine status
				is_examined = False
				if objects.has_attribute( object_id, "is_examined" ):
					is_examined = objects.get_attribute( object_id, "is_examined" )

				# determine object_type
				chests = [ "RES3D_TRES_OBJECTS_BUILDING_TRUHEMITSCHLOSS_ANIMATE",\
						"RES3D_TRES_OBJECTS_BUILDING_STABILEHOLZKISTEMITSCHLOSS_ANIMATE", \
						"RES3D_TRES_OBJECTS_BUILDING_GROSSEMETALLKISTEMITSCHLOSS_ANIMATE", \
						"RES3D_TRES_OBJECTS_BUILDING_FELDKISTEMITSCHLOSS_ANIMATE" ]
				object_type = None
				if string.find( typeid, "RES3D_TRESOR_" ) == 0: # object is a safe
					object_type = "safe"

				if is_locked_object( object_id ):
					if objects.has_attribute( typeid, "examine_locked" ):
						examine_locked = objects.get_attribute( typeid, "examine_locked" )
						if examine_locked.endswith("_"):
							text = examine_locked + str(random.randint(1,5))
							comments.comment(character_id=character_id, text=text)
						else:
							comments.comment(character_id=character_id, text=examine_locked)
					else:
						comments.comment( character_id, "EXAMINE_LOCKED_OBJECT" )
				elif inventorylist:
					if ( object_type == "safe" or typeid in chests ) and not is_examined:
						# open and show object inventory
						lambda_string = 'system.item_panel( taker="%s", object="%s" )' % ( character_id, object_id )
						objects.play_animation( object_id, "ANIM_TRESOR", callback = [ "ONEND", Lambda( lambda_string ) ] )
						objects.set_attribute( object_id, "is_examined", True )
					else:
						# show object inventory
						system.item_panel( character_id, object_id )
				else:
					if ( object_type == "safe" or typeid in chests ) and not is_examined:
						objects.play_animation( object_id, "ANIM_TRESOR" )
						objects.set_attribute( object_id, "is_examined", True )

					examine = objects.get_attribute(typeid, "examine")
					if examine.endswith("_"):
						text = examine + str(random.randint(1,5))
						comments.comment(character_id=character_id, text=text)
					else:
						comments.comment(character_id=character_id, text=examine)
		elif  objects.has_attribute(object_id, "container"): #Derff's Containers
			backpack_transfer( character_id, object_id, False )	
						

def is_locked_object( object_id ):
	"""Checks if the given object is locked.

Parameters:
        object_id - Id of the object that should be checked.
"""
	if objects.has_attribute( object_id, "locked" ):
		locked = objects.get_attribute( object_id, "locked" )
		if len( locked ) <= 0:
			return False
		else:
			return True
	else:
		return False


def can_cook_meat( character_id ):
	"""Returns True if the character has the needed equipment to cook meat.
And, of course, he needs meat to cook.

Parameters:
        character_id - Id of the character.
"""

	has_cooking_item = False
	cook_items = [ 'SET_PAN', 'SET_SPIT' ,'SET_POT_ON_A_BAR']
	inventory_id_list = objects.get_inventory_list( character_id )

	# check if char has one of the cooking items
	for item in cook_items:
		if item in inventory_id_list:
			has_cooking_item = True
			
	# if char has a cooking item then check if he
	# has raw meat to cook
	if has_cooking_item:
		meat = ['SET_MEAT_RAW_HUMONGOUS',
			'SET_MEAT_RAW_BIG',
			'SET_MEAT_RAW',
			'SET_MEAT_RAW_SMALL',
			'SET_MEAT_RAW_TINY']

		# exit function with True if meat is in inventory
		for x in meat:
			if x in inventory_id_list:
				return True

	return False

def on_cook_meat( character_id, object_id, item, cookAll = False ):
	"""Called if meat is cooked by the character.
The raw meat is replaced with cooked meat.

Parameters:
        character_id - Id of the character.
        object_id - Id of the meat that is cooked.
        item - Item that is used to cook.
        all - Determines if all meat in the chars inventory should be cooked.
"""

	# play a animation depending on the cooking item
	if item == "SET_PAN":
		character.play_animation( character_id, "CM_NPC_STEHEN_PFANNE_SCHWENKEN_LOOP" , callback = ['ONCANCEL', Lambda('post_cook_meat( "%s" , "SET_PAN" , "cancel")' %character_id)])
	elif item == "SET_SPIT":
		character.play_animation( character_id, "CM_KNIEND_BRATSPIESS_HALTEN_LOOP" , callback = ['ONCANCEL', Lambda('post_cook_meat( "%s" , "SET_SPIT" , "cancel")' %character_id)])
	elif item == "SET_POT_ON_A_BAR":
		character.play_animation( character_id, "CM_KNIEND_KOCHTOPF_HALTEN_LOOP" , callback = ['ONCANCEL', Lambda('post_cook_meat( "%s" , "SET_POT_ON_A_BAR" , "cancel")' %character_id)])
	
	meat = {	'SET_MEAT_RAW_HUMONGOUS': 'SET_MEAT_COOKED_HUMONGOUS',
			'SET_MEAT_RAW_BIG': 'SET_MEAT_COOKED_BIG',
			'SET_MEAT_RAW': 'SET_MEAT_COOKED',
			'SET_MEAT_RAW_SMALL': 'SET_MEAT_COOKED_SMALL',
			'SET_MEAT_RAW_TINY': 'SET_MEAT_COOKED_TINY' }

	meatlist = []

	if cookAll:
		meatlist = objects.get_inventory_id_list( character_id )
	else:
		meatlist = [ object_id ]
	
	cooked_meat = []

	for object_id in meatlist:
		if objects.has_attribute( object_id, "typeid" ):
			object_type = objects.get_attribute( object_id, "typeid" )
			# check if object is meat
			if object_type in meat.keys():
				cooked_meat.append(meat[object_type])
				objects.remove_item_from_inventory( character_id, object_id )
				
	for meat_temp in cooked_meat:
		new_meat = objects.create_item_in_inventory( character_id, meat_temp )
		# if char has talent to cook then extend 
		# the meats recovery value by 50 percent
		if has_talent( character_id, "survival", "cook" ):
			old_recovery = objects.get_attribute( new_meat, "le_recovery" )
			objects.set_attribute( new_meat, "le_recovery", old_recovery * 1.5 )
		give_first_use_exp(character_id, "cook_meat")

def get_cook_position( character_id, object_id ):
	"""Helper for on_cook_meat.

Returns the position the char should move to in order to cook.

Parameters:
        character_id - Id of the character.
        object_id    - Id of the object the char should move to.
"""

	object_type = None

	if objects.has_attribute( object_id, "typeid" ):
		# get the type of the object 
		object_type = objects.get_attribute( object_id, "typeid" )

	dist = 0

	if object_type == "RES3D_LAGERFEUER":
		# distance the char should move forward
		dist = math.hypot( 0.7, 0 )

	# get characters direction
	direction = objects.get_direction( character_id )

	# direction is measured clockwise
	# turn it counterclockwise for sin/cos functions
	direction = 360 - direction
	# convert it from degree to radiant
	direction = 2.0 * math.pi * ( direction / 360 )

	# calc the new char positions
	char_x = objects.get_x( character_id )
	char_y = objects.get_y( character_id )

	desiredPosX = char_x - dist * math.sin( direction )
	desiredPosY = char_y - dist * math.cos( direction )
	
	return [ desiredPosX, desiredPosY, 0 ]

def remove_normal_pan( character_id ):
	"""Helper for on_cook_meat.

Callback function to remove the normal pan from the inventory.

Parameters:
        character_id - Id of the character.
"""
	objects.remove_item_from_inventory( character_id, "SET_PAN" )
	objects.create_item_in_inventory( character_id, "SET_PAN_WITH_MEAT" )

def remove_normal_spit( character_id ):
	"""Helper for on_cook_meat.

Callback function to remove the normal spit from the inventory.

Parameters:
        character_id - Id of the character.
"""
	objects.remove_item_from_inventory( character_id, "SET_SPIT" )
	objects.create_item_in_inventory( character_id, "SET_SPIT_WITH_MEAT" )

def cook_all_meat( character_id ):
	"""Cooks all meat in the chars inventory.

Parameters:
        character_id - Id of the character.
"""
	cook_meat( character_id, None, True )
	
def cook_meat( character_id, object_id, cookAll = False ):
	"""Called to cook meat.

Plays animation depending on the item the char uses.
Call other functions to replace raw meat with cooked meat.

Parameters:
        character_id - Id of the character.
        object_id    - Id of the object that is cooked.
        all          - True cooks all meat in the chars inventory.
"""

	if not can_cook_meat( character_id ):
		return

	cook_items = [ 'SET_PAN', 'SET_SPIT' ,'SET_POT_ON_A_BAR']
	tmp_cook_items = []
	cooking_item = None

	# delete every item from list that is not in the inventory
	for item in cook_items:
		if objects.count_in_inventory( character_id, item ): # cook items is not in inventory
			tmp_cook_items.append( item )

	cook_items = tmp_cook_items
	
	# check if char already has one of the cook_items equiped 
	for item in cook_items:
		# print 'if', character.is_equiped( character_id, item )
		if character.is_equiped( character_id, item ):
			cooking_item = item 

	if not cooking_item:
		# randomly choose cooking item and play accordant animation
		cooking_item = random.choice( cook_items )
	
	# print 'cook_items', cook_items
	# print 'cooking_item', cooking_item

	if cooking_item == "SET_PAN":
		character.play_animation( character_id, "CM_NPC_STEHEN_PFANNE_SCHWENKEN_HINKNIEN", [[ "ONSTART", remove_normal_pan ], 
										['ONCANCEL', Lambda('post_cook_meat( "%s" , "SET_PAN" , "cancel")' %character_id)]])
	elif cooking_item == "SET_SPIT":
		character.play_animation( character_id, "CM_KNIEND_BRATSPIESS_HALTEN_START", [[ "ONSTART", remove_normal_spit ], 
										['ONCANCEL', Lambda('post_cook_meat( "%s" , "SET_SPIT", "cancel" )' %character_id)]] )
	elif cooking_item == "SET_POT_ON_A_BAR":
		character.play_animation( character_id, "CM_KNIEND_KOCHTOPF_HALTEN_START" )
	
	on_cook_meat( character_id, object_id, cooking_item, cookAll )
	post_cook_meat( character_id, cooking_item )

def add_normal_pan( character_id):
	"""Helper function for cook_meat.

Callback function to add normal pan to the inventory, and remove the pan 
with meat.

Parameters:
        character_id - Id of the character.
"""
	if objects.count_in_inventory(character_id, 'SET_PAN_WITH_MEAT'):
		objects.remove_item_from_inventory( character_id, "SET_PAN_WITH_MEAT" )
		objects.create_item_in_inventory( character_id, "SET_PAN" )
	


def add_normal_spit( character_id ):
	"""Helper function for cook_meat.

Callback function to add normal spit to the inventory, and remove the spit 
with meat.

Parameters:
        character_id - Id of the character.
"""
	if objects.count_in_inventory(character_id, 'SET_SPIT_WITH_MEAT'):
		objects.remove_item_from_inventory( character_id, "SET_SPIT_WITH_MEAT" )
		objects.create_item_in_inventory( character_id, "SET_SPIT" )
				
def post_cook_meat( character_id, item , action = 'normal'):
	"""Helper function for cook_meat.

Called after meat is cooked.
The item used to cook is taken back into the inventory.
The item used before is equipped again.

Parameters:
        character_id - Id of the character.
"""
	# TODO überprüfen ob hier der onend callback auch beim oncancel feuert
	if action == 'normal':
		if item == "SET_PAN":
			character.play_animation( character_id, "CM_NPC_STEHEN_PFANNE_SCHWENKEN_AUFSTEHEN",[ "ONEND", add_normal_pan ])
		elif item == "SET_SPIT":
			character.play_animation( character_id, "CM_KNIEND_BRATSPIESS_HALTEN_ENDE", ["ONEND", add_normal_spit] )
		elif item == "SET_POT_ON_A_BAR":
			character.play_animation( character_id, "CM_KNIEND_KOCHTOPF_HALTEN_ENDE" )
			
	elif action == 'cancel':
		if item == 'SET_PAN':
			add_normal_pan(character_id)
		elif item == "SET_SPIT":
			add_normal_spit(character_id)
		elif item == "SET_POT_ON_A_BAR":
			pass
	
	objects.step_away( character_id )

def can_gut_object( character_id, object_id ):
	"""Returns True if the object can be gutted.

Parameters:
        character_id - Id of the character.
        object_id    - Id of the object.
"""
#	print "basis can_gut_object"
	typeid = ""
	if objects.has_attribute( object_id, "typeid" ):
		typeid = objects.get_attribute( object_id, "typeid" )
		
	if typeid=="LIZARD_SOMA": return False

	# check for animal
	if objects.has_attribute(object_id, "type"):
		_type = objects.get_attribute(object_id, "type")
		if _type=="animal" or typeid == "RES3D_WARGKADAVER_KOPFLOS":
			# knife in inventory?
			if (objects.count_in_inventory( character_id, 'SET_KNIFE' ) or
				objects.count_in_inventory( character_id, 'SET_BIG_KNIFE' )):
				# dead?
				if objects.is_destroyed( object_id ) or objects.get_attribute( object_id, "typeid" ) == "RES3D_WARGKADAVER_KOPFLOS":
					if "REST_RAIDER_" in object_id: return False
					return True
				else:
					return False
			else:
				return False
	return False

def on_heal_light_wounds( character_id, character_target_id ):
	"""Called when heal light wounds is selected from the context menu.

Parameters:
        character_id        - Id of the character.
        character_target_id - Id of the targetChar.
"""
	#print "on_heal_light_wounds", character_id, character_target_id
	mode = character.get_body_mode(character_id)
	lambdastring = 'on_heal_light_wounds_callback("%s", "%s")' %(character_target_id, character_id)
	if character_id!=character_target_id:
		if mode == "STAND":
			character.play_animation( character_id, "CM_STEHEN_UEBERGEBEN_WAFFENLOS" , callback=["ONEND", Lambda(lambdastring)])
		if mode == "KNEEL":
			character.play_animation( character_id, "CM_KNIEND_UEBERGEBEN_WAFFENLOS", callback=["ONEND", Lambda(lambdastring)] )
		if mode == "LIE":
			character.play_animation( character_id, "CM_LIEGEN_UEBERGEBEN_WAFFENLOS" , callback=["ONEND", Lambda(lambdastring)])
	else:
		Lambda(lambdastring)()
		
def on_heal_light_wounds_callback( character_target_id, character_id ):
	"""Helper function for on_heal_light_wounds.

Parameters:
        character_target_id - Id of the targetChar.
"""
	#print "on_heal_light_wounds_callback",  character_target_id

	if objects.is_unconscious(character_target_id) or objects.is_destroyed(character_target_id):
		# prevent healthy corpses :)
		return

	ackhit=objects.get_attribute(character_target_id, "hitpoints")
	maxhit=objects.get_attribute(character_target_id, "maxhitpoints")
	#//value .85 is also tested in y2kkichar.cpp
	if ackhit/maxhit > 0.85:
		objects.set_attribute(character_target_id, "hitpoints",maxhit)

		give_first_use_exp(character_id, "medicine", "specialisation_light_wounds")

def on_psychology( character_id, character_target_id ):
	"""Called when char uses psychology talent on another char.

Parameters:
        character_id        - Id of the character.
        character_target_id - Id of the targetChar.
"""
	#print "on_psychology", character_id, character_target_id
	lambdastring = 'on_psychology_callback("%s","%s")' %(character_id,character_target_id)
	if character_id!=character_target_id:
		mode = character.get_body_mode(character_id)
		if mode == "STAND":
			character.play_animation( character_id, "CM_STEHEN_UEBERGEBEN_WAFFENLOS" , callback=["ONEND", Lambda(lambdastring)])
		if mode == "KNEEL":
			character.play_animation( character_id, "CM_KNIEND_UEBERGEBEN_WAFFENLOS", callback=["ONEND", Lambda(lambdastring)] )
		if mode == "LIE":
			character.play_animation( character_id, "CM_LIEGEN_UEBERGEBEN_WAFFENLOS" , callback=["ONEND", Lambda(lambdastring)])
	else:
		# call callback directly
		Lambda(lambdastring)()

def on_psychology_callback( character_id,character_target_id ):
	"""Helper function for on_psychology.

Parameters:
        character_id        - Id of the character.
        character_target_id - Id of the targetChar.
"""
	if can_use_talent_psychology(character_id, character_target_id):
		objects.set_attribute(character_id, "last_use_of_psychology", system.get_mission_time())

		callback = 	"system.add_text(globaltext.TALENT_MEDICINE_PSYCHOLOGY_OFF);"\
					"import bonus;"\
					"bonus.remove_temp_bonus('%s', 'psychology')" % (character_target_id)
		callback = Lambda(callback)
		property_table = dict(zip(skill_tables.attributes, [2]*len(skill_tables.attributes))) # python mojo! :D
		bonus.add_temp_bonuses(character_target_id, property_table, "psychology", "2:0:0", callback, remove_on_leave=True)

		system.add_text(globaltext.TALENT_MEDICINE_PSYCHOLOGY % {"char": character_id})
		give_first_use_exp(character_id, "medicine", "psychology")
		
def can_use_talent_psychology(character_id, target):
	"""Checks if the char can use the talent 'psychology'.

This talent can only be used every 24 hours.

Parameters:
        character_id - Id of the char.
"""
	if not has_talent( character_id, "medicine", "psychology" ):
		return False

	if bonus.has_keyword(target, "psychology"): return False

	if objects.has_attribute(character_id, "last_use_of_psychology"):
		now = system.get_mission_time()
		time = objects.get_attribute(character_id, "last_use_of_psychology")
		if now - time < timerepr.time("24:0:0"): return False

	return True

def on_heal_alternative( character_id, character_target_id ):
	"""Called when the heal alternative action is selected from the context menu.

Parameters:
        character_id        - Id of the character.
        character_target_id - Id of the targetChar.
"""
	#print "on_heal_alternative", character_id, character_target_id
	mode = character.get_body_mode(character_id)
	lambdastring = 'on_heal_alternative_callback("%s","%s")' %(character_id,character_target_id)
	if character_id!=character_target_id:
		if mode == "STAND":
			character.play_animation( character_id, "CM_STEHEN_UEBERGEBEN_WAFFENLOS" , callback=["ONEND", Lambda(lambdastring)])
		if mode == "KNEEL":
			character.play_animation( character_id, "CM_KNIEND_UEBERGEBEN_WAFFENLOS", callback=["ONEND", Lambda(lambdastring)] )
		if mode == "LIE":
			character.play_animation( character_id, "CM_LIEGEN_UEBERGEBEN_WAFFENLOS" , callback=["ONEND", Lambda(lambdastring)])
	else:
		on_heal_alternative_callback(character_id,character_target_id)
def on_detox( character_id, character_target_id ):
	"""Called when the detox context menu entry is used.

Parameters:
        character_id        - Id of the character.
        character_target_id - Id of the targetChar.
"""
	print "on_detox", character_id, character_target_id
	mode = character.get_body_mode(character_id)
	lambdastring = 'on_detox_callback("%s","%s")' %(character_id,character_target_id)
	if character_id!=character_target_id:
		if mode == "STAND":
			character.play_animation( character_id, "CM_STEHEN_UEBERGEBEN_WAFFENLOS" , callback=["ONEND", Lambda(lambdastring)])
		if mode == "KNEEL":
			character.play_animation( character_id, "CM_KNIEND_UEBERGEBEN_WAFFENLOS", callback=["ONEND", Lambda(lambdastring)] )
		if mode == "LIE":
			character.play_animation( character_id, "CM_LIEGEN_UEBERGEBEN_WAFFENLOS" , callback=["ONEND", Lambda(lambdastring)])
	else:
		on_detox_callback(character_id,character_target_id)

def on_heal_alternative_callback( character_id, character_target_id ):
	"""Helper function for on_heal_alternative.

Parameters:
        character_id        - Id of the character.
        character_target_id - Id of the targetChar.
"""
	#print "on_heal_alternative_callback",  character_target_id
	if objects.count_in_inventory(character_id, "SET_ALOE_VERA") >0:#SET_ALOE_VERA
		item_id="SET_ALOE_VERA"#SET_ALOE_VERA
	elif objects.count_in_inventory(character_id, "SET_WOOD_GARLIC") >0:
		item_id="SET_WOOD_GARLIC"
	elif objects.count_in_inventory(character_id, "SET_BURNET") >0:
		item_id="SET_BURNET"
	else:
		pass
		#print "nothing to alternative heal"
		
	if objects.is_unconscious(character_target_id) or objects.is_destroyed(character_target_id):
		return

	if objects.has_attribute(item_id, "le_recovery"):
		value = objects.get_attribute(character_target_id, "hitpoints")
		value_max = objects.get_attribute(character_target_id, "maxhitpoints")
		if value<value_max:
			# if the item itself has no recovery value
			# take the value of the item type
			le_recovery=objects.get_attribute(item_id, "le_recovery")

			medicine = objects.get_attribute(character_id, "medicine")
			used_charge = 0 # amount of charge that is used from the item
			if item_id=="SET_ALOE_VERA": #SET_ALOE_VERA
				le_recovery+=skill_tables.medicine_aloe_vera(medicine)
				used_charge = 1
			elif item_id=="SET_WOOD_GARLIC":
				le_recovery+=skill_tables.medicine_wood_garlic(medicine)
				used_charge = 1
			elif item_id=="SET_BURNET":
				le_recovery+=skill_tables.medicine_burnet(medicine)
				used_charge = 1
				
			value+=le_recovery
			if value>value_max:
				value = value_max
				#print "heilung mit ", value
			objects.set_attribute(character_target_id, "hitpoints", value)
			if(used_charge == 1):
				objects.remove_item_from_inventory( character_id,item_id )
			system.update_ui()

			give_first_use_exp(character_id, "medicine", "alternative_medicine")

def on_detox_callback( character_id, character_target_id ):
	"""Helper function for on_detox.

Parameters:
        character_id        - Id of the character.
        character_target_id - Id of the targetChar.
"""
	print "on_detox_callback",character_id,  character_target_id
	if objects.count_in_inventory(character_id, "SET_ANGELICA") >0 and has_talent( character_id, "medicine", "alternative_medicine" ):
		item_id="SET_ANGELICA"
	elif objects.count_in_inventory(character_id, "SET_ANTIDOTE") >0 :
		item_id="SET_ANTIDOTE"
	else:
		print "return1"
		return
		
	if objects.is_unconscious(character_target_id) or objects.is_destroyed(character_target_id):
		print "return2"
		return
	print "doit"
	objects.set_attribute(character_target_id,"poison_ticks",0)
	objects.remove_item_from_inventory( character_id,item_id )
	system.update_ui()
	
	if item_id=="SET_ANGELICA": give_first_use_exp(character_id, "medicine", "alternative_medicine")


def on_detox_use_callback( character_id, character_target_id,item_id ):
	"""Helper function for on_use for detox items.

Parameters:
        character_id        - Id of the character.
        character_target_id - Id of the targetChar.
        item_id             - Id of the item used.
"""
	if objects.is_unconscious(character_target_id) or objects.is_destroyed(character_target_id):
		return
	objects.set_attribute(character_target_id,"poison_ticks",0)
	objects.remove_item_from_inventory( character_id,item_id )
	system.update_ui()

			
def on_heal( character_id, character_target_id ):
	"""Called when a char heals another char.

Parameters:
        character_id        - Id of the character.
        character_target_id - Id of the targetChar.
"""
	print "on_heal", character_id, character_target_id
	data("generic").unequiped_for_heal_anim = []
	lambdastring = 'on_heal_callback("%s","%s")' %(character_id,character_target_id)
	if character_id != character_target_id:
		data("generic").unequiped_for_heal_anim = character.get_items_in_hands(character_id)
		character.unequip_hands(character_id)
		objects.turn_to_object(character_id, character_target_id, callback=Lambda(lambdastring))
	else:
		Lambda(lambdastring)()

def on_heal_callback( character_id, character_target_id ):
	"""Helper function for on_heal.

Parameters:
        character_id        - Id of the character.
        character_target_id - Id of the targetChar.
"""
	# did target move? abort if so
	if objects.get_distance_to_object(character_id, character_target_id) > 3: return
	
	mode = character.get_body_mode(character_id)
	lambdastring = 'on_heal_callback_2("%s","%s")' %(character_id,character_target_id)
	if character_id != character_target_id:
		if mode == "STAND":
			character.play_animation( character_id, "CM_STEHEN_UEBERGEBEN_WAFFENLOS" , callback=["ONEND", Lambda(lambdastring)])
		if mode == "KNEEL":
			character.play_animation( character_id, "CM_KNIEND_UEBERGEBEN_WAFFENLOS", callback=["ONEND", Lambda(lambdastring)] )
		if mode == "LIE":
			character.play_animation( character_id, "CM_LIEGEN_UEBERGEBEN_WAFFENLOS" , callback=["ONEND", Lambda(lambdastring)])
	else:
		Lambda(lambdastring)()

def on_heal_callback_2( character_id, character_target_id ):
	"""Helper function for on_heal.

Parameters:
        character_id        - Id of the character.
        character_target_id - Id of the targetChar.
"""
	#print "on_heal_callback",  character_target_id
	for item in data("generic").unequiped_for_heal_anim:
		character.equip(character_id, item)

	item_id, item_type = find_best_heal_item(character_id, character_target_id)

	if item_id and item_type:
		use_heal_item(character_id, character_target_id, item_id, item_type)

def find_best_heal_item(char, target=None):
	"""Returns the best item to heal the target.

get_heal_item_strength is used to evaluate the items.
"best" item means:
    If there are items that heal target completly an item is selected, that does a complete
    heal, but wastes as little healing strengt/HP as possible.
    If no item can completly heal the target the strongest item is selected.

Parameters:
        char   - Id of the char that does the healing.
        target - Id of the char that is healed.
"""
	inventory = objects.get_inventory_id_list(char)
	best_item = None
	best_item_type = None
	needed_HP = 0
	opt_HP = 0
	
	if target:
		needed_HP = objects.get_attribute(target, "maxhitpoints") - objects.get_attribute(target, "hitpoints")
	
	for item in inventory:
		item_type = objects.get_attribute(item, "typeid")
		HP = get_heal_item_strength(char, item, item_type)
		if not target:
			if HP > opt_HP:
				best_item = item
				best_item_type = item_type
				opt_HP = HP
		else:
			if opt_HP < needed_HP:
				if HP > opt_HP:
					best_item = item
					best_item_type = item_type
					opt_HP = HP
			else:
				if HP < opt_HP and HP >= needed_HP:
					best_item = item
					best_item_type = item_type
					opt_HP = HP

	return (best_item, best_item_type)
	
	
def get_heal_item_strength(character_id, item_id, item_type):
	"""Returns how much HP the item could heal when used by this char.
	
Skill and talents of char are used to evaluate item heal strength.

Parameters:
        character_id - Id of the char that does the healing.
        item_id      - Id of the item that is evaluated.
        item_type    - Id of the item type of the item."""
	# le recovery item: some are only useable if character has skill "alternative_medicine"
	if item_type=="SET_ALOE_VERA" or item_type=="SET_WOOD_GARLIC" or item_type=="SET_BURNET" or item_type=="SET_ANGELICA":
		if not has_talent(character_id, "medicine", "alternative_medicine"):
			return 0

	# if the item itself has no recovery value
	# take the value of the item type
	le_recovery = 0
	if objects.has_attribute(item_id, "le_recovery"):
		le_recovery=objects.get_attribute(item_id, "le_recovery")
	elif objects.has_attribute(item_type, "le_recovery"):
		le_recovery=objects.get_attribute(item_type, "le_recovery")
		
	if le_recovery <= 0: return 0

	if objects.has_attribute(item_id, "charge"):
		if objects.get_attribute(item_id, "charge") <= 0: return 0
	if objects.has_attribute(item_type, "charge"):
		if objects.get_attribute(item_type, "charge") <= 0: return 0
	
	medicine = objects.get_attribute(character_id, "medicine")
	if item_type=="SET_MEDIPACK_SMALL":
		le_recovery+=skill_tables.medicine_medipack_standard(medicine)
	elif (item_type=="SET_MEDIPACK_BIG"):
		le_recovery+=skill_tables.medicine_medipack_big(medicine)
	elif (item_type=="SET_MULTI_MEDIPACK"):
		le_recovery+=skill_tables.medicine_medipack_big(medicine) * 1.2 # Anpassung auf 30 pro charge
	elif (item_type=="SET_ALOE_VERA" ):
		le_recovery+=skill_tables.medicine_aloe_vera(medicine)
	elif (item_type=="SET_WOOD_GARLIC" ):
		le_recovery+=skill_tables.medicine_wood_garlic(medicine)
	elif (item_type=="SET_BURNET" ):
		le_recovery+=skill_tables.medicine_burnet(medicine)
	elif (item_type=="SET_ALOE_VERA_OINTMANT" ):
		le_recovery+=skill_tables.medicine_aloe_vera_ointmant(medicine)
	elif (item_type=="SET_WOOD_GARLIC_OINTMANT" ):
		le_recovery+=skill_tables.medicine_wood_garlic_ointmant(medicine)
	elif (item_type=="SET_BURNET_OINTMANT" ):
		le_recovery+=skill_tables.medicine_burnet_ointmant(medicine)

	return le_recovery

def use_heal_item(character_id, target, item_id, item_type):
	"""This function uses an item to heal the target.
	
It is called by on_use (for heal items) and on_heal.

Parameters:
        character_id - Id of the char that does the healing.
        target       - Id of the char that is healed.
        item_id      - Id of the item that is used.
        item_type    - Id of the item type of the item."""
	if target != None and (objects.is_unconscious(target) or objects.is_destroyed(target)):
		# prevent healthy corpses :)
		return False
		
	if not target: target = character_id

	# le recovery item: some are only useable if character has skill "alternative_medicine"
	if item_type=="SET_ALOE_VERA" or item_type=="SET_WOOD_GARLIC" or item_type=="SET_BURNET" or item_type=="SET_ANGELICA":
		if not has_talent(character_id, "medicine", "alternative_medicine"):
			system.add_text(globaltext.MESSAGE_NO_ALTERNATIVE_MEDICINE % {"item": objects.get_attribute(item_type, "name")})
			return True

	value = objects.get_attribute(target, "hitpoints")
	value_max = objects.get_attribute(target, "maxhitpoints")
	if value<value_max:
		# if the item itself has no recovery value
		# take the value of the item type
		if objects.has_attribute( item_id, "le_recovery" ):
			le_recovery=objects.get_attribute(item_id, "le_recovery")
		else:
			le_recovery=objects.get_attribute(item_type, "le_recovery")

		medicine = objects.get_attribute(character_id, "medicine")
		used_charge = 0 # amount of charge that is used from the item
		remove_if_empty = True # should the item be removed from inventory if it is empty
		recreate_jar=False #if its an ointmant, remove and create empty jar
		if item_type=="SET_MEDIPACK_SMALL":
			le_recovery+=skill_tables.medicine_medipack_standard(medicine)
			used_charge = 1
		elif (item_type=="SET_MEDIPACK_BIG"):
			le_recovery+=skill_tables.medicine_medipack_big(medicine)
			used_charge = 1
		elif (item_type=="SET_MULTI_MEDIPACK"):
			le_recovery+=skill_tables.medicine_medipack_big(medicine) * 1.2 # Anpassung auf 30 pro charge
			used_charge = 1
		elif (item_type=="SET_ALOE_VERA" ):
			le_recovery += skill_tables.medicine_aloe_vera(medicine)
			used_charge = 1
		elif (item_type=="SET_WOOD_GARLIC" ):
			le_recovery += skill_tables.medicine_wood_garlic(medicine)
			used_charge = 1
		elif (item_type=="SET_BURNET" ):
			le_recovery += skill_tables.medicine_burnet(medicine)
			used_charge = 1
		elif (item_type=="SET_ALOE_VERA_OINTMANT" ):
			le_recovery += skill_tables.medicine_aloe_vera_ointmant(medicine)
			used_charge = 1
			recreate_jar=True
		elif (item_type=="SET_WOOD_GARLIC_OINTMANT" ):
			le_recovery += skill_tables.medicine_wood_garlic_ointmant(medicine)
			used_charge = 1
			recreate_jar=True
		elif (item_type=="SET_BURNET_OINTMANT" ):
			le_recovery += skill_tables.medicine_burnet_ointmant(medicine)
			used_charge = 1
			recreate_jar=True
		elif global_defines.is_water_repository( item_id ): # le_recovery depends on the fill level
			current_charge    = objects.get_attribute( item_id, "charge" ) # current charge value
			max_charge	  = objects.get_attribute( item_type, "charge" ) # max charge value

			# calc recovery of the repository 
			old_le_recovery = le_recovery
			le_recovery = old_le_recovery * ( float(current_charge) / float(max_charge) )

			# how much recovery does the char need
			value_diff = value_max - value
			if value_diff < le_recovery:
				le_recovery = value_diff

			# calc the charge that is needed to recover
			needed_charge = ( float( le_recovery ) / float( old_le_recovery ) ) * max_charge

			used_charge = needed_charge
			remove_if_empty = False
			
		value+=le_recovery
		if value>value_max:
			value = value_max
		objects.set_attribute(target, "hitpoints", value)

		charge = 0
		if objects.has_attribute(item_id, "charge"):
			charge = objects.get_attribute(item_id, "charge")
			charge = (int)(charge - used_charge)
		elif objects.has_attribute(item_type, "charge"):
			charge = objects.get_attribute(item_type, "charge")
			charge = (int)(charge - used_charge)
#			assert charge >= 0 //jan: can happen in old savegames
		if charge <= 0 and remove_if_empty:
			equipment = objects.get_inventory_id_list( character_id )
			if item_id in equipment:
				#for item in equipment:
				objects.remove_item_from_inventory(character_id, item_id)
				if recreate_jar:
					objects.create_item_in_inventory(character_id,"SET_OINTMANT_JAR")
			else:
				objects.pick_up_item_direct(character_id,item_id)
				objects.remove_item_from_inventory(character_id,item_id)
				if recreate_jar:
					objects.create_item_in_inventory(character_id,"SET_OINTMANT_JAR")
		else:
			objects.set_attribute(item_id, "charge", charge)
			if objects.has_attribute(item_type, 'weight_container') and objects.has_attribute(item_type, 'charge') and objects.has_attribute(item_type, 'weight'):
				weight_container = objects.get_attribute(item_type, 'weight_container')
				weight_per_charge = (objects.get_attribute(item_type,'weight') - weight_container) / objects.get_attribute(item_type, "charge")
				new_weight = (charge * weight_per_charge) + weight_container
				objects.set_attribute(item_id, 'weight', new_weight)

		system.update_ui()
		objects.set_attribute(character_id, "is_healing",False )

		return True
	else:
		system.add_text(globaltext.MESSAGE_NO_HEALING_NEEDED)
		return True

def use_drug(character_id, object_id, item_id, item_type, backlash=True):
	"""Called by on_use when a drug is used."""

	if not object_id: object_id = character_id
	
	if bonus.has_keyword(object_id, "drug_effects"):
		system.add_text(globaltext.DRUGS_ALREADY_UNDER_INFLUENCE % {"char": objects.get_attribute(object_id, "name")})
		return True

	drug = objects.get_attribute(item_type, "drug_effects")

	timeout = drug["effect_time"]
	text = globaltext.DRUGS_CLEAN % {"char": objects.get_attribute(object_id, "name")}
	callback2 = "system.add_text(\"" + text + "\"); import bonus;"\
				"bonus.remove_temp_bonus('%s', 'drug_effects')" % (object_id)
	text = globaltext.DRUGS_BACKLASH % {"char": objects.get_attribute(object_id, "name")}
	callback = "system.add_text(\"" + text + "\"); import bonus;"\
				"bonus.reverse_temp_bonus('%s', 'drug_effects', timeout='%s', callback=Lambda(\"\"\"%s\"\"\"))" %\
				(object_id, timeout, callback2)
	callback = Lambda(callback)
	
	property_table = drug.copy()
	del property_table["effect_time"]
	if "hitpoints" in property_table:
		diff = bonus.add_temp_bonus(object_id, "maxhitpoints", property_table["hitpoints"], "drug_effects")
		property_table["hitpoints"] = diff
	bonus.add_temp_bonuses(object_id, property_table, "drug_effects", timeout, callback)
				
	objects.remove_item_from_inventory(character_id, item_id)
	
	return True

def pre_gut_object( character_id ):
	"""Called before an object is gutted.

Equips the player with a weapon needed to gut, and marks the old item so
it can be equipped again after gutting.

Parameters:
        character_id - Id of the character.
"""

	# list of weapon that can be used to gut objects
	gut_weapons = [ 'SET_KNIFE', 'SET_BIG_KNIFE' ]

	equip_and_mark_unequiped( character_id, gut_weapons, "gut_item" )

def post_lay_down_char( carrying_char_id, carried_char_id ):
	"""Called when a char begins to lay down the one he is carrying.

Parameters:
        carrying_char_id - Id of the char that is going to lay down the other.
        carried_char_id  - Id of the carried char.
"""
	pass

def pre_carry_char( carrying_char_id, carried_char_id ):
	"""Called when a char begins to carry another char.

Parameters:
        carrying_char_id - Id of the char that is going to lay down the other.
        carried_char_id  - Id of the carried char.
"""
	pass

def post_gut_object( character_id, object_id = None ):
	"""Called after an object is gutted.

The weapon used to gut is taken back into the inventory.
The item used before is equipped again.

Parameters:
        character_id - Id of character.
        object_id    - Id of the animal that is gutted.
"""
	unequip_and_equip_marked( character_id, "gut_item" )

def npc_ki_loot_corpse(char):
	"""Handles NPCs that are looting corpses.

This code is inactive for now.
"""
	corpse_action_range = 30
	if not system.in_combat_mode() and not objects.is_fighting(char):
		# only loot if there is enough inventory space, leave reserve for scripting		
		available_slots = objects.get_inventory_slot_count(char) - len(filter(lambda slot: len(slot[0]), objects.get_inventory_ids(char)))
		if available_slots < 6: return
		
		x = objects.get_x(char)
		y = objects.get_y(char)
		all_chars_in_range = system.get_objects(type="character", left=x-corpse_action_range,
			top=y-corpse_action_range, right=x+corpse_action_range, bottom=y+corpse_action_range)
		corpses = filter(lambda ch: objects.is_destroyed(ch), all_chars_in_range)
		for corpse in corpses:
			# corpse should only be looted once
			if objects.has_attribute(corpse, "looted_by_npc")\
			and objects.get_attribute(corpse, "looted_by_npc"): continue
			
			# don't loot if pc is closer than 10 meter
			for pc in system.get_pcs():
				if pc != corpse and objects.get_distance(pc, corpse) < 10: continue
			
			# don't loot if corpse has quest item
			cont = False
			for item in objects.get_inventory_id_list(corpse):
				if objects.has_attribute(item, "generic_item")\
				and not objects.get_attribute(item, "generic_item"):
					cont=True
					break
			if cont: continue
			
			#print char, "loots", corpse
			objects.set_attribute(corpse, "looted_by_npc", True)
			npc_loots_npc(char, corpse)
			break
	
def npc_loots_npc(looter, looted):
	"""Helper function for npc_ki_loot_corpse."""
	assert objects.is_destroyed(looted)

	pos = get_loot_position(looted)
	if pos == None:
		objects.set_attribute(looted, "looted_by_npc", False)
		return
	inner_callback = "objects.cancel_commandos('%s'); npc_loots_npc_2(%s, '%s', '%s')" % (looter, pos, looter, looted)
	callback = "system.timed_callback(100, Lambda(\"%s\"))" % inner_callback
	objects.move_to(looter, pos[0], pos[1], callback=Lambda(callback))
	
def npc_loots_npc_2(pos, looter, looted):
	"""Helper function for npc_ki_loot_corpse."""
	
	# don't loot if pc is closer than 10 meter
	for pc in system.get_pcs():
		if pc != looted and objects.get_distance(pc, looted) < 10: return
		
	# play animations
	objects.turn_to_direction(looter, objects.get_direction_to_object(looter, looted)+pos[2])
	character.play_animation(looter, "CM_NPC_STEHEN_TIER_AUSWEIDEN_START")
	character.play_animation(looter, "CM_NPC_STEHEN_TIER_AUSWEIDEN_LOOP")
	character.play_animation(looter, "CM_NPC_STEHEN_TIER_AUSWEIDEN_ENDE")
	
	# only loot if there is enough inventory space, leave reserve for scripting
	available_slots = objects.get_inventory_slot_count(looter) - len(filter(lambda slot: len(slot[0]), objects.get_inventory_ids(looter)))
	max_looted_items = available_slots - 5
	
	# transfer items
	loot = objects.get_inventory_id_list(looted)
	while max_looted_items > 0 and len(loot):
		objects.transfer_item(looted, loot.pop(0), looter)
		max_looted_items -= 1

	
def get_loot_position( looted ):
	"""Returns the position where the char should move to loot the corpse.

Use get_gut_position if you want to loot an animal.

Parameters:
        looted - Id of the char that should be looted.
"""

	offsets = {
		"CM_STERBEN_ZUSAMMENSACKEN"			: [ 0.70,  0.00,   0],		
		"CM_STERBEN_SACKEN_NACH_LINKS"		: [ 0.00,  0.70,   0],		
		"CM_STERBEN_SACKEN_NACH_VORN"		: [ 0.70, -0.20,   0],		
		"CM_STERBEN_SACKEN_NACH_HINTEN"		: [-0.70,  0.20,   0],		
		"CM_STERBEN_FALLEN_NACH_VORN"		: [ 0.75, -0.05,   0],
		"CM_STERBEN_FLIEGEN_NACH_VORN"		: [ 0.75,  0.15,   0],
		"CM_STERBEN_FLIEGEN_NACH_HINTEN"	: [ 0.70,  0.00,   0],
		"CM_KNIEND_STERBEN1"				: [ 0.75, -0.10,   0],		
		"CM_LIEGEN_STERBEN"					: [ 0.65, -0.30,   0],		
		"CM_NPC_SIEBENSEELE_STERBEN"		: [-0.55,  0.55,   0]
	}
	
	# get offset
	anim = character.get_act_animation_name(char=looted)
	if anim not in offsets:
		return None
		# apparently the death animation is set with a delay. a char can be dead already but can
		# still have his old animation for a moment. 
		# raise Exception, "char '%s' has unknown death animation '%s'" % (looted, anim)
	offset = offsets[anim]
	
	# get corpse base point
	corpse_x = objects.get_x(looted)
	corpse_y = objects.get_y(looted)
	
	# get distance between corpse and loot point
	radius = math.sqrt(offset[0]**2 + offset[1]**2)

	# get direction of the corpse 
	direction = objects.get_direction(looted)
	
	# direction to loot point for corpse direction == 0 
	target_dir = objects.get_direction_to_position(looted, corpse_x + offset[0], corpse_y + offset[1])
	
	# move loot point according to rotation/direction of the corpse
	angle = math.radians(target_dir + direction)
	target_x = corpse_x + math.sin(angle) * radius
	target_y = corpse_y - math.cos(angle) * radius
	
	return [target_x, target_y, offset[2]]

	
def get_gut_position( character_id, animal_id ):
	"""Returns the position where the char should move to gut the object.

Parameters:
        character_id - Id of the character.
        animal_id    - Id of the animal that should be gutted.
"""
	print "get_gut_position", character_id, animal_id
	animal = None	

	if objects.has_attribute( animal_id, "typeid" ):
		animal = objects.get_attribute( animal_id, "typeid" )

	distance = 0.9

	if (animal=="BEAR"):
		distance = 0.8
	elif (animal=="TIGER"):
		distance = 0.9
	elif (animal=="WOLF"):
		distance = 0.75
	elif (animal=="HORSE"):
		distance = 0.85
	elif (animal=="COW"):
		distance = 0.9
	elif (animal=="DEER"):
		distance = 0.9
	elif (animal=="HYENA"):
		distance = 1.3
	elif (animal=="ANTELOPE"):
		distance = 0.7
	elif (animal=="WILDDOG"):
		distance = 0.7
	elif (animal=="BISON"):
		distance = 1.2
	elif (animal=="LIZARD_SOMA"):
		distance = 0.7
	elif (animal=="PIG"):
		distance = 0.8
	elif (animal=="DONKEY"):
		distance = 0.85
	elif (animal=="WARG"):
		distance = 0.9
	elif (animal=="RES3D_WARGKADAVER_KOPFLOS"):
		centerx = objects.get_x(animal_id)
		centery = objects.get_y(animal_id)
		charx = centerx + 2
		chary = centery - 1
		direction = objects.get_direction(animal_id)
		pos_char = calc_rotated_pos(centerx, centery, charx, chary, direction)
		angle = 70
		return [pos_char[0], pos_char[1], get_dir(pos_char[0], pos_char[1], centerx, centery) + angle]

	p1 = objects.get_full_dummy_position(animal_id, "Bip01 Spine1")
	p2 = objects.get_full_dummy_position(animal_id, "Bip01 Spine2")
	dist = math.sqrt((p1[0]-p2[0])**2 + (p1[1]-p2[1])**2)
	spine = calc_rotated_pos(p1[0], p1[1], p2[0], p2[1], 0, 0.5*dist)
	p1 = objects.get_full_dummy_position(animal_id, "Bip01 R Calf")
	p2 = objects.get_full_dummy_position(animal_id, "Bip01 R ForeArm")
	dist = math.sqrt((p1[0]-p2[0])**2 + (p1[1]-p2[1])**2)
	abdomen = calc_rotated_pos(p1[0], p1[1], p2[0], p2[1], 0, 0.5*dist)
	pos_char = calc_rotated_pos(spine[0], spine[1], abdomen[0], abdomen[1], 180, distance)
	return [pos_char[0], pos_char[1], get_dir(pos_char[0], pos_char[1], spine[0], spine[1])]

def on_gut_object( character_id, object_id ):
	"""Called if an item is gutted by a character.

!Attention!
If overridden in zone script, the function in zone script needs to return 
True or False instead of calling this function:
        True  - Stops calling of standard behavior.
        False - Calls the standard functions(object_event).

Parameters:
        character_id - Id of the character.
        object_id    - Id of the object.
"""
	print "on_gut"
	old_level = 0
	if objects.has_attribute( object_id, "disembowl_level" ):
		old_level = objects.get_attribute( object_id, "disembowl_level" )
	new_level = objects.get_attribute( object=character_id, attribute="survival" )

	rand = random.random()
	animal = None	

	if objects.has_attribute(object_id, "typeid"):
		animal = objects.get_attribute(object_id, "typeid")

	if (new_level <= 14):
		# 40% chance of injuring
		if rand < 0.4:
			objects.damage( character_id, 5 )
			comments.comment(character_id=character_id, text="DISEMBOWL_INJURY")
	elif (new_level <= 39):
		# 20% chance of injuring
		if rand < 0.2:
			objects.damage( character_id, 5 )
			comments.comment(character_id=character_id, text="DISEMBOWL_INJURY")

	if (new_level > old_level):
		objects.set_attribute( object_id, "disembowl_level", new_level )

		def get_loot_for_level(level):
			# what stuff gets char
			meat = 0
			teeth = False
			claws = False
			pelt = False
			if (level >= 40):
				if (level <= 54):
					meat = 1
				elif (level <= 69):
					meat = 3
				elif (level <= 84):
					meat = 6
					pelt = True
				elif (level <= 94):
					meat = 8
					pelt = True
					claws = True
				elif (level <= 104):
					meat = 10
					pelt = True
					claws = True
					teeth = True
				elif (level <= 114):
					meat = 12
					pelt = True
					claws = True
					teeth = True
				elif (level <= 124):
					meat = 13
					pelt = True
					claws = True
					teeth = True
				elif (level <= 134):
					meat = 14
					pelt = True
					claws = True
					teeth = True
				elif (level <= 149):
					meat = 15
					pelt = True
					claws = True
					teeth = True
				else:
					meat = 16
					pelt = True
					claws = True
					teeth = True
			return meat, pelt, claws, teeth

		meat, pelt, claws, teeth = get_loot_for_level(new_level)
		old_meat, old_pelt, old_claws, old_teeth = get_loot_for_level(old_level)

		# Look for existing meat in the animals inventory.
		# Remove it but remember the amount of meat to
		# add it to the newly gutted meat.
		# This prevents the existence of many small pieces
		# of meat in the animals inventory
		existing_meat = 0
		inventory = objects.get_inventory_list( object_id )

		if inventory:
			meat_rating = {	'SET_MEAT_RAW_HUMONGOUS': 10,
					'SET_MEAT_RAW_BIG': 6,
					'SET_MEAT_RAW': 4,
					'SET_MEAT_RAW_SMALL': 3,
					'SET_MEAT_RAW_TINY': 1 }

			for item in inventory:
				# if the item is meat then add it to the existing meat
				if meat_rating.has_key( item ):
					existing_meat = existing_meat + meat_rating[ item ]
					# remove existing meat from the inventory
					objects.remove_item_from_inventory( object_id, item )

		
		# diff of old and new stuff
		meat = meat - old_meat + existing_meat
		pelt = pelt and not old_pelt
		claws = claws and not old_claws
		teeth = teeth and not old_teeth

		# calc item list
		stuff = []
		while meat >= 3:
			if meat >= 10:
				meat = meat - 10
				stuff.append( "SET_MEAT_RAW_HUMONGOUS" )
			if meat == 8:
				# to make shure one gets 2 SET_MEAT_RAW when disembowling for 8 meat
				meat = meat - 4
				stuff.append( "SET_MEAT_RAW" )
			if meat >= 6:
				meat = meat - 6
				stuff.append( "SET_MEAT_RAW_BIG" )
			if meat >= 4:
				meat = meat - 4
				stuff.append( "SET_MEAT_RAW" )
			if meat >= 3:
				meat = meat - 3
				stuff.append( "SET_MEAT_RAW_SMALL" )
		# add remaining 1 hitpoint meat 
		for dummy in range( meat ):
			stuff.append( "SET_MEAT_RAW_TINY" )

		if (animal=="BEAR"):
			if pelt:
				stuff.append( "SET_BEAR_SKIN" )
			if claws:
				stuff.append( "SET_BEAR_CLAW" )
			if teeth:
				stuff.append( "SET_BEAR_TEETH" )
		elif (animal=="TIGER"):
			if pelt:
				stuff.append( "SET_TIGER_FUR" )
			if claws:
				stuff.append( "SET_TIGER_CLAW" )
			if teeth:
				stuff.append( "SET_TIGER_TEETH" )
		elif (animal=="WOLF"):
			if pelt:
				stuff.append( "SET_WOLF_PELT" )
			if claws:
				stuff.append( "SET_WOLF_CLAW" )
			if teeth:
				stuff.append( "SET_WOLF_TEETH" )
		elif (animal=="HORSE"):
			if pelt:
				stuff.append( "SET_HORSE_SKIN" )
		elif (animal=="COW"):
			if pelt:
				stuff.append( "SET_COW_SKIN" )
		elif (animal=="DEER"):
			if pelt:
				stuff.append( "SET_DEER_SKIN" )
		elif (animal=="HYENA"):
			if pelt:
				stuff.append( "SET_HYENA_PELT" )
			if claws:
				stuff.append( "SET_HYENA_CLAW" )
			if teeth:
				stuff.append( "SET_HYENA_TEETH" )
		elif (animal=="DONKEY"):
			pass
			#if pelt:
				#stuff.append( "SET_DONKEY_PELT" )
		elif (animal=="PIG"):
			pass
			#if pelt:
				#stuff.append( "SET_PIG_PELT" )
		elif (animal=="ANTELOPE"):
			if pelt:
				stuff.append( "SET_ANTELOPE_PELT" )
		elif (animal=="WILDDOG"):
			if pelt:
				stuff.append( "SET_WILD_DOG_PELT" )
			if claws:
				stuff.append( "SET_WILD_DOG_CLAW" )
			if teeth:
				stuff.append( "SET_WILD_DOG_TEETH" )
		elif animal=="WARG" or animal == "RES3D_WARGKADAVER_KOPFLOS":
			if "SET_WARG_HEAD" in objects.get_inventory_list( object_id):
				objects.set_attribute( object_id, "has_head_in_inventory", True )
			# warg has nothing to gut. But it must be recognized by this function.
		elif (animal=="BISON"):
			if pelt:
				stuff.append( "SET_BISON_SKIN" )
		else:
			raise ValueError, "unknown animal type '" + object_id + "'"

		if stuff:
			objects.create_item_in_inventory(
				object=object_id, equipment=stuff)
#		else:
#			print "no_survival"
#			system.add_text(globaltext.NO_SURVIVAL_SKILL_RESULT % {"char": objects.get_attribute(character_id, "name")})
		

	inventorylist = objects.get_inventory_list(object_id)

	if len( inventorylist ) > 0:
		system.item_panel( character_id, object_id )
		give_first_use_exp(character_id, "gut_animal")
	else:
		system.add_text(globaltext.NO_SURVIVAL_SKILL_RESULT % {"char": objects.get_attribute(character_id, "name")})

def get_group_speed(chars):
	"""Helper function for update_speed; group speed is the speed of the slowest char.

Parameters:
        chars - List of ids of chars.
"""
	def get_speed(char):
		speed = objects.get_attribute(char, "speed_factor")
		if character.is_carrying_char(char) or character.is_carried(char):
			speed = 0.5
		return speed

	speeds = map(lambda char: get_speed(char), chars)
	speed = min(speeds)
	return speed

def update_speed( character_id ):
	"""Calculates and sets character speed.

Parameters:
        character_id - Id of the character.
"""
	
	##--> um zu verhindern dass bei laufender cutscene der speed_factor geändedrt wird <--##
	if system.is_cutscene():
		return
	
	load = float(character.get_load( char=character_id ))

	strength = objects.get_attribute( object=character_id, attribute="strength" )
	speed_factor = skill_tables.agility_move_speed(
		objects.get_attribute( object=character_id, attribute="agility" ))

	if strength == 0: rel_load = 0
	else: rel_load = load / skill_tables.strength_max_load(strength)
	speed_factor *= skill_tables.strength_move_speed(rel_load)
	
	# move silent talents can influence speed for bodymodes "KNEEL" & "LIE"
	mode = character.get_body_mode(character_id)
	if mode == "KNEEL" and has_talent(character_id, "sneak", "sneak_fast"):
		speed_factor *= 1.5
	if mode == "LIE" and has_talent(character_id, "sneak", "crawl_fast"):
		speed_factor *= 2.0
		
	if objects.has_attribute(character_id, "group_move"):
		group = objects.get_attribute(character_id, "group_move")
		if group:
			speed_factor = get_group_speed(objects.get_attribute(character_id, "group_move"))

	if character.is_carrying_char(character_id) or character.is_carried(character_id):
		speed_factor = 1.0

	objects.set_attribute( object=character_id, attribute="rel_load", value=rel_load )
	objects.set_attribute( object=character_id, attribute="speed_factor", value=speed_factor )


def can_equip( objectid, itemtype ):
	"""Returns True if the char can equip the item.

Parameters:
        objectid - Id of the character.
        itemtype - Type of the item.
"""
	# only player characters can equip
	if not character.exists(objectid):
		return False

	if objects.is_unconscious( objectid ):
		return False

	# only items with non empty "occupied_slots" attribute are equipable
	if not objects.has_attribute(itemtype, "occupied_slots"):
		return False
	if not len(objects.get_attribute(itemtype, "occupied_slots")):
		return False

	# char may have unusable/forbidden slots
	if objects.has_attribute(objectid, "forbidden_slots"):
		used_slots = objects.get_attribute(itemtype, "occupied_slots")
		forbidden_slots = objects.get_attribute(objectid, "forbidden_slots")
		for slot in used_slots:
			if slot in forbidden_slots:
				return False

	return True

def can_unequip( objectid, itemtype ):
	"""Returns True if the char can unequip this item.

Parameters:
        objectid - Id of the character.
        itemtype - Type of the item.
"""
	# only player characters can equip
	if not character.exists(objectid):
		return False

	if objects.is_unconscious( objectid ):
		return False

	return True

def helper_appearance(objectid, appearance_slot, itemtype):
	"""Helper function for on_equip and on_unequip.

Parameters:
        objectid        - Id of the character.
        appearance_slot - Slot id.
        itemtype        - Type of the item.
"""
	objects.set_attribute(objectid, appearance_slot, itemtype)
	character.update_appearance(objectid)
	calc_armor_value(objectid)

def helper_remove_weapon_accustomisation(objectid, itemtype, itemid):
	"""Helper function for on_equip, on_unequip, and on_object_killed.

Parameters:
        objectid - Id of the character.
        itemtype - Type of the item.
        itemid   - Id of the item.
"""

	if not objectid or not len(objectid): return
	if not itemtype or not len(itemtype): return
	while objects.has_attribute(itemtype, "base_weapon"):
		itemtype = objects.get_attribute(itemtype, "base_weapon")
	if not objects.has_attribute(itemtype, "item_type"): return
	if objects.get_attribute(itemtype, "item_type")!="weapon": return
	slot = objects.get_attribute(itemtype, "occupied_slots")[0]

	#jan: does currently not work for wurf weapons
	_type = objects.get_attribute(itemtype, "weapon_type")
	if(_type=="wurf"):
		return
	
	assert len(_type)
	type_list = ["schwer", "leicht", "sniper", "wurf"]
	if _type in type_list:
		bonus.remove_temp_bonus(objectid, "weapon_accustom_bonus" + slot)

def helper_add_weapon_accustomisation(objectid, itemtype, itemid):
	"""Helper function for on_equip, on_unequip and on_object_killed.

Parameters:
        objectid - Id of the character.
        itemtype - Type of the item.
        itemid   - Id of the item.
"""

	if not objectid or not len(objectid): return
	if not itemtype or not len(itemtype): return
	while objects.has_attribute(itemtype, "base_weapon"):
		itemtype = objects.get_attribute(itemtype, "base_weapon")
	if not objects.has_attribute(itemtype, "item_type"): return
	if objects.get_attribute(itemtype, "item_type")!="weapon": return
	slot = objects.get_attribute(itemtype, "occupied_slots")[0]
	
	#jan: does currently not wor for throwing weapons, so early out here
	_type = objects.get_attribute(itemtype, "weapon_type")
	if(_type=="wurf"):
		return
	assert not objects.has_attribute(objectid, "weapon_accustom_bonus" + slot)

	id_kills = 0
	type_kills = 0
	if objects.has_attribute(objectid, "weapon_type_history"):
		weapon_type_history = objects.get_attribute(objectid, "weapon_type_history")
		if itemtype in weapon_type_history:
			type_kills = weapon_type_history[itemtype]
			type_kills = sum(type_kills)
	if objects.has_attribute(objectid, "weapon_id_history"):
		weapon_id_history = objects.get_attribute(objectid, "weapon_id_history")
		if itemid in weapon_id_history:
			id_kills = weapon_id_history[itemid]
			id_kills = sum(id_kills)
	skill_bonus = skill_tables.weapon_accustoming(id_kills, type_kills)
	if skill_bonus:
		_type = objects.get_attribute(itemtype, "weapon_type")
		assert len(_type)
		type_list = ["schwer", "leicht", "sniper", "wurf"]
		skill_list = ["heavy_weapons", "light_weapons", "sniper_weapons", "throw_weapons"]
		if _type in type_list:
			skill = skill_list[type_list.index(_type)]
			bonus.add_temp_bonus(objectid, skill, skill_bonus, "weapon_accustom_bonus" + slot, remove_on_leave=True)

def helper_update_talent_effects(objectid):
	"""Helper function for on_attribute_change.

Parameters:
        objectid - Id of the character.
"""
	weapon_id = character.get_primary_weapon(objectid)
	if weapon_id != "":
		weapon_type = objects.get_attribute(weapon_id, "typeid")
		helper_remove_talent_effects(objectid, weapon_type, weapon_id)
		helper_add_talent_effects(objectid, weapon_type, weapon_id)

def helper_remove_talent_effects(objectid, itemtype, itemid):
	"""Helper function for on_equip.

Parameters:
        objectid - Id of the character.
        itemtype - Type of the item.
        itemid   - Id of the item.
"""
	if not objects.has_attribute(objectid, "equip_dont_setup_attributes"):
		objects.set_attribute(objectid, "headshot_chance", None)
		objects.set_attribute(objectid, "critical_hit_chance", None)
		objects.set_attribute(objectid, "reload_speed_factor", None)
		objects.set_attribute(objectid, "knockout_chance", None)
		objects.set_attribute(objectid, "baffle_chance", None)
		objects.set_attribute(objectid, "combo_chance", None)

def helper_add_talent_effects(objectid, itemtype, itemid):
	"""Helper function for on_equip.

Parameters:
        objectid - Id of the character.
        itemtype - Type of the item.
        itemid   - Id of the item.
"""
	if not objectid or not len(objectid): return
	if not itemtype or not len(itemtype): return
	if not objects.has_attribute(itemtype, "item_type"): return
	if objects.get_attribute(itemtype, "item_type")!="weapon": return
	if objects.has_attribute(objectid, "equip_dont_setup_attributes"): return
	
	_type = objects.get_attribute(itemtype, "weapon_type")
	assert len(_type)
	if _type == "leicht":
		if has_talent(objectid, "light_weapons", "headshot"):
			objects.set_attribute(objectid, "headshot_chance", 0.02)
		if has_talent(objectid, "light_weapons", "critical_hit"):
			objects.set_attribute(objectid, "critical_hit_chance", 0.1)
		if has_talent(objectid, "light_weapons", "fast_reload"):
			objects.set_attribute(objectid, "reload_speed_factor", 5.0)
	if _type == "schwer":
		if has_talent(objectid, "heavy_weapons", "critical_hit"):
			objects.set_attribute(objectid, "critical_hit_chance", 0.1)
		if has_talent(objectid, "heavy_weapons", "fast_reload"):
			objects.set_attribute(objectid, "reload_speed_factor", 5.0)
	if _type == "sniper":
		if itemtype == 'SET_SR800':
			if has_talent(objectid, "sniper_weapons", "headshot"):
				objects.set_attribute(objectid, "headshot_chance", 0.4)
			else:
				objects.set_attribute(objectid, "headshot_chance", 0.2)
		else:
			if has_talent(objectid, "sniper_weapons", "headshot"):
				objects.set_attribute(objectid, "headshot_chance", 0.2)
			
	if _type == "nahkampf":
		if has_talent(objectid, "close_combat", "atc"):
			objects.set_attribute(objectid, "knockout_chance", 0.1)
		if has_talent(objectid, "close_combat", "baffle"):
			objects.set_attribute(objectid, "baffle_chance", 0.1)
		if has_talent(objectid, "close_combat", "combo"):
			objects.set_attribute(objectid, "combo_chance", 0.2)

def on_equip(objectid, itemtype, itemid):
	"""Called when a character equips an item.

Parameters:
        objectid - Id of the character.
        itemtype - Type of the item.
        itemid   - Id of the item.
"""
	if not can_equip( objectid, itemtype ) \
		and not (objects.has_attribute(objectid, "direct_equip") \
				 and objects.get_attribute(objectid, "direct_equip")):
		raise ValueError, "object '" + str(objectid) + "' can not equip item '" + itemtype + "'"

	if not objects.has_attribute(objectid, "slots"):
		objects.set_attribute(objectid, "slots", {})

	# unequip items to make room for the new item
	item_slots = objects.get_attribute(itemtype, "occupied_slots")
	if objects.has_attribute(itemtype, "blocked_slots"):
		item_slots = item_slots + objects.get_attribute(itemtype, "blocked_slots")
	if not objects.has_attribute(objectid, "equip_dont_setup_attributes"):
		for slot in item_slots:
			if slot in objects.get_attribute(objectid, "slots"):
				if objects.get_attribute(objectid, "slots")[slot]:
					character.un_equip(objectid, objects.get_attribute(objectid, "slots")[slot])
		# register new item in chars equip slots
		slots = objects.get_attribute(objectid, "slots")
		for slot in item_slots:
			slots[slot] = itemid
		objects.set_attribute(objectid, "slots", slots)

	# set new appearance
	if "helm" in objects.get_attribute(itemtype, "occupied_slots"):
		helper_appearance(objectid, "helmet", itemtype)
	elif "boots" in objects.get_attribute(itemtype, "occupied_slots"):
		helper_appearance(objectid, "clothes_boots", itemtype)
	elif "gloves" in objects.get_attribute(itemtype, "occupied_slots"):
		helper_appearance(objectid, "clothes_gloves", itemtype)
	elif "clothes" in objects.get_attribute(itemtype, "occupied_slots"):
		helper_appearance(objectid, "clothes", itemtype)
	elif "implantant" in objects.get_attribute(itemtype, "occupied_slots"):
		DR_recalculate_bonus(objectid, "implantant", itemtype )
	# Derff's backpacks
	elif "backpack" in objects.get_attribute ( itemtype, "occupied_slots" ) :
		weight_bonus = objects.get_att ( itemtype, "weight_bonus" )
		if weight_bonus == None: weight_bonus = 0
		objects.set_attribute ( itemid, "backpack_weight_bonus", weight_bonus )	# [BrainRipper]
		update_speed(objectid)
	# Derff's end	

	if not objects.has_attribute(objectid, "equip_dont_setup_attributes"):
		# add skill bonus from weapon accustomisation
		helper_add_weapon_accustomisation(objectid, itemtype, itemid)
	
		# add talent effects
		helper_update_talent_effects(objectid)
	
	if itemtype=="SET_NIGHT_VISION_GEAR" or itemtype=="SET_BINOCULARS"or itemtype=="SET_FIELD_GLASSES":
		calc_perception_values(objectid)
	


def on_unequip(objectid, itemtype, itemid):
	"""Called when a character unequips an item.

Parameters:
        objectid - Id of the character.
        itemtype - Type of the item.
        itemid   - Id of the item.
"""
	# unregister item from chars equip slots
	item_slots = objects.get_attribute(itemtype, "occupied_slots")
	if objects.has_attribute(itemtype, "blocked_slots"):
		item_slots = item_slots + objects.get_attribute(itemtype, "blocked_slots")
		
	if not objects.has_attribute(objectid, "equip_dont_setup_attributes"):
		slots = objects.get_attribute(objectid, "slots")
		for slot in item_slots:
			slots[slot] = None
		objects.set_attribute(objectid, "slots", slots)

	# set new appearance
	if "helm" in objects.get_attribute(itemtype, "occupied_slots"):
		helper_appearance(objectid, "helmet", None)
	elif "boots" in objects.get_attribute(itemtype, "occupied_slots"):
		helper_appearance(objectid, "clothes_boots", "naked")
	elif "gloves" in objects.get_attribute(itemtype, "occupied_slots"):
		helper_appearance(objectid, "clothes_gloves", "naked")
	elif "clothes" in objects.get_attribute(itemtype, "occupied_slots"):
		helper_appearance(objectid, "clothes", "naked")
	elif "implantant" in objects.get_attribute(itemtype, "occupied_slots"):
		DR_recalculate_bonus(objectid, "implantant", None )
	# Derff's backpacks
	elif "backpack" in objects.get_attribute(itemtype, "occupied_slots"):
		objects.set_attribute ( itemid, "backpack_weight_bonus", 1 )
		update_speed(objectid)
	# Derff's end

	if not objects.has_attribute(objectid, "equip_dont_setup_attributes"):
		# remove weapon accustomisation skill bonus
		helper_remove_weapon_accustomisation(objectid, itemtype, itemid)

		# remove talent effects
		helper_update_talent_effects(objectid)

	if itemtype=="SET_NIGHT_VISION_GEAR" or itemtype=="SET_BINOCULARS" or itemtype=="SET_FIELD_GLASSES":
		calc_perception_values(objectid)

def on_approach( target, operator ):
	"""Called when a player char talks to another char or object.

Parameters:
        target   - Char/object that is talked to (can also be a player char).
        operator - Char that starts the conversation.
"""
	npcs = system.get_npcs()
	if target in npcs and did_fail_heist( operator ):
		random_comment( target, "NPC_THEFT_DENY_TALK_", 5 )
		return True
	return global_character.on_approach( target, operator )
	
def on_trade( target, operator ):
	"""Called when a trade is about to be started.

When this function returns False, the zone on_trade function shouldn't start the trade.

Parameters:
        target   - Id of the Trader.
        operator - Char that starts the conversation.
"""
	npcs = system.get_npcs()
	if target in npcs and did_fail_heist( operator ):
		random_comment( target, "NPC_THEFT_DENY_TALK_", 5 )
		return False
	return True

def remove_survive_bonus(char):		# obsolete 24.01.2006; only for old savegames
	"""Removes the 'survive' bonus from this char."""
	if objects.has_attribute(char, "survive_activated"):
		if objects.get_attribute(char, "survive_activated"):
			objects.set_attribute(char, "survive_activated", None)
	
			if objects.has_attribute(char, "survive_maxhitpoint_diff"):
				max_hitpoints = objects.get_attribute( char, "maxhitpoints")
				diff = objects.get_attribute(char, "survive_maxhitpoint_diff")
				objects.set_attribute(char, "maxhitpoints", max_hitpoints - diff)
		else:
			objects.set_attribute(char, "survive_activated", None)		# ?

def remove_psychology_bonus(char):		# obsolete 19.01.2006; only for old savegames
	"""Removes the psychology bonus from this char."""
	objects.set_attribute(char, "psychology_bonus", None)
	att_change = objects.get_attribute(char, "psychology_att_change")
	for att in att_change:
		old = objects.get_attribute(char, att)
		new = old - att_change[att]
		objects.set_attribute(char, att, new)

def remove_increase_moral_bonus(char): # obsolete 20.01.2006; only for old savegames
	"""Removes the increase moral bonus from this char."""
	objects.set_attribute( char, "increase_moral_activated", None )
	if objects.has_attribute(char, "inc_moral_diff"):
		inc_moral_diff = objects.get_attribute( char, "inc_moral_diff")
		for skill in inc_moral_diff:
			skill_value = objects.get_attribute(char, skill)
			# 10 percent lesser skillpoints because increase_moral effect is over
			new_skill_value = int(skill_value -  inc_moral_diff[skill])
			objects.set_attribute(char, skill, new_skill_value)
	else:
		# obsolete. only for old savegames
		skills = [ "light_weapons", "heavy_weapons", "sniper_weapons", "speech", "throw_weapons", \
		"explosives", "survival", "technic", "medicine", "sneak", "driving", "pick_pocket", "lock_pick", "close_combat" ]
		for skill in skills:
			skill_value = objects.get_attribute( char, skill )
			# 10 percent lesser skillpoints because increase_moral effect is over
			new_skill_value = math.ceil(skill_value / 1.1)
			objects.set_attribute( char, skill, int( new_skill_value ) )

def on_party_left( character_id ):
	"""Called when a char leaves the player party.

Parameters:
        character_id - Id of the char.
"""
	global_character.on_party_left( character_id )

	# deactivate bonuses
	bonus.remove_on_leave_party(character_id)
		
	objects.set_attribute( character_id, "joined_party_time", None )
	
	# sync interiors and pcs
	grid = objects.get_grid( character_id )
	if (grid != "landscape"):
		on_grid_enter( character_id, "landscape", grid, True )
		on_grid_enter( character_id, grid, "landscape" )

def on_party_join( character_id ):
	"""Called when a char joins the player party.

Parameters:
        character_id - Id of the char.
"""
	objects.set_attribute( character_id, "joined_party_time", system.get_mission_time() )


def can_steal_from( thief, victim ):
	# print 'can_steal_from(', thief, victim ,')'
	"""Returns True if the thief can steal from the victim.

For this, the thief must be a PC, and the victim must be an NPC.

Parameters:
        thief  - Id of the thief.
        victim - Id of the victim.
"""
	
	if victim in ["FRANKLIN", "ABEL", "ANIE", "IAN", "LINDA", "PAULA", "ABRAHAM", "MICKEY", "SUE_Z7", "FJODR"]:
		return False
	
	if objects.is_npc( victim ) and objects.is_pc( thief ) and not objects.get_attribute(victim,"trader"):

		# Bug 15431: don't steal from chars, who attack the thief
		if objects.has_attribute(victim, "target"):
			if objects.get_attribute(victim, "target")==thief:
				return False

		return True
	else:
		return False

def is_in_front( object_id, target_id ):
	"""Returns True if object is in front of target.

Parameters:
        object_id - Id of the object.
        target_id - Id of the object where the above object is in front of.
"""
	oX,oY,oZ = objects.get_position( object_id )
	tX, tY, tZ = objects.get_position( target_id )

	# calc the vector from object to target
	o2t_vector = [ tX - oX, tY - oY ]
	# the north vector, because this is where the direction depends on
	north = [ 0, -1 ]

	# some intermediate steps
	numerator = ( o2t_vector[0] * north[0] + o2t_vector[1] * north[1] ) 
	denominator1 = math.sqrt( math.pow( o2t_vector[0], 2 ) + math.pow( o2t_vector[1], 2 ) )
	denominator2 = math.sqrt( math.pow( north[0], 2 ) + math.pow( north[1], 2 ) )
	denominator = denominator1 * denominator2

	# calc the direction of the object to the target in degree
	o2t_direction = 0
	if denominator != 0:
		if ( math.pi * math.acos( numerator / denominator ) ) != 0:
			o2t_direction = 180 / math.pi * math.acos( numerator / denominator )
	
	target_direction = objects.get_direction( target_id )

	if target_direction < 90:
		# normalize values
		target_direction = target_direction + 90
		o2t_direction = o2t_direction + 90
		
		if o2t_direction >= 360:
			o2t_direction = o2t_direction - 360

	if abs( o2t_direction - target_direction ) <= 90:
		return False
	else:
		return True

def calc_steal_chance( target, operator ):
	"""Calculates the chance to steal something from a char.

Returns the chance.

Parameters:
        operator - Id of the thief.
        target   - Id of the victim.
"""

	if not ( objects.is_npc( target ) and objects.is_pc( operator ) ):
		return

	pick_pocket = objects.get_attribute(operator, "pick_pocket")

	# calculate the chances of a successful heist depending on the 
	# position of the operator and on his skill
	if is_in_front( operator, target ):
		basic_chance_of_success = 0.1 # 10% chance stealing something from the victim
		additional_chance = skill_tables.pick_pocket_success_front(pick_pocket)
		if has_talent( operator, "pick_pocket", "diversion" ):
			additional_chance = additional_chance + 0.1
	else:
		basic_chance_of_success = 0.2 # 20% chance stealing something from the victim
		additional_chance = skill_tables.pick_pocket_success_back(pick_pocket)
		if has_talent( operator, "pick_pocket", "slink" ):
			additional_chance = additional_chance + 0.1
	
	# 30% better chance to steal something if the operator has the talent flatter
	# and the target is of the opposite gender
	if has_talent( operator, "pick_pocket", "flatter" ):
		if objects.has_attribute( target, "gender" ):
			operator_gender = objects.get_attribute( operator, "gender" )
			target_gender = objects.get_attribute( target, "gender" )

			if ( operator_gender == "female" and target_gender == "male" ) or \
			   ( operator_gender == "male" and target_gender == "female" ):
				additional_chance = additional_chance + 0.3

	# look if the target was bereft before.
	# the bereft attribute determines that a char tried to bereft
	# the npc before. The more often he tries the smaller the
	# bereft value gets.
	# bereft_list = { operator: bereft }
	bereft = 1.0 # 100%
	bereft_list = {}
	if objects.has_attribute( target, "bereft" ):
		bereft_list = objects.get_attribute( target, "bereft" )

	# chance of a successful heist will be reduced by the fact that
	# the target was bereft before
	if bereft_list.has_key( operator ):
		bereft = bereft_list[ operator ]
		
	chance = ( basic_chance_of_success + additional_chance ) * bereft	
	chance *= skill_tables.dexterity_pick_pocket(objects.get_attribute(operator, "dexterity"))

	return chance

def on_steal(target, operator):
	"""Called when a player char tries to steal something.

Parameters:
        operator - Id of the thief.
        target   - Id of the victim.
"""
	chance = calc_steal_chance( target, operator )

	r = random.random()

	if r < chance: # heist was successful
		inventorylist = objects.get_inventory_list(target)
		# Check for talent inside_pocket
		if has_talent( operator, "pick_pocket", "inside_pocket" ):
			# if target ha snot yet an inside_pocket_item, then create one
			if not objects.has_attribute( target, "inside_pocket_item" ):
				inside_pocket_item_type = get_random_item()
				inside_pocket_item_id = objects.create_item_in_inventory( target, inside_pocket_item_type )
				objects.set_attribute( target, "inside_pocket_item", inside_pocket_item_id )

		if inventorylist:
			# show the item panel but filter out the equiped items
			system.item_panel( operator, target, separate_out_callback )
			
			# zum prüfen ob der party dialog ,"Lin hat gerade einen männlichen NPC erfolgreich beklaut.", kommt
			if not hasattr( data("comments"), "spoken_party_dialog_en" ): 
				data("comments").spoken_party_dialog_en = {}
			if (operator == 'MERCENARY_SALLY' and 
				'MERCENARY_BUTCH' in system.get_pcs() and
				objects.get_attribute(target, 'gender') == 'male'):
					data("comments").spoken_party_dialog_en['steal'] = target
					system.notify_global_timer("timer_spoken_party_dialog_en", 15*1000)
					
			give_first_use_exp(operator, "steal_item")
			
	else: # heist was a failure
		# target will abuse operator
		# Wegen Problemen mit Bänken etc das Turn_to abgeklemmt
		#lambda_string = 'heist_failure( target="%s", operator="%s" )' %( target, operator )
		#objects.cancel_commandos(target)
		#objects.turn_to_object( target, operator, callback=[ "ONEND", Lambda( lambda_string ) ] )
		heist_failure( target, operator )

inside_pocket_items = [ "SET_RED_SHARD", "SET_STAPLE_GUN", "SET_TOOTHBRUSH", "SET_GAME_JOY", "SET_GARLIC_PRESS", "SET_WIRE_WHISK",
	"SET_COIN_CELL_BATTERY", "SET_MULTIPLE_SOCKET", "SET_BROKEN_POCKET_CALCULATOR", "SET_SMALL_PICTURE_FRAME",	# [BrainRipper]
	"SET_PLAYING_CARD", "SET_BRUSH", "SET_DUCT_TAPE", "SET_WATERTIGHT_RING", "SET_LIGHTER", "SET_LASERPOINTER",
	"SET_SHORT_NAILS", "SET_RAGS", "SET_STETHOSCOPE", "SET_LONG_NAILS", "SET_CRANK", "SET_PLIERS", "SET_BULLET_CASINGS", "SET_LIGHT_BULB",
	"SET_RASP", "SET_RIVETS", "SET_DICE", "SET_FUSE", "SET_BOTTLE_OF_HOOCH", "SET_BATTERY", "SET_HAIR_SPRAY", "SET_WALTER_PPK",
	"SET_BERETTA_92F", "SET_DESERT_EAGLE", "SET_SPECIAL_38", "SET_GLOCK_21", "SET_HEGRENADE", "SET_FRAGGRENADE", "SET_MOLOTOV_COCKTAIL", "SET_THROWING_KNIFE", "SET_SHURIKEN", "SET_DART", "SET_BRASS_KNUCKLES", "SET_KNIFE", "SET_BIG_KNIFE",
	"SET_MACHETE", "SET_AMMOPACK_7_65_MM", "SET_AMMOPACK_38", "SET_AMMOPACK_44", "SET_AMMOPACK_357", "SET_AMMOPACK_9_MM",
	"SET_AMMOPACK_50", "SET_AMMOPACK_45", "SET_AMMOPACK_50_BMG", "SET_AMMOPACK_5_7_MM", "SET_AMMOPACK_4_6_MM", "SET_MEDIPACK_SMALL",
	"SET_DRUGS_PILLS_01", "SET_DRUGS_PILLS_02", "SET_DRUGS_PILLS_03", "SET_DRUGS_PILLS_04", "SET_DRUGS_VIALS_01", "SET_DRUGS_VIALS_02",
	"SET_DRUGS_VIALS_03", "SET_APPLE", "SET_BREAD", "SET_CARROT" ]

def get_random_item():
	"""Called to randomly choose 1 out of 50 items.

This is used for the talent "inside pocket".
"""
	return random.choice( inside_pocket_items )

def heist_failure( target, operator ):
	"""Called after a heist failed and the target turns to the thief. 

This function starts a dialog about the heist between the target and the thief.

Parameters:
        target   - Id of the bereft char.
        operator - Id of the thief.
"""
	print "heist failure"
	dialog.init_dialog( type=global_defines.DIALOGSMALL )
	# random for the dialog texts
	rand = random.randint( 1, 5 )
	rand1 = random.randint( 1, 3 )
	rand2 = random.randint( 1, 3 )

	# increase the bereft attribute so that it is more difficult
	# for the operator to steal from the target the next time
	if not has_talent( operator, "pick_pocket", "excuse" ):
		cha = objects.get_attribute(operator, "charisma")
		objects.set_attribute( 'ALTER_EGO', "failed_heist", 60*1000*10*skill_tables.charisma_npc_bad_mood_time_factor(cha) ) #10 minutes
		dialog.add_text( text = "NPC_THEFT_00" + str(rand), speaker = target, follower = "ENDDIALOG" )
		dialog.start()
		if objects.get_attribute(operator, "name") != "": #can be "" befor char creation
			system.add_text(globaltext.NPC_BECOME_UNFRIENDLY % {"char": objects.get_attribute(operator, "name")})

		bereft_list = {}
		if objects.has_attribute( target, "bereft" ):
			bereft_list = objects.get_attribute( target, "bereft" )

		if len( bereft_list ) > 0:
			if bereft_list.has_key( operator ):
				new_bereft = bereft_list[ operator ]
				new_bereft = new_bereft / 2.0
			else:
				new_bereft = 0.5
			bereft_list[ operator ] = new_bereft
			objects.set_attribute( target, "bereft", bereft_list )
		else:
			bereft_list[ operator ] = 0.5
			objects.set_attribute( target, "bereft", bereft_list )
	else:
		callback = Lambda('give_first_use_exp("%s", "pick_pocket", "excuse")' % operator)
		dialog.add_text( text = "NPC_THEFT_00" + str(rand), speaker = target, follower = "NPC_THEFT_EXCUSE_00" + str(rand1), callback = callback )
		dialog.add_text( text = "NPC_THEFT_EXCUSE_00" + str(rand1), speaker = operator, follower = "NPC_THEFT_ACCEPT_EXCUSE_00"+ str(rand2) )
		dialog.add_text( text = "NPC_THEFT_ACCEPT_EXCUSE_00" + str(rand2), speaker = target, follower = "ENDDIALOG" )
		dialog.start()



def random_comment( character_id, comment_string, number_comments ):
	"""Lets the char say a random comment.

Parameters:
        character_id    - Id of the char.
        comment_string  - Base string of the comments id.
        number_comments - Number of existing comments.
"""

	index = "00"
	if number_comments >= 10:
		index = "0"
	if number_comments >= 100:
		index = ""

	comment_id = comment_string + index + str(random.randint(1,number_comments))
	comments.comment( character_id, comment_id )

def get_random_comment( comment_string, number_comments ):
	"""Makes a random comment string.

Parameters:
        comment_string  - Base string of the comments id.
        number_comments - Number of existing comments.
"""
	index = "00"
	if number_comments >= 10:
		index = "0"
	if number_comments >= 100:
		index = ""

	comment_id = comment_string + index + str(random.randint(1,number_comments))

	return comment_id


def separate_out_callback( taker_id, source_id, item_id, item_type ):
	"""Helper function for the ItemPanel in on_steal.

Checks if item_id is equipped by the char, or if the taker has the 
talent "inside_pocket", then the inside_pocket_item is shown too.

Parameters:
        character_id - Id of the char.
        item_id      - Id of the item.
        item_type    - Type of the item.
"""
	
	if objects.has_attribute( source_id, "inside_pocket_item" ):
		if item_id == objects.get_attribute( source_id, "inside_pocket_item" ):
			if has_talent( taker_id, "pick_pocket", "inside_pocket" ):
				return True
			else:
				return False
	
	if objects.has_attribute(item_id, "generic_item"):
		if not objects.get_attribute(item_id, "generic_item"):
			# don't steal quest items
			return False

	if objects.has_attribute(item_id, "stealable"):
		if not objects.get_attribute(item_id, "stealable"):
			# don't steal protected items
			return False

	return not character.is_equiped( source_id, item_id )

def did_fail_heist( character_id ):
	"""Returns True if the char tried to steal from an NPC in the past 10 minutes 
and failed.

Parameters:
        character_id - Id of the char.
"""
	#jan: das ist der aktuelle code
	if objects.has_attribute( 'ALTER_EGO', "failed_heist" ):
		heist_time = objects.get_attribute( 'ALTER_EGO', "failed_heist" )
		if heist_time <= 0:
			return False
		else:
			return True
	#jan: das is falscher code, bite NICHT reaktivieren
#	if objects.has_attribute( character_id, "failed_heist" ):
#		heist_time = objects.get_attribute( character_id, "failed_heist" )
#		# if the last heist was more than 10 min ago then delete the attribute
#		cha = objects.get_attribute(character_id, "charisma")
#		t = time("00:%d:00" % (10 * skill_tables.charisma_npc_bad_mood_time_factor(cha)))
#		if system.get_mission_time() - heist_time > t:
#			objects.set_attribute( character_id, "failed_heist", None )
#			return False
#		else:
#			return True
	# char did not have the attribute, that means he did not steal
	# in the past 10 minutes
	else: 
		return False

def remove_bereft_attribute():
	"""Remove the bereft attribute from all NPCs.
"""
	npcs = system.get_npcs()
	
	for npc in npcs:
		if character.exists( npc ):
			if objects.has_attribute( npc, "bereft"):
				objects.set_attribute( npc, "bereft", None )
	

exp_table = [
	0,		#1
	200,	#2
	500,	#3
	800,	#4
	1400,	#5
	2200,	#6
	3500,	#7
	6000,	#8
	7700,	#9
	10000,	#10
	13000,	#11
	17000,	#12
	21000,	#13
	25000,	#14
	30000,	#15
	35000,	#16
	40000,	#17
	45000,	#18
	50000,	#19
	55000,	#20
	61000,	#21
	68000,	#22
	70000,	#23
	79000,	#24
	89000,	#25
	99000,	#26
	112000,	#27
	128000,	#28
	148000, #29
	172000, #30
	200000, #31
	232000, #32
	268000,	#33
	308000,	#34
	352000,	#35
	400000,	#36
	452000,	#37
	508000,	#38
	568000,	#39
	632000,	#40
	]

def calc_level( character_id, new_exp, old_exp ):
	"""Helper function for on_attribute_change.

Calcs and sets the new level if enough experience has been gained by the char.

Parameters:
        character_id - Id of the char.
        new_exp      - Amount of exp the char now has.
        old_exp      - Amount of exp the char had before.
"""

	global exp_table
	level = objects.get_attribute(object=character_id, attribute="level" )
	levelup = True
	if level==-1:
		level = 0
		levelup = False
		
	attribute_points_left = 0
	skill_points_left = 0

	if objects.has_attribute(character_id, "attribute_points_left"):
		attribute_points_left = objects.get_attribute(character_id, "attribute_points_left")

	if objects.has_attribute(character_id, "skill_points_left"):
		skill_points_left = objects.get_attribute(character_id, "skill_points_left")

	skill_points = 10
	skill_points+=skill_tables.intelligence_skill_points(
		objects.get_attribute(character_id, "intelligence"))
		
	while level < len( exp_table ) and new_exp >= exp_table[level]:
		level+=1
		attribute_points_left+=1
		skill_points_left+=skill_points
		
	if levelup:
		objects.set_attribute(object=character_id, 
			attribute="attribute_points_left", value=attribute_points_left)
		objects.set_attribute(object=character_id, 
			attribute="skill_points_left", value=skill_points_left)
	
	objects.set_attribute(object=character_id, attribute="level", value=level )

	next_level_exp = -1
	if level < len( exp_table ):
		next_level_exp = exp_table[level]
	else:
		next_level_exp = exp_table[len(exp_table) - 1]
	objects.set_attribute(object=character_id, 
		attribute="experience_next_level", value=next_level_exp)

#							FA		 MA		 VE		 SU		 CR		 HC		 ME
bonus_malus_experience_of_life = {
	"close_combat":			( 0,	+15,	  0,	  0,	 +5,	  0,	-10),
	"light_weapons":		(+5,	  0,	  0,	  0,	 +5,	  0,	  0),
	"heavy_weapons":		(+5,	-10,	  0,	  0,	 -5,	  0,	  0),
	"sniper_weapons":		(+5,	  0,	  0,	  0,	 -5,	  0,	  0),
	"throw_weapons":		(-5,	+10,	  0,	+10,	  0,	  0,	 -5),
	"explosives":			( 0,	  0,	  0,	  0,	 +5,	  0,	  0),
	"survival":				( 0,	  0,	 -5,	+15,	-10,	 -5,	  0),
	"sneak":				( 0,	 +5,	 -5,	+10,	  0,	  0,	  0),
	"pick_pocket":			(-5,	  0,	  0,	  0,	+10,	  0,	  0),
	"lock_pick":			(-5,	  0,	  0,	 -5,	 +5,	+10, 	  0),
	"technic":				( 0,	  0,	+10,	 -5,	  0,	+15,	 +5),
	"driving":				( 0,	  0,	+15,	-10,	  0,	  0,	  0),
	"speech":				(-5,	  0,	  0,	 -5,	 +5,	 +5,	 +5),
	"medicine":				( 0,	  0,	  0,	  0,	  0,	 -5,	+15),
}

def calc_experience_of_life(character_id, new_value, old_value):
	"""Helper function for on_attribute_change.

Calcs and sets the effects of the life experience 
(i.e., previous "job" experience).

Parameters:
        character_id - Id of the char.
        new_value    - New value.
        old_value    - Old value.

Where value is:
        0 - Firearms
        1 - Martial Arts
        2 - Vehicles
        3 - Survival
        4 - Crime
        5 - Handcraft
        6 - Medicine
"""
	global bonus_malus_experience_of_life
	if old_value!=None:
		for entry in bonus_malus_experience_of_life:
			value=objects.get_attribute(character_id, entry)
			value-=bonus_malus_experience_of_life[entry][old_value]
			objects.set_attribute(character_id, entry, value)

	for entry in bonus_malus_experience_of_life:
		value=objects.get_attribute(character_id, entry)
		value+=bonus_malus_experience_of_life[entry][new_value]
		objects.set_attribute(character_id, entry, value)

#						none	tall	short	strong	wiry	handsome 	ugly
bonus_malus_body_features = {
	"strength":			(0,		+2,		-2,		+3,		-1,		 0,		 	0),
	"agility":			(0,		-2,		+1,		-3,		+1,		 0,		 	0),
	"dexterity":		(0,		-1,		+2,		 0,		 0,		 0,		 	0),
	"constitution":		(0,		+1,		-1,		 0,		+1,		 0,		 	0),
	"intelligence":		(0,		 0,	 	 0,		 0,		 0,		-3,			+3),
	"charisma":			(0,		 0,	 	 0,		 0,		-1,		+3,			-3),
}

def calc_body_feature(character_id, new_value, old_value):
	"""Helper function for on_attribute_change.

Calcs and sets the effects of the body features.

Parameters:
        character_id - Id of the char.
        new_value    - New value.
        old_value    - New value.

Where value is:
        0 - none
        1 - tall
        2 - short
        3 - strong
        4 - wiry
        5 - handsome
        6 - ugly
"""
	global bonus_malus_body_features
	if old_value!=None:
		for entry in bonus_malus_body_features:
			value=objects.get_attribute(character_id, entry)
			value-=bonus_malus_body_features[entry][old_value]
			objects.set_attribute(character_id, entry, value)

	for entry in bonus_malus_body_features:
		value=objects.get_attribute(character_id, entry)
		value+=bonus_malus_body_features[entry][new_value]
		objects.set_attribute(character_id, entry, value)

def calc_armor_value(character_id):
	"""Helper function calcs and sets the armor the character gets from his equipment.

Parameters:
        character_id - Id of the char.
"""
	armor = 0
	equipted = []
	inventory = objects.get_inventory_ids(character_id)
	for entry in inventory:
		if entry[1] != 0:
			for elem in entry[0]:
				equipted.append(elem)
	for item in equipted:
		if objects.has_attribute(item, "armor"):
			armor = armor + objects.get_attribute(item, "armor")
		else:
			_type = objects.get_attribute(item, "typeid")
			if objects.has_attribute(_type, "armor"):
				armor = armor + objects.get_attribute(_type, "armor")
	objects.set_attribute(character_id, "armor", armor)	
	DR_recalculate_bonus(character_id, "armor_effect", None)
	armor = objects.get_attribute(character_id, "armor")
	armor += skill_tables.agility_armor(objects.get_attribute(character_id, "agility"))	
	objects.set_attribute(character_id, "armor_display_value", armor)	
	if armor<0: armor=0	
	objects.set_attribute(character_id, "armor", armor)		

#					base exp		exp per level
kill_exp = {
	"WOLF": 			(30,				15),
	"ANTELOPE":			(10,				5),
	"BEAR":				(40,				20),
	"COW":				( 5,				3),
	"DEER":				(20,				10),
	"HORSE":			(15,				8),
	"TIGER":			(50,				25),
	"WILDDOG":			(30,				15),
	"BISON":			(15,				8),
	"PIG":				( 5,				3),
	"DONKEY":			( 5,				3),
	"WARG":				(60,				30),
	"LIZARD_SOMA":		(40,				20),
	
	"RAT_SKULLS":		(20,				10),
	"DESERT_MONKS":		(30,				15),
	"SHADOWS":			(30,				20),
	"INDIANS":			(20,				10),
	"NOMADS":			(20,				10),
	"GNO_SOLDIERS":		(40,				15),
	"VILLAGE_PEOPLE":	(20,				10),
	"SEEKER":			(20,				10),
}

def on_object_killed(victim, attacker, weapon_type, weapon_id, victims_party):
	# print 'object_events.on_object_killed(',victim, attacker, weapon_type, weapon_id, victims_party,')'
	"""Called when an object gets killed/destroyed.

Parameters:
        attacker    - Id of the attacker, might be None, or "".
        victim      - Id of the victim.
        weapon_type - Type of the weapon the attacker used, might be None, or "".
        weapon_id   - Id of the weapon the attacker used, might be None, or "".
        victims_party - Party of the victim
"""
	#print "on_object_killed", victim, attacker, weapon_type, weapon_id, victims_party

	if weapon_type:
		while objects.has_attribute(weapon_type, "base_weapon"):
			weapon_type = objects.get_attribute(weapon_type, "base_weapon")

	#Ueberpruefen ob Spawnanimal
	import spawnanimals
	spawnanimals.set_killed_animals(victim)
	
	if (attacker in system.get_pcs()):
		_type = helper_get_faction(victim)

		#experience per kill calculation
		exp = 0
		if _type in kill_exp:
			exp=kill_exp[_type][0]
			level=1
			if objects.has_attribute(victim, "level"):
				level=objects.get_attribute(victim, "level")
			exp+=int(kill_exp[_type][1]*(level-1))

		if exp>0:
			name = ""
			if objects.has_attribute(attacker,"name"):
				name = objects.get_attribute(attacker,"name")
				name+=": "
			system.add_object_text(victim, name+str(exp))
			character.add_experience(attacker, exp)

		character.add_kill_stat(attacker, _type, weapon_type, weapon_id)
		
		set_reputation_bonus(attacker)
	
	# update weapon accustomisation skill bonus
	helper_remove_weapon_accustomisation(attacker, weapon_type, weapon_id)
	helper_add_weapon_accustomisation(attacker, weapon_type, weapon_id)
	
	
	
	if objects.has_attribute(victim, "type"):
		_type = objects.get_attribute(victim, "type")
		if _type=="vehicle":
			vehicle_crew = vehicle.get_crew(victim)
			# set the party out of the vehicle and kill them
			for crew_member in vehicle_crew:
				character.set_out(crew_member)
				range_x = 3
				range_y = 3
				random_range_x = random.randint( -2, 2)
				random_range_y = random.randint( -2, 2)
				if random_range_x < 0:
					range_x =  - range_x
				if random_range_x < 0:
					range_y = - range_y 	
				new_x =  objects.get_x(crew_member) + range_x + random_range_x 
				new_y =  objects.get_y(crew_member) + range_y + random_range_y 
				objects.set_position(crew_member,new_x,new_y)
				objects.destroy(crew_member)
			# destroy the vehicle
			vehicle_explosion( victim )
			
		elif _type=="character":
			if objects.has_attribute( victim, "gender"):
				if objects.get_attribute( victim, "gender")=="male":
					if random.randint(0, 1):
						sounds.play_3d_sound_object(sfx_id=random.choice([
							"male_heavy_hit_1","male_medium_hit_1",
							"male_medium_hit_2","male_medium_hit_3",
							"male_slightly_hit_1","male_slightly_hit_2"]),
							object=victim)	
	
	# zur globalen Behandlung wen die GOE Gang getötet wird.
	# in z6 und zz4 gesonderte Bearbeitung in der zone
	if attacker in system.get_pcs():
		if victim in ["ABRAHAM", "MICKEY", "SUE_Z7", "FJODR"]:
			if not system.get_act_mission_name() in ['zone_6.zone_6', 'zzone_4.zzone_4']:
				if global_defines.was_zone_entered('zone_6.zone_6'):
					for char_id in ["ABRAHAM", "MICKEY", "SUE_Z7", "FJODR"]:
						if char_id in system.get_npcs():
							objects.set_attribute(char_id,"zone_transfer",False)
					data("zone_6.zone_6").abraham_und_co_folgen = False
					for char in ["ABRAHAM", "SUE_Z7", "FJODR"]:
						if char in system.get_npcs():
							if not objects.is_destroyed(char):
								import daily_routine
								daily_routine.prohibit_activity(char)
								objects.set_attribute(char, "foes", ['UISPIELER'])
					if system.get_qb_entry_state(data("zone_6.zone_6").QB_020) != global_defines.IMPOSSIBLE:
						system.set_qb_entry_state(data("zone_6.zone_6").QB_020, global_defines.IMPOSSIBLE) 
	
	if hasattr(data("ambient"), "ambient_set"):
		if data("ambient").ambient_set:
			zone_ambients.set_dead_meat_vulture(victim)
	

def helper_get_faction(victim):
	"""Helper function for on_object_killed; returns the faction/type of the object"""
	_type="none"

	if objects.has_attribute(victim, "typeid"):
		_type=objects.get_attribute(victim, "typeid")

	if objects.has_attribute(victim, "faction"):
		_type=objects.get_attribute(victim, "faction")

	if _type not in kill_type_list:
		if victim in system.get_npcs() or victim in system.get_pcs():
			_type = "MISC_NPCS"
		elif victim in system.get_animals():
			_type = "PEACEFUL_ANIMALS"
		elif victim in system.get_vehicles():
			_type = None
		elif objects.has_attribute(victim, "type") and objects.get_attribute(victim, "type")=="building":
			_type = None
		else:
			assert False, "unknown faction '%s'" % _type
	
	return _type

	
def calc_life_energy_start(character_id, new_value, old_value):
	"""Helper function for on_attribute_change.

Calcs and sets the HP with which a char starts.

Parameters:
        character_id - Id of the char.
        new_value    - New constitution.
        old_value    - Old constitution.
"""
	value = skill_tables.constitution_life_energy_start(new_value)
	objects.set_attribute(character_id, "maxhitpoints", value)
	objects.set_attribute(character_id, "hitpoints", value)

def calc_life_energy(character_id, new_value, old_value):
	"""Helper function for on_attribute_change

Calcs and sets the new HP after level up.

Parameters:
        character_id - Id of the char.
        new_value    - New level.
        old_value    - Old level.
"""
	if old_value > 0:
		i=old_value
		max_le=objects.get_attribute(character_id, "maxhitpoints")
		constitution=objects.get_attribute(character_id, "constitution")
		le_gain = 0
		while i < new_value:
			#Pro Stufe erhöht sich die LE bei jedem Charakter um 4 - 8 Punkte.
			#Der Konstitutionswert beeinflusst diesen Wert durch einen Bonus.
			le_gain+=random.randint(4,8)
			le_gain+=skill_tables.constitution_life_energy_level(constitution)
			i+=1
		max_le+=le_gain
		objects.set_attribute(character_id, "maxhitpoints", max_le)
		# die act. hp steigt um den wert, um die sich die max. hp erhöht hat
		act_le=objects.get_attribute(character_id, "hitpoints")+le_gain
		if act_le>max_le:
			act_le=max_le
		objects.set_attribute(character_id, "hitpoints", act_le)

def can_do_action(character_id, action, just_checking):
	"""Returns True if the char can do the action.

Where just_checking is:
        True  - Only returns True or False if char can do action.
        False - Also executes action.
        
Known actions:
        "action_kneel"
        "action_climb"
        "action_liedown"
For unknown actions, True is returned by default.

Parameters:
        character_id  - Id of the char.
        action        - Action to check.
        just_checking - Deactivates execution of action.
"""
	if (action=="action_kneel" or
		action=="action_climb" or
		action=="action_liedown"):

		# missing rel_load attribute; create it
		if not objects.has_attribute( object=character_id, attribute="rel_load" ):
			update_speed( character_id )

		rel_load = objects.get_attribute( object=character_id, attribute="rel_load" )
		deny = False
		if rel_load > 1 and action=="action_climb": deny = True
		elif rel_load > 1.1:
			if action=="action_kneel": deny = True
			elif action=="action_liedown": deny = True
		if deny:
			print "deny_action"
			# not in cutscene and about to execute the action
			if not system.is_cutscene() and not just_checking:
				# not to often
				# "0:01" = 1min ingame time ~2.5s timeo
				current_time = system.get_mission_time()
				print "deny_action2"
				if not objects.has_attribute( object=character_id, attribute="last_refuse_action_weight" ):
					comments.comment(character_id=character_id, text="REFUSE_ACTION_WEIGHT")
					objects.set_attribute( object=character_id, \
						attribute="last_refuse_action_weight", value=current_time )
				else:
					print "deny_action3"
					last_refused = objects.get_attribute( object=character_id, attribute="last_refuse_action_weight" )
					if (current_time > last_refused) and \
						((current_time - last_refused) > timerepr.time("0:01")):
						print "deny_action4"
						comments.comment(character_id=character_id, text="REFUSE_ACTION_WEIGHT")
						objects.set_attribute( object=character_id, \
							attribute="last_refuse_action_weight", value=current_time )
			return False
	return True

def on_water_found( character_id, x, y ):
	"""Called when the player has found a water source and digs it.

Parameters:
        character_id - Id of the char.
        x,y          - Coordinate of the water source.
"""
	# check for water_unearthed list in the data() structure
	if not hasattr(data(), "water_unearthed"):
		data().water_unearthed = []
	
	# only play animation if the source is not unearthed already
	if (x,y) not in data().water_unearthed:
		if objects.count_in_inventory( character_id, "SET_SPADE" ):
			character.play_animation( character_id, "CM_NPC_STEHEN_LOCH_GRABEN_START" )
			character.play_animation( character_id, "CM_NPC_STEHEN_LOCH_GRABEN_LOOP" )
			character.play_animation( character_id, "CM_NPC_STEHEN_LOCH_GRABEN_LOOP" )
		else:
			character.play_animation( character_id, "CM_KNIEND_WASSERLOCH_GRABEN_START" )
			character.play_animation( character_id, "CM_KNIEND_WASSERLOCH_GRABEN_LOOP" )
			character.play_animation( character_id, "CM_KNIEND_WASSERLOCH_GRABEN_LOOP" )
			character.play_animation( character_id, "CM_KNIEND_WASSERLOCH_GRABEN_LOOP" )

	amount_water = water.get_available_water(x, y, 1)

	if (x,y) not in data().water_unearthed:
		if amount_water > 0:
			system.create_object( "RES3D_TRES_OBJECTS_BUILDING_WATERHOLE_FULL", x, y )
			
			give_first_use_exp(character_id, "find_water")
		else:
			system.create_object( "RES3D_TRES_OBJECTS_BUILDING_WATERHOLE_EMPTY", x, y )

		if objects.count_in_inventory( character_id, "SET_SPADE" ):
			character.play_animation( character_id, "CM_NPC_STEHEN_LOCH_GRABEN_ENDE" )
		else:
			character.play_animation( character_id, "CM_KNIEND_WASSERLOCH_GRABEN_ENDE" )

	# the water source is now completly unearthed 
	data().water_unearthed.append( (x,y) )

def get_water_sensible_chars():
	"""Returns a list of chars that can detect water and comment about it if they 
find it.

If more than one char detects the same water source, then the one with the
highest survival level is taken.
"""

	# dictionary of all chars that can detect water
	# key = character_id
	# item = [ water_source_pos, survival_value ]
	chars = {}

	for character_id in system.get_pcs():
		survival = objects.get_attribute( character_id, "survival" )
		_range = skill_tables.survival_water_dection_range( survival ) 
		# if the water detector is equipped then water in a range of 20
		# meters can be detected
		if character.is_equiped( character_id, "SET_WATER_DETECTOR" ) and _range < 20:
			_range = 20

		if _range > 0:
			nearest_water_source = water.get_nearest_water_source( objects.get_x( character_id ), objects.get_y( character_id ), _range )
			# char has water source in his range
			if len( nearest_water_source ) > 0:
				found = False
				for char in chars:
					# char found who detected the same water source
					if chars[char][0] == nearest_water_source:
						found = True
						# found char has lower survival level.
						# therefore delete it from the chars list
						if  chars[char][1] < survival:
							del chars[char]
							chars[ character_id ] = [ nearest_water_source, survival ]
						break

				# no char found who detected the same water source.
				# therefore add the new char to the dict
				if not found:
					chars[ character_id ] = [ nearest_water_source, survival ]

	return chars
		
def can_detect_water_source( character_id ):
	"""Returns True if the char is able to detect a water source.

Doesn't care if the source is detected and/or been dug before.

Parameters:
        character_id - Id of the character.
"""
	# no water detection while resting
	if hasattr(data("rest"), "resting") and data("rest").resting: return False
	if hasattr(data("rest"), "raid") and data("rest").raid: return False

	survival = objects.get_attribute( character_id, "survival" )
	_range = skill_tables.survival_water_dection_range( survival ) 

	# if the water detector is equipped then water in a range of 20
	# meters can be detected
	if character.is_equiped( character_id, "SET_WATER_DETECTOR" ) and _range < 20:
		_range = 20

	# if char can detect water
	if _range > 0:
		nearest_water_source = water.get_nearest_water_source( objects.get_x( character_id ), objects.get_y( character_id ), _range )
		# if there is a water source in the chars range that was detected before
		if len( nearest_water_source ) > 0:
			# convert coords to tuple to fit the datatype of the 
			# data.water_detected keys
			source_coords = ( nearest_water_source[0], nearest_water_source[1] )
			if source_coords in data().water_detected.keys():
				return True
		else:
			return False
	
	return False

def can_use_water_source( character_id, water_source_id ):
	"""Returns True if the char can fill up his water repositories using the 
given water source. The function tests if the char has water repositories in his 
inventory, and if one or some of them are not fully filled.

Parameters:
        character_id   - Id of the character.
        watersource_id - Id of the water source.
"""

	if not is_water_source( water_source_id ):
		return False

	if water.get_available_water( objects.get_x( water_source_id ), objects.get_y( water_source_id ), 1 ) <= 0:
		return False

	equipment = objects.get_inventory_id_list( character_id )

	for item in equipment:
		if global_defines.is_water_repository( item ):
			if objects.has_attribute( item, "typeid" ):
				item_type = objects.get_attribute( item, "typeid" )
			else:
				continue

			current_charge = objects.get_attribute( item, "charge" )
			max_charge = objects.get_attribute( item_type, "charge" )

			if current_charge < max_charge:
				return True
	
	return False
	
	

pc_comment_counter = 0
pc_comment_cycle = 1000 * 60 * 10

def timer_events(lastcall):
	"""Called cyclic by the program to check for new comments.

Parameters:
        lastcall - Time in ms since the last call to timer_events
                   (is useally called every second, i.e. lastcall == 1000).
"""
	global pc_comment_counter
	pc_comment_counter+=lastcall

	comments.allow_mercenary_comments( True )

	### MUSIC ###
	music.timer_events(lastcall)
	
	### WATER ###
	PCs = system.get_pcs()
	
	# get all chars that have a water source in their range
	chars = get_water_sensible_chars()
	
	pcs_in_vehicles = []
	
	for vehicle_id in system.get_vehicles():
		crew = vehicle.get_crew(vehicle_id)
		for crew_member in crew:
			if crew_member in PCs:
				pcs_in_vehicles.append(crew_member)
			
		
	
	if len( chars ) > 0:
		for character_id in chars:
			if (character_id) not in pcs_in_vehicles:
				
				nearest_water_source = chars[ character_id ][0]

				# check for water_detected dict in the data() structure
				# water_detected:
				# key: water source coordinates as tuple
				# item: mission time the source was detected 
				if not hasattr(data(), "water_detected"):
					data().water_detected = {}
	
				# convert the water source position from list to a tuple 
				# so that it can be used as a key in the data().water_detected dict
				nearest_water_source = ( nearest_water_source[0], nearest_water_source[1] )
	
				# water source was not detected before or the detection
				# was more than 24 hours ago
				if nearest_water_source not in data().water_detected.keys() or \
				data().water_detected[ nearest_water_source ] > system.get_mission_time() or \
				system.get_mission_time() - data().water_detected[ nearest_water_source ] >\
				timerepr.time( "24:00:00" ):
					# no water detection while resting
					if not (hasattr(data("rest"), "resting") and data("rest").resting):
						if not (hasattr(data("rest"), "raid") and data("rest").raid):
							text = "WATER_PERCEIVED_" + str(random.randint(1,3))
							comments.comment( character_id, text )
							# save detected water source and the time it was detected
							data().water_detected[ nearest_water_source ] = system.get_mission_time()

	### MERCENARY COMMENTS ###
	comments.check_for_injury_comments()

	comments.check_for_traders_in_sight()
	comments.check_for_motorbikes_in_sight()
	comments.check_for_cars_in_sight()


def on_resuscitate( aide_id, unconscious_id, animated = True, force = False ):
	"""Called when a char tries to resuscitate another char.

Parameters:
        aide_id        - Id of the char that resuscitates the other, can be None.
        unconscious_id - Id of the unconscious char.
        animated       - Play a standup animation? default True.
"""

	if objects.is_unconscious(unconscious_id) or force:
		if animated:
			if aide_id:
				give_first_use_exp(aide_id, "medicine", "resuscitation")

			l2 = "import object_events; object_events.resuscitate_callback('%s')" % unconscious_id
			l = "character.play_animation('%s', 'CM_NPC_STEHEN_WARTEN_5', Lambda(\"%s\"), adapt_orientation=True)" % (unconscious_id, l2)
			character.play_animation(unconscious_id, "CM_LIEGEN_WIEDERBELEBT_WERDEN_ENDE", Lambda(l))
		else:
			resuscitate_callback(unconscious_id)
	elif objects.is_destroyed( unconscious_id ) and aide_id:
		if objects.get_attribute( unconscious_id, "gender" )=="male":
			system.add_text(globaltext.RESUSCITATION_USELESS_MALE)
		elif objects.get_attribute( unconscious_id, "gender" )=="female":
			system.add_text(globaltext.RESUSCITATION_USELESS_FEMALE)

def resuscitate_callback(unconscious_id):
	"""Helper function for on_resuscitate.

Parameters:
        unconscious_id - Id of the unconscious char.
"""
	set_unconscious(unconscious_id, False)
	objects.set_attribute(unconscious_id, "hitpoints", 1)
	objects.set_attribute(unconscious_id, "played_unconscious_anim", False)


def set_unconscious( character_id, unconscious ):
	"""Sets the char unconscious if he's not already.

After set to unconscious, the char loses one hit point per minute.
If the hit points are less than -10, then the char dies.

Parameters:
        character_id - Id of the char.
        unconscious  - True for set to unconscious, and False for conscious.
"""
	if character_id in system.get_pcs(include_unconscious = True):
		if unconscious:
			if not objects.is_unconscious( character_id ):
				timer_id = "unconscious_timer_" + character_id
				objects.set_attribute( character_id, "unconscious", True )
				if not objects.has_attribute(character_id, "unconscious_subtract_hp") \
				or objects.get_attribute(character_id, "unconscious_subtract_hp"):
					# start the timer that makes 1 damagpoint every minute to the char
					system.notify_global_timer( timer_id, 60000, False ) 
		else:
			objects.set_attribute( character_id, "unconscious", False )
	
def get_weapon_speed_factor(char, weapon_id):
	"""Returns the weapon speed factor the char has with his equipped main weapon.

Parameters:
        char - Id of the char.
"""
	factor = 1.0

	weapon_class = "UNKNOWN WEAPON CLASS"
	if weapon_id:
		weapon_class = objects.get_attribute(weapon_id, "weapon_type")

	# include attribute & skill influence
	if weapon_class == "schwer":
		factor *= skill_tables.strength_heavy_weapons_speed(objects.get_attribute(char, "strength"))
	if weapon_class == "leicht":
		factor *= skill_tables.light_weapons_speed(objects.get_attribute(char, "light_weapons"))
	elif weapon_class == "schwer":
		factor *= skill_tables.heavy_weapons_speed(objects.get_attribute(char, "heavy_weapons"))
	elif weapon_class == "sniper":
		factor *= skill_tables.sniper_weapons_speed(objects.get_attribute(char, "sniper_weapons"))
	elif weapon_class == "wurf":
		factor *= skill_tables.throw_weapons_speed(objects.get_attribute(char, "throw_weapons"))
		if has_talent(char, "throw_weapons", "specialisation_grenades")\
		and objects.get_attribute(weapon_id, "fire_animation")==global_defines.FPA_THROW_GRENADE\
		and factor > 0:
			factor *= 0.9
	elif weapon_class == "nahkampf":
		factor *= 1.0
	else: raise AttributeError
	return factor

def get_damage_factor(char, weapon_id, target):
	"""Returns the damage factor the char has with his equipped main weapon
when attacking the target.

Parameters:
        char      - Id of the char.
        weapon_id - Id of the weapon used by char.
        target    - Id of the target.
"""
	factor = 1.0
	weapon_class = "UNKNOWN WEAPON CLASS"
	if weapon_id:
		weapon_class = objects.get_attribute(weapon_id, "weapon_type")
	if weapon_class == "nahkampf":
		#include effects of attribute strength 
		factor *= skill_tables.strength_close_combat_damage(objects.get_attribute(char, "strength"))
		#include effects of skill close combat
		factor *= skill_tables.close_combat_weapons_damage(objects.get_attribute(char, "close_combat"))
		if target!=None:
			if has_talent(target, "close_combat", "stamina"):
				#include effects of talent stamina
				factor *= 0.7
	#else: raise AttributeError
	return factor
	

def calc_hit_chance(char, weapon, target):
	"""Returns the hit chance.
	
Is used in the hint for enemy chars.

Parameters:
        char   - Id of the char.
        weapon - Id of the weapon used by char.
        target - Id of the target.
"""
	weapon_type = objects.get_attribute(weapon, "typeid")
	hit_factor = get_hit_chance_factor(char, weapon, target)
	hit_factor *= objects.get_attribute(weapon_type, "genauigkeit")
	distance = objects.get_distance(char, target)
	max_fire_range = objects.get_attribute(weapon_type, "maximale_feuerreichweite")
	max_fire_range *= get_weapon_max_fire_range_factor(char, weapon)
	min_fire_range = objects.get_attribute(weapon_type, "minimale_feuerreichweite")
	
	dist_factor = 1.0 - (distance - min_fire_range) / ( max_fire_range - min_fire_range)
	if dist_factor > 1.0: dist_factor = 1.0
	if dist_factor < 0.2: dist_factor = 0.2

	if distance > max_fire_range: dist_factor = 0.0

	# for close combat the dist has no influence on hit chance (as long as target is within reach)
	if objects.has_attribute(weapon, "weapon_type")\
	and objects.get_attribute(weapon, "weapon_type") == "nahkampf"\
	and dist_factor > 0.0:
		dist_factor = 1.0
	
	hit_factor *= dist_factor

	if objects.has_attribute(target, "silent_kill") and objects.get_attribute(target, "silent_kill"):
		hit_factor = 1.0
	
	return hit_factor

def get_hit_chance_factor(char, weapon_id, target):
	"""Returns the hit chance factor the char has with his equipped main weapon.

Parameters:
        char      - Id of the char.
        weapon_id - Id of the weapon.
        target    - Id of the target.
"""
	if char in system.get_pcs(): #Derff's hack for knowing current for of character
		data(char).foe = target

	factor = 1.0

	#inquire weapon
	weapon_type = objects.get_attribute(weapon_id, "typeid")
	#print weapon_id
	#print weapon_type
	weapon_class = "UNKNOWN WEAPON CLASS"
	if weapon_id:
		weapon_class = objects.get_attribute(weapon_id, "weapon_type")

	# select skill/talent for this weapon
	# include skill influence
	if weapon_class == "leicht":
		skill = "light_weapons"
		factor *= skill_tables.light_weapons_hit_chance(objects.get_attribute(char, skill))
	if weapon_class == "schwer":
		skill = "heavy_weapons"
		factor *= skill_tables.heavy_weapons_hit_chance(objects.get_attribute(char, skill))
	if weapon_class == "sniper":
		skill = "sniper_weapons"
		factor *= skill_tables.sniper_weapons_hit_chance(objects.get_attribute(char, skill))
	if weapon_class == "wurf":
		skill = "throw_weapons"
		factor *= skill_tables.throw_weapons_hit_chance(objects.get_attribute(char, skill))
		if has_talent(char, "throw_weapons", "precision"):
			factor *= 1.1
		if has_talent(char, "throw_weapons", "specialisation_grenades") and \
		objects.get_attribute(weapon_id, "fire_animation")==global_defines.FPA_THROW_GRENADE:
			factor *= 1.1
		if has_talent(char, "throw_weapons", "ninja") and weapon_type=="SET_SHURIKEN":
			factor *= 1.1		
	if weapon_class == "nahkampf":
		skill = "close_combat"
		factor *= skill_tables.close_combat_weapons_hit_chance(objects.get_attribute(char, skill))
		if target!=None:
			if has_talent(target, "close_combat", "avoid"):
				factor *= 0.9
	talent = skill
		
	#include body mode
	mode = character.get_body_mode(char)
	if talent in ["light_weapons", "heavy_weapons", "sniper_weapons"]\
	and has_talent(char, talent, "stable_shot"):
		#Stehend und kniend wie liegend schießen
		factor *= 1.2
	elif mode=="LIE":
		if weapon_class == "wurf": factor *= 0.8
		else: factor *= 1.2
	elif mode=="KNEEL":
		if weapon_class == "wurf": factor *= 0.9
		else: factor *= 1.1
	#if objects.is_moving(char):
	#	factor *= 0.7

	# include talent influences
	if talent in ["light_weapons", "heavy_weapons", "sniper_weapons"]\
	and has_talent(char, talent, "precision"):
		#+ 5 % zielgenauigkeit
		factor *= 1.05
		
	# include attribute influence
	if weapon_class == "leicht" or weapon_class == "sniper" or weapon_class == "wurf" or weapon_class == "nahkampf":
		factor *= skill_tables.dexterity_weapons_hitchance(objects.get_attribute(char, "dexterity"))
	elif weapon_class == "schwer":
		factor *= skill_tables.strength_heavy_weapons_hitchance(objects.get_attribute(char, "strength"))
	else: raise AttributeError

	# hit chance factor from ammo
	if objects.has_attribute(weapon_id, "act_ammo_type"):
		ammo = objects.get_attribute(weapon_id, "act_ammo_type")
		if ammo and ammo!="" and objects.has_attribute(ammo, "hit_chance_factor"):
			factor *= objects.get_attribute(ammo, "hit_chance_factor")

	#no effects of lighting for close combat
	if weapon_class != "nahkampf":
		# hit chance factor for brightness
		night_sight_bonus = 0.0
		if talent == "sniper_weapons" and has_talent(char, talent, "night_sight"):
			night_sight_bonus = 0.2
		d = data("sky")
		if hasattr(d, "daytime"):
			t = d.daytime
			if t == "night":
				factor *= 0.7 + night_sight_bonus
			elif t == "dusk":
				factor *= 0.85 + night_sight_bonus
			elif t == "day":
				factor *= 1.0
			elif t == "dawn":
				factor *= 0.85 + night_sight_bonus	
			else:
				raise ValueError, "illegal value '%s' in data('sky').daytime" % str(t)
	
	return factor
	
def get_weapon_max_fire_range_factor(char, weapon_id):
	"""Returns a factor that influences the weapon range for this char depending on his skills.

Parameters:
        char      - Id of the char.
        weapon_id - Id of the weapon.
"""
	factor = 1.0
	
	#inquire weapon
	weapon_class = "UNKNOWN WEAPON CLASS"
	if weapon_id:
		weapon_class = objects.get_attribute(weapon_id, "weapon_type")

	#select skill/talent for this weapon
	if weapon_class == "leicht":
		skill = "light_weapons"
	if weapon_class == "schwer":
		skill = "heavy_weapons"
	if weapon_class == "sniper":
		skill = "sniper_weapons"
	if weapon_class == "wurf":
		skill = "throw_weapons"
	if weapon_class == "nahkampf":
		skill = "close_combat"
	talent = skill

	if talent in ["light_weapons", "heavy_weapons", "sniper_weapons"]\
	and has_talent(char, talent, "precision"):
		#+ 10 % maximale Schussdistanz
		factor *= 1.1
	
	# range factor from ammo
	if objects.has_attribute(weapon_id, "act_ammo_type"):
		ammo = objects.get_attribute(weapon_id, "act_ammo_type")
		if ammo and ammo!="" and objects.has_attribute(ammo, "fire_range_factor"):
			factor *= objects.get_attribute(ammo, "fire_range_factor")

	if weapon_class == "wurf":
		if not has_talent(char, "throw_weapons", "stable_throw"):
			# reduce range according to body mode
			bm = character.get_body_mode(char)
			if bm=="LIE": factor *= 0.333
			elif bm=="KNEEL": factor *= 0.5
		
		if has_talent(char, "throw_weapons", "precision"):
			factor *= 1.2
			
	return factor

def on_grid_enter( object_id, grid_id, old_grid_id, force_pc = False ):
	# print 'object_eventson_grid_enter(', object_id, grid_id, old_grid_id, force_pc ,')'
	"""Called if an object enters a grid.

Parameters:
        object_id   - Id of the object that enters a new grid.
        grid_id     - Id of the entered grid.
        old_grid_id - Id of the grid the object leaves.
        force_pc    - True shows new grid.
                      Default False shows new grid only when a PC enters.
"""

	# handle interior grids
	if objects.is_pc( object_id ) or force_pc:
		
		# update pcs_on_grid attribute on old grid
		if grids.has_attribute( old_grid_id, "pcs_on_grid" ):
			pcs_on_grid = grids.get_attribute( old_grid_id, "pcs_on_grid" )
			grids.set_attribute( old_grid_id, "pcs_on_grid", pcs_on_grid - 1 )

			# last pc left grid, so hide interior
			if pcs_on_grid == 1 and \
				grids.has_attribute( old_grid_id, "interior_object" ) and \
				grids.has_attribute( old_grid_id, "exterior_object" ):
					
				# check that there is really no one left in one of the interiors
				interior_object = grids.get_attribute( old_grid_id, "interior_object" )
				exterior_object = grids.get_attribute( old_grid_id, "exterior_object" )
				
				attached_grids = objects.get_attribute( interior_object, "attached_grids" )
				pcs_in_interior = False
				for attached_grid in attached_grids:
					if grids.has_attribute( attached_grid, "pcs_on_grid" ):
						if grids.get_attribute( attached_grid, "pcs_on_grid" ) > 0:
							pcs_in_interior = True
							break
				
				if not pcs_in_interior:
					objects.set_visible( interior_object, False )
					objects.set_visible( exterior_object, True )

		# update pcs_on_grid attribute on new grid
		if not grids.has_attribute( grid_id, "pcs_on_grid" ):
			grids.set_attribute( grid_id, "pcs_on_grid", 0 )
		pcs_on_grid = grids.get_attribute( grid_id, "pcs_on_grid" )
		grids.set_attribute( grid_id, "pcs_on_grid", pcs_on_grid + 1 )

		# first pc entered grid, so show interior
		if pcs_on_grid == 0:
			#jan: changed order of "if" statements does this statement make any sense????
			if (not grids.has_attribute( grid_id, "interior_object" )) and grids.has_attribute( grid_id, "exterior_object" ):
				exterior_object = grids.get_attribute( grid_id, "exterior_object" )
				objects.set_visible( exterior_object, False )
#				objects.set_visible( interior_object, True )#jan: any problems with this?

			# check that there is really no one already in one of the interiors
			if grids.has_attribute( grid_id, "interior_object" ) and \
				grids.has_attribute( grid_id, "exterior_object" ):
				
				interior_object = grids.get_attribute( grid_id, "interior_object" )
				exterior_object = grids.get_attribute( grid_id, "exterior_object" )
				
				attached_grids = objects.get_attribute( interior_object, "attached_grids" )
				pcs_in_interior = 0
				for attached_grid in attached_grids:
					if grids.has_attribute( attached_grid, "pcs_on_grid" ):
						pcs_in_interior += grids.get_attribute( attached_grid, "pcs_on_grid" ) > 0
				
				if pcs_in_interior == 1:
					objects.set_visible( exterior_object, False )
					objects.set_visible( interior_object, True )
				

		if len(system.get_selected_pcs()) > 0:
			if system.camera_in_follow_mode() and system.get_selected_pcs()[0] == object_id:
				if old_grid_id=="landscape":
					system.set_camera_zoom_parameters("indoor")

def switch_to_interior( object_id ):
	"""Switches to the interior; used in the editor.

Parameters:
        object_id - Id of the entered/showed grid.
"""
	if objects.has_attribute( object_id, "attached_interior_objects" ):
		attached_interior_objects = objects.get_attribute( object_id, "attached_interior_objects")
		objects.set_visible( object_id, False )
		objects.set_visible( attached_interior_objects[0], True )
		objects.set_direction(attached_interior_objects[0], objects.get_direction(object_id))
		objects.set_position(attached_interior_objects[0], objects.get_x(object_id),objects.get_y(object_id))

def switch_to_exterior( object_id_exterior, object_id_interior ):
	"""Switches to the exterior; used in the editor.

Parameters:
        object_id_exterior - Id of the exterior grid.
        object_id_interior - Id of the sub grid to hide.
"""
	objects.set_visible( object_id_interior, False )
	objects.set_visible( object_id_exterior, True )

def on_enemy_spotted( object_id ):
	"""Called if the player chars spot an enemy and no enemy has been visible yet.

Parameters:
        object_id - Id of the object seeing an enemy.
"""
	# print 'object_events.on_enemy_spotted(', object_id ,')'
	check_attack( object_id )
	
	music.on_enemy_spotted( object_id )


def on_sector_cleared( object_id ):
	"""Called if enemies have been visible and are now gone.

Parameters:
        object_id - Id of the object without enemies.
"""
	pass
	
def on_corpse_spotted( object_id ):
	"""Called if the player chars spot a corpse and no corpse has been visible yet.

Parameters:
        object_id - Id of the object seeing a corpse.
"""
	pass

def on_attack( operator_id, target_id ):
	"""Called when an object is attacked.

Parameters:
        object_id - Id of the char attacking.
        target_id - Id of the attacked char.
"""
	# print 'on_attack(', operator_id, target_id ,')'
	
	if not objects.is_destroyed(target_id):
		check_attack( target_id )

def check_attack( object_id ):
	"""Checks if an attacked char has a daily routine, and ends the daily routine.

Parameters:
        object_id - Id of the attacked char.
"""
	# print '##### check_attack(', object_id ,') ########'
	if object_id != None and object_id in system.get_npcs():
		if hasattr(system.get_act_mission(), 'schedules'):
			import npc_activities
			if npc_activities.npc_activity(object_id, system.get_act_mission().schedules.schedules):
				
				objects.cancel_commandos( object_id )
				
				import daily_routine
				daily_routine.finish_activity( object_id, speed = 2)
				import enemy_script
				enemy_script.is_equip_weapon(object_id)
				
				objects.set_attribute(object_id, 'ignore_foes', "ignore_until_idle")

def on_pick_up( character_id, item_id, item_type ):
	"""Called when an item is picked up.

Char goes to the item, bends down, and then on_pick_up is called.
When it returns True, the item is picked up, otherwise the item stays 
where it is.

Parameters:
        character_id - Id of the char.
        item_id      - Id of the item.
        item_type    - Type of the item.
"""
	bm = character.get_body_mode(character_id)
	if bm in ["KNEEL", "LIE"]:
		# bodymodes KNEEL and LIE are illegal for overloaded chars
		action = "action_liedown"
		if bm=="KNEEL": action = "action_kneel"
		weight = objects.get_attribute(item_id, "weight")
		objects.set_attribute(character_id, "virtual_inventory_weight", weight)
		update_speed(character_id)
		can = can_do_action(character_id, action, False)
		objects.set_attribute(character_id, "virtual_inventory_weight", None)
		update_speed(character_id)
		if not can: return False

	return True

def pre_pick_up(character_id, item_id):
	"""Called when an item is picked up.

Called before the char moves towards the item. When it returns False, the 
pick up is aborted.

Parameters:
        character_id - Id of the char.
        item_id      - Id of the item.
"""
	return True

def can_pick_up(character_id, item_id):
	"""Returns True if the char can pick up the item.

Parameters:
        character_id - Id of the char.
        item_id      - Id of the item.
"""
	if not objects.is_active(item_id): return False
	#cant/wont pick up a sharp bomb
	if objects.has_attribute(item_id, "bomb_is_sharp"):
		if objects.get_attribute(item_id, "bomb_is_sharp"):
			return False
	if objects.has_attribute(item_id, "flying_grenade") and objects.get_attribute(item_id, "flying_grenade"):
		return False
	return True

def can_defuse(character_id, item_id):
	"""Returns True if the char can defuse the bomb.

Parameters:
        character_id - Id of the char.
        item_id      - Id of the item.
"""
	if(objects.has_attribute(item_id, "bomb_is_sharp")):
		if objects.get_attribute(item_id, "bomb_is_sharp"):
			explosives = objects.get_attribute( object=character_id, attribute="explosives" )
			item_type= objects.get_attribute( item_id, "typeid" )
			if explosives <55:
				if(item_type=="SET_GAS_BOMB" or \
					item_type=="SET_DYNAMITE_WITH_TIME_BASED_DETONATOR" or \
					item_type=="SET_DYNAMITE" ):
					return False
				
			if explosives <60:
				if(item_type=="SET_C4_TIMEBASED" or \
					item_type=="SET_C4_TIMEBASED_W_NAILS" or \
					item_type=="SET_C4_REMOTE_CONTROL_W_NAILS" or \
					item_type=="SET_ANTITANKMINE" or \
					item_type=="SET_LANDMINE" or \
					item_type=="SET_FERTILIZER_EXPLOSIVE_TIME_BASED" or \
					item_type=="SET_FERTILIZER_EXPLOSIVE_REMOTE_CONTROL" or \
					item_type=="SET_C4_REMOTE_CONTROL" ):
					return False
			return True
	return False

def on_put_down( character_id, item_id, item_type ):
	"""Called if an item is put down.

Parameters:
        character_id - Id of the char.
        item_id      - Id of the item.
        item_type    - Type of the item.
"""
	#print "on_put_down", character_id, item_id, item_type
	pass

def can_put_down( character_id, item_id, item_type, x, y, grid_identifier ):
	"""Tests if the given item can be put down by the char.

Returns True if the item can be put down, otherwise False.

To use this function, it has to be overwritten in the 
appropriate zone script.

Parameters:
        character_id    - Id of the char.
        item_id         - Id of the item.
        item_type       - Type of the item.
        x,y             - Target coordinates.
        grid_identifier - Id of the target grid.
"""
	
	# default return value is True
	return True
	
def get_item_3d_offset( character_id, node_name, type_id ):
	"""Gets the 3D offset for the item.

Parameters:
        character_id - Id of the char.
        node_name    - Id of the node to which the item is attached.
        type_id      - Type of the item.
"""
	if (objects.has_attribute(type_id, "offset")):
		offset = objects.get_attribute(type_id, "offset")
		if (objects.has_attribute(character_id, "gender") and
			objects.has_attribute(character_id, "model")):
			gender = objects.get_attribute(character_id, "gender")
			model = objects.get_attribute(character_id, "model")
			for entry in offset:
				if len(entry)==4:
					if (entry[0]==gender and
						entry[1]==model and
						entry[2]==node_name):
						vector = entry[3]
						if len(vector)!=3:
							raise ValueError, "vector needs entries for x,y,z"
						#print vector
						return vector
	return [0,0,0]

def is_feigning_death( character_id ):
	"""Returns True if the char is feigning death.

Parameters:
        character_id - Id of he char.
"""
	# if the char has the attr then check its state
	if objects.has_attribute( character_id, "feigning_death" ):
		if objects.get_attribute( character_id, "feigning_death" ):
			return True
		else: # char does not have the attr, that means he is not feigning death
			return False
	else:
		return False
			


def feign_death( character_id, status = None ):
	"""Determines if the char should feign death.
The old body mode is saved in the attribute feigning_death.

Parameters:
        character_id - Id of the char.
        Status       - Controls feign death.

Where status is:
        If status True, then the char feigns death.
        If status False, then the char ends feigning death.
        If status None, then the char switches feigning death.
"""

	if status == None:
		# if the char has the attr this means he is feigning death
		if objects.has_attribute( character_id, "feigning_death" ):
			status = False
		else: # char does not have the attr, that means he is NOT feigning death
			status = True

	if status:
		system.add_text(globaltext.PC_FEIGN_DEATH % {"char": objects.get_attribute(character_id, "name")})

	give_first_use_exp(character_id, "survival", "feign_death")
	objects.set_feigning_death_state( character_id, status )

def remove_from_foes_list( character_id, enemy_id ):
	"""Removes the enemy from the foes list of the char.

Parameters:
        character_id - Id of the char that has the enemy list.
        enemy_id     - Id of the enemy that should be removed.
"""

	if objects.has_attribute( character_id, "foes" ):
		foes = objects.get_attribute( character_id, "foes" )
		if enemy_id in foes:
			foes.remove( enemy_id )
			objects.set_attribute( character_id, "foes", foes )
			# cancel the attacking commandos of the char
			objects.cancel_commandos( character_id ) 
				

def has_talent( character_id, skill, talent ):
	"""Returns True if the char has the talent.

Parameters:
        character_id - Id of the character.
        skill        - The skill where the talent is part of.
        talent       - The talent itself.
"""

	return global_defines.has_talent( character_id, skill, talent )

def can_use_talent_increase_moral( character_id ):
	"""Checks if the char can use the talent 'increase_moral'.

This talent can only be used every 24 hours.

Parameters:
        character_id - Id of the char.
"""

	if not has_talent( character_id, "speech", "increase_moral" ):
		return False
	# increase moral is already aktiv for the party
	if bonus.has_keyword(character_id, "increase_moral"):
		return False

	if objects.has_attribute( character_id, "used_increase_moral" ):
		last_used = objects.get_attribute( character_id, "used_increase_moral" )
		if system.get_mission_time() - last_used > timerepr.time( "24:00:00" ):
			return True
		else:
			return False
	else:
		return True

def on_use_increase_moral( character_id ):
	"""The char uses the talent increase_moral.

This gives the party a 20% bonus on their hit points for 5 minutes. 

Parameters:
        character_id - Id of the char.
"""
	
	if not can_use_talent_increase_moral( character_id ):
		return

	# let the char shout some motivating words
	random_comment( character_id, "INCREASE_MORAL_", 3 )

	# set the time the char startetd to use increase_moral.
	# With this value we can measure that he would not use it twice 
	# in a time span of 24 hours.
	objects.set_attribute( character_id, "used_increase_moral", system.get_mission_time() )

	party_members = system.get_pcs()
	
	give_first_use_exp(character_id, "speech", "increase_moral")

	timeout = "2:0:0"
	property_table = dict(zip(skill_tables.skills, [20]*len(skill_tables.skills))) # python mojo! :D
	for member in party_members:
		callback = None
		if member == party_members[0]:
			callback = 	"system.add_text(globaltext.TALENT_SPEECH_MORAL_OFF);"\
						"import bonus;"\
						"bonus.remove_temp_bonus('%s', 'increase_moral')" % (member)
			callback = Lambda(callback)
		bonus.add_temp_bonuses(member, property_table, "increase_moral", timeout, callback, remove_on_leave=True)

	system.update_ui()



def can_use_talent_survive( character_id ):
	"""Checks if the char can use the talent 'survive'.

This talent can only be used every 24 hours.

Parameters:
        character_id - Id of the char.
"""

	if not has_talent( character_id, "survival", "survive" ):
		return False

	if objects.has_attribute( character_id, "used_survive" ):
		last_used = objects.get_attribute( character_id, "used_survive" )
		if system.get_mission_time() - last_used > timerepr.time( "24:00:00" ):
			return True
		else:
			return False
	else:
		return True

def on_use_survive( character_id ):
	"""The char uses the talent survive.

This gives the party a 10% bonus on their hit points for 5 minutes.
If survive is already active for the party, then extend the time
by setting a new start time for survive_active.

Parameters:
        character_id - Id of the char.
"""
	
	if not can_use_talent_survive( character_id ):
		return

	party_members = system.get_pcs()

	for member in party_members:
		# if a char has the attribute survive_activated
		# then do not extend hitpoints again
		if bonus.has_keyword(member, "survive"):
			system.add_text(globaltext.MESSAGE_USE_TALENT_TWICE %
				{	"char": objects.get_attribute(character_id, "name"),
					"talent": globaltext.MISSION_TALENT_SURVIVAL_NAME_SURVIVE
				})
			return

	callback = 	"system.add_text(globaltext.TALENT_SURVIVAL_SURVIVE_OFF);"\
				"import bonus;"\
				"bonus.remove_temp_bonus('%s', 'survive')"
	for member in party_members:
		if callback: callback = Lambda(callback % member)
		diff = bonus.add_temp_bonus(member, "maxhitpoints", 1.1, "survive", timeout="2:0:0", callback=callback, remove_on_leave=True)
		callback = None
		bonus.add_temp_bonus(member, "hitpoints", diff, "survive")

	# set the time the char startetd to use survive.
	# With this value we can measure that he would not use it twice 
	# in a time span of 24 hours.
	objects.set_attribute( character_id, "used_survive", system.get_mission_time() )

	system.add_text(globaltext.TALENT_SURVIVAL_SURVIVE_ON % {"char": objects.get_attribute(character_id, "name")})

	give_first_use_exp(character_id, "survival", "survive")

def on_wait_for_commando(id):
	"""Called whenever a char has "nothing to do", i.e., he would play a wait animation.

The wait animation is played if on_wait_for_commando returns False.
If on_wait_for_commando gives the char a new command or another animation, it
should return True.

Parameters:
        id - Id of the char.
"""
	# handle alerted chars
	if objects.has_attribute(id, "alerted")\
	and objects.get_attribute(id, "alerted")\
	and character.exists(id):
		weapon = character.get_primary_weapon(id)
		weapon_type = None
		if weapon:
			weapon_type = objects.get_attribute(weapon, "weapon_type")
		if weapon_type and weapon_type != "nahkampf":
			if character.get_body_mode(id) != "KNEEL":
				character.change_body_mode(id, "KNEEL")
				character.aim_animation(id)
			else:
				animation_type = objects.get_attribute(weapon, "fire_animation")
				if animation_type in [global_defines.FPA_PISTOL_SINGLE, global_defines.FPA_PISTOL_VOLLEY]:
					character.play_animation(id, "CM_KNIEND_ALARMIERT_PISTOLE")
				else:
					character.play_animation(id, "CM_KNIEND_ALARMIERT_GEWEHR")
		else:
			character.play_animation(id, "CM_KNIEND_ALARMIERT_WAFFENLOS")
		return True
	
	data = global_defines.data("rest")
	if hasattr(data, "resting") and data.resting and id in data.char_activity.keys():		
		if data.char_activity[id] == "lie_on_camping_bed":			
			character.play_animation(id, "CM_NPC_LIEGEN_BETT_LOOP")
			return True
		elif data.char_activity[id] == "lie_on_sleeping_bag":			
			character.play_animation(id, "CM_NPC_LIEGEN_LOOP")
			return True
		elif data.char_activity[id] == "read_book":			
			character.play_animation(id, "CM_NPC_SITZEN_BANK_BUCH_LESEN_LOOP")
			return True			
		elif data.char_activity[id] == "play_flute":
			character.play_animation(id, "CM_NPC_SITZEN_BANK_FLOETE_SPIELEN_LOOP")
			return True			
		elif data.char_activity[id] == "cook_meal":
			character.play_animation(id, "CM_NPC_STEHEN_PFANNE_SCHWENKEN_LOOP")
			return True
		elif data.char_activity[id] == "write_pad":
			character.play_animation(id, "CM_NPC_SITZEN_BANK_LOOP")
			return True
		elif data.char_activity[id] == "drink":
			if not random.randint(0, 10):
				character.play_animation(id, "CM_NPC_SITZEN_BODEN_TRINKEN_LOOP")
			else:
				character.play_animation(id, "CM_NPC_SITZEN_BODEN_LOOP")
			return True
		elif data.char_activity[id] == "eat_and_drink":
			if not random.randint(0, 10):
				character.play_animation(id, "CM_NPC_SITZEN_BODEN_TRINKEN_LOOP")
			elif not random.randint(0, 2):				
				character.play_animation(id, "CM_NPC_SITZEN_BODEN_ESSEN_LOOP")
			else:
				character.play_animation(id, "CM_NPC_SITZEN_BODEN_LOOP")
			return True	
		elif data.char_activity[id] == "play_cards":
			if not random.randint(0, 5):
				character.play_animation(id, "CM_NPC_SITZEN_BODEN_KARTEN_SPIELEN_AUSSPIELEN_LOOP")
			else:
				character.play_animation(id, "CM_NPC_SITZEN_BODEN_KARTEN_SPIELEN_GRUEBELN_LOOP")
			return True
		
	if objects.has_attribute(id, "ignore_foes"):
		if objects.get_attribute(id, "ignore_foes") == "ignore_until_idle":
			objects.set_attribute(id, "ignore_foes", "do_not_ignore" )
	
	# check if this npc can/should loot a corpse
	if random.randint(0,10) == 0:
		if objects.can_do_npc_ki_action(id):
			#npc_ki_loot_corpse(id)
			pass
			
	return False

def can_crack_lock( character_id, object_id, dummy ):
	"""Checks if the char is able to crack a lock.

This is only possible if he has a picklock.

Parameters:
        character_id - Id of the char.
        object_id    - Id of the object to crack.
        dummy        - Id of the Dummy for the lock of this object.
"""
	
	picklocks = [ "SET_BASIC_PICKLOCK", "SET_VAMPED_PICKLOCK_SET", "SET_SET_OF_PICKLOCKS", "SET_SPECIAL_PICKLOCK" ]

	for picklock in picklocks:
		if( objects.count_in_inventory( character_id, picklock ) ):
			return True

	return False

def can_blast_lock( character_id, object_id, dummy ):
	"""Checks if the char is able to blast a lock.

Parameters:
        character_id - Id of the char.
        object_id    - Id of the object to crack.
        dummy        - Id of the Dummy for the lock of this object.
"""
	if not has_talent( character_id, "explosives", "blast_locks" ):
		return False
	explosives = [ "SET_GUN_POWDER" ]

	for explosive in explosives:
		if( objects.count_in_inventory( character_id, explosive ) ):
			return True

	return False

def on_blast_lock( character_id, object_id, dummy_name, x, y, z ):
	"""Called when the char blasts a lock open.

Parameters:
        character_id - Id of the char.
        object_id    - Id of the object to crack.
        dummy        - Id of the dummy for the lock of this object.
        x,y,z        - Coordinates of the dummy.
"""
	lock_data = {}
	lock = None
	lock_position = None

	objects.remove_item_from_inventory(character_id, "SET_GUN_POWDER")
	interior_object_id=None
	#jan: dummy für schloss sind am interior!! 
	if objects.has_attribute( object_id, "attached_interior_objects" ): #jan: hier muss eigentlich über alle interiors itteriert werden, aber wir nutzen momentan nur 1 interior
		interior_object_id=objects.get_attribute( object_id, "attached_interior_objects" )[0]
	else:
		interior_object_id=object_id
		
		
	if objects.has_attribute( object_id, "exterior_object_id" ):
		object_id = objects.get_attribute( object_id, "exterior_object_id" )
	object_type = objects.get_attribute( object_id, "typeid" )
	if objects.has_attribute( object_type, "lock_data" ):
		lock_data = objects.get_attribute( object_type, "lock_data" )

		# search the lock by the given dummy
		for key in lock_data.keys():
			if dummy_name in lock_data[ key ][ "dummies" ]:
				lock = key
	else:
		return

	if lock == None:
		return
	
	# get the position of the lock to determine the correct animation
	lock_position = lock_data[ lock ][ "position" ]
	# fix von roger: position des dummys holen, dort fx starten
	x,y,z = objects.get_full_dummy_position(interior_object_id, dummy_name)
	#z = z - objects.get_attribute(interior_object_id,"z") # absolutes z umrechnen auf relatives
	lambda_string = 'on_lock_explode(object_id="%s", dummy_name="%s", x=%f, y=%f, z=%f )' %(object_id, dummy_name, x, y, z )
	bm = character.get_body_mode(character_id)
	talk_callback = "dialog.init_dialog( type=global_defines.DIALOGSMALL )"
	talk_callback += ';dialog.add_text( text = get_random_comment( "CRACK_LOCK_SUCCESS_", 2), speaker = "%s", follower = "ENDDIALOG")' % character_id
	talk_callback += ";dialog.start()"

	data("pick_lock").finish_callback = "character.change_body_mode('%s', '%s')" % (character_id, bm)
	data("pick_lock").finish_callback += "; objects.step_away('%s', callback=Lambda('%s'))" % (character_id, talk_callback)
	data("pick_lock").finish_callback += "; give_first_use_exp('%s', 'explosives', 'blast_locks')" % (character_id)
	data("pick_lock").finish_callback = Lambda(data("pick_lock").finish_callback)
	
	
	if lock_position == "bottom":
		character.play_animation( character_id, "KNIEND_TRUENSCHLOSS_KNACKEN" , callback=[ "ONEND", Lambda( lambda_string ) ])
	if lock_position == "center":
		character.play_animation( character_id, "STEHEND_TUERSCHLOSS_KNACKEN" , callback=[ "ONEND", Lambda( lambda_string ) ])
	if lock_position == "top":
		Lambda(lambda_string)()

def on_lock_explode( object_id, dummy_name, x, y, z ):
	"""Called by on_blast_lock when the lock explodes.

Parameters:
        object_id    - Id of the object to crack.
        dummy        - Id of the dummy for the lock of this object.
        x,y,z        - Coordinates of the dummy.
"""
	system.start_effect( x, y, z, x, y, z, global_defines.fx_explosion )
	sounds.play_3d_sound( "grenade_explo_fire", x, y, z )
	objects.remove_closed_lock( object_id, dummy_name ) # lock is open because of the explosion
	data("pick_lock").finish_callback()

def calc_crack_lock_position(object_id, dummy_name, x, y):
	"""helper function for on_crack_lock"""
	dist = 0.40
	lock_data, lock = get_lock_data(object_id, dummy_name)
	lock_position = lock_data[ lock ][ "position" ]
	if lock_position == "bottom": dist = 0.50
	if lock_position == "center": dist = 0.35
	pos_obj_center = (objects.get_x(object_id), objects.get_y(object_id))
	return calc_rotated_pos(x, y, pos_obj_center[0], pos_obj_center[1], 180, dist)

def on_crack_lock(character_id, object_id, dummy_name, x, y, z ):
	"""Equips the char with the right utilities, moves the char to the lock, and starts 
the crack animations.

Parameters:
        character_id - Id of the char.
        object_id    - Id of the object to crack.
        dummy        - Id of the dummy for the lock of this object.
        x,y,z        - Coordinates of the dummy.
"""
	lamstr = "on_crack_lock_2('%s', '%s', '%s', %f, %f, %f)" % (character_id, object_id, dummy_name, x, y, z)
	if objects.get_distance_to_position(character_id, x, y) > 2.0:
		x,y = calc_crack_lock_position(object_id, dummy_name, x, y)
		objects.move_to(character_id, x, y, grid=objects.get_grid( object_id ), callback=Lambda(lamstr))
	else:
		Lambda(lamstr)()
def get_lock_data(object_id, dummy_name):
	"""Helper for on_crack_lock.

Parameters:
        object_id    - Id of the object to crack.
        dummy        - Id of the dummy for the lock of this object.
"""
	object_type = objects.get_attribute( object_id, "typeid" )
	if objects.has_attribute( object_type, "lock_data" ):
		lock_data = objects.get_attribute( object_type, "lock_data" )
		# search the lock by the given dummy
		for key in lock_data.keys():
			if dummy_name in lock_data[ key ][ "dummies" ]:
				lock = key
	return lock_data, lock
def on_crack_lock_2(character_id, object_id, dummy_name, x, y, z):
	"""Helper for on_crack_lock.

Parameters:
        object_id    - Id of the object to crack.
        dummy        - Id of the dummy for the lock of this object.
"""
	lamstr = "on_crack_lock_3('%s', '%s', '%s', %f, %f, %f)" % (character_id, object_id, dummy_name, x, y, z)

	x,y = calc_crack_lock_position(object_id, dummy_name, x, y)
	objects.step_to(character_id, x, y, callback=Lambda(lamstr))

        
def on_crack_lock_3(character_id, object_id, dummy_name, x, y, z):
	"""Helper for on_crack_lock.

Parameters:
        character_id - Id of the char.
        object_id    - Id of the object to crack.
        dummy        - Id of the dummy for the lock of this object.
        x,y,z        - Coordinates of the dummy.
"""
	if hasattr(data("pick_lock"), "blast_lock") and data("pick_lock").blast_lock:
		lamstr = "call('on_blast_lock', '%s', '%s', '%s', %f, %f, %f)" % (character_id, object_id, dummy_name, x, y, z)
	else:
		lamstr = "on_crack_lock_4('%s', '%s', '%s', %f, %f, %f)" % (character_id, object_id, dummy_name, x, y, z)
	objects.turn_to_position(character_id, x, y, callback=Lambda(lamstr))
        
def on_crack_lock_4(character_id, object_id, dummy_name, x, y, z):
	"""Helper for on_crack_lock.

Parameters:
        character_id - Id of the char.
        object_id    - Id of the object to crack.
        dummy        - Id of the dummy for the lock of this object.
        x,y,z        - Coordinates of the dummy.
"""
	pre_crack_lock( character_id ) # quip the right picklock

	lock_data = {}
	lock = None
	lock_position = None
	global crack_lock_comments
	crack_lock_comments = []
	

	if objects.has_attribute( object_id, "exterior_object_id" ):
		object_id = objects.get_attribute( object_id, "exterior_object_id" )
		
	lock_data, lock = get_lock_data(object_id, dummy_name)

	if lock == None or lock_data == None:
		return
	
	# get the position of the lock to determine the correct animation
	lock_position = lock_data[ lock ][ "position" ]

	# play a animation showing the char cracking a lock
	lambda_string = 'char_tried_cracking( character_id="%s", object_id="%s", dummy_name="%s", x=%f, y=%f, z=%f )' %( character_id ,object_id, dummy_name, x, y, z )
	bm = character.get_body_mode(character_id)
	data("pick_lock").finish_callback = "character.change_body_mode('%s', '%s')" % (character_id, bm)
	data("pick_lock").finish_callback += "; objects.step_away('%s')" % (character_id)
	data("pick_lock").finish_callback = Lambda(data("pick_lock").finish_callback)

	if lock_position == "bottom":
		callback = "character.play_animation('%s', 'KNIEND_TRUENSCHLOSS_KNACKEN', callback=Lambda('%s'))" % (character_id, lambda_string)
		character.change_body_mode(character_id, "KNEEL", callback=Lambda(callback))
	if lock_position == "center":
		callback = "character.play_animation('%s', 'STEHEND_TUERSCHLOSS_KNACKEN', callback=Lambda('%s'))" % (character_id, lambda_string)
		character.change_body_mode(character_id, "STAND", callback=Lambda(callback))
	if lock_position == "top":
		assert False
	
def calc_crack_lock_chances( character_id, object_id, dummy_name ):
	"""Calcs the chance of the char to crack a lock.

The chance that the lock is destroyed, and the chance to destroy the picklock
while trying to crack a lock.

Returns all three values: 
        float - crack_lock_chance.
        bool  - lock_destroyed.
        float - destroy_picklock_chance. 

Parameters:
        character_id - Id of the char.
        object_id    - Id of the object to crack.
        dummy        - Id of the dummy for the lock of this object.
        x,y,z        - Coordinates of the dummy.
"""
	lock_data = {}
	lock = None

	object_type = objects.get_attribute( object_id, "typeid" )
	if objects.has_attribute( object_type, "lock_data" ):
		lock_data = objects.get_attribute( object_type, "lock_data" )

		# search the lock by the given dummy
		for key in lock_data.keys():
			if dummy_name in lock_data[ key ][ "dummies" ]:
				lock = key

	if lock == None:
		return 1.0, False, 0.0

	cracklock_skill = 0
	bonus = 0 # is the bonus the chars get if he has some talents
	crack_lock_chance = 0.0
	destroy_picklock_chance = 0.0 # chance to destroy the picklock while cracking a lock
	lock_destroyed = False # determines if the lock is destroyed while trying to open it

	# calc the bonus. If the char uses a professionell picklock then 
	# the bonus is 5%
	# check if picklock is equiped
	professionell_picklocks = [ "SET_SET_OF_PICKLOCKS" ]

	# if a picklock is already equiped than do nothing
	for picklock in professionell_picklocks:
		if character.is_equiped( character_id, picklock ):
			bonus = 0.05

	# check if char has talent to open this particular lock
	lock_type = lock_data[ lock ][ "type" ]

	if lock_type == "door" and has_talent( character_id, "lock_pick", "specialisation_doors" ):
		bonus = bonus + 0.2
	if lock_type == "chest" and has_talent( character_id, "lock_pick", "specialisation_chests" ):
		bonus = bonus + 0.2
	if lock_type == "safe" and has_talent( character_id, "lock_pick", "specialisation_safes" ):
		bonus = bonus + 0.2

	if objects.has_attribute( character_id, "lock_pick" ):
		cracklock_skill = objects.get_attribute( character_id, "lock_pick" )

	# set the chance to crack the lock depending on the skill
	crack_lock_chance = skill_tables.lock_pick_crack_lock_chance(cracklock_skill)
	destroy_picklock_chance = skill_tables.lock_pick_destroy_picklock_chance(cracklock_skill)
	if random.random() <= ( skill_tables.lock_pick_destroy_lock_chance(cracklock_skill) - bonus ):
		lock_destroyed = True
		
	crack_lock_chance += bonus
	crack_lock_chance *= skill_tables.dexterity_lock_picking(objects.get_attribute(character_id, "dexterity"))
		
	if character.is_equiped(character_id, "SET_SPECIAL_PICKLOCK"):
		destroy_picklock_chance = 0.0

	return ( crack_lock_chance, lock_destroyed, destroy_picklock_chance )

		
# globale var to store the crack_lock  comments
crack_lock_comments = []

def char_tried_cracking( character_id, object_id, dummy_name, x, y, z ):
	"""Helper for on_crack_lock.

Called after the crack lock animation is played.

Parameters:
        character_id - Id of the char.
        object_id    - Id of the object to crack.
        dummy        - Id of the dummy for the lock of this object.
        x,y,z        - Coordinates of the dummy.
"""

	lock_data = {}
	lock = None

	object_type = objects.get_attribute( object_id, "typeid" )
	if objects.has_attribute( object_type, "lock_data" ):
		lock_data = objects.get_attribute( object_type, "lock_data" )

		# search the lock by the given dummy
		for key in lock_data.keys():
			if dummy_name in lock_data[ key ][ "dummies" ]:
				lock = key

	# if dummy does not determine a lock
	if lock == None:
		random_comment( character_id, "CRACK_LOCK_NO_LOCK_", 2 )
		call("post_crack_lock", character_id, -1, object_id )
		return

	destroyed_locks = []

	# check if the lock that is determined by the given dummy is destroyed before.
	# If yes than it can not be opened anymore.
	if objects.has_attribute( object_id, "destroyed_locks" ):
		destroyed_locks = objects.get_attribute( object_id, "destroyed_locks" )

		# is the lock is a destroyed lock return
		# because then the lock can not be opened
		if lock in destroyed_locks:
			random_comment( character_id, "CRACK_LOCK_LOCK_ALREADY_DESTROYED_", 3 )

			# cleanup, get char out of illegal area (step_to has been used to position the char)
			if not objects.is_destroyed(character_id) and not objects.is_unconscious(character_id):
				objects.stack_callback(character_id, data("pick_lock").finish_callback)

			return

	crack_lock_chance, lock_destroyed, destroy_picklock_chance = calc_crack_lock_chances( character_id, object_id, dummy_name )
	
	# check the chance to crack the lock if it is not destroyed
	# before.
	global crack_lock_comments
	booby_trap_comment = False
	lock_trap_comment = False
	poison_trap_comment = False
	
	if not lock_destroyed:
		# if the lock has a trap and the char does not have the talent to deactivate it,
		# then the trap is activated
		rand = random.random()
		handle_lock_traps( character_id, object_id, lock_data, lock, dummy_name, x, y, z, destroy_picklock_chance )
		if objects.has_closed_lock(object_id, lock):
			if rand < crack_lock_chance: # cracking was a success
				closure_type = lock_data[ lock ][ "closure_type" ]
				if closure_type=="booby-trap" and  has_talent( character_id, "explosives", "detect_booby_traps" ):
					booby_trap_comment = True
				elif closure_type=="lock-trap" and  has_talent( character_id, "lock_pick", "lock_trap_trick" ):
					lock_trap_comment = True
				elif closure_type=="poison-trap" and  has_talent( character_id, "lock_pick", "lock_trap_trick" ):
					poison_trap_comment = True
				objects.remove_closed_lock( object_id, dummy_name )
				crack_lock_comments.append( get_random_comment( "CRACK_LOCK_SUCCESS_", 3 ) )
				give_first_use_exp(character_id, "open_look")
			else: # cracking failed
				#random_comment( character_id, "CRACK_LOCK_FAILED_", 3 )
				crack_lock_comments.append( get_random_comment( "CRACK_LOCK_FAILED_", 3 ) )
	else:
		destroyed_locks.append( lock )
		crack_lock_comments.append( get_random_comment( "CRACK_LOCK_LOCK_DESTROYED_", 2 ) )
		call("post_crack_lock", character_id, destroy_picklock_chance, object_id )

	# set the new destroyed_locks list
	objects.set_attribute( object_id, "destroyed_locks", destroyed_locks )
	
	additional_crack_lock_comments(character_id)
	if lock_trap_comment:
		system.add_text(globaltext.PC_DISARM_RAZORTRAP % {"char": objects.get_attribute(character_id, "name")})
		give_first_use_exp(character_id, "lock_pick", "lock_trap_trick")
		print "system_comment"
	if poison_trap_comment:
		system.add_text(globaltext.PC_DISARM_POISONTRAP % {"char": objects.get_attribute(character_id, "name")})
		give_first_use_exp(character_id, "lock_pick", "lock_trap_trick")
		print "system_comment"
	if booby_trap_comment:
		system.add_text(globaltext.PC_DISARM_BOOBYTRAP % {"char": objects.get_attribute(character_id, "name")})
		give_first_use_exp(character_id, "explosives", "detect_booby_traps")
		print "system_comment"
	
	if lock_data[ lock ][ "closure_type" ] == 'poison-trap':
		if objects.has_attribute(character_id, "poison_ticks"):
			if objects.get_attribute(character_id,"poison_ticks") == 20:
				system.add_text(globaltext.COMMENT_POISEN_TRAP %{'char': objects.get_attribute(character_id, 'name')})
				print "system_comment"
		
	
def handle_lock_traps( character_id, object_id, lock_data, lockname, dummy_name, x, y, z, destroy_picklock_chance ):
	"""Called when the char has activated a trap.

Parameters:
        character_id - Id of the char.
        object_id    - Id of the object to crack.
        lock_data    - Type of the lock.
        lockname     - Name of the lock that was not cracked.
        dummy        - Id of the dummy for the lock of this object.
        x,y,z        - Coordinates of the dummy.
        destroy_picklock_chance - Chance that Picklock is destroyed.
"""
	comment_text = ""
	# check for closure_type of the lock that the dummy represents
	# and play the appropriate animation
	closure_type = lock_data[ lockname ][ "closure_type" ]

	callback = Lambda("call('post_crack_lock', '%s', %f, '%s')" % (character_id, destroy_picklock_chance, object_id))
	
	# booby-trap will explode if char does not have the talent to deactivate it
	if closure_type == "booby-trap" and not has_talent( character_id, "explosives", "detect_booby_traps" ):
		system.start_effect( x, y, z, x, y, z, global_defines.fx_explosion )
		sounds.play_3d_sound( "grenade_explo_fire", x, y, z )
		character.play_animation( character_id, "KNIEND_TRUENSCHLOSS_KNACKEN_SPRENGFALLE_TREFFER", callback=callback)
		comment_text = get_random_comment( "CRACK_LOCK_BOOBY_TRAP_", 2 )
		# char gets 5-15 damage
		rand = random.randrange( 5, 15, 1 )
		objects.damage( character_id, rand )
		objects.remove_closed_lock( object_id, dummy_name ) # lock is open because of the explosion
	# poison-trap will poison if char does not have the talent to deactivate it
	elif closure_type == "poison-trap" and not has_talent( character_id, "lock_pick", "lock_trap_trick" ):
		objects.set_attribute(character_id,"poison_ticks",20)
		sounds.play_3d_sound( "throwing_knife_loop", x, y, 0 )
		lock_position = lock_data[ lockname ][ "position" ]
		if lock_position == "bottom":
			character.play_animation( character_id, "KNIEND_TRUENSCHLOSS_KNACKEN_MESSERFALLE_TREFFER", callback=callback)
		else:
			character.play_animation( character_id, "STEHEND_TUERSCHLOSS_KNACKEN_MESSERFALLE_TREFFER", callback=callback)

		# solange kein eigener text für giftfallen existiert
		comment_text = 'CRACK_LOCK_LOCK_TRAP_002'

	# lock-trap will be activated if char does not have the talent to deactivate it
	elif closure_type == "lock-trap" and not has_talent( character_id, "lock_pick", "lock_trap_trick" ):
		sounds.play_3d_sound( "throwing_knife_loop", x, y, 0 )
		lock_position = lock_data[ lockname ][ "position" ]
		if lock_position == "bottom":
			character.play_animation( character_id, "KNIEND_TRUENSCHLOSS_KNACKEN_MESSERFALLE_TREFFER", callback=callback)
		else:
			character.play_animation( character_id, "STEHEND_TUERSCHLOSS_KNACKEN_MESSERFALLE_TREFFER", callback=callback)
		comment_text = get_random_comment( "CRACK_LOCK_LOCK_TRAP_", 2 )

		rand = random.randrange( 1, 5, 1 )
		objects.damage( character_id, rand )
	else:
		if closure_type == "booby-trap" and has_talent( character_id, "explosives", "detect_booby_traps" ):
			give_first_use_exp(character_id, "explosives", "detect_booby_traps")
		elif closure_type == "poison-trap" and has_talent( character_id, "lock_pick", "lock_trap_trick" ):
			give_first_use_exp(character_id, "lock_pick", "lock_trap_trick")
		elif closure_type == "lock-trap" and has_talent( character_id, "lock_pick", "lock_trap_trick" ):
			give_first_use_exp(character_id, "lock_pick", "lock_trap_trick")
		system.timed_callback(100, callback)

	global crack_lock_comments
	if objects.get_attribute(character_id,"hitpoints") >0: #lives
		if comment_text != "":
			crack_lock_comments.append( comment_text )


def pre_crack_lock( character_id ):
	"""Called before cracking a lock.

Char equips picklock, or complains if he doesn't have any.

Parameters:
        character_id - Id of the char.
"""
	# check if picklock is equiped
	picklocks = [ "SET_SET_OF_PICKLOCKS", "SET_VAMPED_PICKLOCK_SET", "SET_BASIC_PICKLOCK", "SET_SPECIAL_PICKLOCK" ]

	equip_and_mark_unequiped( character_id, picklocks, "picklock_item" )
	

def post_crack_lock( character_id, destroy_picklock_chance, object_id ):
	"""Called after a char tries to crack a lock.

The picklock is taken back into the inventory.
The item used before is equipped again.

Parameters:
        character_id            - Id of the char.
        destroy_picklock_chance - Chance Picklock is destroyed.
        object_id               - Id of the object to crack.
"""

	used_picklock = None
	comment_text = ""

	used_picklock = unequip_and_equip_marked( character_id, "picklock_item" )

	if used_picklock != None:
		# check if char destroyed the picklock while trying to crack a lock
		rand = random.random()
		if rand < destroy_picklock_chance:
			comment_text = get_random_comment( "CRACK_LOCK_PICKLOCK_DESTROYED_", 3 )

			if character.is_equiped( character_id, used_picklock ):
				character.un_equip( character_id, used_picklock )

			objects.remove_item_from_inventory( character_id, used_picklock )

	global crack_lock_comments
	if comment_text != "":
		crack_lock_comments.append( comment_text )

	# cleanup, get char out of illegal area (step_to has been used to position the char)
	if not objects.is_destroyed(character_id) and not objects.is_unconscious(character_id):
		objects.stack_callback(character_id, data("pick_lock").finish_callback)
	
	additional_crack_lock_comments(character_id)

def additional_crack_lock_comments(character_id):
	"""helper function for crack_lock"""
	global crack_lock_comments
	
	if dialog.is_dialog_active():
		# don't display several crack lock comments at once
		system.timed_callback(100, Lambda("additional_crack_lock_comments('%s')" % character_id))
		return

	# no talking corpses pls!
	if objects.get_attribute(character_id,"hitpoints") <= 0: return
	
	if len( crack_lock_comments ) > 0:
		dialog.init_dialog( type=global_defines.DIALOGSMALL )
		for x in range( len( crack_lock_comments ) ):
			if x < len( crack_lock_comments ) - 1:
				if crack_lock_comments[x + 1] in ['CRACK_LOCK_BOOBY_TRAP_001', 'CRACK_LOCK_BOOBY_TRAP_002', 'CRACK_LOCK_LOCK_TRAP_001', 'CRACK_LOCK_LOCK_TRAP_002']:
					dialog.add_text( text = crack_lock_comments[ x+1 ], speaker = character_id, follower = 'ENDDIALOG')
					break
				else:
					dialog.add_text( text = crack_lock_comments[ x ], speaker = character_id, follower = crack_lock_comments[ x + 1 ] )
			else:
				dialog.add_text( text = crack_lock_comments[ x ], speaker = character_id, follower = "ENDDIALOG" )
		dialog.start()
		crack_lock_comments = []
	
def is_closed_lock_dummy( building_id, dummy_id ):
	"""Checks if the given dummy is registered as a closed lock dummy
for the given building.

Parameters:
        building_id - Id of the building.
        dummy_id    - Id of the dummy.
"""

	if objects.has_attribute( building_id, "exterior_object_id" ):
		building_id = objects.get_attribute( building_id, "exterior_object_id" )

	# test if object is a buildig
	if objects.has_attribute( building_id, "type" ):
		if objects.get_attribute( building_id, "type" ) == "building":
			# get locked door dummies of the building
			# and check if the given dummy exists in the list
			if objects.has_attribute( building_id, "locked" ):
				locked = objects.get_attribute( building_id, "locked" )
						
				if dummy_id in locked:
					return True
		
	return False

def did_detect_lock_trap( character_id, object_id, dummy_name, x, y, z ):
	"""Called when right-clicked on a lock.

If the char has the talent to detect lock traps or booby traps, then a
glow effect is shown on the lock.

Parameters:
        character_id - Id of the char.
        object_id    - Id of the object to crack.
        dummy        - Id of the dummy for the lock of this object.
        x,y,z        - Coordinates of the dummy.
"""
	lock_data = {}
	lock = None

	if objects.has_attribute( object_id, "exterior_object_id" ):
		object_id = objects.get_attribute( object_id, "exterior_object_id" )

	object_type = objects.get_attribute( object_id, "typeid" )
	if objects.has_attribute( object_type, "lock_data" ):
		lock_data = objects.get_attribute( object_type, "lock_data" )

		# search the lock by the given dummy
		for key in lock_data.keys():
			if dummy_name in lock_data[ key ][ "dummies" ]:
				lock = key
				break
	else:
		return

	if lock == None:
		return
		
	if has_talent( character_id, "lock_pick", "find_lock_traps" ):
		if lock_data[ lock ][ "closure_type" ] in ["lock-trap", "poison-trap"]:
			give_first_use_exp(character_id, "lock_pick", "find_lock_traps")
			system.start_effect_object(object=object_id,
				node=dummy_name,
				parameter=global_defines.fx_lock_trap)
	if has_talent( character_id, "explosives", "detect_booby_traps" ):
		if lock_data[ lock ][ "closure_type" ] == "booby-trap":
			system.start_effect_object(object=object_id,
				node=dummy_name,
				parameter=global_defines.fx_lock_trap)

def equip_and_mark_unequiped( character_id, items, tag ):
	"""This function equips one of the given items, and marks the item that is 
unequipped to equip it again later.

Returns the new equipped item.

Parameters:
        character_id - Id of the char.
        items        - List of items. Char equips the first he owns.
        tag          - A tag that is used to mark the unequipped item.
"""
	# if a item is already equiped than do nothing
	for item in items:
		if character.is_equiped( character_id, item ):
			objects.set_attribute( item, tag, "used" )
			return item

	# search for the item(s) that is/are equiped in the hands
	# of the char. Unequip it and mark it as 'swap'
	for old_item in objects.get_inventory_id_list(character_id):
		if character.is_equiped( character_id, old_item ):
			if objects.has_attribute( old_item, "occupied_slots" ):
				slots = objects.get_attribute( old_item, "occupied_slots" )
				if "right_hand" in slots or "left_hand" in slots:
					objects.set_attribute( old_item, tag, "swap" )
					character.un_equip_direct( character_id, old_item )

	# equip on of the items
	for item in items:
		if objects.count_in_inventory( character_id, item ): # item is in inventory
			# equip the item and mark it as 'used'
			_id = character.equip_direct( character_id, item ) # equip the item
			objects.set_attribute(_id, tag, "used")
			return _id

	return None


def unequip_and_equip_marked( character_id, tag ):
	"""Searches for items that have the given tag, and unequips the ones marked 
with "used", and equips the ones marked with "swap".

Returns the unequipped item.

Parameters:
        character_id - Id of the char.
        tag          - A tag that is used to mark the unequipped item.
"""

	used_item = None

	for item in objects.get_inventory_id_list(character_id):
		# if the slot is not empty and has the attribute tag
		if objects.has_attribute( item, tag ):
			# slot item is used , so put it back in the inventory 
			# and empty the attribute
			if objects.get_attribute( item, tag ) == "used":
				objects.set_attribute( item, tag, None )
				used_item = item
				if character.is_equiped( character_id, item ):
					character.un_equip_direct( character_id, item )
			# slot item was used before, so take it back
			# and empty the attribute
			elif objects.get_attribute( item, tag ) == "swap":
				objects.set_attribute( item, tag, None )
				if not character.is_equiped( character_id, item ):
					character.equip_direct( character_id, item )

	return used_item

def pre_resuscitate( character_id ):
	"""Called before a char tries to resuscitate another char.

The char just unequips every handheld item.

Parameters:
        character_id - Id of the char.
"""
	equip_and_mark_unequiped( character_id, [], "resuscitate_item" )

def post_resuscitate( character_id ):
	"""Called after a char tried to resuscitate another char.

The char equips the item he has equipped before resuscitation.

Parameters:
        character_id - Id of the char.
"""
	unequip_and_equip_marked( character_id, "resuscitate_item" )
	

def calc_perception_values(char, daytime_change = False):
	"""Calcs the perception values for this char.

Both being perceived and perceiving are calculated and set here.

Parameters:
        char           - Id of the Char.
        daytime_change - Marks a Daytime switch.
"""
	# inquire daytime
	daytime = "day"
	d = data("sky")
	if hasattr(d, "daytime"):
		daytime = d.daytime
		
	# has the char binoculars or a night vision device equiped?
	night_vision = 0
	binoculars = 0
	if objects.has_attribute(char, "slots"):
		slots = objects.get_attribute(char, "slots")
		if "vision" in slots and slots["vision"]:
			itemtype = objects.get_attribute(slots["vision"], "typeid") 
			if objects.has_attribute ( itemtype, "night_vision_range" ):
				night_vision = objects.get_attribute ( itemtype, "night_vision_range" ) 	# maximum range for night vision
			elif objects.has_attribute ( itemtype, "day_vision_mult" ):
				binoculars = objects.get_attribute ( itemtype, "day_vision_mult" )
			else: raise Exception, "unknown vision equipment '%s'" % slots["vision"]
	
	weapon = character.get_primary_weapon ( char )
	night_vision_add = night_vision
	binoculars_mult = binoculars
	if objects.has_attribute ( weapon, "night_vision_range" ) and objects.has_attribute ( weapon, "night_vision_range" ) > night_vision:
		night_vision_add = objects.get_attribute ( weapon, "night_vision_range" )			# if weapon has night vision optics
	if objects.has_attribute ( weapon, "day_vision_mult" ) and objects.has_attribute ( weapon, "day_vision_mult" ) > binoculars :
		binoculars_mult = objects.get_attribute ( weapon, "day_vision_mult" )				# if weapon has optics
	
	# get bodymode
	bodymode = "STAND"
	bodymode = character.get_body_mode(char)
	
	# calc range of vision in meter for this char (how far this char can see) 
	if daytime == "night":
		range_of_vision = 25
		base_range_of_vision = 10
	elif daytime == "dusk" or daytime == "dawn":
		range_of_vision = 35 
		base_range_of_vision = 15
	elif daytime == "day":
		range_of_vision = 50 
		base_range_of_vision = 20

	if night_vision and daytime != "day": range_of_vision = night_vision
	if night_vision_add and daytime != "day": base_range_of_vision 	= night_vision_add
	if binoculars and daytime != "night": range_of_vision *= binoculars
	if binoculars_mult and daytime != "night": base_range_of_vision *= binoculars_mult
	
	objects.set_attribute(char, "range_of_vision", range_of_vision)
	objects.set_attribute(char, "base_range_of_vision", base_range_of_vision)
	
	# set max range of hearing for this char (how far this char can hear)
	# nothing is heard farther than this, not even loud weapons
	objects.set_attribute(char, "max_earshot", 100.0)


	# calc influence from camouflage talents
	camouflage_factor = 1.0
	if has_talent(char, "sneak", "camouflage") and bodymode in ["LIE", "KNEEL"]:
		camouflage_factor *= 0.8
	if has_talent(char, "sneak", "night_camouflage"): 
		if daytime == "night":
			camouflage_factor *= 0.7
			if daytime_change:
				system.add_text(globaltext.TALENT_SNEAK_NIGHT_CAMOUFLAGE_ON % {"char": objects.get_attribute(char, "name")})
		elif daytime == "dawn" and daytime_change:
			system.add_text(globaltext.TALENT_SNEAK_NIGHT_CAMOUFLAGE_OFF % {"char": objects.get_attribute(char, "name")})
	for teammate in system.get_pcs():
		if has_talent(teammate, "sneak", "group_camouflage"):
			camouflage_factor *= 0.9
			break

	# calc visibility factor for this char
	# visibility factor is applied to the range_of_vision of everyone trying to perceive this char
	visibility_factor = 1.0
	if bodymode == "LIE":
		if has_talent(char, "sniper_weapons", "camouflage"):
			visibility_factor = 0.2
		else: visibility_factor = 0.6
	if bodymode == "KNEEL": visibility_factor = 0.8
	visibility_factor *= camouflage_factor
	objects.set_attribute(char, "visibility_factor", visibility_factor)

	# calc audibility for this char
	objects.set_attribute(char, "audibility_range_motionless", 0)
	objects.set_attribute(char, "audibility_range_moving", 10) # max. distance how far this char can be heard
	skill = objects.get_attribute(char, "sneak")
	agility = objects.get_attribute(char, "agility")
	if bodymode == "LIE":
		audibility = 0.1
	elif bodymode == "KNEEL":
		audibility = 0.7
	else:
		audibility = 1.0
	audibility *= skill_tables.sneak_detection_factor(skill)
	audibility *= skill_tables.agility_move_silently_factor(agility)
	objects.set_attribute(char, "audibility_chance", audibility) # chance to be heard when inside the audibility_range
	

def on_alert(obj):
	"""Called when the object (char or animal) goes on alert.

Possible reasons for alerts are:
        enemy spotted
        getting attacked/hit/damaged
        an explosion in earshot
        etc.

Parameters:
        obj - Id of the char.
"""
	if global_defines.LOCAL_USER == global_defines.USER_ALEXANDER_MISELER:
		#system.add_text("alert for: %s" % obj)
		pass
		
		
	if objects.has_attribute( obj, "ignore_foes" ):
		ignore_foes = objects.get_attribute( obj, "ignore_foes" )
		
		if ignore_foes == "do_not_ignore":
			pass
		elif ignore_foes == "ignore":
			return 2000
		elif ignore_foes == "ignore_until_idle":
			return 2000
		else:
			raise Exception( "'%s' is not a valid value for the 'ignore foes' attribute\n" % ignore_foes )
	
	pc_is_foe = False
	foes = []
	if objects.has_attribute( obj, "foes" ):
		foes = objects.get_attribute( obj, "foes" )
	pcs = system.get_pcs()
	for pc in pcs:
		if pc in foes or "UISPIELER" in foes:
			pc_is_foe = True
			if not objects.is_fighting(obj):
				objects.cancel_commandos(obj)
			objects.set_attribute(obj, "alerted", True)
			break
	
	if pc_is_foe:
		return random.randint(5000, 10000); # alarm time in ms
	else:		
		return 2000
		#jan allert per default.    return 0
		
def on_alert_expired(obj):
	"""Called when the alert state is over.

Parameters:
        obj - Id of the char.
"""
	if global_defines.LOCAL_USER == global_defines.USER_ALEXANDER_MISELER:
		#system.add_text("alert expired for: %s" % obj)
		pass
	if character.exists(obj) and not objects.is_destroyed(obj) and not (obj in system.get_pcs()):
		character.change_body_mode(obj, "STAND")
	objects.set_attribute(obj, "alerted", False)

def offend(char):
	"""Called when a char offends some NPCs to get their attention.

Parameters:
        character_id - Id of the char.
"""
	number_opponents = 0
	for enemy in system.get_npcs():
		if not objects.is_destroyed(enemy) and objects.is_active(enemy) and objects.has_attribute(enemy, "foes"):
			foes = objects.get_attribute(enemy, "foes")
			if char in foes or objects.get_party(char) in foes:
				if objects.get_distance(char, enemy) < 30:
					objects.cancel_commandos(enemy)
					objects.attack(enemy, char)
					number_opponents += 1

	if number_opponents == 1:
		random_comment(char, "OFFEND_SINGLE_", 3)
	elif number_opponents > 1:
		random_comment(char, "OFFEND_MULTI_", 3)

	give_first_use_exp(char, "speech", "offend")

npc_level_table = {
	# attributes
	"strength":			((1,12),(5,13),(9,14),(13,15),(17,16),(21,17),(21,18),(29,19)),
	"agility":			((1,12),(4,13),(8,14),(12,15),(16,16),(20,17),(24,18),(28,19)),
	"dexterity":		((1,12),(3,13),(8,14),(12,15),(16,16),(19,17),(23,18),(27,19)),
	"constitution": 	((1,12),(2,13),(6,14),(10,15),(14,16),(18,17),(22,18),(26,19)),
	"intelligence": 	((1,10),),
	"charisma":			((1,12),),
	# skills
	"close_combat":		((1,55),(3,60),(6,65),(10,70),(14,75),(19,80),(24,85),(29,90)),
	"light_weapons":	((1,60),(2,65),(3,70),(5,75),(9,80),(13,85),(18,90),(28,99)),
	"heavy_weapons":	((1,60),(2,65),(4,70),(7,75),(12,80),(17,85),(22,90),(27,95)),
	"sniper_weapons":	((1,60),(8,65),(15,70),(20,75),(25,80)),
	"throw_weapons":	((1,60),(4,65),(11,70),(16,75),(21,80),(26,85)),
	"explosives":		((1,55),(13,60),(20,65)),
	"survival":			((1,50),(8,55),(19,60),(28,55)),
	"sneak":			((1,50),(5,55),(14,60),(22,65)),
	"pick_pocket":		((1,50),(10,55),(17,60),(27,65)),
	"lock_pick":		((1,50),(6,55),(16,60),(25,65)),
	"technic":			((1,50),(11,55),(21,60),(29,65)),
	"driving":			((1,50),(9,55),(18,60),(26,65)),
	"speech":			((1,50),(12,55),(23,60)),
	"medicine":			((1,50),(7,55),(15,60),(24,65)),
}

npc_animals_le_table = {
	"WOLF": 			(8,					4),
	"ANTELOPE":			(8,					4),
	"BEAR":				(14,				6),
	"COW":				(6,					3),
	"DEER":				(10,				5),
	"HORSE":			(10,				3),
	"TIGER":			(14,				8),
	"WILDDOG":			(6,					3),
	"BISON":			(12,				6),
	"PIG":				(4,					2),
	"DONKEY":			(6,					3),
	"WARG":				(18,				10),
	"LIZARD_SOMA":		(12,				6),

	"RAT_SKULLS":		(4,					3),
	"DESERT_MONKS":		(5,					4),
	"SHADOWS":			(6,					8),
	"INDIANS":			(4,					4),
	"NOMADS":			(4,					4),
	"GNO_SOLDIERS":		(6,					7),
	"VILLAGE_PEOPLE":	(4,					2),
	"SEEKER":			(4,					5),
}

hp_difficulty_factor_table = {
	0: 0.5,
	1: 0.75,
	2: 1.5,
	3: 3.0,
	4: 6.0,
}

def calc_npc_attribute_skills( object_id , new_value, old_value ):
	"""Helper function for on_attribute_change("level").

Parameters:
        object_id - Id of the object.
        new_value - New value.
        old_value - Old value.
"""
	# attribute/skills
	act_level = new_value
	assert act_level > 0
	for entry in npc_level_table:
		if objects.has_attribute( object_id, entry ):
			value_list = npc_level_table[entry]
			for value in value_list:
				if value[0] < act_level:
					objects.set_attribute( object_id, entry, value[1] )
		else:
			raise ValueError, "attribute/skill not found"

def calc_npc_le( object_id , new_value, old_value ):
	"""Helper function for on_attribute_change("level").

Parameters:
        object_id - Id of the object.
        new_value - New value.
        old_value - Old value.
"""
	# le
	if string.find( object_id, "MERCENARY" ) == 0: #its a merc, dont manipulate
		return
	act_level = new_value
	assert act_level > 0
	_type = None
	max_hp = 10
	if objects.has_attribute(object_id, "typeid"):
		_type=objects.get_attribute(object_id, "typeid")

	if objects.has_attribute(object_id, "faction"):
		_type=objects.get_attribute(object_id, "faction")

	if _type in npc_animals_le_table:
		max_hp = npc_animals_le_table[_type][0]
		max_hp+=(act_level-1)*npc_animals_le_table[_type][1]

	difficulty = options.get_attribute("difficulty")
	if difficulty in hp_difficulty_factor_table:
		max_hp*=hp_difficulty_factor_table[difficulty]
	else:
		raise ValueError, "difficulty level not found"
	if max_hp==0: max_hp=1
	objects.set_attribute(object_id,"maxhitpoints",max_hp)
	objects.set_attribute(object_id,"hitpoints",max_hp)

def check_lay_down_area( character_id, carried_char ):
	"""Checks if the char can lay down the carried char where he stands.

Parameters:
        character_id - Id of the char.
        carried_char - Id of the char that is carried.
"""
	x = objects.get_x( character_id )
	y = objects.get_y( character_id )

	# check if area is empty
	_objects = system.get_objects( type = None, left = x - 1.5, top = y - 1.5, right = x + 1.5, bottom = y + 1.5 )
	# filter out everything that is in front of the carrying char
	_objects = filter(lambda obj: is_in_front( obj, character_id ), _objects)
	# filter out the carrying char and the carried char.
	_objects = filter(lambda obj: obj != character_id and obj != carried_char, _objects)

	if len(_objects):
		if objects.has_attribute( carried_char, "gender" ):
			gender = objects.get_attribute( carried_char, "gender" )
			if gender == "female":
				random_comment( character_id, "CARRY_LAY_DOWN_FAILED_FEMALE_", 3 )
			else:
				random_comment( character_id, "CARRY_LAY_DOWN_FAILED_MALE_", 3 )
		return False

	return True

def vehicle_explosion_callback(id, type, triggertime):
	"""Helper function for vehicle_explosion.
"""
	objects.set_attribute( id , "end_explosion_chassis", True)
	objects.set_attribute( id , "end_explosion_wheels", True)

def vehicle_explosion( vehicle ):
	"""Called by on_object_killed when a vehicle is destroyed
	
Handles the graphic & sound effects for vehicle destruction.

Parameters:
        vehicle - Id of the vehicle.
"""
	if objects.has_attribute(vehicle, "typeid"):
		typeid = objects.get_attribute(vehicle, "typeid")
		
		if (typeid=="SET_PICKUP2" or
			typeid=="SET_PICKUP"):
			objects.set_attribute( vehicle , "destroy_model", True)

			sounds.play_3d_sound_object("pickup_explosion", vehicle) 

			system.start_effect_object(object=vehicle,
				node="main_explosion_1",
				parameter=global_defines.fx_explosion_big)

			system.start_effect_object(object=vehicle,
				node="side_explosion_1",
				parameter=global_defines.fx_explosion_big)

			objects.play_animation(vehicle,"PICKUP_ZERSTOERN",
				["ONTIME",vehicle_explosion_callback,2000])

			objects.fade_node( vehicle, "shockwave", 500)	
			objects.fade_node( vehicle, "wheel_steer_r", 2500)
			objects.fade_node( vehicle, "wheel_steer_l", 2500)
			objects.fade_node( vehicle, "wheel_axle_r", 2500)
			objects.fade_node( vehicle, "wheel_axle_l", 2500)
			objects.fade_node( vehicle, "parts_1", 2500)
			objects.fade_node( vehicle, "parts_2", 2500)

		if (typeid=="SET_HUMVEE"):
			objects.set_attribute( vehicle , "destroy_model", True)
			sounds.play_3d_sound_object("humvee_explosion", vehicle) 
			
			system.start_effect_object(object=vehicle,
				node="main_explosion_1",
				parameter=global_defines.fx_explosion_big)

			system.start_effect_object(object=vehicle,
				node="side_explosion_1",
				parameter=global_defines.fx_explosion_big)

			objects.play_animation(vehicle,"HUMVEE_ZERSTOEREN",
				["ONTIME",vehicle_explosion_callback,2000])

			objects.fade_node( vehicle, "shockwave", 500)	
			objects.fade_node( vehicle, "wheel_steer_r", 2500)
			objects.fade_node( vehicle, "wheel_steer_l", 2500)
			objects.fade_node( vehicle, "wheel_axle_r", 2500)
			objects.fade_node( vehicle, "wheel_axle_l", 2500)
			objects.fade_node( vehicle, "parts_1", 2500)
			objects.fade_node( vehicle, "doors", 2000)
			

		if (typeid=="SET_WHEELTANK"):
			objects.set_attribute( vehicle , "destroy_model", True)
			sounds.play_3d_sound_object("tank_explosion", vehicle) 
			
			system.start_effect_object(object=vehicle,
				node="rest",
				parameter=global_defines.fx_explosion_big)

			objects.play_animation(vehicle,"WHEELTANK_ZERSTOEREN",
				["ONTIME",vehicle_explosion_callback,2000])

			objects.fade_node( vehicle, "shockwave", 500)	
			objects.fade_node( vehicle, "wheel_steer_r", 2500)
			objects.fade_node( vehicle, "wheel_steer_l", 2500)
			objects.fade_node( vehicle, "wheel_axle_r", 2500)
			objects.fade_node( vehicle, "wheel_axle_l", 2500)

		if (typeid=="SET_BUGGY"):
			objects.set_attribute( vehicle , "destroy_model", True)
			sounds.play_3d_sound_object("buggy_explosion", vehicle) 
			
			system.start_effect_object(object=vehicle,
				node="main_explosion_1",
				parameter=global_defines.fx_explosion_big)

			system.start_effect_object(object=vehicle,
				node="side_explosion_1",
				parameter=global_defines.fx_explosion_big)

			objects.play_animation(vehicle,"BUGGY_ZERSTOEREN",
				["ONTIME",vehicle_explosion_callback,2000])

			objects.fade_node( vehicle, "shockwave", 500)	
			objects.fade_node( vehicle, "wheel_steer_r", 2500)
			objects.fade_node( vehicle, "wheel_steer_l", 2500)
			objects.fade_node( vehicle, "wheel_axle_r", 2500)
			objects.fade_node( vehicle, "wheel_axle_l", 2500)
			objects.fade_node( vehicle, "parts_1", 2500)
			objects.fade_node( vehicle, "parts_2", 2500)

def on_entered_vehicle(char, vehicle, seat):
	if seat == 0: give_first_use_exp(char, "drive_vehicle")

def on_vehicle_seat_state_change( vehicle_id ):
	"""Called whenever the number of chars in the vehicle changes.

Parameters:
        vehicle_id - Id of the vehicle.
"""
	# print "on_vehicle_seat_state_change"
	print vehicle_id
	print vehicle.get_crew( vehicle_id )
	driver = vehicle.get_char_from_seat( vehicle_id, 0 )
	print driver
	if not hasattr( data("vehicle"), "last_crewmember" ):
			data("vehicle").last_crewmember = {}
	else:
		if len(vehicle.get_crew( vehicle_id ))==0:
			data("vehicle").last_crewmember[vehicle_id]=[]
	
	can_drive = False
	typeid = None
	speedfactor = 0.6
	fuel_consumption_factor_type = 0.0
	fuel_consumption_factor_obj = 0.0

	if objects.has_attribute(vehicle_id, "typeid"):
		typeid = objects.get_attribute(vehicle_id, "typeid")
		fuel_consumption_factor_type = objects.get_attribute( typeid, "fuel_consumption_factor")
		#print objects.get_attribute( typeid, "max_speed") 

	if driver!=None:
		if driver in system.get_pcs():
			data("ALTER_EGO").Last_Vehicle = vehicle_id 
			
			if objects.has_attribute( driver, "driving"):
				skill = objects.get_attribute( driver, "driving")
				
				if skill > 54:
					can_drive = True
					fuel_consumption_factor_obj = fuel_consumption_factor_type 	
				if skill > 69:
					speedfactor = 0.8
					fuel_consumption_factor_obj = fuel_consumption_factor_type * 0.9
				if skill > 84:
					speedfactor = 0.9
					fuel_consumption_factor_obj = fuel_consumption_factor_type * 0.8
				if skill > 94:
					speedfactor = 1.0
					fuel_consumption_factor_obj = fuel_consumption_factor_type * 0.7
				if skill > 104:
					speedfactor = 1.0
					fuel_consumption_factor_obj = fuel_consumption_factor_type * 0.6
				if skill > 114:
					speedfactor = 1.0
					fuel_consumption_factor_obj = fuel_consumption_factor_type * 0.55
				if skill > 124:
					speedfactor = 1.0
					fuel_consumption_factor_obj = fuel_consumption_factor_type * 0.5
				if skill > 134:
					speedfactor = 1.0
					fuel_consumption_factor_obj = fuel_consumption_factor_type * 0.47
				if skill > 149:
					speedfactor = 1.0
					fuel_consumption_factor_obj = fuel_consumption_factor_type * 0.45

				if has_talent( driver, "driving", "economic_driving"):
					fuel_consumption_factor_obj = fuel_consumption_factor_obj * 0.8
					
				objects.set_attribute( vehicle_id, "speed_factor", speedfactor)
				objects.set_attribute( vehicle_id, "fuel_consumption_factor", fuel_consumption_factor_obj)
			
			if has_talent( driver, "driving", "driving_tricks"):
				objects.set_attribute( vehicle_id, "alternative_physic_mode", True)
			else:
				objects.set_attribute( vehicle_id, "alternative_physic_mode", False)
				
			if not can_drive and len(vehicle.get_crew( vehicle_id ))==1:
				if not data("vehicle").last_crewmember.has_key(vehicle_id):
					if vehicle.get_char_from_seat(vehicle_id,0)==driver :
						if objects.get_attribute(driver,"gender") == "female":
							system.add_text(globaltext.DRIVER_CANT_DRIVE_F % {"char": objects.get_attribute(driver, "name") })
						else:
							system.add_text(globaltext.DRIVER_CANT_DRIVE_M % {"char": objects.get_attribute(driver, "name") })
				else:
					if not data("vehicle").last_crewmember[vehicle_id] == vehicle.get_crew( vehicle_id ) and not len(vehicle.get_crew( vehicle_id )) < len(data("vehicle").last_crewmember[vehicle_id]) :
						if objects.get_attribute(driver,"gender") == "female":
							system.add_text(globaltext.DRIVER_CANT_DRIVE_F % {"char": objects.get_attribute(driver, "name") })
						else:
							system.add_text(globaltext.DRIVER_CANT_DRIVE_M % {"char": objects.get_attribute(driver, "name") })
		else:
			can_drive = True

	objects.set_attribute( vehicle_id, "human_player_can_drive", can_drive)
	data("vehicle").last_crewmember[vehicle_id] = vehicle.get_crew( vehicle_id )	

def can_enter_building( character_id, building_id ):
	"""Called if the user clicks to enter a building. 

Returns True if that is allowed, or False if not. E.g., you should return False 
if the building is locked. That accompanied with a comment for the user.

Parameters:
        character_id - Id of the char.
        building_id  - Id of the entered building.
"""
	return True


def on_hit( object_id ):
	"""Called when the object gets damaged.

Parameters:
        object_id - Id of the damaged object.
"""
	pass

def can_carry( character_id, object_id ):
	"""Called to test if the character can carry the object.

Parameters:
        character_id - Id of the char to carry the object.
        object_id    - Id of the object to be carried.
"""
	#Tragen von toten Kindern verhindern
	if objects.has_attribute(object_id, "model"):
		model = objects.get_attribute(object_id, "model")
		if model == "child":
			return False
	return True

def post_climb( character_id ):
	"""Called after the char has climbed over something.

Parameters:
        character_id - Id of the char.
"""
	pass

def on_change_body_mode( object_id, new_value, old_value ):
	"""Called when an object changes its body mode.

Parameters:
        object_id - Id of the char.
        new_value - Id of the new bodymode.
        old_value - Id of the actual bodymode.
"""
	pass

def unequip_hands( char_id, direct_unequip = True ):
	"""Makes char unequip all equipped items and weapons.

Parameters:
       char_id        - Id of the Char.
       direct_unequip - True unequips without playing animations.
"""
	character.unequip_hands( char_id, direct_unequip )

def get_combat_value(weapon):
	"""Calculates a value that expresses the power of the given weapon.

This is used to find out who is the strongest enemy.

Parameters:
        weapon - Id of the weapon.
"""
	value = 0.0
	try:
		value = objects.get_attribute(weapon.replace("_W_SILENCER", ""), "value")
	except:
		value = objects.get_attribute(weapon, "value")
	return value
	
		
def call(function, *args, **keywords):
	"""Call overrideable object_events function.

If a function with the same name exists in the zone script, then this function is called. Otherwise
the function in object_events is called."""
	mod = system.get_act_mission()
	if mod and hasattr(mod, function) and callable(mod.__dict__[function]):
		f = mod.__dict__[function]
		return f(*args, **keywords)
	else:
		import sys
		mod = sys.modules["object_events"]
		f = mod.__dict__[function]
		return f(*args, **keywords)

	

def on_ui_player_spotted(spotter):
	"""Called when an NPC sees/hears a PC.

This is only called for the first PC spotted. It will not be called again unless
on_ui_player_out_of_view has been called for this spotter.

Parameters:
        spotter - Id of the char noticing the PC.
"""
	pass

def on_ui_player_out_of_view(spotter):
	"""Called when an NPC no longer perceives PCs.

This is called when the last PC moves out of perception.

Parameters:
        spotter - Id of the char noticing the PC.
"""
	pass
	
def get_speech_skill(char):
	"""Returns the charisma-influenced speech skill for this char.

Should be used by dialogs to choose different dialog paths according to the 
speech skill.

Parameters:
        char - Id of the char (should be AE).
"""
	skill = objects.get_attribute(char, "speech")
	factor = skill_tables.charisma_talk_bonus_factor(objects.get_attribute(char, "charisma"))
	return int(skill*factor)

def trader_filter( item_list, filter ):
	"""Filters the item_list for the trader panel.

Filter is one of "all", "weapons", "ammo", "armor", "le_recovery".

Returns the filtered list.

Parameters:
        itme_list - List of Items to filter.
        filter    - Sets the filter type.
"""
	if filter=="all":
		return item_list
	filter_result = []
	if filter=="weapons":
		for item in item_list:
			if objects.has_attribute(item, "item_type"):
				if objects.get_attribute(item, "item_type")=="weapon":
					filter_result.append(item)
	elif filter=="ammo":
		for item in item_list:
			if objects.has_attribute(item, "item_type"):
				if objects.get_attribute(item, "item_type")=="ammo":
					filter_result.append(item)
	elif filter=="armor":
		for item in item_list:
			if objects.has_attribute(item, "armor"):
				filter_result.append(item)
	elif filter=="le_recovery":
		for item in item_list:
			if objects.has_attribute(item, "le_recovery"):
				filter_result.append(item)
	return filter_result

def helper_calc_item_value(id):
	"""Helper function for calc_trader_values.

Parameters:
        id - Id of the item.
"""
	value = 1.0 
	if objects.has_attribute(id, "value"):
		value = objects.get_attribute(id, "value")

	if objects.get_attribute(id, "type")=="equipment":
		if objects.has_attribute(id, "item_type"):
			#ammo pack
			if objects.get_attribute(id, "item_type")=="ammo":
				percent = 0.0 
				percent = float(objects.get_attribute(id, "act_ammo_count")) / float(objects.get_attribute(id, "schuss"))
				return int(value * percent)
			elif objects.get_attribute(id, "item_type")=="weapon":
				weapon_type = objects.get_attribute(id,"weapon_type")

				#weapon quality
				if objects.has_attribute(id, "quality"):
					quality = objects.get_attribute(id, "quality")
					new_value = 0
					if quality >= 50:
						percent = (float(quality) - 50.0) / 50.0
						new_value = int(value * (percent**2))
					if new_value < int(value * 0.2):
						value = int(value * 0.2)
					else:
						value = new_value

				#loaded ammo
				if (weapon_type!="nahkampf" and
					weapon_type!="wurf"):
					ammo_count = objects.get_attribute(id, "act_ammo_count")
					if ammo_count > 0:
						ammo_type = objects.get_attribute(id, "act_ammo_type")
						if ammo_type!=None:
							percent = 0.0 
							percent = float(ammo_count) / float(objects.get_attribute(ammo_type, "schuss"))
							ammo_value = objects.get_attribute(ammo_type, "value")
							value+=int(ammo_value * percent)
				return value

		#water
		if objects.has_attribute(id, "water_repository"):
			if objects.has_attribute(id, "charge"):
				typeid = objects.get_attribute(id, "typeid")
				charge = objects.get_attribute(id, "charge")
				charge_type = objects.get_attribute(typeid, "charge")
				return int(value - (value * 0.75) * (1-float(charge)/float(charge_type)))

		#medi pack
		if objects.has_attribute(id, "le_recovery"):
			if objects.has_attribute(id, "charge"):
				typeid = objects.get_attribute(id, "typeid")
				charge = objects.get_attribute(id, "charge")
				charge_type = objects.get_attribute(typeid, "charge")
				return int(value * float(charge) / float(charge_type))

		#gas
		if objects.has_attribute(id, "fuel"):
			typeid = objects.get_attribute(id, "typeid")
			fuel = objects.get_attribute(id, "fuel")
			fuel_type = objects.get_attribute(typeid, "fuel")
			return int(value - (value * 0.75) * (1-float(fuel)/float(fuel_type)))

	return value

def calc_trader_values(items):
	"""Calcs the trader value for the selected items.

Parameters:
        items - List of items.
"""
	for _id in items:
		value = helper_calc_item_value(_id)
		if value < 1.0: value = 1.0
		objects.set_attribute(_id, "temp_value",value)

def get_trade_result(trader, negotiator, trader_value, pc_value):
	"""Calculates the trade result (i.e., trader profit/trader satisfaction).

Parameters:
        trader       - Id of the trader.
        negotiator   - Id of PC bartering.
        trader_value - Value of selected trader's items.
        pc_value     - Value of selected PC's items
"""
	skill = get_speech_skill(negotiator)
	bonus_malus = skill_tables.speech_trader_value(skill)

	if has_talent(negotiator, "speech", "trade"):
		bonus_malus-=0.2

	if objects.has_attribute(trader, "last_trade_bonus_malus"):
		last_trade_bonus_malus = objects.get_attribute(trader, "last_trade_bonus_malus")
		if last_trade_bonus_malus.has_key(negotiator):
			bonus_malus-=last_trade_bonus_malus[negotiator]

	trader_value = trader_value + trader_value * bonus_malus
	profit = ((pc_value / trader_value) * 100.0) - 100.0
	profit_table = [60,40,20,0]

	value = 5
	for i in range(len(profit_table)):
		if profit >= profit_table[i]:
			value = i+1
			break
	return value

def helper_get_equivalent_items_list(all_items_list, item ):
	"""Helper function for on_update_trader.
"""
	value = objects.get_attribute( item, "value" )
	items_list = all_items_list[:]
	item_type = None
	if objects.has_attribute(item, "item_type"):
		item_type = objects.get_attribute( item, "item_type" )

	if item_type!=None:
		result = filter(lambda act_item:
			(objects.has_attribute(act_item, "item_type") and
			objects.get_attribute(act_item, "item_type")==item_type), items_list)

	if objects.has_attribute(item, "le_recovery"):
		result = filter(lambda act_item:
			objects.has_attribute(act_item, "le_recovery"), items_list)

	if objects.has_attribute(item, "armor"):
		armor = objects.get_attribute(item, "armor")
		result = filter(lambda act_item:
			(objects.has_attribute(act_item, "armor") and
			objects.get_attribute(act_item, "armor")>(armor*0.8) and
			objects.get_attribute(act_item, "armor")<(armor*1.2)), items_list)

	result = filter(lambda act_item:
		(objects.has_attribute(act_item, "value") and
		(objects.get_attribute(act_item, "value")>(value*0.8) and
		objects.get_attribute(act_item, "value")<(value*1.2)) and
		objects.get_att(act_item, "pseudo_weapon") == None), items_list)

	return result

def update_time_limit ():
	difficulty_to_time = {
		0:	"42:0:0",
		1:	"48:0:0",
		2:	"54:0:0",
		3:	"60:0:0",
		4:	"66:0:0"
	}
	difficulty = options.get_attribute("difficulty")
	if difficulty in difficulty_to_time:
		return difficulty_to_time[difficulty]
	return "60:0:0"
	
def on_update_trader( character_id ):
	"""Called when the trading panel opens.

Parameters:
        character_id - Id of the trader.
"""
	if not hasattr ( data(), "number_of_trade" ): data().number_of_trade = 0
	data().number_of_trade += 1 # This value store number of trade opened, so we could check new items

	if objects.has_attribute( character_id, "last_trade_update" ):
		last_trade_time = objects.get_attribute(character_id, "last_trade_update") # Derff's hack for reguar trade update
		act_time = system.get_mission_time()
		elapsed_time = act_time - last_trade_time
		if elapsed_time >= timerepr.time(update_time_limit ()):
			objects.set_attribute( character_id, "last_trade_update", system.get_mission_time() ) # Derff's hack for reguar trade update
			if objects.has_attribute( character_id, "backup_inventory" ):
				act_inventory = objects.get_inventory_list( character_id )
				backup_inventory = objects.get_attribute( character_id, "backup_inventory")
				missing_objects = backup_inventory[:]
				for _id in act_inventory:
					if _id in missing_objects:
						missing_objects.remove(_id)
				if len(missing_objects):
					print missing_objects
					all_items_list = system.get_item_list()
					all_items_list = filter(lambda act_item:
						(objects.has_attribute(act_item, "item_type") or
						objects.has_attribute(act_item, "le_recovery") or
						objects.has_attribute(act_item, "armor")), all_items_list)
					all_items_list = filter(lambda act_item:
						((objects.has_attribute(act_item, "not_tradable") and
						not objects.get_attribute(act_item, "not_tradable")) or
						not objects.has_attribute(act_item, "not_tradable")), all_items_list)

					for item in missing_objects:
						_list = helper_get_equivalent_items_list( all_items_list, item )
						if len(_list) :
							new_item = random.choice(_list)
							new_id = objects.create_item_in_inventory(object=character_id, 
								equipment=new_item)
							objects.set_attribute ( new_id, "trader_new_item", data().number_of_trade )
							backup_inventory.remove(item)
							backup_inventory.append(new_item)
	else:
		inventory_list = objects.get_inventory_list( character_id )
		objects.set_attribute( character_id, "backup_inventory", inventory_list)
		objects.set_attribute( character_id, "last_trade_update", system.get_mission_time() ) # Derff's hack for reguar trade update

def on_exit_trader( trader_id, negotiator_id, profit ):
	"""Called when the trading panel is closed.

Parameters:
        trader_id     - Id of the trader.
        negotiator_id - Id of the customer.
        profit        - Profit in percent (can be negative).
"""
	if not hasattr ( data(), "number_of_trade" ): data().number_of_trade = 1
	data().number_of_trade += 1 # This value store number of trade open/closed, so we could check newest trader items
	pass

def on_close_bargain(trader, negotiator, result):
	"""Called when a trade is finished."""
	#save last trade time
	objects.set_attribute( trader, "last_trade", system.get_mission_time() )

	#save bonus/malus
	bonus_malus = {}

	if objects.has_attribute(trader, "last_trade_bonus_malus"):
		bonus_malus = objects.get_attribute( trader, "last_trade_bonus_malus")

	value = 0

	if result==1: value = 0.1
	elif result==2:	value = 0.05
	elif result==4:	value = -0.05
	if value>0:
		bonus_malus[negotiator] = value
		objects.set_attribute( trader, "last_trade_bonus_malus", bonus_malus)
	else:
		if bonus_malus.has_key(negotiator):
			del bonus_malus[negotiator]
			objects.set_attribute( trader, "last_trade_bonus_malus", bonus_malus)

def degree_to_radian(degree):
	"""Our degrees are clockwise with 0 degree being north. This converts it to
radians for the unit circle.

Parameters:
        degree - Value.
"""
	r = math.radians(degree)
	r -= 0.5*math.pi # turn it 90° to fit the start point of the unit circle
	r *= -1 # turn clockwise to counterclockwise
	# rotate til it is within 0 <= r < 2*pi
	while r >= 2*math.pi: r -= 2*math.pi
	while r < 0: r += 2*math.pi
	return r
	
def radian_to_degree(radian):
	"""Our degrees are clockwise with 0 degree being north. This converts radians
to our degree."""
	d = radian * -1 # turn counterclockwise to clockwise
	d += 0.5*math.pi # turn it 90° to fit the start point of the unit circle
	d = math.degrees(d)
	# rotate til it is within 0 <= d < 360°
	while d >= 360: d -= 360
	while d < 0: d += 360
	return d
	
def get_dir(x1, y1, x2, y2):
	"""Calcs direction/angle from point x1,y1 to x2,y2.

Parameters:
        x1,y1,x2,y2 - Coordinates.
"""
	source_x = x1
	source_y = y1
	target_x = x2
	target_y = y2
	xdiff = target_x - source_x
	ydiff = target_y - source_y
	radius = math.sqrt(xdiff**2 + ydiff**2)
	if radius==0: return 0 # both chars are at the same position
	if xdiff>=0:
		angle = math.pi + math.acos(ydiff/radius)
	else:
		angle = math.pi - math.acos(ydiff/radius)
	angle *= -1
	while angle < 0: angle += 2*math.pi
	while angle > math.pi*2: angle -= 2*math.pi
	return math.degrees(angle)
	
def calc_rotated_pos(center_x, center_y, start_pos_x, start_pos_y, rotate_by, new_radius=None):
	"""Rotates a point around a center point.

Parameters:
        center_x, center_y       - Central point.
        start_pos_x, start_pos_y - Point that will be rotated.
        rotate_by                - Angle in degree.
        new_radius               - Distance from the rotated end point to the center.
                                   If new_radius=None the distance between center
                                   and start point is used.

Output:
        [x,y] of the end point.
"""
	if new_radius==None:
		new_radius = math.sqrt((start_pos_y - center_y)**2 + (start_pos_x-center_x)**2)
	
	alpha = get_dir(center_x, center_y, start_pos_x, start_pos_y)
	alpha += rotate_by
	alpha = degree_to_radian(alpha)
	diff_x = math.cos(alpha) * new_radius
	diff_y = math.sin(alpha) * new_radius
	diff_y *= -1	# flip y axis (konvert between sin&cos and our coord system)
	return [center_x + diff_x, center_y + diff_y]

def is_approachable(target):
	"""Returns True if the target can be approached (i.e., can be talked to) by PCs.

Parameters:
        target - Id of the target NPC.
"""
	if objects.is_destroyed(target): return False
	if objects.is_unconscious(target): return False
	if not objects.has_attribute(target, "approachable"): return False
	if not objects.get_attribute(target, "approachable"): return False
	
	if objects.has_attribute(target, 'foes'):
		if 'UISPIELER' in objects.get_attribute(target, 'foes'): return False
		
	return True

def on_control_animal_talent_fired(pc, animal):
	"""Called when a PC used the "control_animal" talent against an animal."""
	controled_animals = []
	if objects.has_attribute(pc, "controled_animals"):
		controled_animals = objects.get_attribute(pc, "controled_animals")
	
	if animal not in controled_animals:
		controled_animals.append(animal)
		objects.set_attribute(pc, "controled_animals", controled_animals)
		
		last_msg_time = None
		if objects.has_attribute(pc, "last_control_animals_msg_time"):
			last_msg_time = objects.get_attribute(pc, "last_control_animals_msg_time")
			
		if not last_msg_time or last_msg_time < system.get_mission_time() - "0:0:30":
			system.add_text(globaltext.TALENT_SURVIVAL_CONTROL_ANIMALS % {"char": objects.get_attribute(pc, "name")})

			give_first_use_exp(pc, "survival", "control_animals")
			
			objects.set_attribute(pc, "last_control_animals_msg_time", system.get_mission_time())

def get_kill_stats(char):
	"""Returns the kill stats for this char.

Parameters:
        char - Id of the char.
Returns:
        dict with "NPC type/animal type": kills pairs.
        (contains "REPUTATION" as speziall key for the reputation points for this char)
"""
	weapon_type_history={}
	if objects.has_attribute(char, "weapon_type_history"):
		weapon_type_history = objects.get_attribute(char, "weapon_type_history")

	kill_count = [0] * len(kill_type_list)
	for weapon_type in weapon_type_history:
		kill_count = map(lambda a,b: a+b, kill_count, weapon_type_history[weapon_type])
		#print kill_count
		assert len(kill_type_list)==len(kill_count), "added new kill_type without converting savegames?"

	rep = 0
	kill_table = {}
	for i in range(len(kill_count)):
		kill_table[kill_type_list[i]] = kill_count[i]
		rep += kill_count[i] * kill_points[kill_type_list[i]]
		#print kill_count[i], kill_type_list[i], kill_points[kill_type_list[i]], rep
	kill_table["REPUTATION"] = rep
	
	return kill_table

def set_reputation_bonus(char):
	"""Sets the reputation bonus for this char."""
	kill_stats = get_kill_stats(char)
	rep = kill_stats["REPUTATION"]
	rep_bonus = skill_tables.get_reputation_bonus_per_killpoints(rep)
	rep_desc = skill_tables.get_reputation_description(rep)
	if rep_bonus != 0:
		property_table = dict(zip(skill_tables.skills, [rep_bonus]*len(skill_tables.skills))) # python mojo! :D
		bonus.add_temp_bonuses(char, property_table, "reputation", remove_on_leave=True)
	else:
		bonus.remove_temp_bonus(char, "reputation")
	
	if not hasattr(data("generic"), "rep_desc")\
	or not data("generic").rep_desc\
	or not type(data("generic").rep_desc)==dict:
		data("generic").rep_desc = {}
	if char not in data("generic").rep_desc:
		data("generic").rep_desc[char] = rep_desc
	if rep_desc != data("generic").rep_desc[char]:
		chars = kill_type_list[:9]
		animals = kill_type_list[9:]
		char_kills=0
		animals_kills=0
		for char_type in chars:
			char_kills += kill_stats[char_type]
		for animal_type in animals:
			animals_kills += kill_stats[animal_type]

		text = globaltext.MESSAGE_REPUTATION_CHANGE
		text %=	{	"char": objects.get_attribute(char, "name"),
					"value1": data("generic").rep_desc[char],
					"value2": rep_desc,
					"enemies": char_kills,
					"animals": animals_kills
				}
		system.add_text(text)
		data("generic").rep_desc[char] = rep_desc

def can_mine_trigger(mine, triggering_object):
	return not system.is_cutscene()

# Derff's try use to backpack's
import helpfile

def backpack_transfer(character_id, item_id, side):
	if not character_id in system.get_pcs():
		return False
	itemer = helpfile.create_itemer(item_id)
	objects.set_active_state(itemer,1)
	objects.backpack_check(item_id)
	objects.set_attribute(item_id,"backpack_is_opened",True)
	data().open_backpack = item_id # save id of open backpack 
	data().open_backpack_char = character_id # save id of backpack opener
	data().backpack_was_equiped = character.is_equiped(character_id, item_id)
	if data().backpack_was_equiped:
		character.un_equip(character_id, item_id) 
	
	if side: #take from inventory
		system.item_panel(itemer,character_id,callback_filter=backpack_filter,callback_close=backpack_close,callback_cancel=backpack_cancel)
	else:
		system.item_panel( character_id, item_id, callback_close = backpack_return, callback_cancel = backpack_cancel1)
		
	return True

def backpack_info(char, backpack):
	comments.comment( char, "CONTAINER_"+objects.get_att(backpack,"typeid"))

def backpack_filter( taker_id, source_id, item_id, item_type ):
	"""Filters items that cannot be transfered into backpack
"""	
	if objects.has_attribute(item_id,"container"): return False # do not transfer container in container
	if objects.has_attribute(item_id, "generic_item"): return False #quest items
	if character.is_equiped(source_id, item_id): return False #equiped items should not be transfered	
	backpack = data().open_backpack # it's name of backpack
	if not objects.has_attribute(backpack,"max_item_weight"): return True # if backpack has no limit at item weight, than o'k
	if not objects.has_attribute(item_id,"weight"): return True
	if objects.get_attribute(backpack,"max_item_weight") > objects.get_attribute(item_id,"weight"): return True # if max_item_weight > weight, o'k
	return False 

def backpack_close( taker, items ):
	backpack = data().open_backpack
	char = data().open_backpack_char
	if not backpack_allowed(backpack, items): 
		comments.comment( char, "CONTAINER_PUT_ITEMS_FAILED" )
		update_backpack(char,backpack)		
		return False
	for item in items:
		if objects.count_in_inventory(char, item):
			objects.transfer_item(char, item, backpack)
	update_backpack(char,backpack)
	return True

def backpack_cancel(taker):
	"""User abort transfet items to backpack in inventory
"""
	backpack = data().open_backpack
	char = data().open_backpack_char
	update_backpack(char,backpack)
	
def backpack_cancel1(char):
	backpack = data().open_backpack
	update_backpack(char,backpack)

def backpack_return(char, items):
	backpack = data().open_backpack
	update_backpack(char,backpack)
	
def backpack_allowed(backpack, items):
	inventory = objects.get_inventory_list (backpack)
	max_len = objects.get_att(backpack, "max_item_allowed")
	if max_len == None: max_len = 0
	print "lenght check", max_len, "? ", len (Made_Container(inventory + items)) 
	if max_len and len (Made_Container(inventory + items)) > max_len: return False # max_len is present and count of item is greater -- no allowed

	type = objects.get_attribute(backpack,"typeid")	
	weight_bonus = objects.get_att(type,"weight_bonus")
	if weight_bonus == None: weight_bonus = 1
	if objects.has_attribute(backpack,"real_weight"):
		weight = objects.get_attribute(backpack,"real_weight")
	elif not data().backpack_was_equiped:
		weight = objects.get_attribute(backpack,"weight")	
	else:	
		weight = (objects.get_attribute(backpack,"weight") - objects.get_attribute(type,"weight")) / weight_bonus # calculation of real weight	
	for item in items:
		if objects.has_attribute(item, "weight"):
			w = objects.get_attribute(item,"weight")
		else:
			w = 0
		weight += w 

	max_weight = objects.get_att(backpack, "max_weight_allowed")
	if max_weight == None: max_weight = 0
	if max_weight and weight > max_weight: return False
	
	return True
	
def update_backpack(char,backpack):
	"""Update parameters of backpack and character after transfer completion	
"""
	type = objects.get_attribute(backpack,"typeid")
	inventory = objects.get_inventory_id_list (backpack)
	weight = 0
	for item in inventory:
		if objects.has_attribute(item, "weight"):
			weight += objects.Calculate_Weight_With_Charges ( item )
	container = Made_Container( inventory )
		
	objects.set_attribute ( backpack, "container",container )
	objects.set_attribute ( backpack, "container_version",2 )
	objects.set_attribute ( backpack, "inside_weight", weight )	
	if data().backpack_was_equiped:
		character.equip(char, backpack)
	update_speed(char)

	objects.set_attribute(backpack,"backpack_is_opened",False)
	itemer = helpfile.create_itemer(backpack)
	objects.set_active_state (itemer, 0)	
	
def Made_Container(items):
	"""Function to create a container list {[item1, count], [item2, count], ...} from backpack inventory
"""
	inventory = items
	inventory.sort()
	container = []
	allow = []
	for item in inventory:
		if objects.has_attribute(item,"typeid"):
			item_type = objects.get_attribute(item,"typeid")		
		else:
			item_type = item
		if objects.has_attribute(item_type,"stacking"):
			x = objects.get_attribute(item_type,"stacking")
			y = allow.count(item_type) + 1
			if x > y:
				allow.append(item_type)
			else:
				container.append([item_type, x])
				for i in range(x - 1):
					allow.remove (item_type)
		else:
			container.append([item_type, 1])			
	allow.sort()
	temp = ""
	for item_type in allow:
		if temp != item_type:
			y = allow.count(item_type)
			container.append([item_type, y])
			temp = item_type

	return container	
		
def try_to_made_backpack(object_id):
	"""
"""
	typeid = objects.get_att(object_id,"typeid")
	if typeid == None or not objects.has_attribute(typeid,"container"):
		return False
	attributes = ["weight", "container", "max_weight_allowed", "max_item_allowed", "max_item_weight", "examine"]
	for item in attributes:
		if objects.has_attribute(typeid,item):
			objects.set_attribute(object_id,item,objects.get_attribute(typeid,item))
	return True		
		
# Derff's try to backpack's end
# Derff's bonuses
BONUS_1_ARRAY = [
		["SET_LEATHER_CLOTHES", "SET_LEATHER_GLOVES", "SET_LEATHER_CAP", "SET_LEATHER_BOOTS"],
		["SET_BULLET_PROOF_CLOTHES", "SET_PROTECTIVE_GLOVES", "SET_STEEL_HELMET", "SET_STEEL_CLAD_BOOTS"],
		["SET_PLATE_ARMOR", "SET_PLATE_GLOVES", "SET_KEVLAR_HELMET", "SET_STEEL_CLAD_BOOTS"]
		]
BONUS_2_ARRAY = [
		[ "SET_DT21_LIGHT_ARMOR", "SET_DT21_GAUNTLETS", "SET_DT21_STEEL_CLAD_HELMET", "SET_DT21_STEEL_CLAD_BOOTS"]
		]
BONUS_3_ARRAY = [
		["SET_M46_HEAVY_ARMOR",	"SET_M46_GAUNTLETS", "SET_M46_ARMORED_HELMET",	"SET_M46_STEEL_CLAD_BOOTS"]
		]		
BONUS_4_ARRAY = [
		["SET_RAT_FUR_JACKET",	"SET_LEATHER_GLOVES", None, "SET_LOW_SHOES" ]
		]
BONUS_5_ARRAY = [
		["SET_OVERALL", "naked", None, "SET_LOW_SHOES" ]
		]
LEVEL_CLOTHES = [
		["SET_LEATHER_CLOTHES", "SET_LEATHER_GLOVES", "SET_LEATHER_CAP", "SET_LEATHER_BOOTS", "SET_BULLET_CATCH", "SET_ORDINARY_HELMET"],
		["SET_BULLET_PROOF_CLOTHES", "SET_PROTECTIVE_GLOVES", "SET_STEEL_HELMET", "SET_STEEL_CLAD_BOOTS", "SET_CHAIN_MAIL", \
			"SET_PLATE_ARMOR", "SET_PLATE_GLOVES", "SET_KEVLAR_HELMET"],
		BONUS_2_ARRAY[0],
		BONUS_3_ARRAY[0],
		]

		
def DR_armor_bonus_calculator ( object_id ):
	"""
	bonus 1 -- full compecte of items.
		LEATHER_CLOTHES 	LEATHER_GLOVES		LEATHER_CAP		LEATHER_BOOTS  		 4+1+2+2 = 13(+4) +1  
		BULLET_PROOF_CLOTHES	PROTECTIVE_GLOVES	STEEL_HELMET		STEEL_CLAD_BOOTS	 8+2+6+4 = 20(+4) +2
		PLATE_ARMOR		PLATE_GLOVES		KEVLAR_HELMET		STEEL_CLAD_BOOTS	16+4+8+4 = 32(+4) +3
	bonus 2 -- set of DT21 (20 + )
		DT21_LIGHT_ARMOR	DT21_GAUNTLETS		DT21_STEEL_CLAD_HELMET	DT21_STEEL_CLAD_BOOTS	20+6+10+6 = 42(+4) +4, +1 Str
	bonus 3 -- set M46		
		M46_HEAVY_ARMOR		M46_GAUNTLETS		M46_ARMORED_HELMET	M46_STEEL_CLAD_BOOTS	30+8+12+8 = 58(+4) +6, +2 Str, +1 Con
	bonus 4 -- nice clothes
		SET_RAT_FUR_JACKET	LEATHER_GLOVES		None			SET_LOW_SHOES		+1 cha
	bonus 5 -- thieves clothes
		SET_OVERAL		None			None			SET_LOW_SHOES

	clothes levels
	1	INTRO, NORMAL, RATFUR, OVERAL						Low B
	2	LC, BC			LG			LC, OH			L_B
	3	BPC, CM, PA		PG, PlG			SH, KH			SCB
	4	DT21			DT21			DT21			DT21
	5	M46			M46			M46			M46

	bonus 6 -- scapped clothes
		
"""	
	clothes = objects.get_att( object_id, "clothes" )
	clothes_boots = objects.get_att( object_id, "clothes_boots" )
	clothes_gloves = objects.get_att( object_id, "clothes_gloves" )
	helmet = objects.get_att( object_id, "helmet" )
	
	if [ clothes, clothes_gloves, helmet, clothes_boots ] in BONUS_1_ARRAY:
		return {"armor": 1.1}
	
	if [ clothes, clothes_gloves, helmet, clothes_boots ] in BONUS_2_ARRAY: 
		#return { "armor": +1.1 , "strength": 1 }	#
		return { "armor": 1.1 , "strength": 1 }		#[160430][half-integer]
	
	if [ clothes, clothes_gloves, helmet, clothes_boots ] in BONUS_3_ARRAY:
		#return { "armor": +1.1 , "strength": 2 , "constitution": 1 }	#
		return { "armor": 1.1 , "strength": 2 , "constitution": 1 }		#[160430][half-integer]
		
	if [ clothes, clothes_gloves, helmet, clothes_boots ] in BONUS_4_ARRAY:
		return { "charisma": 1 }
		
	if [ clothes, clothes_gloves, helmet, clothes_boots ] in BONUS_5_ARRAY:
		return { "lock_pick": 1.1 , "sneak": 1.1 , "pick_pocket": 1.1}

	levels = []
	for item in [ clothes, clothes_gloves, helmet, clothes_boots ]:
		if item == None or item == "naked":		#
			continue							#[160516][half-integer]
		is_level_1 = True
		for i in range(4):
			if item in LEVEL_CLOTHES[i]:
				if not levels.count(i+1):
					levels.append(i+1)
				is_level_1 = False
		if is_level_1 and not levels.count(1):
			levels.append(1)
	if len(levels) >= 3:
		#return { "armor": -0.95 }	# [BrainRipper]
		return { "armor": 0.95 }	#[160430][half-integer]

def DR_recalculate_bonus ( character_id, object_type, itemtype ):
	if character_id == None or object_type == None:
		return
	bonus.remove_temp_bonus( character_id, object_type )		
	if object_type == "armor_effect":
		properity_table = DR_armor_bonus_calculator ( character_id )
	elif object_type == "implantant":
		properity_table = objects.get_att ( itemtype, "implantant_effect" )
	else:
		properity_table = None
	if properity_table:
		bonus.add_temp_bonuses( character_id, properity_table, object_type ) 
			

# Derff's bonuses end

type_to_hard = {			# Hardness for knowlege by statistic's name.
	"weight": 0,
	"weapon type": 0,
	"damage": 60,
	"dumdum": 75,
	"scope": 60,
	"durchschlag": 80,
	"fire range": 50,
	"salvaenge": 85,
	"fire speed": 80,
	"accuracy": 85,
	"shot idle time": 95,
	"earshot": 99,
	"accustom": 0,
	"hit chance factor": 95,
	"fire range factor": 99,
	"fire modes": 40,
	"weapon ammo": 70,
	"armor": 50,
	"armor bonus": 50,
	"binoculars": 55,
	"silencer": 60,
	"laserpointer": 65,
	"le_recovery": 60,
	"drugs": 70,
	"drugs_time": 80,
	"implants bonus": 99,
	"value": 60,
	"enemy_le": 0,
	"combat_value": 20,
	"hit_chance": 30,
	"enemy_weapon": 0,
	"quality": 70,
	}

type_to_skill = {
	"weight": "survival",
	"weapon type": "weapon",
	"damage": "ammo",
	"dumdum": "ammo",
	"scope": "ammo",
	"durchschlag": "ammo",
	"fire range": "weapon",
	"salvaenge": "weapon",
	"fire speed": "weapon",
	"accuracy": "weapon",
	"shot idle time": "weapon",
	"earshot": "weapon",
	"accustom": "weapon",
	"hit chance factor": "ammo",
	"fire range factor": "ammo",	
	"fire modes": "weapon",
	"weapon ammo": "weapon",
	"armor": "technic",
	"armor bonus": "technic",
	"binoculars": "technic",
	"silencer": "weapon",
	"laserpointer": "weapon",
	"le_recovery": "survival",
	"drugs": "medicine",
	"drugs_time": "medicine",
	"implants bonus": "technic",
	"value": "speech",
	"enemy_le": "medicine",
	"combat_value": "survival",
	"hit_chance": "weapon",
	"enemy_weapon": "weapon",
	"quality": "weapon",
}

def item_hint_collection ( ids ) :
	"""
	Plain case for hint generation, one if for every type for statistics, and with errors.
"""

	def hint_append ( string, value, mode, id, count = -1 ):
		"""
		Cover for result.append, wich check knowlege and could be used in for's operators as increment
	"""
		knowlege = get_party_knowlege ( mode, id )
		hard = type_to_hard[ mode ]
		if knowlege > hard :
			if count > 0 :
				result.append(["", value ])
			else:
				if string[-1] == ":" : tmp_string = string[:-1] + get_error_sign ( knowlege, hard ) 
				else: tmp_string = string 
				result.append([tmp_string, value ])
			count += 1	
		return count 

	id = ids[0]
	pc_inventory = ""
	for pc in system.get_pcs():
		inventory = objects.get_inventory_id_list(pc)
		if len(inventory):
			for item in inventory:
				if len(item[0]) and id == item :
					pc_inventory = pc
	type_id = objects.get_att (id, "typeid")
	item_type = objects.get_att (id, "item_type")
	weapon_type = objects.get_att (id, "weapon_type")
	munition = ""
		
	result = []
	# type of item
	if objects.has_attribute ( id, "name" ) :
		# newest items for trader
		if hasattr ( data(), "number_of_trade" ) and objects.has_attribute ( id, "trader_new_item" ) and \
			objects.get_attribute ( id, "trader_new_item" ) == data().number_of_trade:
			newest_flag = globaltext.MISSION_EXTENDED_HINT_NEW_TRADER_ITEM
		else: 	newest_flag = ""
		result.append([globaltext.MISSION_EXTENDED_HINT_WEAPON_TYPE_NAME,objects.get_attribute(id, "name") + newest_flag ])
		
	# nickname for weapon
	if item_type == "weapon" : 
		nickname = globaltext.MISSION_EXTENDED_HINT_WEAPON_NICK_NAME_VALUE_NONE	
		if objects.has_attribute(id, "nickname"):
			nickname = objects.get_attribute(id, "nickname")
		result.append([globaltext.MISSION_EXTENDED_HINT_WEAPON_NICK_NAME,nickname])

	# weight
	if objects.has_attribute(id, "weight"):
		value = get_error ( "weight", "weight", id )
		weight = "%.2f "% value + globaltext.MISSION_EXTENDED_HINT_KG
		result.append ( [ globaltext.MISSION_EXTENDED_HINT_WEAPON_WEIGHT, weight ] )
	
	# weapon type
	if item_type == "weapon" and weapon_type  :
		if (weapon_type=="explosiv"):
			value = globaltext.MISSION_EXTENDED_HINT_WEAPON_TYPE_NAME_1 
		if (weapon_type=="wurf"):
			value = globaltext.MISSION_EXTENDED_HINT_WEAPON_TYPE_NAME_2 
		if (weapon_type=="nahkampf"):
			value = globaltext.MISSION_EXTENDED_HINT_WEAPON_TYPE_NAME_3 
		if (weapon_type=="leicht"):
			value = globaltext.MISSION_EXTENDED_HINT_WEAPON_TYPE_NAME_4 
		if (weapon_type=="schwer"):
			value = globaltext.MISSION_EXTENDED_HINT_WEAPON_TYPE_NAME_5 
		if (weapon_type=="sniper"):
			value = globaltext.MISSION_EXTENDED_HINT_WEAPON_TYPE_NAME_6 
		hint_append ( globaltext.MISSION_EXTENDED_HINT_WEAPON_TYPE_NAME_0, value, "weapon type", id )

	# HINT_AMMO_COUNT
	if item_type == "weapon" and objects.has_attribute(id,"munitionsarten"):
		stack_size = 0
		bore = ""
		sup_munition = objects.get_attribute(id, "munitionsarten")
		if objects.has_attribute(id,"magazingroesse"):
			stack_size = objects.get_attribute(id, "magazingroesse")
		for mun_type in sup_munition:
			if objects.has_attribute(mun_type,"kaliber"):
				bore = objects.get_attribute(mun_type, "kaliber")
		if bore != "" and stack_size!= 0:
			tmp_data_value = str(stack_size)  + " x " +  bore	
			result.append ( [ globaltext.MISSION_EXTENDED_HINT_WEAPON_STACK_SIZE_BORE, tmp_data_value ] )

	if item_type == "ammo" and objects.has_attribute(id,"act_ammo_count"):
		act_ammo_count = objects.get_attribute(id, "act_ammo_count")
		max_count = objects.get_attribute(id, "schuss")
		result.append([globaltext.MISSION_EXTENDED_HINT_AMMO_COUNT,str(act_ammo_count) + """ / """ +  str(max_count)])	
	
	# damage min/max for weapon and ammo
	if item_type == "weapon" and objects.get_att ( id, "act_ammo_type") \
		and type_id != "SET_THROWING_KNIFE" and type_id !="SET_SHURIKEN" and type_id  !="SET_DART":
		munition = objects.get_att (id, "act_ammo_type")

	if item_type  == "ammo":
		munition = id
	
	if munition and objects.has_attribute(munition,"schaden_organisch_min") and objects.has_attribute(munition,"schaden_organisch_max"):
		damage_min = get_error ( "schaden_organisch_min", "damage", munition ) 
		damage_max = get_error ( "schaden_organisch_max", "damage", munition ) 
		if damage_max < damage_min : damage_max = damage_min  
		hint_append ( globaltext.MISSION_EXTENDED_HINT_DAMAGE, str(damage_min) + """ / """ +  str(damage_max), "damage", munition )
		
	# dumdum_modifiable
	if item_type  == "ammo" and objects.has_attribute(id, "dumdum_modifiable"):
		if objects.get_attribute(id,"dumdum_modifiable"):
			hint_append( globaltext.MISSION_EXTENDED_HINT_AMMO_DUMDUM_MODIFIACTION,globaltext.MISSION_EXTENDED_HINT_AMMO_DUMDUM_MODIFIACTION_0, "dumdum", id )
		else:
			hint_append( globaltext.MISSION_EXTENDED_HINT_AMMO_DUMDUM_MODIFIACTION,globaltext.MISSION_EXTENDED_HINT_AMMO_DUMDUM_MODIFIACTION_1, "dumdum", id )

	# Weapon scope
	if item_type == "ammo" and objects.has_attribute(id, "wirkungsbereich"):
		scope = objects.get_attribute(id, "wirkungsbereich") 
		if scope > 0:
			scope = "%.1f" % get_error ( "wirkungsbereich", "scope", id )
			hint_append ( globaltext.MISSION_EXTENDED_HINT_WEAPON_SCOPE, scope, "scope", id )
		
	#durchschlag
	if item_type =="weapon" and objects.get_att (id, "act_ammo_type") \
		and type_id != "SET_THROWING_KNIFE" and type_id  !="SET_SHURIKEN" and type_id  !="SET_DART":	
		munition = objects.get_att (id, "act_ammo_type")		

	if item_type  == "ammo":
		munition = id

	if munition != "" and objects.has_attribute(munition, "durchschlag"):
		breakdown = get_error ( "durchschlag", "durchschlag", munition )
		hint_append ( globaltext.MISSION_EXTENDED_HINT_WEAPON_BREAKDOWN,str(breakdown), "durchschlag", munition )
	
	# fire range
	if item_type == "weapon" and objects.has_attribute(id,"maximale_feuerreichweite"):
		f_range_id = globaltext.MISSION_EXTENDED_HINT_WEAPON_FIRE_RANGE_0
		f_range=0.0
		f_range =  get_error ( "maximale_feuerreichweite", "fire range", id )
		if (f_range > 17):
			f_range_id = globaltext.MISSION_EXTENDED_HINT_WEAPON_FIRE_RANGE_1
		if (f_range > 33):
			f_range_id = globaltext.MISSION_EXTENDED_HINT_WEAPON_FIRE_RANGE_2
		if (f_range > 49):
			f_range_id = globaltext.MISSION_EXTENDED_HINT_WEAPON_FIRE_RANGE_3
						
		#fire_range_factor= objects.get_attribute(id, "fire_range_factor") 
		fire_range_factor = 1.0
		if pc_inventory != "":
			fire_range_factor= get_weapon_max_fire_range_factor ( pc_inventory, id )
		mod_fire_range = f_range * fire_range_factor
		tmp_value = ""
		if fire_range_factor != 1.0:
			name = globaltext.MISSION_EXTENDED_HINT_WEAPON_FIRE_RANGE.replace(":","")
			tmp_value=f_range_id + " (" + str("%.1f" %f_range) + " / "+str("%.1f" %mod_fire_range)+")" 
		else:	
			name = globaltext.MISSION_EXTENDED_HINT_WEAPON_FIRE_RANGE		
			tmp_value=f_range_id + " (" + str("%.1f" %f_range) + ")" 
		hint_append ( name, tmp_value, "fire range", id )

	f_fusilade = 0
	# salvaenge
	if item_type == "weapon" and objects.has_attribute(id,"salvenlaenge") and weapon_type in [ "leicht" , "schwer", "sniper" ]:
		f_fusilade = "%i" % get_error ( "salvenlaenge", "salvaenge", id )
		hint_append ( globaltext.MISSION_EXTENDED_HINT_WEAPON_FUSILLADE, str(f_fusilade), "salvaenge", id )

	# fire speed
	if item_type == "weapon" and objects.has_attribute(id,"feuergeschwindigkeit") and weapon_type in [ "leicht" , "schwer", "sniper" ]:
		f_velocity = "%.2f" % get_error ( "feuergeschwindigkeit", "fire speed", id )
		if (f_velocity > 0) and not f_fusilade==1:
			hint_append ( globaltext.MISSION_EXTENDED_HINT_WEAPON_FIRE_SPEED,str(f_velocity), "fire speed", id )
		else:
			hint_append ( globaltext.MISSION_EXTENDED_HINT_WEAPON_FIRE_SPEED,"-", "fire speed", id )

	# accuracy
	if item_type == "weapon" and objects.has_attribute(id, "genauigkeit"):
		accuracy_factor =1.0
		if pc_inventory != "":
			accuracy_factor= get_hit_chance_factor(pc_inventory,id,None)
		tmp_value = ""
		accuracy = get_error ( "genauigkeit", "accuracy", id )
		mod_accuracy  = accuracy*accuracy_factor
		if accuracy_factor != 1.0:
			tmp_value = str("%.1f" %accuracy) + " / " + str("%.1f" %mod_accuracy)
			hint_append( globaltext.MISSION_EXTENDED_HINT_WEAPON_ACCURACY.replace(":","")+ " " +globaltext.MISSION_EXTENDED_HINT_WEAPON_BASE_MOD,tmp_value, "accuracy", id )
		else:
			tmp_value = "%.1f" %accuracy
			hint_append( globaltext.MISSION_EXTENDED_HINT_WEAPON_ACCURACY,tmp_value, "accuracy", id )
	
	# schusspausenzeit
	if item_type == "weapon" and objects.has_attribute(id, "schusspausenzeit"):
		shot_idle_time = "%.1f" % get_error ( "schusspausenzeit", "shot idle time", id) 
		if weapon_type in [ "leicht" , "schwer", "sniper" ] :
			hint_append( globaltext.MISSION_EXTENDED_HINT_WEAPON_SHOT_IDLETIME,shot_idle_time, "shot idle time", id )
		else:
			hint_append( globaltext.MISSION_EXTENDED_HINT_WEAPON_DELAY,shot_idle_time, "shot idle time", id )

	# earshot
	if item_type == "weapon" and objects.has_attribute(id, "hoerweite") and (weapon_type!="nahkampf"):
		earshot= "%.1f" % get_error ( "hoerweite", "earshot", id ) 
		hint_append( globaltext.MISSION_EXTENDED_HINT_WEAPON_SHOT_EARSHOT, earshot, "earshot", id )
	
	# weapon_accustom_bonus
	if item_type == "weapon" and objects.get_att (id, "item_type") =="weapon" and pc_inventory != "": 
		text_id_accustom = globaltext.MISSION_EXTENDED_HINT_WEAPON_ACCUSTOM_0
		max_accustom = 20.0
		weapon_accustom = 0.0
		id_kills = 0
		type_kills = 0
		if objects.has_attribute(pc_inventory, "weapon_type_history"):
			weapon_type_history = objects.get_attribute(pc_inventory, "weapon_type_history")
			if type_id in weapon_type_history:
				type_kills = weapon_type_history[type_id]
				type_kills = sum(type_kills)
		if objects.has_attribute(pc_inventory, "weapon_id_history"):
			weapon_id_history = objects.get_attribute(pc_inventory, "weapon_id_history")
			if id in weapon_id_history:
				id_kills = weapon_id_history[id]
				id_kills = sum(id_kills)
		weapon_accustom = skill_tables.weapon_accustoming(id_kills, type_kills)
		accustom_percent =  (weapon_accustom / max_accustom) * 100
		if accustom_percent > 24: 
			text_id_accustom  = globaltext.MISSION_EXTENDED_HINT_WEAPON_ACCUSTOM_1
		if accustom_percent > 49: 
			text_id_accustom  = globaltext.MISSION_EXTENDED_HINT_WEAPON_ACCUSTOM_4
		if accustom_percent > 74: 
			text_id_accustom  = globaltext.MISSION_EXTENDED_HINT_WEAPON_ACCUSTOM_5
		if accustom_percent > 99: 
			text_id_accustom  = globaltext.MISSION_EXTENDED_HINT_WEAPON_ACCUSTOM_6
		hint_append ( globaltext.MISSION_EXTENDED_HINT_WEAPON_ACCUSTOM,text_id_accustom, "accustom", id )
	
	# firing modes
	if item_type == "weapon" and type_id and objects.has_attribute( type_id , "Fire_Modes" ) and get_party_knowlege ( "fire modes", id ) > 30 :
		current_mode = "mode_"+objects.get_att ( type_id, "weapon_mode_current" )
		if current_mode == 'mode_Single' :
			text1 = globaltext.MISSION_EXTENDED_HINT_FIRE_MODE_SINGLE
		elif current_mode == 'mode_Cutoff' :
			text1 = globaltext.MISSION_EXTENDED_HINT_FIRE_MODE_CUTOFF
		elif current_mode == 'mode_Auto' :
			text1 = globaltext.MISSION_EXTENDED_HINT_FIRE_MODE_AUTO
		elif current_mode == 'mode_Undergun' :
			text1 = globaltext.MISSION_EXTENDED_HINT_FIRE_MODE_UNDERGUN
		elif current_mode == 'mode_Throw' :
			text1 = globaltext.MISSION_EXTENDED_HINT_FIRE_MODE_THROW 
		elif current_mode == 'mode_Thrust' :
			text1 = globaltext.MISSION_EXTENDED_HINT_FIRE_MODE_THRUST 
		elif current_mode == 'mode_Baton' :
			text1 = globaltext.MISSION_EXTENDED_HINT_FIRE_MODE_BATON 
		else:
			text1 = ""

		butt_mode = objects.get_att ( type_id, "butt_state" )
		if butt_mode == "ON" :
			text2 = globaltext.MISSION_EXTENDED_HINT_FIRE_MODE_BUTT_ON
		elif butt_mode == "OFF" :
			text2 = globaltext.MISSION_EXTENDED_HINT_FIRE_MODE_BUTT_OFF
		else:
			text2 = ""
							
		result.append([globaltext.MISSION_EXTENDED_HINT_FIRE_MODES_CURRENT, text1+text2])
						
		count = 0
		text=globaltext.MISSION_EXTENDED_HINT_FIRE_MODES
		for mode in Fire_Modes_Char :
			if objects.has_attribute ( type_id , mode ) and mode != current_mode :
				if mode == 'mode_Single' :
					text1 = globaltext.MISSION_EXTENDED_HINT_FIRE_MODE_SINGLE_A % chr ( Fire_Modes_Char[mode] )
				elif mode == 'mode_Cutoff' :
					text1 = globaltext.MISSION_EXTENDED_HINT_FIRE_MODE_CUTOFF_A % chr ( Fire_Modes_Char[mode] ) + \
					str(objects.get_attribute( type_id , "Fire_Modes" )['Cutoff']) + \
					globaltext.MISSION_EXTENDED_HINT_FIRE_MODE_AMMO
				elif mode == 'mode_Auto' :
					text1 = globaltext.MISSION_EXTENDED_HINT_FIRE_MODE_AUTO_A % chr ( Fire_Modes_Char[mode] ) + \
					str(objects.get_attribute( type_id , "Fire_Modes" )['Auto']) + \
					globaltext.MISSION_EXTENDED_HINT_FIRE_MODE_AMMO
				elif mode == 'mode_Butt' :
					text1 = globaltext.MISSION_EXTENDED_HINT_FIRE_MODE_BUTT_A % chr ( Fire_Modes_Char[mode] )
				elif mode == 'mode_Undergun' :
					text1 = globaltext.MISSION_EXTENDED_HINT_FIRE_MODE_UNDERGUN_A % chr ( Fire_Modes_Char[mode] )
				elif mode == 'mode_Throw' :
					text1 = globaltext.MISSION_EXTENDED_HINT_FIRE_MODE_THROW_A % chr ( Fire_Modes_Char[mode] )
				elif mode == 'mode_Thrust' :
					text1 = globaltext.MISSION_EXTENDED_HINT_FIRE_MODE_THRUST_A % chr ( Fire_Modes_Char[mode] )
				elif mode == 'mode_Baton' :
					text1 = globaltext.MISSION_EXTENDED_HINT_FIRE_MODE_BATON_A % chr ( Fire_Modes_Char[mode] )
			
				count = hint_append( text, text1, "fire modes", id, count)


	# hit chance factor
	if item_type == "ammo" and objects.has_attribute(id, "hit_chance_factor") and objects.get_attribute(id, "hit_chance_factor") != 1.0 :
		hit_chance_factor= "%.1f" % get_error ( "hit_chance_factor", "hit chance factor", id ) 
		hint_append( globaltext.MISSION_EXTENDED_HINT_WEAPON_HIT_CHANCE_FACTOR,hit_chance_factor, "hit chance factor", id )

	# fire range factor
	if item_type == "ammo" and objects.has_attribute(id, "fire_range_factor") and objects.get_attribute(id, "fire_range_factor") != 1.0 :
		fire_range_factor= "%.1f" % get_error ( "fire_range_factor", "fire range factor", id ) 
		hint_append( globaltext.MISSION_EXTENDED_HINT_WEAPON_FIRE_RANGE_FACTOR,fire_range_factor, "fire range factor", id )

	# weapon types of ammo
	if item_type == "ammo" and objects.has_attribute( type_id, "weapon_types" ) :
		weapons = objects.get_attribute( type_id, "weapon_types" )
		count = 0
		title = globaltext.MISSION_EXTENDED_HINT_AMMO_WEAPONS
		
		for weapon_t in weapons:
			has_attachement = False
			value = objects.get_attribute(weapon_t, "name")
						
			if (objects.has_attribute(weapon_t,"attachments")): 
				attachments = []
				attachments = objects.get_attribute(weapon_t, "attachments")	
				if "SET_SILENCER" in attachments or  "SET_LASERPOINTER" in attachments:
					has_attachement = True 
		
			if not has_attachement:
				count = hint_append( title, value, "weapon ammo", weapon_t, count )

	# armor 
	if objects.has_attribute(id,"armor"):
		armor = get_error ( "armor", "armor", id )
		hint_append( globaltext.MISSION_EXTENDED_HINT_ITEMS_ARMOR, str(armor), "armor", id )

	# armor combination bonus
	if objects.has_attribute(id,"armor") and pc_inventory != "" and bonus.has_keyword( pc_inventory, "armor_effect" ) \
		and character.is_equiped ( pc_inventory, id ) :
		bonus_table = objects.get_attribute(pc_inventory, "bonus_table")
		text=globaltext.MISSION_COMBINATION_ARMOR
		count = 0
		for prop in bonus_table:
			table_entry = bonus_table[prop]  
			if "armor_effect" in table_entry :
				value = table_entry["armor_effect"][0]
				x = value
				name = name_of_stats ( prop )
				count = hint_append( text, name + " " + str (x), "armor bonus", id, count )				

	# slots
	if objects.has_attribute(id,"occupied_slots") and not objects.has_attribute(id,"water_repository") and not objects.has_attribute(id,"armor"):
		if pc_inventory and character.is_equiped ( pc_inventory, id ) :
			result.append([globaltext.MISSION_EXTENDED_HINT_ITEMS_EQUIP,globaltext.MISSION_EXTENDED_HINT_ITEMS_EQUIP_1])
		else:
			result.append([globaltext.MISSION_EXTENDED_HINT_ITEMS_EQUIP,globaltext.MISSION_EXTENDED_HINT_ITEMS_EQUIP_0])
		
	# binoculars			
	if type_id == "SET_BINOCULARS" or type_id =="SET_FIELD_GLASSES":	
		hint_append(globaltext.MISSION_EXTENDED_HINT_BINOCULARS_FUNCTION,globaltext.MISSION_EXTENDED_HINT_BINOCULARS_FUNCTION_0, "binoculars", id )
	if type_id == "SET_NIGHT_VISION_GEAR":	
		hint_append(globaltext.MISSION_EXTENDED_HINT_BINOCULARS_FUNCTION,globaltext.MISSION_EXTENDED_HINT_BINOCULARS_FUNCTION_1, "binoculars", id )

	# silencer	
	if type_id =="SET_SILENCER":
		hint_append( globaltext.MISSION_EXTENDED_HINT_WEAPON_SHOT_EARSHOT,globaltext.MISSION_EXTENDED_HINT_WEAPON_SHOT_EARSHOT_0,"silencer","SET_UZI")	# [BrainRipper]

	#laserpointer
	if type_id =="SET_LASERPOINTER":
		hint_append( globaltext.MISSION_EXTENDED_HINT_WEAPON_ACCURACY,globaltext.MISSION_EXTENDED_HINT_WEAPON_ACCURACY_POINTER,"laserpointer","SET_UZI" )
		
	# le_recovery
	if objects.has_attribute(id,"le_recovery"):
		le_recovery = 0
		charges = 0
		if objects.has_attribute(id,"charge") and not type_id == "SET_MULTI_MEDIPACK" :
			max_charge = objects.get_attribute(type_id,"charge")
			le_recovery = objects.get_attribute(id, "le_recovery") / max_charge
		else:
			le_recovery = objects.get_attribute(id, "le_recovery")
		for stack_id in ids:
			if objects.has_attribute(stack_id,"charge"):
				charge = objects.get_attribute(stack_id,"charge") 
				charges = charges + charge 
			else:
				charges = charges + 1
		if objects.has_attribute(id,"water_repository"):
			hint_append(globaltext.MISSION_EXTENDED_HINT_ITEMS_WATER_AMOUNT+" x "+globaltext.MISSION_EXTENDED_HINT_ITEMS_LE_RECOVERY,str(charges) + " x " + str(le_recovery), "le_recovery", id )
		elif type_id == "SET_MULTI_MEDIPACK" or type_id == "SET_MEDIPACK_SMALL" or type_id == "SET_MEDIPACK_BIG":
			hint_append( globaltext.MISSION_EXTENDED_HINT_ITEMS_MULTI_MEDIPACK+" x "+globaltext.MISSION_EXTENDED_HINT_ITEMS_LE_RECOVERY,str(charges) + " x " + str(le_recovery), "le_recovery", id )
		else:
			hint_append(globaltext.MISSION_EXTENDED_HINT_ITEMS_STACK+" x "+globaltext.MISSION_EXTENDED_HINT_ITEMS_LE_RECOVERY,str(charges) + " x " + str(le_recovery), "le_recovery", id )

	drugs= {
		'SET_DRUGS_PILLS_01': 	[[globaltext.MISSION_ATTRIBUTE_NAME_STRENGTH,'+2']],
		'SET_DRUGS_PILLS_02': 	[[globaltext.MISSION_ATTRIBUTE_NAME_STRENGTH,'+2'],
							[globaltext.MISSION_CREATECHARACTER_HEALTH,'+20%']],
		'SET_DRUGS_PILLS_03': 	[[globaltext.MISSION_CREATECHARACTER_HEALTH,'+25%']],
		'SET_DRUGS_PILLS_04': 	[[globaltext.MISSION_ATTRIBUTE_NAME_CHARISMA,'+2']],
		'SET_DRUGS_PILLS_05': 	[[globaltext.MISSION_ATTRIBUTE_NAME_CHARISMA,'+3']],
		'SET_DRUGS_PILLS_06': 	[[globaltext.MISSION_ATTRIBUTE_NAME_STRENGTH,'+2'],
							[globaltext.MISSION_ATTRIBUTE_NAME_AGILITY,'+2'],
							[globaltext.MISSION_ATTRIBUTE_NAME_DEXTERITY,'+2'],
							[globaltext.MISSION_ATTRIBUTE_NAME_CONSTITUTION,'-4']],
		'SET_DRUGS_VIALS_01': 	[[globaltext.MISSION_ATTRIBUTE_NAME_AGILITY,'+2'],
							[globaltext.MISSION_ATTRIBUTE_NAME_DEXTERITY,'+2']],
		'SET_DRUGS_VIALS_02': 	[[globaltext.MISSION_ATTRIBUTE_NAME_STRENGTH,'+3']],
		'SET_DRUGS_VIALS_03': 	[[globaltext.MISSION_ATTRIBUTE_NAME_AGILITY,'+3']],
		'SET_DRUGS_SYRINGE': 	[[globaltext.MISSION_CREATECHARACTER_HEALTH,'+30%']]	
	}

	# drugs
	if drugs.has_key(type_id):
		drug_hints=[]
		drug_hints = drugs[type_id]
		for drug_hint in drug_hints:
			if len(drug_hint)==2:
				hint_append( drug_hint[0], drug_hint[1], "drugs", id )

	# Derff's backpacks
	if objects.has_attribute(id,"container"): 
		if objects.get_att(id,"container_version") == 2:
			container = objects.get_attribute(id,"container")
		else:
			container = Made_Container(objects.get_attribute(id,"container"))
				
		count = 0
		for item in container:
		 	if count:
				text = ""
			else:
				text=globaltext.MISSION_EXTENDED_HINT_ITEMS_CONTAINER
			x = item[1]
			if x > 1:
				result.append([text,str(x) + ' * ' + objects.get_attribute(item[0], "name")])
			else:
				result.append([text,objects.get_attribute(item[0], "name")])
			count += 1
			
		if objects.get_att(id,"max_item_allowed") and objects.get_att(id,"max_weight_allowed") :
			ability = globaltext.CONTAINER_AB%( objects.get_att(id,"max_item_allowed"), objects.get_att(id,"max_weight_allowed"))
			result.append([globaltext.CONTAINER_ABILITY, ability])
	
	# implants bonus
	if objects.has_attribute (id,"occupied_slots") and "implantant" in objects.get_attribute (id,"occupied_slots"):
		properity_table = objects.get_att ( id, "implantant_effect" )	
		text=globaltext.MISSION_COMBINATION_IMPLANTANT
		count = 0
		for prop in properity_table:
			x = properity_table [ prop ]
			name = name_of_stats ( prop )			
			count = hint_append( text, name + " " + str (x), "implants bonus", id, count )

	# quality
	if item_type == "weapon" and objects.has_attribute (id,"quality"):
		quality = "%.2f %%" % get_error ( "quality", "quality", id ) 
		hint_append( globaltext.MISSION_EXTENDED_HINT_WEAPON_QUALITY, quality, "quality", id )
		
	# value 
	if objects.has_attribute (id,"value"):
		x = "%i" % get_error ( "value", "value", id )
		hint_append ( globaltext.MISSION_EXTENDED_HINT_PRICE, x , "value", id )

	#error 
	#if objects.has_attribute (type_id,"knowlege_error"):
	#	import pprint
	#	result.append ( ["error:", pprint.pprint(objects.get_attribute ( type, "knowlege_error" )) ] )

	return result

def name_of_stats ( stat ):
	stats_name = {
		'strength': 	globaltext.MISSION_ATTRIBUTE_NAME_STRENGTH,
		'charisma':	globaltext.MISSION_ATTRIBUTE_NAME_CHARISMA,
		'agility':	globaltext.MISSION_ATTRIBUTE_NAME_AGILITY,
		'dexterity':	globaltext.MISSION_ATTRIBUTE_NAME_DEXTERITY,
		'constitution': globaltext.MISSION_ATTRIBUTE_NAME_CONSTITUTION,
		'intelligence': globaltext.MISSION_ATTRIBUTE_NAME_INTELLIGENCE,
		'health':	globaltext.MISSION_CREATECHARACTER_HEALTH,
		'armor':	globaltext.MISSION_CREATECHARACTER_ARMOR,
		'sneak':	globaltext.MISSION_SKILL_NAME_SNEAK,
		'lock_pick':	globaltext.MISSION_SKILL_NAME_LOCK_PICK,
		'pick_pocket':	globaltext.MISSION_SKILL_NAME_PICK_POCKET
	}
	
	lower_stat = stat.lower()
	if lower_stat in stats_name:
		return stats_name[lower_stat]
	else:
		return ""

def get_party_knowlege ( mode, id, target = None ):
	"""Returns the value of best knowlege about item type ( id -- is needed only for ammo to calculate their stats)
	knowlege get penalty for item price (1 per each 10 gp cost), and bonus/penalty for game dificulty
	
"""
	weapon_to_skill = {
		"explosiv":"explosives",
		"wurf":"throw_weapons",
		"nahkampf":"close_combat",
		"leicht":"light_weapons",
		"schwer":"heavy_weapons",
		"sniper":"sniper_weapons"
	}
	difficulty_to_skill = {
		0: 20,
		1: 10,
		2: 0,
		3: -5,
		4: -10,
	}
	
	def get_distance_mult ( pc, target ):
		if target:
			distance = objects.get_distance ( pc, target )
			range_of_vision = objects.get_attribute ( pc, "range_of_vision" )
			if distance > range_of_vision : return 0
			if not objects.has_attribute ( pc, "base_range_of_vision" ): calc_perception_values ( pc )
			base_range_of_vision = objects.get_attribute ( pc, "base_range_of_vision" )
			if distance < base_range_of_vision: return 1
			return ( 1 - ( distance - base_range_of_vision ) / ( range_of_vision - base_range_of_vision ) ) 
		else: return 1
	
	penalty = 0 
	party_statistics = None

	if not mode in type_to_skill: raise ValueError, "unknown hint mode" 
	type = type_to_skill [ mode ]
	
	if type in skill_tables.skills :
		party_statistics = [type]
	elif type == "weapon":
		party_statistics = [weapon_to_skill[objects.get_att ( id, "weapon_type" )]]
	elif type == "ammo":
		if objects.has_attribute ( id, "ammo_weapon_types" ):
			party_statistics = objects.get_attribute ( id, "ammo_weapon_types" )
		elif objects.has_attribute ( id, "weapon_types" ):
			party_statistics = []
			weapons = objects.get_attribute ( id, "weapon_types" )
			for weapon in weapons:
				w_type = objects.get_att ( weapon, "weapon_type" )
				if w_type and not weapon_to_skill[w_type] in party_statistics :
					party_statistics.append ( weapon_to_skill[w_type] )
			objects.set_attribute ( id, "ammo_weapon_types", party_statistics)		
		
	if id and objects.exists ( id ) and objects.has_attribute ( id, "value" ) :
		penalty += objects.get_attribute ( id, "value" ) % 10
	
	best_stat = 0
	if party_statistics :
		for pc in system.get_pcs():
			mult = get_distance_mult( pc, target )
			for stat in party_statistics:
				if objects.has_attribute ( pc, stat ) and objects.get_attribute ( pc, stat ) * mult > best_stat :
					best_stat = objects.get_attribute ( pc, stat ) * mult			

	difficulty = options.get_attribute("difficulty")
	if difficulty in difficulty_to_skill:
		bonum = difficulty_to_skill[difficulty]
	else: bonum = 0
	
	return ( best_stat - penalty + bonum ) 

def get_error ( value_name, mode, id, target = None ):
	"""
	return value with name value_name of objects (char) id with error. If value_name == "BASE_ERROR", that return error of value 1
"""

	RANDOM_BASE = 0.3
	MAX_KNOWLEGE = 100 # if resulted knowlege more than 100, than no error apply
	
	type = objects.get_att ( id, "typeid" )
	knowlege = get_party_knowlege ( mode, id, target )
	hard = type_to_hard[mode]
	
	if value_name == "weight":	 	value = objects.Calculate_Weight_With_Charges ( id )
	elif value_name == "BASE_ERROR": 	value = 1.0
	else: 					value = objects.get_att ( id, value_name )
	
	is_item = ( objects.get_attribute(id, "type")=="equipment")
	
	if type and knowlege > hard and MAX_KNOWLEGE > knowlege :
		is_int = isinstance( value, int )
		
		if is_item and objects.has_attribute ( type, "knowlege_error" ):
			knowlege_base = objects.get_attribute ( type, "knowlege_error" )
		elif objects.has_attribute ( id, "knowlege_error" ):
			knowlege_base = objects.get_attribute ( id, "knowlege_error" )
		else:
			knowlege_base = {}
		
		if mode in knowlege_base:
			error = knowlege_base[mode]
		else:
#			error = ( random.lognormvariate ( 0, 1 ) - 1 ) / ( MAX_KNOWLEGE - hard ) * RANDOM_BASE
			error = random.uniform( -1, 1 ) / ( MAX_KNOWLEGE - hard ) * RANDOM_BASE
			knowlege_base[mode] = error
			if is_item: 
				objects.set_attribute ( type, "knowlege_error", knowlege_base )				
			else: 
				objects.set_attribute ( id, "knowlege_error", knowlege_base )

		tmp_value = ( 1 + error * ( MAX_KNOWLEGE - knowlege ) ) * value
		if is_int :
			ret_value = int ( round ( tmp_value ) ) 
		else:
			ret_value = tmp_value

		return ret_value 
	else:
		return value 
	
def get_error_sign ( knowlege, hard ):
	"""
	return appropriate sign for error
"""
	RANDOM_BASE = 0.3
	MAX_KNOWLEGE = 100 

	if knowlege >= MAX_KNOWLEGE : return ":"
	elif knowlege > hard :
		error_percintile = ( MAX_KNOWLEGE - knowlege ) / ( MAX_KNOWLEGE - hard ) * RANDOM_BASE * 100
		if error_percintile < 1: return "="
		elif error_percintile < 5: return "~"
		elif error_percintile < 25: return "?"
		else: return "$?"
	else: return "-"
	
def character_hint_collection(ids):
	
	def hint_append ( string, value, mode, id, target = None ):
		"""
		Cover for data.append, wich check knowlege and could be used in for's operators as increment
	"""
		knowlege = get_party_knowlege ( mode, id, target )
		hard = type_to_hard[ mode ]
		if knowlege > hard :
			if string[-1] == ":" : tmp_string = string[:-1] + get_error_sign ( knowlege, hard ) 
			else: tmp_string = string 
			data.append([tmp_string, value ])
			return True
		return False

	def CMB_Value ( id, NPC = True ):
		if NPC: return character.get_combat_value (id) * get_error ( "BASE_ERROR", "combat_value", id, id )
		tmp_level = get_error ( "level", "combat_value", id, id )
		if ( not tmp_level ) or tmp_level < 1: tmp_level = 1 
		return tmp_level 
	
	id = ids[0]
	is_character = ( objects.get_attribute(id, "type" ) == "character" )
	is_foe = ( objects.has_attribute(id, "foes") and objects.get_attribute(id, "foes") == ["UISPIELER"] )
	data = []

	
	# name
	if objects.has_attribute(id, "name"):
		data.append([globaltext.MISSION_EXTENDED_HINT_CHARACTER_NAME,objects.get_attribute(id, "name")])
	
	# type
	if objects.get_attribute(id, "type")=="animal":
		animal_type = objects.get_attribute(id, "typeid")
		data.append([globaltext.MISSION_EXTENDED_HINT_ANIMAL_TYPE,eval('globaltext.MISSION_EXTENDED_HINT_ANIMAL_TYPE_'+animal_type)])

	# LE
	if id in system.get_pcs():
		act_hp = objects.get_attribute ( id, "hitpoints" )
		if act_hp<0: act_hp = 0
		max_hp = objects.get_attribute(id, "maxhitpoints")
		data.append([globaltext.MISSION_EXTENDED_HINT_CHARACTER_LE,str(int(math.ceil(act_hp))) +" / " + str(int(math.ceil(max_hp))) ])
	
	# consider
	if is_foe: 
		combat_value_average = 0.0
		count = 0
		pcs = system.get_selected_pcs()
		if not len(pcs): pcs = system.get_pcs()
		for id_sel in pcs:
			tmp_combat_value = CMB_Value ( id_sel, is_character ) 
			combat_value_average = combat_value_average + tmp_combat_value
			count += 1
		if count:
			combat_value_average = combat_value_average / count
		combat_value_foe = CMB_Value ( id, is_character )
		if combat_value_average <= 0 :
			combat_value_average = 0.001
		if combat_value_average: 
			combat_value_percent = ( combat_value_foe * 100.0 ) / combat_value_average 
				
		text_id_consider = globaltext.MISSION_EXTENDED_HINT_CHARACTER_CONSIDER_0
		if combat_value_percent > 50: text_id_consider = globaltext.MISSION_EXTENDED_HINT_CHARACTER_CONSIDER_1
		if combat_value_percent > 75: text_id_consider = globaltext.MISSION_EXTENDED_HINT_CHARACTER_CONSIDER_2
		if combat_value_percent > 125: text_id_consider = globaltext.MISSION_EXTENDED_HINT_CHARACTER_CONSIDER_3
		if combat_value_percent > 150: text_id_consider = globaltext.MISSION_EXTENDED_HINT_CHARACTER_CONSIDER_4
		hint_append( globaltext.MISSION_EXTENDED_HINT_CHARACTER_CONSIDER,text_id_consider, "combat_value", id, id )

	# status
	act_hp = get_error ( "hitpoints", "enemy_le", id, id )
	if act_hp<0: act_hp = 0
	max_hp = objects.get_attribute(id, "maxhitpoints")
	percent = act_hp/max_hp * 100
	text_id_status = globaltext.MISSION_EXTENDED_HINT_CHARACTER_STATUS_0
	if percent > 33: text_id_status  = globaltext.MISSION_EXTENDED_HINT_CHARACTER_STATUS_1
	if percent > 84: text_id_status  = globaltext.MISSION_EXTENDED_HINT_CHARACTER_STATUS_2
	if percent > 99: text_id_status  = globaltext.MISSION_EXTENDED_HINT_CHARACTER_STATUS_3
	if objects.is_unconscious(id): text_id_status  = globaltext.MISSION_EXTENDED_HINT_CHARACTER_STATUS_4 
	if objects.is_destroyed(id): text_id_status  = globaltext.MISSION_EXTENDED_HINT_CHARACTER_STATUS_6	
	hint_append ( globaltext.MISSION_EXTENDED_HINT_CHARACTER_STATUS, text_id_status, "enemy_le", id, id )	

	# drug's effects
	if bonus.has_keyword ( id, "drug_effects"):
		timeout_time = timerepr.time ( bonus.get_timeout ( id, "drug_effects" ) ) 
		current_time = system.get_mission_time()
		if timeout_time > current_time:	
			elapsed_time = timeout_time - current_time 
			if bonus.is_reversed( id, "drug_effects" ): 	text = globaltext.MISSION_EXTENDED_HINT_CHARACTER_DRUGS_POSTEFFECT
			else:					 	text = globaltext.MISSION_EXTENDED_HINT_CHARACTER_DRUGS_EFFECT
			hint_append ( text, elapsed_time.get_small_time(), "drugs_time", id, id )

	# hit chance
	if is_foe:
		hit_chance = 0.0
		chars = system.get_selected_pcs()
		for char in chars:
			weapon = character.get_primary_weapon(char)
			_hit_chance = calc_hit_chance(char, weapon, id) * get_error ( "BASE_ERROR", "hit_chance", weapon, id )
			if _hit_chance > hit_chance: hit_chance = _hit_chance
	
		if hit_chance < 0.1: text_id_hit_chance = globaltext.MISSION_EXTENDED_HINT_CHARACTER_HIT_CHANCE_0
		elif hit_chance < 0.5: text_id_hit_chance = globaltext.MISSION_EXTENDED_HINT_CHARACTER_HIT_CHANCE_1
		elif hit_chance < 0.8: text_id_hit_chance = globaltext.MISSION_EXTENDED_HINT_CHARACTER_HIT_CHANCE_2
		else: text_id_hit_chance = globaltext.MISSION_EXTENDED_HINT_CHARACTER_HIT_CHANCE_3
		hint_append( globaltext.MISSION_EXTENDED_HINT_CHARACTER_HIT_CHANCE, text_id_hit_chance, "hit_chance", weapon, id )
				

	# enemy weapon type, range and speed
	if is_character and character.get_primary_weapon (id) :
		enemy_weapon = character.get_primary_weapon (id)
		type_id = objects.get_att (enemy_weapon, "typeid")
		item_type = objects.get_att (enemy_weapon, "item_type")
		weapon_type = objects.get_att (enemy_weapon, "weapon_type")
		if objects.has_attribute (enemy_weapon, "munitionsarten"):
			munition = objects.get_attribute (enemy_weapon, "munitionsarten")[0]
	
		# weapon name
		if objects.has_attribute ( enemy_weapon, "name" ) :
			know_weapon = hint_append( globaltext.MISSION_EXTENDED_HINT_ENEMY_WEAPON, objects.get_attribute(enemy_weapon, "name"), "enemy_weapon", enemy_weapon, id )
		
		# weapon type
		if is_foe and item_type == "weapon" and weapon_type  :
			if (weapon_type=="explosiv"):
				value = globaltext.MISSION_EXTENDED_HINT_WEAPON_TYPE_NAME_1 
			if (weapon_type=="wurf"):
				value = globaltext.MISSION_EXTENDED_HINT_WEAPON_TYPE_NAME_2 
			if (weapon_type=="nahkampf"):
				value = globaltext.MISSION_EXTENDED_HINT_WEAPON_TYPE_NAME_3 
			if (weapon_type=="leicht"):
				value = globaltext.MISSION_EXTENDED_HINT_WEAPON_TYPE_NAME_4 
			if (weapon_type=="schwer"):
				value = globaltext.MISSION_EXTENDED_HINT_WEAPON_TYPE_NAME_5 
			if (weapon_type=="sniper"):
				value = globaltext.MISSION_EXTENDED_HINT_WEAPON_TYPE_NAME_6 
			hint_append ( globaltext.MISSION_EXTENDED_HINT_WEAPON_TYPE_NAME_0, value, "weapon type", enemy_weapon, id )
		
		# damage min/max for weapon and ammo
		if is_foe and know_weapon and munition and objects.has_attribute(munition,"schaden_organisch_min") and objects.has_attribute(munition,"schaden_organisch_max"):
			damage_min = get_error ( "schaden_organisch_min", "damage", munition, id ) 
			damage_max = get_error ( "schaden_organisch_max", "damage", munition, id ) 
			if damage_max < damage_min : damage_max = damage_min 			
			hint_append ( globaltext.MISSION_EXTENDED_HINT_DAMAGE, str(damage_min) + """ / """ +  str(damage_max), "damage", munition, id )
		
		# fire range
		if is_foe and item_type =="weapon" and objects.has_attribute(id,"maximale_feuerreichweite"):
			f_range_id = globaltext.MISSION_EXTENDED_HINT_WEAPON_FIRE_RANGE_0
			f_range =  get_error ( "maximale_feuerreichweite", "fire range", enemy_weapon, id )
			if (f_range > 17):
				f_range_id = globaltext.MISSION_EXTENDED_HINT_WEAPON_FIRE_RANGE_1
			if (f_range > 33):
				f_range_id = globaltext.MISSION_EXTENDED_HINT_WEAPON_FIRE_RANGE_2
			if (f_range > 49):
				f_range_id = globaltext.MISSION_EXTENDED_HINT_WEAPON_FIRE_RANGE_3
						
			name = globaltext.MISSION_EXTENDED_HINT_WEAPON_FIRE_RANGE		
			tmp_value = f_range_id + " (" + str("%.1f"%f_range) + ")" 
			hint_append ( name, tmp_value, "fire range", enemy_weapon, id )

		# fire speed
		if is_foe and item_type == "weapon" and objects.has_attribute(id,"feuergeschwindigkeit") and weapon_type in [ "leicht" , "schwer", "sniper" ]:
			f_velocity = "%.2f" % get_error ( "feuergeschwindigkeit", "fire speed", enemy_weapon, id )
			if f_velocity > 0 :
				hint_append ( globaltext.MISSION_EXTENDED_HINT_WEAPON_FIRE_SPEED,str(f_velocity), "fire speed", enemy_weapon, id )
			else:
				hint_append ( globaltext.MISSION_EXTENDED_HINT_WEAPON_FIRE_SPEED,"-", "fire speed", enemy_weapon, id )

		# trader timer
		if objects.has_attribute( id, "last_trade_update"):
			last_trade_time = objects.get_attribute( id, "last_trade_update") 
			act_time = system.get_mission_time()
			elapsed_time = act_time - last_trade_time
			data.append([globaltext.MISSION_EXTENDED_HINT_TIME_FROM_LAST_TRADE, elapsed_time.get_small_time() ])
	
	return data
